SET NAMES utf8;
SET time_zone = '+00:00';
SET foreign_key_checks = 0;
SET sql_mode = 'NO_AUTO_VALUE_ON_ZERO';

SET NAMES utf8mb4;

--
-- Table structure for table `batch`
--

DROP TABLE IF EXISTS `batch`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `batch` (
  `bid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique batch ID.',
  `token` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'A string token generated against the current user''s session id and the batch id, used to ensure that only the user who submitted the batch can effectively access it.',
  `timestamp` int NOT NULL COMMENT 'A Unix timestamp indicating when this batch was submitted for processing. Stale batches are purged at cron time.',
  `batch` longblob COMMENT 'A serialized array containing the processing data for the batch.',
  PRIMARY KEY (`bid`),
  KEY `token` (`token`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores details about batches (processes that run in…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `batch`
--

LOCK TABLES `batch` WRITE;
/*!40000 ALTER TABLE `batch` DISABLE KEYS */;
/*!40000 ALTER TABLE `batch` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content`
--

DROP TABLE IF EXISTS `block_content`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `block_content_field__uuid__value` (`uuid`),
  UNIQUE KEY `block_content__revision_id` (`revision_id`),
  KEY `block_content_field__type__target_id` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content`
--

LOCK TABLES `block_content` WRITE;
/*!40000 ALTER TABLE `block_content` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content__body`
--

DROP TABLE IF EXISTS `block_content__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content__body`
--

LOCK TABLES `block_content__body` WRITE;
/*!40000 ALTER TABLE `block_content__body` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_field_data`
--

DROP TABLE IF EXISTS `block_content_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `info` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `reusable` tinyint DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `block_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `block_content__revision_id` (`revision_id`),
  KEY `block_content_field__type__target_id` (`type`),
  KEY `block_content_field__reusable` (`reusable`),
  KEY `block_content__status_type` (`status`,`type`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_field_data`
--

LOCK TABLES `block_content_field_data` WRITE;
/*!40000 ALTER TABLE `block_content_field_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_field_revision`
--

DROP TABLE IF EXISTS `block_content_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_field_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `info` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `block_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_field_revision`
--

LOCK TABLES `block_content_field_revision` WRITE;
/*!40000 ALTER TABLE `block_content_field_revision` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_revision`
--

DROP TABLE IF EXISTS `block_content_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `block_content__id` (`id`),
  KEY `block_content_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_revision`
--

LOCK TABLES `block_content_revision` WRITE;
/*!40000 ALTER TABLE `block_content_revision` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_revision__body`
--

DROP TABLE IF EXISTS `block_content_revision__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_revision__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_revision__body`
--

LOCK TABLES `block_content_revision__body` WRITE;
/*!40000 ALTER TABLE `block_content_revision__body` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_revision__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_access_policy`
--

DROP TABLE IF EXISTS `cache_access_policy`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_access_policy` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_access_policy`
--

LOCK TABLES `cache_access_policy` WRITE;
/*!40000 ALTER TABLE `cache_access_policy` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_access_policy` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_bootstrap`
--

DROP TABLE IF EXISTS `cache_bootstrap`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_bootstrap` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_bootstrap`
--

LOCK TABLES `cache_bootstrap` WRITE;
/*!40000 ALTER TABLE `cache_bootstrap` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_bootstrap` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_config`
--

DROP TABLE IF EXISTS `cache_config`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_config` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_config`
--

LOCK TABLES `cache_config` WRITE;
/*!40000 ALTER TABLE `cache_config` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_config` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_container`
--

DROP TABLE IF EXISTS `cache_container`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_container` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_container`
--

LOCK TABLES `cache_container` WRITE;
/*!40000 ALTER TABLE `cache_container` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_container` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_data`
--

DROP TABLE IF EXISTS `cache_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_data` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_data`
--

LOCK TABLES `cache_data` WRITE;
/*!40000 ALTER TABLE `cache_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_default`
--

DROP TABLE IF EXISTS `cache_default`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_default` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_default`
--

LOCK TABLES `cache_default` WRITE;
/*!40000 ALTER TABLE `cache_default` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_default` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_discovery`
--

DROP TABLE IF EXISTS `cache_discovery`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_discovery` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_discovery`
--

LOCK TABLES `cache_discovery` WRITE;
/*!40000 ALTER TABLE `cache_discovery` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_discovery` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_dynamic_page_cache`
--

DROP TABLE IF EXISTS `cache_dynamic_page_cache`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_dynamic_page_cache` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_dynamic_page_cache`
--

LOCK TABLES `cache_dynamic_page_cache` WRITE;
/*!40000 ALTER TABLE `cache_dynamic_page_cache` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_dynamic_page_cache` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_entity`
--

DROP TABLE IF EXISTS `cache_entity`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_entity` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_entity`
--

LOCK TABLES `cache_entity` WRITE;
/*!40000 ALTER TABLE `cache_entity` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_entity` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_file_mdm`
--

DROP TABLE IF EXISTS `cache_file_mdm`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_file_mdm` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_file_mdm`
--

LOCK TABLES `cache_file_mdm` WRITE;
/*!40000 ALTER TABLE `cache_file_mdm` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_file_mdm` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_menu`
--

DROP TABLE IF EXISTS `cache_menu`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_menu` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_menu`
--

LOCK TABLES `cache_menu` WRITE;
/*!40000 ALTER TABLE `cache_menu` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_menu` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_page`
--

DROP TABLE IF EXISTS `cache_page`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_page` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_page`
--

LOCK TABLES `cache_page` WRITE;
/*!40000 ALTER TABLE `cache_page` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_page` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_render`
--

DROP TABLE IF EXISTS `cache_render`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_render` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_render`
--

LOCK TABLES `cache_render` WRITE;
/*!40000 ALTER TABLE `cache_render` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_render` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_toolbar`
--

DROP TABLE IF EXISTS `cache_toolbar`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_toolbar` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_toolbar`
--

LOCK TABLES `cache_toolbar` WRITE;
/*!40000 ALTER TABLE `cache_toolbar` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_toolbar` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cachetags`
--

DROP TABLE IF EXISTS `cachetags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cachetags` (
  `tag` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Namespace-prefixed tag string.',
  `invalidations` int NOT NULL DEFAULT '0' COMMENT 'Number incremented when the tag is invalidated.',
  PRIMARY KEY (`tag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Cache table for tracking cache tag invalidations.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cachetags`
--

LOCK TABLES `cachetags` WRITE;
/*!40000 ALTER TABLE `cachetags` DISABLE KEYS */;
INSERT INTO `cachetags` VALUES ('4xx-response',237),('breakpoints',109),('config:action_list',2),('config:block.block.bootstrap_barrio_account_menu',2),('config:block.block.bootstrap_barrio_breadcrumbs',2),('config:block.block.bootstrap_barrio_content',2),('config:block.block.bootstrap_barrio_help',2),('config:block.block.bootstrap_barrio_main_menu',2),('config:block.block.bootstrap_barrio_messages',2),('config:block.block.bootstrap_barrio_page_title',2),('config:block.block.bootstrap_barrio_powered',2),('config:block.block.bootstrap_barrio_primary_admin_actions',2),('config:block.block.bootstrap_barrio_primary_local_tasks',2),('config:block.block.bootstrap_barrio_search_form_narrow',2),('config:block.block.bootstrap_barrio_search_form_wide',2),('config:block.block.bootstrap_barrio_secondary_local_tasks',2),('config:block.block.bootstrap_barrio_site_branding',2),('config:block.block.claro_help_search',1),('config:block.block.ept_light_account_menu',7),('config:block.block.ept_light_breadcrumbs',8),('config:block.block.ept_light_content',7),('config:block.block.ept_light_footer',3),('config:block.block.ept_light_help',7),('config:block.block.ept_light_main_menu',7),('config:block.block.ept_light_main_navigation',3),('config:block.block.ept_light_messages',7),('config:block.block.ept_light_page_title',10),('config:block.block.ept_light_powered',2),('config:block.block.ept_light_primary_admin_actions',7),('config:block.block.ept_light_primary_local_tasks',7),('config:block.block.ept_light_search_form_narrow',9),('config:block.block.ept_light_search_form_wide',9),('config:block.block.ept_light_secondary_local_tasks',7),('config:block.block.ept_light_site_branding',7),('config:block.block.ept_light_syndicate',2),('config:block.block.gin_breadcrumbs',1),('config:block.block.gin_content',1),('config:block.block.gin_help',1),('config:block.block.gin_local_actions',1),('config:block.block.gin_messages',1),('config:block.block.gin_page_title',1),('config:block.block.gin_primary_local_tasks',1),('config:block.block.gin_secondary_local_tasks',1),('config:block.block.olivero_search_form_narrow',2),('config:block.block.olivero_search_form_wide',2),('config:block_list',21),('config:bootstrap_barrio.settings',1),('config:core.entity_form_display.node.article.default',1),('config:core.entity_form_display.node.page.default',5),('config:core.entity_form_display.paragraph.ept_bottle.default',1),('config:core.entity_form_display.paragraph.ept_super_slider.default',1),('config:core.entity_view_display.node.article.default',1),('config:core.entity_view_display.node.article.rss',1),('config:core.entity_view_display.node.article.teaser',1),('config:core.entity_view_display.node.page.default',2),('config:core.entity_view_display.node.page.teaser',1),('config:core.entity_view_display.paragraph.ept_bottle.default',1),('config:core.entity_view_display.paragraph.ept_carousel.default',1),('config:core.entity_view_display.paragraph.ept_carousel_item.default',1),('config:core.entity_view_display.paragraph.ept_carousel_item.slider',1),('config:core.entity_view_display.paragraph.ept_super_slider.default',1),('config:core.extension',86),('config:core.menu.static_menu_link_overrides',5),('config:editor.editor.full_html',3),('config:editor.editor.webform_default',1),('config:editor_list',4),('config:entity_form_display_list',38),('config:entity_form_mode_list',1),('config:entity_view_display_list',39),('config:entity_view_mode_list',7),('config:ept_light.settings',3),('config:field.field.node.article.comment',1),('config:field.field.node.page.field_components',3),('config:field.field.paragraph.ept_block.field_ept_block_block',1),('config:field.field.paragraph.ept_bottle.field_ept_settings',1),('config:field.field.paragraph.ept_bottle.field_ept_text',1),('config:field.field.paragraph.ept_bottle.field_ept_title',1),('config:field.field.paragraph.ept_columns.field_ept_columns',1),('config:field.field.paragraph.ept_super_slider.field_ept_settings',1),('config:field.field.paragraph.ept_super_slider.field_ept_text',1),('config:field.field.paragraph.ept_super_slider.field_ept_title',1),('config:field.storage.node.comment',1),('config:field.storage.node.field_components',2),('config:field.storage.paragraph.field_ept_block_block',1),('config:field.storage.paragraph.field_ept_columns',1),('config:filter.format.basic_html',1),('config:filter.format.full_html',4),('config:filter.format.plain_text',1),('config:filter.format.restricted_html',1),('config:filter_format_list',5),('config:gin.settings',1),('config:image.style.ept_gallery_image',6),('config:image_style_list',11),('config:media_type_list',1),('config:menu_list',10),('config:node.settings',2),('config:node.type.article',1),('config:node_type_list',1),('config:paragraphs.paragraphs_type.ept_bottle',1),('config:paragraphs.paragraphs_type.ept_super_slider',1),('config:paragraphs_type_list',30),('config:search.page.help_search',1),('config:search.page.node_search',1),('config:search.page.user_search',1),('config:search.settings',1),('config:search_page_list',1),('config:system.mail',1),('config:system.menu.account',109),('config:system.menu.admin',104),('config:system.menu.footer',110),('config:system.menu.main',119),('config:system.menu.tools',104),('config:system.performance',1),('config:system.site',1),('config:system.theme',5),('config:tb_megamenu.menu_config.main__ept_light',9),('config:tb_megamenu_list',10),('config:user.role.administrator',5),('config:user.role.anonymous',7),('config:user.role.authenticated',7),('config:user.role.content_editor',5),('config:user_role_list',7),('config:views.view.media',1),('config:views.view.media_library',1),('config:views.view.webform_submissions',1),('config:views.view.what_s_new',13),('config:view_list',11),('config:webform_list',1),('config:webform_options_list',1),('entity_bundles',47),('entity_field_info',289),('entity_types',128),('file:1',1),('file:10',2),('file:11',2),('file:12',2),('file:13',2),('file:14',2),('file:15',2),('file:16',2),('file:17',2),('file:18',2),('file:19',2),('file:20',2),('file:21',1),('file:22',2),('file:23',2),('file:24',2),('file:3',2),('file:4',2),('file:5',2),('file:6',2),('file:7',2),('file:8',2),('file:9',2),('file_list',47),('http_response',91),('icon_pack_collector',4),('icon_pack_plugin',4),('library_info',78),('link_attributes',43),('local_task',135),('media:19',1),('media:4',2),('media:5',1),('media:6',1),('media:7',1),('media_list',28),('media_list:image',27),('media_list:remote_video',1),('media_view',5),('menu_link_content:1',5),('menu_link_content:11',2),('menu_link_content:12',2),('menu_link_content:13',6),('menu_link_content:14',1),('menu_link_content:2',2),('menu_link_content:3',2),('menu_link_content:4',3),('menu_link_content:5',2),('menu_link_content:7',1),('menu_link_content:9',1),('menu_link_content_list',33),('menu_link_content_list:menu_link_content',33),('node:1',44),('node:19',5),('node_list',68),('node_list:article',17),('node_list:page',51),('node_view',7),('paragraph:1',45),('paragraph:10',21),('paragraph:11',15),('paragraph:12',13),('paragraph:13',12),('paragraph:14',12),('paragraph:15',12),('paragraph:16',12),('paragraph:17',12),('paragraph:18',12),('paragraph:19',12),('paragraph:2',36),('paragraph:20',12),('paragraph:21',12),('paragraph:22',12),('paragraph:23',11),('paragraph:24',10),('paragraph:25',10),('paragraph:26',9),('paragraph:27',9),('paragraph:28',9),('paragraph:29',9),('paragraph:3',33),('paragraph:30',8),('paragraph:31',6),('paragraph:32',6),('paragraph:33',5),('paragraph:34',3),('paragraph:35',3),('paragraph:36',2),('paragraph:38',6),('paragraph:39',4),('paragraph:4',33),('paragraph:40',3),('paragraph:5',33),('paragraph:6',32),('paragraph:7',25),('paragraph:8',25),('paragraph:9',24),('paragraph_list',51),('paragraph_list:ept_accordion',3),('paragraph_list:ept_accordion_section',3),('paragraph_list:ept_block',5),('paragraph_list:ept_carousel',12),('paragraph_list:ept_carousel_item',12),('paragraph_list:ept_counter',10),('paragraph_list:ept_counter_item',10),('paragraph_list:ept_cta',16),('paragraph_list:ept_hero',49),('paragraph_list:ept_image_gallery',22),('paragraph_list:ept_quote',14),('paragraph_list:ept_slideshow',9),('paragraph_list:ept_slideshow_item',9),('paragraph_list:ept_stats',25),('paragraph_list:ept_stats_item',25),('paragraph_list:ept_tabs',6),('paragraph_list:ept_tabs_item',6),('paragraph_list:ept_text',37),('paragraph_list:ept_tiles',33),('paragraph_list:ept_tiles_item',33),('paragraph_list:ept_views',6),('paragraph_view',34),('rendered',12),('routes',91),('route_match',93),('search_index:help_search',15),('search_index:node_search',10),('views_data',37),('webform_submission_list',2);
/*!40000 ALTER TABLE `cachetags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment`
--

DROP TABLE IF EXISTS `comment`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment` (
  `cid` int unsigned NOT NULL AUTO_INCREMENT,
  `comment_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`cid`),
  UNIQUE KEY `comment_field__uuid__value` (`uuid`),
  KEY `comment_field__comment_type__target_id` (`comment_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for comment entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment`
--

LOCK TABLES `comment` WRITE;
/*!40000 ALTER TABLE `comment` DISABLE KEYS */;
/*!40000 ALTER TABLE `comment` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment__comment_body`
--

DROP TABLE IF EXISTS `comment__comment_body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment__comment_body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `comment_body_value` longtext NOT NULL,
  `comment_body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `comment_body_format` (`comment_body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for comment field comment_body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment__comment_body`
--

LOCK TABLES `comment__comment_body` WRITE;
/*!40000 ALTER TABLE `comment__comment_body` DISABLE KEYS */;
/*!40000 ALTER TABLE `comment__comment_body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment_entity_statistics`
--

DROP TABLE IF EXISTS `comment_entity_statistics`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment_entity_statistics` (
  `entity_id` int unsigned NOT NULL DEFAULT '0' COMMENT 'The entity_id of the entity for which the statistics are compiled.',
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'node' COMMENT 'The entity_type of the entity to which this comment is a reply.',
  `field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field_name of the field that was used to add this comment.',
  `cid` int NOT NULL DEFAULT '0' COMMENT 'The "comment".cid of the last comment.',
  `last_comment_timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp of the last comment that was posted within this node, from "comment".changed.',
  `last_comment_name` varchar(60) DEFAULT NULL COMMENT 'The name of the latest author to post a comment on this node, from "comment".name.',
  `last_comment_uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The user ID of the latest author to post a comment on this node, from "comment".uid.',
  `comment_count` int unsigned NOT NULL DEFAULT '0' COMMENT 'The total number of comments on this entity.',
  PRIMARY KEY (`entity_id`,`entity_type`,`field_name`),
  KEY `last_comment_timestamp` (`last_comment_timestamp`),
  KEY `comment_count` (`comment_count`),
  KEY `last_comment_uid` (`last_comment_uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maintains statistics of entity and comments posts to show …';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment_entity_statistics`
--

LOCK TABLES `comment_entity_statistics` WRITE;
/*!40000 ALTER TABLE `comment_entity_statistics` DISABLE KEYS */;
INSERT INTO `comment_entity_statistics` VALUES (2,'node','comment',0,1729063268,NULL,1,0);
/*!40000 ALTER TABLE `comment_entity_statistics` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment_field_data`
--

DROP TABLE IF EXISTS `comment_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment_field_data` (
  `cid` int unsigned NOT NULL,
  `comment_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `pid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `entity_id` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `subject` varchar(64) DEFAULT NULL,
  `name` varchar(60) DEFAULT NULL,
  `mail` varchar(254) DEFAULT NULL,
  `homepage` varchar(255) DEFAULT NULL,
  `hostname` varchar(128) DEFAULT NULL,
  `created` int NOT NULL,
  `changed` int DEFAULT NULL,
  `thread` varchar(255) NOT NULL,
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`cid`,`langcode`),
  KEY `comment__id__default_langcode__langcode` (`cid`,`default_langcode`,`langcode`),
  KEY `comment_field__comment_type__target_id` (`comment_type`),
  KEY `comment_field__uid__target_id` (`uid`),
  KEY `comment_field__created` (`created`),
  KEY `comment__status_comment_type` (`status`,`comment_type`,`cid`),
  KEY `comment__status_pid` (`pid`,`status`),
  KEY `comment__num_new` (`entity_id`,`entity_type`,`comment_type`,`status`,`created`,`cid`,`thread`(191)),
  KEY `comment__entity_langcode` (`entity_id`,`entity_type`,`comment_type`,`default_langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for comment entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment_field_data`
--

LOCK TABLES `comment_field_data` WRITE;
/*!40000 ALTER TABLE `comment_field_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `comment_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `config`
--

DROP TABLE IF EXISTS `config`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `config` (
  `collection` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object collection.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object name.',
  `data` longblob COMMENT 'A serialized configuration object data.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for configuration data.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `config`
--

LOCK TABLES `config` WRITE;
/*!40000 ALTER TABLE `config` DISABLE KEYS */;
INSERT INTO `config` VALUES ('','admin_toolbar.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvTSppzcgH5wnzBhX5xnAExcp2I1CzkQ_aky65XNfYI\";}s:10:\"menu_depth\";i:4;}'),('','admin_toolbar_tools.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WgdZsrd_5w9jlmcHV4R9dD2tG9OZEkYo4I_O8h7Gq8Q\";}s:17:\"max_bundle_number\";i:20;s:25:\"hoverintent_functionality\";b:1;s:16:\"show_local_tasks\";b:0;}'),('','announcements_feed.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0G5pZBcxbg8ONYzNLd1RJIsvuFFewm9htnS4I-ABKJ8\";}s:7:\"max_age\";i:86400;s:13:\"cron_interval\";i:21600;s:5:\"limit\";i:10;}'),('','automated_cron.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fUksROt4FfkAU9BV4hV2XvhTBSS2nTNrZS4U7S-tKrs\";}s:8:\"interval\";i:10800;}'),('','block.block.claro_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"be976f48-8227-4e04-b46e-05849e446c76\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NjcxOBrPOiK5-38t56DwFBDVY4yer7YSlbRWXFuHe7A\";}s:2:\"id\";s:17:\"claro_breadcrumbs\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"ce83be5e-1fd7-4a0f-9b06-0a0d8710cb26\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a0Yyx1GeyKarZ4T_yXQBR_ZFKnXiFLtxAb6gWLd8nr0\";}s:2:\"id\";s:13:\"claro_content\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"d66baf8e-252f-4c79-acb6-b8b6d6b0a27a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jccFSSVqV0WCDb6NtML1VWAWTtDbZ-zn5YgTRMgMrIM\";}s:2:\"id\";s:10:\"claro_help\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"916365b2-7723-493b-8918-5f3ff7d57c7d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdXfDmRgAvms7EQovxxWPdYi0GitxeRbVtScYK16ZH0\";}s:2:\"id\";s:19:\"claro_local_actions\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"3b00e68f-1ed0-4482-b8b1-e496f1da9936\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Ac3ISpIT0PQ-whzD7_dw0SdKi6dAbRFNWdSjOiVDqg\";}s:2:\"id\";s:14:\"claro_messages\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"b76f1641-4f78-438e-a0fe-ce65bd7f9006\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNwDdW063tk_ktzSWzZVeQS9wzvLooVO280BQ9WrsIs\";}s:2:\"id\";s:16:\"claro_page_title\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"a8c9d41b-02e1-478d-85b3-fb3a1f815f49\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ACjBZI5shAMiiUpsz-inLYVXDqNNXRnSzAWV3kV_8Hw\";}s:2:\"id\";s:25:\"claro_primary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"bb1e9b33-93c2-4829-9613-e4ccc525f30b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2L0geP-ixCbCkEpW6BVF6H7vDUZN4ea07_Y9CociQm4\";}s:2:\"id\";s:27:\"claro_secondary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_account_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"f35c55e3-3d40-497f-9b7f-2896cbc2e345\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:22:\"ept_light_account_menu\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"7010f57e-634e-4b97-8a69-97b80a011cb4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:21:\"ept_light_breadcrumbs\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:3:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:1;s:5:\"pages\";s:10:\"/whats-new\";}}}'),('','block.block.ept_light_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"7b17ab28-0376-4ee3-91ee-5bd02432291e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:17:\"ept_light_content\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_footer',_binary 'a:12:{s:4:\"uuid\";s:36:\"a78731d9-6557-4805-9b50-71d93a910730\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:18:\"system.menu.footer\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:2:\"id\";s:16:\"ept_light_footer\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"footer\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:24:\"system_menu_block:footer\";s:8:\"settings\";a:7:{s:2:\"id\";s:24:\"system_menu_block:footer\";s:5:\"label\";s:24:\"Have a question or idea?\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:0;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"8edfdbdd-cd33-4ebe-b1d4-74fb38d1039e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:14:\"ept_light_help\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_main_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"736d4519-e22a-419a-87cd-009a768a73b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:19:\"ept_light_main_menu\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"c8fc509e-9767-4eae-81f5-6cdbe64aa2b3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:18:\"ept_light_messages\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"f45a0a49-c001-47cb-b97e-767aac0f24f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:20:\"ept_light_page_title\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:1:{s:18:\"entity_bundle:node\";a:4:{s:2:\"id\";s:18:\"entity_bundle:node\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:1:{s:4:\"node\";s:29:\"@node.node_route_context:node\";}s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}}}'),('','block.block.ept_light_primary_admin_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"feb5ed42-838e-41fe-bce3-ac32e38425f9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:31:\"ept_light_primary_admin_actions\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"56ef6a64-122b-4123-89be-e28c850c9ab5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:29:\"ept_light_primary_local_tasks\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"901eabdd-054d-4bcb-9773-45c7fd010fdf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:31:\"ept_light_secondary_local_tasks\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-3;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_site_branding',_binary 'a:13:{s:4:\"uuid\";s:36:\"91c1ee17-a1ad-4235-992c-274ff1022382\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:23:\"ept_light_site_branding\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"906009a1-78bd-4b80-9f60-5260448561b2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"y9X3xgCsO59pQyzNLzY1D3SDJJxCHILLWkpPnmuTJ2E\";}s:2:\"id\";s:15:\"gin_breadcrumbs\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"38507368-0a7f-4498-a629-376fb4821455\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBHXB7hC05XU7pDYzETt-GUcpFlogK1gkjyAsg0Ym58\";}s:2:\"id\";s:11:\"gin_content\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"e3753ad7-7b76-4f93-add9-02296fe5a072\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8nOAry2oKqJOr0zbrlJ3sZHDFJLIO6j-0vT0K_TYca4\";}s:2:\"id\";s:8:\"gin_help\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"f127d369-8154-4de3-9366-638b32c1d495\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OQ9aJ-4qVwK1x00o9EOYK4eFDjQr_HLpbPiJaPSVZiQ\";}s:2:\"id\";s:17:\"gin_local_actions\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"302175a6-2514-4728-9834-feade3c1cb23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WvPhI8OwllG0gE69-F8qL3ai3nd5SbYD6JpmEuZcyok\";}s:2:\"id\";s:12:\"gin_messages\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"37f8f7d2-81b3-4c42-a9a4-84cb29380e2c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HLQY2xgby8K3vN_98hiOSasOhm9pdCsH234-s0duJ8Q\";}s:2:\"id\";s:14:\"gin_page_title\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"877e883f-c61a-49fd-bf14-7370c20fec8c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hh01DLj9k7UnNdPpOQXHZHW7GHf2OPNDQyCJF7_R9ac\";}s:2:\"id\";s:23:\"gin_primary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"11d088e1-eb0e-4d66-ac1d-c629d4c31759\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCWhood0xXFQYqxFgL1spXdb9KeIuXH1YvTdjIEedDg\";}s:2:\"id\";s:25:\"gin_secondary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_account_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"360ce22f-fdb1-4a74-baf4-b253df6d8b6d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:20:\"olivero_account_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"19cc65dc-0021-4f62-9692-28154e28e6d6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:19:\"olivero_breadcrumbs\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"45129ab9-c3af-46c1-b266-7caf3e552d05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:15:\"olivero_content\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"1f0cb4e0-55ff-4097-a00c-015a0892bae5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:12:\"olivero_help\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_main_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"447aab50-0670-4a09-ad2b-204da3cad682\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:17:\"olivero_main_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"07cc9530-0745-41b8-a927-b15f94d11bfb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:16:\"olivero_messages\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"8ed1a440-61c0-42d9-af64-c0573a386802\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:18:\"olivero_page_title\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_powered',_binary 'a:13:{s:4:\"uuid\";s:36:\"4e19c95d-851d-48dd-8e91-3df3501787a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYL19CLDyinGTWYQfBD1DswWzglEotE_kHnHx3AxTXM\";}s:2:\"id\";s:15:\"olivero_powered\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"footer_bottom\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_powered_by_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_powered_by_block\";s:5:\"label\";s:17:\"Powered by Drupal\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_admin_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"2889853d-c6c8-46fb-8345-4f1161d60b42\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:29:\"olivero_primary_admin_actions\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"4a702f15-1477-4e9c-a8bf-5c98f5bff5f5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:27:\"olivero_primary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"b7350fce-d849-4243-936a-283b164fea04\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:29:\"olivero_secondary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-2;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_site_branding',_binary 'a:13:{s:4:\"uuid\";s:36:\"5e004719-546a-4a9e-8ed6-bce3b1438316\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:21:\"olivero_site_branding\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_syndicate',_binary 'a:13:{s:4:\"uuid\";s:36:\"b7ad69dc-b6ab-4ee3-ab50-2994b490c801\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0gq3VPg-_UM69FCCWurLFIrrnIjC2HLKhwo9iQNtcUo\";}s:2:\"id\";s:17:\"olivero_syndicate\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"social\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:20:\"node_syndicate_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:20:\"node_syndicate_block\";s:5:\"label\";s:8:\"RSS feed\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"node\";s:11:\"block_count\";i:10;}s:10:\"visibility\";a:0:{}}'),('','block_content.type.basic',_binary 'a:9:{s:4:\"uuid\";s:36:\"682f8d4b-7fbf-4b68-aeeb-78ff6ffa44c8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQP5iQy4SdhAMVcjDUncCfkJmTofnHVtXrsMzx4k6Yk\";}s:2:\"id\";s:5:\"basic\";s:5:\"label\";s:11:\"Basic block\";s:8:\"revision\";b:0;s:11:\"description\";s:42:\"A basic block contains a title and a body.\";}'),('','ckeditor5_plugin_pack.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uAMHMIBA-fCvlzeeOYZ4vKwSBXvThlEytdEKK_Ur8nI\";}s:12:\"dll_location\";s:0:\"\";}'),('','claro.settings',_binary 'a:1:{s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),('','comment.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNUW2Ij5uE7a4oaXp3i_2lvaFdYM1zNKPPfnEjB0jEc\";}s:16:\"log_ip_addresses\";b:0;}'),('','comment.type.comment',_binary 'a:9:{s:4:\"uuid\";s:36:\"33c6c326-f5e0-4ece-8508-28b245963a92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bqZsN31T2n0UjcbyCpOPi9D2iO0sAOHR7FnEs9qMvaA\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:16:\"Default comments\";s:21:\"target_entity_type_id\";s:4:\"node\";s:11:\"description\";s:28:\"Allows commenting on content\";}'),('','contact.form.feedback',_binary 'a:12:{s:4:\"uuid\";s:36:\"d9d62dfa-bada-46f4-869f-64b74f835a2f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vymHlgJy26BuI5GGj9-IXjwR3dRC5C0tij4BpWJnoqw\";}s:2:\"id\";s:8:\"feedback\";s:5:\"label\";s:16:\"Website feedback\";s:10:\"recipients\";a:1:{i:0;s:17:\"admin@example.com\";}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.form.personal',_binary 'a:12:{s:4:\"uuid\";s:36:\"3d45f5dc-8385-44e2-add9-10e58ad548b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jonvgt3CkUM2eMLTFwWfHileWWDC4YtXCuIlCahTk_I\";}s:2:\"id\";s:8:\"personal\";s:5:\"label\";s:21:\"Personal contact form\";s:10:\"recipients\";a:0:{}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U69DBeuvXuNVOC15rVNaBjDPK2fWFbo9v4takdYSSO8\";}s:12:\"default_form\";s:8:\"feedback\";s:5:\"flood\";a:2:{s:5:\"limit\";i:5;s:8:\"interval\";i:3600;}s:20:\"user_default_enabled\";b:1;}'),('','core.base_field_override.node.page.promote',_binary 'a:17:{s:4:\"uuid\";s:36:\"3818335f-a764-468f-ba14-8dbe325fa7f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:14:\"node.type.page\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fPUEnm4T5zfZRr3ttDUqq7yCDd2uW3clWD-pvos4tlQ\";}s:2:\"id\";s:17:\"node.page.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','core.date_format.fallback',_binary 'a:9:{s:4:\"uuid\";s:36:\"3d36a601-a518-4117-b489-72f027a4d007\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7klS5IWXrwzVaPpYZFAs6wcx8U2FF1X73OfrtTsvuvE\";}s:2:\"id\";s:8:\"fallback\";s:5:\"label\";s:20:\"Fallback date format\";s:6:\"locked\";b:1;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),('','core.date_format.html_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"1e7ea1cc-62aa-4605-b6b6-e50e8e13c716\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EOQltUQPmgc6UQ2rcJ4Xi_leCEJj5ui0TR-12duS-Tk\";}s:2:\"id\";s:9:\"html_date\";s:5:\"label\";s:9:\"HTML Date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-m-d\";}'),('','core.date_format.html_datetime',_binary 'a:9:{s:4:\"uuid\";s:36:\"c34d2a68-a9e5-40c6-8224-8940032e30eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxfClwZIRXIdcvMrE--WkcZxDGUVoOIE3Sm2NRZlFuE\";}s:2:\"id\";s:13:\"html_datetime\";s:5:\"label\";s:13:\"HTML Datetime\";s:6:\"locked\";b:1;s:7:\"pattern\";s:13:\"Y-m-d\\TH:i:sO\";}'),('','core.date_format.html_month',_binary 'a:9:{s:4:\"uuid\";s:36:\"1db472d5-aa8d-43d1-99f1-0718ae5620bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Z7KuCUwM_WdTNvLcoltuX3_8d-s-8FZkTN6KgNwF0eM\";}s:2:\"id\";s:10:\"html_month\";s:5:\"label\";s:10:\"HTML Month\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"Y-m\";}'),('','core.date_format.html_time',_binary 'a:9:{s:4:\"uuid\";s:36:\"504c65d8-2f56-4376-8b9b-e7ca5b007ba8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M7yqicYkU36hRy5p9drAaGBBihhUD1OyujFrAaQ93ZE\";}s:2:\"id\";s:9:\"html_time\";s:5:\"label\";s:9:\"HTML Time\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"H:i:s\";}'),('','core.date_format.html_week',_binary 'a:9:{s:4:\"uuid\";s:36:\"9c97ee83-74c2-4456-80d2-eb94e9ca333e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKD4WsoV_wFgv2vgI4mcAAFSIzrye17ykzdwrnApkfY\";}s:2:\"id\";s:9:\"html_week\";s:5:\"label\";s:9:\"HTML Week\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-\\WW\";}'),('','core.date_format.html_year',_binary 'a:9:{s:4:\"uuid\";s:36:\"045e5b96-3ec2-48a7-ba8c-c6cd6c3e6478\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjekiQuX9RbVQ2_8jOHBL94RgYLePqX7wpfNGgcQzrk\";}s:2:\"id\";s:9:\"html_year\";s:5:\"label\";s:9:\"HTML Year\";s:6:\"locked\";b:1;s:7:\"pattern\";s:1:\"Y\";}'),('','core.date_format.html_yearless_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"ebd666ec-7725-4d54-8907-f69b8c4e48ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VpawMrKPEPCkoO4YpPa0TDFO2dgiIHfTziJtwlmUxc\";}s:2:\"id\";s:18:\"html_yearless_date\";s:5:\"label\";s:18:\"HTML Yearless date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"m-d\";}'),('','core.date_format.long',_binary 'a:9:{s:4:\"uuid\";s:36:\"26c2a255-dd57-40de-9edb-d3ecd4eafa69\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"og8sWXhBuHbLMw3CoiBEZjgqSyhFBFmcbUW_wLcfNbo\";}s:2:\"id\";s:4:\"long\";s:5:\"label\";s:17:\"Default long date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:15:\"l, F j, Y - H:i\";}'),('','core.date_format.medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"b3b94f80-dd74-4a2f-b128-51de30c5e289\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nzL5d024NjXIX_8TlT6uFAu973lmfkmHklJC-2i9rAE\";}s:2:\"id\";s:6:\"medium\";s:5:\"label\";s:19:\"Default medium date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),('','core.date_format.olivero_medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"f5992887-d80e-47c5-bcb3-28c304448abb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mt6cmxUbDZ9XxD6p25WQ8tj3_JcX8ylfcddwZc8gcAE\";}s:2:\"id\";s:14:\"olivero_medium\";s:5:\"label\";s:14:\"Olivero Medium\";s:6:\"locked\";b:0;s:7:\"pattern\";s:8:\"j  F,  Y\";}'),('','core.date_format.short',_binary 'a:9:{s:4:\"uuid\";s:36:\"c5c2ce9a-1442-4bf1-a654-b45e23c4b6e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AlzeyytA8InBgxIG9H2UDJYs3CG98Zj6yRsDKmlbZwA\";}s:2:\"id\";s:5:\"short\";s:5:\"label\";s:18:\"Default short date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:11:\"m/d/Y - H:i\";}'),('','core.entity_form_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"21a9c7b6-423a-4c02-931a-6bb7c808ca5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jAps3FCxvKecABS_tgExbhCZrBLQB3bNPWw18WjE3ss\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"46bc1cc1-610e-4909-9538-f9f08a6a24c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0Pa0aQvT_jawlPo9oz4FE3h_ickc55dYKTPl6gILes\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:6:\"author\";a:2:{s:6:\"weight\";i:-2;s:6:\"region\";s:7:\"content\";}s:12:\"comment_body\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:7:\"subject\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.media.audio.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"1912a858-abb3-4ca8-aa94-e9265ace4567\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"G2_SKH3jmI9FQeXSUxo3KgQqiyF1hPDEkc7-3-rCSbc\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_audio_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.audio.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"4c160f87-d7c6-4dde-a9d2-878ce2336387\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:16:\"media.type.audio\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"28vwMIYtvyjPcD4RyciZXIztxtZgmuWRCNgYemr_SZE\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.document.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c24b87ec-64f6-4fa0-aed7-1c3d86160e5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aewrRkePgJzdD5kPOq8JeMcKHs6yat49nE7ZeCQzQZg\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_media_document\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.document.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"8323a260-ffc2-4476-8123-c40c72552a6e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:19:\"media.type.document\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dcpfpqyLXOSGpulacMAJW3H-G34_LeNsjdfxd1_oCfY\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f08ad847-8b1c-4396-9081-ca9a56f6b01a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:21:\"image.style.thumbnail\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JSY4-JPyNZBiYYo6imdRYF6_SdtWQexPndrLvn3-vw4\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.image.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"91fbcfb7-0a83-434f-99ac-c23c349657be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BMLrK4zKp8-FFnMseBdT_6h6YipUsKRfbDf_3WUB5HA\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:5:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.remote_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"97a32351-c013-445a-af13-08939389c3b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pM8mGlwfpvfG_y5tZn0lGAXFLXz2_yKkL7MvWZsRqdA\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_media_oembed_video\";a:5:{s:4:\"type\";s:16:\"oembed_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.remote_video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"47cd5408-95d9-4b89-a9c5-7d8aedd625f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBgPW-uaXRaICBwLaVc16rXpRiLSknDIdF9q0XL7qso\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"7c5e18c3-3d08-4151-8d31-a9d9a597a5ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0kIIaDTt6dixXy8TZkat2MNGZJ6vkRG8TaBWTy3E1bM\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_video_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"3d683f4e-cbb1-4a0e-b1df-f9f9c87e4284\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:16:\"media.type.video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kGv8YsopqHvzTzb7QTINWcv0fnNa5ZDQyZxpOQR2vro\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"de67467e-664b-4fd4-b096-f4f20912ea91\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:35:\"field.field.node.article.field_tags\";i:3;s:21:\"image.style.thumbnail\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ewbd6G2uX456-bgwseM2Q-KQG3RkASoyHmTh-XR3oLU\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:10:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:11:\"field_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:10:\"field_tags\";a:5:{s:4:\"type\";s:34:\"entity_reference_autocomplete_tags\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c6ec1d38-d434-4a7d-be65-080873fd0aff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:38:\"field.field.node.page.field_components\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:3:{i:0;s:17:\"layout_paragraphs\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:9:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:31;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:16:\"field_components\";a:5:{s:4:\"type\";s:17:\"layout_paragraphs\";s:6:\"weight\";i:121;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:10;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.paragraph.ept_accordion.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"bcf372a8-c025-4ef1-bc1e-7467ead740ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:55:\"field.field.paragraph.ept_accordion.field_ept_accordion\";i:1;s:54:\"field.field.paragraph.ept_accordion.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_accordion.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_accordion.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:4:{i:0;s:13:\"ept_accordion\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:19:\"field_ept_accordion\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0pJauu3QzSH4aBsmd_KTxzf59AWAoqGvmpFOuI3phow\";}s:2:\"id\";s:31:\"paragraph.ept_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:19:\"field_ept_accordion\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_accordion\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_accordion_section.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a18df3e8-1c60-449a-81fb-3d8f4dc347dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:68:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_text\";i:1;s:69:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_title\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-D0_ofC0E9vG5JgJKn-KVVKS8EddSulFMva-vLSGBq4\";}s:2:\"id\";s:39:\"paragraph.ept_accordion_section.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ept_accordion_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_accordion_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_basic_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"3bbc19b5-b8d1-4737-93da-814614ad0da5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:66:\"field.field.paragraph.ept_basic_button.field_ept_basic_button_link\";i:1;s:57:\"field.field.paragraph.ept_basic_button.field_ept_settings\";i:2;s:53:\"field.field.paragraph.ept_basic_button.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_basic_button.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:3:{i:0;s:16:\"ept_basic_button\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BDM_dmNUeNyOV7_jEouKixGZvfGdfIYFnegSbt0TFUk\";}s:2:\"id\";s:34:\"paragraph.ept_basic_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:27:\"field_ept_basic_button_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:25:\"ept_settings_basic_button\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_block.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"063fafbf-a44a-44d9-b44e-e6b7f1c968f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";i:1;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";i:2;s:46:\"field.field.paragraph.ept_block.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_block.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:8:\"ept_core\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:21:\"field_ept_block_block\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kf0CKi0lVMCHZKEFVJNSYNl5CpKFKRH7JLsGDr_mt24\";}s:2:\"id\";s:27:\"paragraph.ept_block.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:21:\"field_ept_block_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_bootstrap_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"39e1a15a-eab7-4dcc-af37-af10f81e96dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:74:\"field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";i:1;s:61:\"field.field.paragraph.ept_bootstrap_button.field_ept_settings\";i:2;s:57:\"field.field.paragraph.ept_bootstrap_button.field_ept_text\";i:3;s:58:\"field.field.paragraph.ept_bootstrap_button.field_ept_title\";i:4;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:3:{i:0;s:20:\"ept_bootstrap_button\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WwkZbBHhL-k1BpcZgfCET2hj9ScPYC5rcs4an-tHYB4\";}s:2:\"id\";s:38:\"paragraph.ept_bootstrap_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:31:\"field_ept_bootstrap_button_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:29:\"ept_settings_bootstrap_button\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_cards.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"343bdaca-8837-45f9-9879-bc37b630068f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:50:\"field.field.paragraph.ept_cards.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_cards.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_cards.field_ept_title\";i:3;s:36:\"paragraphs.paragraphs_type.ept_cards\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bsDZ_W6zC0Z-XF3k1wOPjfyjNZZTDsDa88bWGz-XWpM\";}s:2:\"id\";s:27:\"paragraph.ept_cards.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_cards\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_carousel.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"3b42b32b-b440-4ab8-9a73-96284648f0b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_carousel\";i:1;s:53:\"field.field.paragraph.ept_carousel.field_ept_settings\";i:2;s:49:\"field.field.paragraph.ept_carousel.field_ept_text\";i:3;s:50:\"field.field.paragraph.ept_carousel.field_ept_title\";i:4;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:4:{i:0;s:12:\"ept_carousel\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:18:\"field_ept_carousel\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9B69asgWfAo5TT1550-4nwxxD-NZ9b_eK0DwrqjPbAI\";}s:2:\"id\";s:30:\"paragraph.ept_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_carousel\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:21:\"ept_settings_carousel\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_carousel_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"209743da-7b46-410c-8256-e9acf9b4200b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:1;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0MubGNP7-aRTqqknjrXSWiyr6o87xC8YYQSjnFL1qMA\";}s:2:\"id\";s:35:\"paragraph.ept_carousel_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_carousel_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_columns.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"4fadf498-bcbb-44d6-b829-6d1abdabf326\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:51:\"field.field.paragraph.ept_columns.field_ept_columns\";i:1;s:52:\"field.field.paragraph.ept_columns.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_columns.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_columns.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:4:{i:0;s:11:\"ept_columns\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:17:\"field_ept_columns\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MfVgHlmnR_bb8akzrozdi7R7KwnEOtq9cQ0OpHkngMs\";}s:2:\"id\";s:29:\"paragraph.ept_columns.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:17:\"field_ept_columns\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_columns\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_countdown.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"ed55009f-a01e-42ae-987d-b5ccc04e073b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ept_countdown.field_ept_countdown_date\";i:1;s:54:\"field.field.paragraph.ept_countdown.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_countdown.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_countdown.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:4:{i:0;s:8:\"datetime\";i:1;s:13:\"ept_countdown\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:24:\"field_ept_countdown_date\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZxcirB8U5v0ZYrJRdwsxmS_1WIhbNwZMbBqsAz988cQ\";}s:2:\"id\";s:31:\"paragraph.ept_countdown.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_countdown_date\";a:5:{s:4:\"type\";s:16:\"datetime_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_countdown\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_counter.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"6e0ad4c3-90f1-4e63-9ad2-e7c012a124d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_counter.field_ept_counter_items\";i:1;s:52:\"field.field.paragraph.ept_counter.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_counter.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_counter.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:4:{i:0;s:11:\"ept_counter\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:23:\"field_ept_counter_items\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:9;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eaw1Ar6YTSIRF829Uy9SPd0v5CFQ_XobGxIEZV3aq_Q\";}s:2:\"id\";s:29:\"paragraph.ept_counter.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_counter_items\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_counter\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_counter_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8c95a60e-1c70-45a6-b8a2-c4d53b93ce5d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_counter_item.field_ept_counter_description\";i:1;s:61:\"field.field.paragraph.ept_counter_item.field_ept_counter_icon\";i:2;s:63:\"field.field.paragraph.ept_counter_item.field_ept_counter_number\";i:3;s:62:\"field.field.paragraph.ept_counter_item.field_ept_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HdOx-dFGYXleAxDzMra4AkSnLaUMOZ6Sgl69k93sJcg\";}s:2:\"id\";s:34:\"paragraph.ept_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ept_counter_description\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ept_counter_icon\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_counter_number\";a:5:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ept_counter_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_cta.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"8a29f047-88c0-4af9-8cd2-705177201f7a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:56:\"field.field.paragraph.ept_cta.field_ept_cta_column_image\";i:1;s:48:\"field.field.paragraph.ept_cta.field_ept_cta_link\";i:2;s:55:\"field.field.paragraph.ept_cta.field_ept_cta_second_link\";i:3;s:48:\"field.field.paragraph.ept_cta.field_ept_settings\";i:4;s:44:\"field.field.paragraph.ept_cta.field_ept_text\";i:5;s:45:\"field.field.paragraph.ept_cta.field_ept_title\";i:6;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:5:{i:0;s:7:\"ept_cta\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:26:\"field_ept_cta_column_image\";i:3;s:18:\"field_ept_cta_link\";i:4;s:25:\"field_ept_cta_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4FYtKN9WoslLXaZoBk3fkuVx6aDPk0YoM6rC8pnsieA\";}s:2:\"id\";s:25:\"paragraph.ept_cta.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:26:\"field_ept_cta_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_cta_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_cta_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:16:\"ept_settings_cta\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_hero.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"be53fd67-518c-4b3c-ac43-3b2c15a8d954\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";i:1;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";i:2;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";i:3;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";i:4;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";i:5;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";i:6;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";i:7;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:5:{i:0;s:8:\"ept_hero\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:6:{i:0;s:15:\"field_ept_title\";i:1;s:27:\"field_ept_hero_title_prefix\";i:2;s:14:\"field_ept_text\";i:3;s:27:\"field_ept_hero_column_image\";i:4;s:19:\"field_ept_hero_link\";i:5;s:26:\"field_ept_hero_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jU5fU7CphqYF6ZSn4c9q-QZ0_XHfDeFV936TKmTKPIM\";}s:2:\"id\";s:26:\"paragraph.ept_hero.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:27:\"field_ept_hero_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_hero_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ept_hero_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_hero_title_prefix\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:17:\"ept_settings_hero\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_image.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a60ae7a6-353d-412e-81ca-b8eff5eb6f78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_image\";i:1;s:55:\"field.field.paragraph.ept_image.field_ept_image_caption\";i:2;s:52:\"field.field.paragraph.ept_image.field_ept_image_link\";i:3;s:50:\"field.field.paragraph.ept_image.field_ept_settings\";i:4;s:46:\"field.field.paragraph.ept_image.field_ept_text\";i:5;s:47:\"field.field.paragraph.ept_image.field_ept_title\";i:6;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:5:{i:0;s:9:\"ept_image\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_image\";i:3;s:23:\"field_ept_image_caption\";i:4;s:20:\"field_ept_image_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6-OjP-OV8uHyYxN_ycg0WCoPJRu34t3ix7LwCCNbTzE\";}s:2:\"id\";s:27:\"paragraph.ept_image.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:15:\"field_ept_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ept_image_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_image_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_image\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_image_gallery.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"bd32a1a0-f63c-4e6b-b14f-7dfa6323a07a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_image_gallery.field_ept_image_gallery\";i:1;s:58:\"field.field.paragraph.ept_image_gallery.field_ept_settings\";i:2;s:54:\"field.field.paragraph.ept_image_gallery.field_ept_text\";i:3;s:55:\"field.field.paragraph.ept_image_gallery.field_ept_title\";i:4;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:4:{i:0;s:17:\"ept_image_gallery\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:23:\"field_ept_image_gallery\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9b_KN3kBrDhBERN17M7jxBYPF-IXaw1nLONpCw4Dtzo\";}s:2:\"id\";s:35:\"paragraph.ept_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_image_gallery\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:26:\"ept_settings_image_gallery\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_micromodal.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"c0e1ca3f-d656-43c4-a362-86c7cb0ac490\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_micromodal.field_ept_micromodal_title\";i:1;s:55:\"field.field.paragraph.ept_micromodal.field_ept_settings\";i:2;s:51:\"field.field.paragraph.ept_micromodal.field_ept_text\";i:3;s:52:\"field.field.paragraph.ept_micromodal.field_ept_title\";i:4;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:3:{i:0;s:14:\"ept_micromodal\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:14:\"group_settings\";i:1;s:13:\"group_content\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:26:\"field_ept_micromodal_title\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:6:\"hidden\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ynF9PLVVYG00_7Br42jxgJ02cMPPwmtf3jssH3Gx9T8\";}s:2:\"id\";s:32:\"paragraph.ept_micromodal.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_micromodal_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:23:\"ept_settings_micromodal\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_quote.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"62a89609-5a89-4eb4-a5a2-c3c58c93480d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:54:\"field.field.paragraph.ept_quote.field_ept_quote_author\";i:1;s:53:\"field.field.paragraph.ept_quote.field_ept_quote_image\";i:2;s:50:\"field.field.paragraph.ept_quote.field_ept_settings\";i:3;s:46:\"field.field.paragraph.ept_quote.field_ept_text\";i:4;s:47:\"field.field.paragraph.ept_quote.field_ept_title\";i:5;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_quote\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:4:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:22:\"field_ept_quote_author\";i:3;s:21:\"field_ept_quote_image\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rMIoq7ATvLm5GYUegulzLGA67l1jIqNeN1Vma_Calus\";}s:2:\"id\";s:27:\"paragraph.ept_quote.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:22:\"field_ept_quote_author\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_quote_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_quote\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slick_slider.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"6b2455af-c7c1-4faf-ae2f-5faf8b33c82d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_slick_slider.field_ept_settings\";i:1;s:61:\"field.field.paragraph.ept_slick_slider.field_ept_slick_slider\";i:2;s:53:\"field.field.paragraph.ept_slick_slider.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_slick_slider.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:4:{i:0;s:16:\"ept_slick_slider\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:22:\"field_ept_slick_slider\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hDbTWzuXu3VZtJk1OkYoVRSHUWjZQRwzNKl8MSfnHZo\";}s:2:\"id\";s:34:\"paragraph.ept_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:25:\"ept_settings_slick_slider\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ept_slick_slider\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slick_slider_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"0e9a2579-f110-4139-81b2-dc1025db5053\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:72:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";i:1;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";i:2;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";i:3;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CjC8L66tFduxz7PpSEZ_n5Vewr_T4E3BXo6iZw5cPjs\";}s:2:\"id\";s:39:\"paragraph.ept_slick_slider_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ept_slick_slider_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_slick_slider_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_slick_slider_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slideshow.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"1003a694-14ea-404d-bf58-34d4ad51a83c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:54:\"field.field.paragraph.ept_slideshow.field_ept_settings\";i:1;s:55:\"field.field.paragraph.ept_slideshow.field_ept_slideshow\";i:2;s:50:\"field.field.paragraph.ept_slideshow.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_slideshow.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:4:{i:0;s:13:\"ept_slideshow\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:19:\"field_ept_slideshow\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tILUBTEfzAAfH3RNpAfKLafcB4BQ1rEs4TXsefzXpz8\";}s:2:\"id\";s:31:\"paragraph.ept_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_slideshow\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_slideshow\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slideshow_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"483f7e15-2bcb-4ed9-952b-548c4960e622\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link\";i:1;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide\";i:2;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text\";i:3;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title\";i:4;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wXdtnml8iEI3B2hPt_jBFMcr9wunJPj97vsPtPVoSlI\";}s:2:\"id\";s:36:\"paragraph.ept_slideshow_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_slideshow_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_slideshow_slide\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_slideshow_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_slideshow_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_stats.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a9e1d9c8-64cb-4c33-ae6e-7c4617fa82d4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_stats.field_ept_settings\";i:1;s:47:\"field.field.paragraph.ept_stats.field_ept_stats\";i:2;s:46:\"field.field.paragraph.ept_stats.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_stats.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_stats\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_stats\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iULioKDpET9pDqjdWoX6RbIYNdzK6nuBHJbWBY8s8hw\";}s:2:\"id\";s:27:\"paragraph.ept_stats.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_stats\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_stats\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_stats_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"11f77720-51d3-4dc6-b653-b86d5771046b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_image\";i:1;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_link\";i:2;s:64:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_number\";i:3;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wF_mUJwfQr8bsVI-d3u1R2W8PUu9gazphbDkBAY2SEk\";}s:2:\"id\";s:32:\"paragraph.ept_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_stats_item_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_stats_item_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_stats_item_number\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_stats_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tabs.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"e1a6c8e5-95b1-4c04-8b08-798a42e3f990\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:49:\"field.field.paragraph.ept_tabs.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_tabs.field_ept_tabs\";i:2;s:45:\"field.field.paragraph.ept_tabs.field_ept_text\";i:3;s:46:\"field.field.paragraph.ept_tabs.field_ept_title\";i:4;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_tabs\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:14:\"field_ept_tabs\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qwxwo_7tJPCVoTpGT3EGZT8rcmOT-hnPcBxVGLjPG78\";}s:2:\"id\";s:26:\"paragraph.ept_tabs.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:17:\"ept_settings_tabs\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_tabs\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tabs_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2ba6d267-9074-4e3c-a4c5-e392e2e1b8ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_block\";i:1;s:57:\"field.field.paragraph.ept_tabs_item.field_ept_tab_content\";i:2;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_page\";i:3;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_text\";i:4;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_title\";i:5;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_views\";i:6;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oVvZoAPE_jk4D2dNYM8_LohZLLeaIQBnleftotvYd7o\";}s:2:\"id\";s:31:\"paragraph.ept_tabs_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:19:\"field_ept_tab_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tab_content\";a:5:{s:4:\"type\";s:14:\"options_select\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_tab_page\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_tab_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_tab_title\";a:5:{s:4:\"type\";s:14:\"text_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_tab_views\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_text.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"0a168361-abfe-403a-8922-8305dbbef7af\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:49:\"field.field.paragraph.ept_text.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_text.field_ept_text\";i:2;s:46:\"field.field.paragraph.ept_text.field_ept_title\";i:3;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:6:\"hidden\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"shyYm2rY3OjdKeiRCtoWJpvauXuaTQJb8xb0cyNYRM8\";}s:2:\"id\";s:26:\"paragraph.ept_text.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:21;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:23;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:22;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tiles.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a5784c00-a16b-4f3b-91dd-568be1356d3a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_tiles.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_tiles.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_tiles.field_ept_tiles\";i:3;s:47:\"field.field.paragraph.ept_tiles.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_tiles\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_tiles\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:11;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:12;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fub48PSonCbwVzLnLvqqeYQk1wGzEf65HefNdP-qQaQ\";}s:2:\"id\";s:27:\"paragraph.ept_tiles.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_tiles\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_tiles\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tiles_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"45b2e5a1-2031-4177-b3c2-580549849e46\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ept_tiles_item.field_ept_clickable_tile\";i:1;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_image\";i:2;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_link\";i:3;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_text\";i:4;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U9PXobBv4clQdnuyNB31xyZFAqJ5NgK_WHOSbnw6g98\";}s:2:\"id\";s:32:\"paragraph.ept_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ept_clickable_tile\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tiles_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_tiles_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_tiles_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tiles_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"fe1a956f-1eb5-49f4-8ccd-d852faeeea9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_video.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_video.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_video.field_ept_title\";i:3;s:47:\"field.field.paragraph.ept_video.field_ept_video\";i:4;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_video\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:15:\"field_ept_video\";i:2;s:14:\"field_ept_text\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uWfzDvi2652DPEZs_2EApToxb-ZwFGKVzEDZ3Jd27xU\";}s:2:\"id\";s:27:\"paragraph.ept_video.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_video\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_video\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video_and_image_gallery.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"2a6ec3c5-051d-451f-bfa5-ae16ca4d9cc1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_settings\";i:1;s:64:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_text\";i:2;s:65:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_title\";i:3;s:77:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";i:4;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:4:{i:0;s:27:\"ept_video_and_image_gallery\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:27:\"field_ept_videos_and_images\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rOQ-MHiLNktgV1oHnzDodKFBNZKJGnpQ_jcoXGPWl3s\";}s:2:\"id\";s:45:\"paragraph.ept_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:36:\"ept_settings_video_and_image_gallery\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_videos_and_images\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video_and_image_gallery_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"5a1fd1b5-9098-41dc-99e7-65246d6fe6da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";i:1;s:82:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-EpWxbfVxkolF4xO3v_gR4i7gLA_X1pxspQ3sm0jgQY\";}s:2:\"id\";s:50:\"paragraph.ept_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:22:\"field_ept_gallery_item\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_gallery_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_views.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"5f9fd1ed-53a9-4349-8202-c90230a11f12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_views.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_views.field_ept_title\";i:3;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";i:4;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";i:3;s:14:\"viewsreference\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:20:\"field_ept_views_view\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_i5XjlBN7MBo2rHWjbgIick135me8C2QqOcKTkr7Sx0\";}s:2:\"id\";s:27:\"paragraph.ept_views.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_views_view\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_webform.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d798701f-5b10-44f6-b850-ac38718396b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:52:\"field.field.paragraph.ept_webform.field_ept_settings\";i:1;s:48:\"field.field.paragraph.ept_webform.field_ept_text\";i:2;s:49:\"field.field.paragraph.ept_webform.field_ept_title\";i:3;s:56:\"field.field.paragraph.ept_webform.field_ept_webform_form\";i:4;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E0IjG-r8QfTmGUoGidNGmC64-k8eCONH_yhAUTGU9ZE\";}s:2:\"id\";s:29:\"paragraph.ept_webform.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ept_webform_form\";a:5:{s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:12:\"default_data\";b:1;s:8:\"webforms\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_webform_popup.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"71680c26-8af6-49c5-94f2-7276e46d9545\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:58:\"field.field.paragraph.ept_webform_popup.field_ept_settings\";i:1;s:54:\"field.field.paragraph.ept_webform_popup.field_ept_text\";i:2;s:55:\"field.field.paragraph.ept_webform_popup.field_ept_title\";i:3;s:68:\"field.field.paragraph.ept_webform_popup.field_ept_webform_popup_form\";i:4;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:3:{i:0;s:17:\"ept_webform_popup\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gxEA8BYs6sWNkpdD8h1XtwAUuUMpWV8fj1lzvtOLatM\";}s:2:\"id\";s:35:\"paragraph.ept_webform_popup.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:26:\"ept_settings_webform_popup\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:28:\"field_ept_webform_popup_form\";a:5:{s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:12:\"default_data\";b:1;s:8:\"webforms\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8eb5837f-793f-476b-8d5b-8eb1ea190520\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FaQ9Ptcpxpg30AtiqRDtl_8zbJArHP1LPfug_s59TOA\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"account\";a:2:{s:6:\"weight\";i:-10;s:6:\"region\";s:7:\"content\";}s:7:\"contact\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:8:\"language\";a:2:{s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:8:\"timezone\";a:2:{s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_mode.media.media_library',_binary 'a:10:{s:4:\"uuid\";s:36:\"94fd7791-9806-4755-a50f-91d35400a4cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_form_mode.user.register',_binary 'a:10:{s:4:\"uuid\";s:36:\"ef62034d-b624-4a32-9e4a-54a2baf7fa78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5pE_4hurqtIlZN3XDi7eTo5RG13BMG0Rh9HYlRI3h8U\";}s:2:\"id\";s:13:\"user.register\";s:5:\"label\";s:8:\"Register\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"53a48e63-4272-4544-9051-7617915e3d41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBNNDTFwakREOTa6GGMqN899Iyrii0hInwSJtQ7Kj30\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"da002566-b092-4563-9d08-c4b5c52593e5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aBQUGsQ46M4048fIlFuTXwl2zV0j2cJX89CTUobh9hA\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:12:\"comment_body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.media.audio.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"87bcc8b2-7f6c-4c74-800a-a87d1b94f5f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AS765MdDfNpK6K5eE7WVnBvpynClz_havy1R3bO3gVo\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_audio_file\";a:6:{s:4:\"type\";s:10:\"file_audio\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:4:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.audio.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"fd3c8ee0-7347-4825-a6ac-e712dc98946b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tcAUW1Xzq5Tjw5jomR6XKGSgfiXO7QiRAHJBF-n0akg\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.document.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"af3b0da5-5654-474f-b056-1b7fe53c1991\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XxUyhaTuM0OUUZpr8G6jdrFBEh5eag7auWxBKhm6cvY\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:20:\"field_media_document\";a:6:{s:4:\"type\";s:12:\"file_default\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.document.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"3027dd27-1f17-44e8-84f5-7366b5d87788\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:21:\"image.style.thumbnail\";i:3;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YcWqjhIlo-2RZUM5ogvRsrKB7M3voF2XB3lVLwgOlLU\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"19dfadc9-d9a4-4d4c-9953-240f406fe79c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:17:\"image.style.large\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"73xaTNkI5J6sfFcBmNYeuk070X3mQS_iwwWaPYyfG2M\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:5:\"large\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.ept_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"4f8ec3e2-1797-492f-8b2d-8ce7545d59bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:45:\"core.entity_view_mode.media.ept_image_gallery\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:29:\"image.style.ept_gallery_image\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n90nNuXho9mrkYYsIQ1XTO6AvAhpgl2KtPDCGCOnGhM\";}s:2:\"id\";s:29:\"media.image.ept_image_gallery\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:17:\"ept_image_gallery\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:17:\"ept_gallery_image\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:6:\"parent\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"c47a77e8-55b1-49a2-adeb-dc69b79b24e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:60:\"core.entity_view_mode.media.ept_video_and_image_gallery_item\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:39:\"image.style.ept_video_and_image_gallery\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rH_qHt_lYqhJQjixn1J6qIQ6Nll3micOpoBEVEtJ4CA\";}s:2:\"id\";s:44:\"media.image.ept_video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:32:\"ept_video_and_image_gallery_item\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:27:\"ept_video_and_image_gallery\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"1053ac57-9af0-4e5b-ba2f-c5695c62ef08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:18:\"image.style.medium\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ILLWu5KFvbsX6J7sh2Itd4w8-lBBRhR_H8ZrmQiN2yo\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:17:\"field_media_image\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"9ecc7509-3522-45c5-bda4-7ed77885a161\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZdPcl2hPxl5pgv3pI-07R7h51OjeUeKJTy-ab1NfM34\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:6:\"oembed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:9:\"max_width\";i:0;s:10:\"max_height\";i:0;s:7:\"loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.ept_video',_binary 'a:11:{s:4:\"uuid\";s:36:\"51e43f2e-4f69-45a1-95c7-5ecf07778894\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:37:\"core.entity_view_mode.media.ept_video\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1KlyRkRbqUbxJgk8eo1S40_quArKzT_wKaIMWWlaSoU\";}s:2:\"id\";s:28:\"media.remote_video.ept_video\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:9:\"ept_video\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:4:\"post\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"72019611-98d6-4f86-81ec-768c71520e64\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:60:\"core.entity_view_mode.media.ept_video_and_image_gallery_item\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3xEp_ZELSvrqfzLRi2XtfPP7KVrHNdRe-XdyCYK3Jc8\";}s:2:\"id\";s:51:\"media.remote_video.ept_video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:32:\"ept_video_and_image_gallery_item\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:27:\"ept_video_and_image_gallery\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"b0bc3306-d88a-4581-af6c-2a1f29aac6ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:18:\"image.style.medium\";i:3;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PGGoP-hVkXe_S-GiJRAub4PHDu0KhMExylclrqjdJb4\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"63fe648a-c5c1-42b9-8b04-7bb9db119166\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxvbuGh-6cQMxl9bBV27-hGI46u7ZvwlMm5ObaJMNnw\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_video_file\";a:6:{s:4:\"type\";s:10:\"file_video\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";s:5:\"muted\";b:0;s:5:\"width\";i:640;s:6:\"height\";i:480;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"5672ce5e-9fb4-4800-8c9d-3b15ca3f7fde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_fnkUKwQYHkXO1Ngmq9nE6FqWUNAmkddOxAH1h5aiKg\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"0f767bd2-1919-4166-8346-62c5fc895c81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:35:\"field.field.node.article.field_tags\";i:3;s:16:\"image.style.wide\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"br6izr-iGEu--JvNbCJNtOBpRnxpFLXfoV5y61U9Nqc\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.node.article.rss',_binary 'a:11:{s:4:\"uuid\";s:36:\"bad692de-34e5-483c-9717-c610a77e5be5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2rIr6K5Q0UQ9khg0zE_CK-PtJH76UL-BDDZcZnZzwCc\";}s:2:\"id\";s:16:\"node.article.rss\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:3:\"rss\";s:7:\"content\";a:1:{s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:3:{s:4:\"body\";b:1;s:11:\"field_image\";b:1;s:10:\"field_tags\";b:1;}}'),('','core.entity_view_display.node.article.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"b696c09e-d916-4b49-a1c2-566c781bf923\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:18:\"image.style.medium\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O8PxzfG8DOHHRu6M23kwR6TDPq_MNfYQ10Mp367ICUQ\";}s:2:\"id\";s:19:\"node.article.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"bc183acd-cdee-4366-86c4-4db46beceef3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:38:\"field.field.node.page.field_components\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Y8L5tfmhx7DR143E05YyZSpvgil6VFvqcfBWykalg\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:16:\"field_components\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:4:\"body\";b:1;}}'),('','core.entity_view_display.node.page.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"b64bcaef-5bd0-446f-a6d5-7096df12851d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:26:\"field.field.node.page.body\";i:2;s:38:\"field.field.node.page.field_components\";i:3;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8BgdRtLbtQ0F__o0FHSH0Mx5fvXOra9tfT1GmNKbRYw\";}s:2:\"id\";s:16:\"node.page.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:16:\"field_components\";b:1;}}'),('','core.entity_view_display.paragraph.ept_accordion.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f60b271e-f09b-45a9-8e92-1ae341b267f5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:55:\"field.field.paragraph.ept_accordion.field_ept_accordion\";i:1;s:54:\"field.field.paragraph.ept_accordion.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_accordion.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_accordion.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PJi5yKQ_AuFiKp81hRO_aQKSuuwBJkStIGM6f0wBBX8\";}s:2:\"id\";s:31:\"paragraph.ept_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:19:\"field_ept_accordion\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_accordion_section.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d4e6aedc-c8f3-451b-94d6-cd44fc4b6c11\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:68:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_text\";i:1;s:69:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_title\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UjA4zXZ3oMZFxRvkNrsM94SAiqKznnxAtCPUVIC6MT0\";}s:2:\"id\";s:39:\"paragraph.ept_accordion_section.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ept_accordion_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_accordion_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_basic_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f4454fef-a659-4b88-9579-11ba22f32177\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:66:\"field.field.paragraph.ept_basic_button.field_ept_basic_button_link\";i:1;s:57:\"field.field.paragraph.ept_basic_button.field_ept_settings\";i:2;s:53:\"field.field.paragraph.ept_basic_button.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_basic_button.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4gJX4ZzysdJ_kzlqlJAB2uqXRXQJi3VjikD1N3iepgA\";}s:2:\"id\";s:34:\"paragraph.ept_basic_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:27:\"field_ept_basic_button_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_block.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e7417c73-82e0-49a6-b66c-942b3596d612\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";i:1;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";i:2;s:46:\"field.field.paragraph.ept_block.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_block.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BFcfVmJHF2899wHjHN2VFWpiUyRAjvacvce9Cfs79BY\";}s:2:\"id\";s:27:\"paragraph.ept_block.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:21:\"field_ept_block_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_bootstrap_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a806c6af-6b6a-4398-a270-06147cb09d21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:74:\"field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";i:1;s:61:\"field.field.paragraph.ept_bootstrap_button.field_ept_settings\";i:2;s:57:\"field.field.paragraph.ept_bootstrap_button.field_ept_text\";i:3;s:58:\"field.field.paragraph.ept_bootstrap_button.field_ept_title\";i:4;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1s6HjRSAsva6N8IAwlMIIoLxlmMtVw7ygPp4U_Z7_1I\";}s:2:\"id\";s:38:\"paragraph.ept_bootstrap_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:31:\"field_ept_bootstrap_button_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_cards.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8ee3416a-ed7c-41d9-a9fd-2b0aca7d452b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:50:\"field.field.paragraph.ept_cards.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_cards.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_cards.field_ept_title\";i:3;s:36:\"paragraphs.paragraphs_type.ept_cards\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kx91MDtB9twVA76JC_brbEdU-Fwbok0L76fdkEmYqYI\";}s:2:\"id\";s:27:\"paragraph.ept_cards.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_cards\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a34b4adb-f67d-4569-90a5-e74b6a28bcdb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_carousel\";i:1;s:53:\"field.field.paragraph.ept_carousel.field_ept_settings\";i:2;s:49:\"field.field.paragraph.ept_carousel.field_ept_text\";i:3;s:50:\"field.field.paragraph.ept_carousel.field_ept_title\";i:4;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hW53xnntQ786Y9Dng5tbHj61F_Xq405ejwkoK9cGxUg\";}s:2:\"id\";s:30:\"paragraph.ept_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_carousel\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"95f5dba7-e075-42d7-bb71-a987d5625124\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:1;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:2;s:18:\"image.style.medium\";i:3;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kypuOk2yxicxTkEhw3Xo0FLPQXZVoNvTgwtmyMtUUKk\";}s:2:\"id\";s:35:\"paragraph.ept_carousel_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel_item.slider',_binary 'a:11:{s:4:\"uuid\";s:36:\"fa961609-f5ef-403a-8089-73f33b1e73f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:38:\"core.entity_view_mode.paragraph.slider\";i:1;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:2;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:3;s:18:\"image.style.medium\";i:4;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kypuOk2yxicxTkEhw3Xo0FLPQXZVoNvTgwtmyMtUUKk\";}s:2:\"id\";s:34:\"paragraph.ept_carousel_item.slider\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:6:\"slider\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_columns.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"83448cb5-91c5-4a34-a576-3ea914fa7d6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:51:\"field.field.paragraph.ept_columns.field_ept_columns\";i:1;s:52:\"field.field.paragraph.ept_columns.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_columns.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_columns.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vOC7NP0p0aXc-869ZBnA91HhUz6DjvKa3lJQB7amMmo\";}s:2:\"id\";s:29:\"paragraph.ept_columns.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:17:\"field_ept_columns\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_countdown.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"08b2118c-18b9-4669-b9e4-0786d49af6ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ept_countdown.field_ept_countdown_date\";i:1;s:54:\"field.field.paragraph.ept_countdown.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_countdown.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_countdown.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:3:{i:0;s:8:\"datetime\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0tZvxTE9_SxYclV0-qXTYzgXSfZoC1elFCKHb9scTG4\";}s:2:\"id\";s:31:\"paragraph.ept_countdown.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_countdown_date\";a:6:{s:4:\"type\";s:16:\"datetime_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:17:\"timezone_override\";s:0:\"\";s:11:\"format_type\";s:6:\"medium\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_counter.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"ad408e08-db1a-47df-8098-0b2a61f16481\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_counter.field_ept_counter_items\";i:1;s:52:\"field.field.paragraph.ept_counter.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_counter.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_counter.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eZqA1TwH5tWY55LrWFHFJQ_5F6K3z2LZAXPoKY6znBw\";}s:2:\"id\";s:29:\"paragraph.ept_counter.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_counter_items\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_counter_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"077ee820-2041-4778-8135-0fc65cd20cb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_counter_item.field_ept_counter_description\";i:1;s:61:\"field.field.paragraph.ept_counter_item.field_ept_counter_icon\";i:2;s:63:\"field.field.paragraph.ept_counter_item.field_ept_counter_number\";i:3;s:62:\"field.field.paragraph.ept_counter_item.field_ept_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7The1phmhJ8Ls_nSR64aLtEXudYALjs5Zzdf10AFuA\";}s:2:\"id\";s:34:\"paragraph.ept_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ept_counter_description\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ept_counter_icon\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_counter_number\";a:6:{s:4:\"type\";s:14:\"number_integer\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:23:\"field_ept_counter_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_cta.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"4bf53171-20df-4e38-bb87-a451cfc4aa6c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:56:\"field.field.paragraph.ept_cta.field_ept_cta_column_image\";i:1;s:48:\"field.field.paragraph.ept_cta.field_ept_cta_link\";i:2;s:55:\"field.field.paragraph.ept_cta.field_ept_cta_second_link\";i:3;s:48:\"field.field.paragraph.ept_cta.field_ept_settings\";i:4;s:44:\"field.field.paragraph.ept_cta.field_ept_text\";i:5;s:45:\"field.field.paragraph.ept_cta.field_ept_title\";i:6;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LbUDjHCE5jPK-SF4gEbg6BwzdKjd1y4Wm5lHH77LQHE\";}s:2:\"id\";s:25:\"paragraph.ept_cta.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:26:\"field_ept_cta_column_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_cta_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_cta_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_hero.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2727e08a-658f-4ab5-b47b-287082974eca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";i:1;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";i:2;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";i:3;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";i:4;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";i:5;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";i:6;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";i:7;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RyJFBZtpPZyel78RpfsF1AiH8hwBQOOxLrAmCsQUA3E\";}s:2:\"id\";s:26:\"paragraph.ept_hero.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:27:\"field_ept_hero_column_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_hero_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:26:\"field_ept_hero_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_hero_title_prefix\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a5054ddd-1cf1-49bf-bb8f-790f40e08130\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_image\";i:1;s:55:\"field.field.paragraph.ept_image.field_ept_image_caption\";i:2;s:52:\"field.field.paragraph.ept_image.field_ept_image_link\";i:3;s:50:\"field.field.paragraph.ept_image.field_ept_settings\";i:4;s:46:\"field.field.paragraph.ept_image.field_ept_text\";i:5;s:47:\"field.field.paragraph.ept_image.field_ept_title\";i:6;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DTOYjl8a1qPkDZ2tUSk7QmiHQ0xgbKAbv7qw0jY4LTE\";}s:2:\"id\";s:27:\"paragraph.ept_image.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:15:\"field_ept_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:23:\"field_ept_image_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_image_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_image_gallery.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"49052cac-09f9-471f-8cc0-d9c144baf2ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_image_gallery.field_ept_image_gallery\";i:1;s:58:\"field.field.paragraph.ept_image_gallery.field_ept_settings\";i:2;s:54:\"field.field.paragraph.ept_image_gallery.field_ept_text\";i:3;s:55:\"field.field.paragraph.ept_image_gallery.field_ept_title\";i:4;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"baNfcT8hwfXqGdk9GFr_Uo5DAZw65OmnpJIPGu7rwLU\";}s:2:\"id\";s:35:\"paragraph.ept_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_image_gallery\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:17:\"ept_image_gallery\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_micromodal.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2b90284a-5b66-4a1f-8feb-f7da7fba402f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_micromodal.field_ept_micromodal_title\";i:1;s:55:\"field.field.paragraph.ept_micromodal.field_ept_settings\";i:2;s:51:\"field.field.paragraph.ept_micromodal.field_ept_text\";i:3;s:52:\"field.field.paragraph.ept_micromodal.field_ept_title\";i:4;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3RH7OegTiWFWXapSfExaq4iTqsXp0J-FoDgKn3BLvug\";}s:2:\"id\";s:32:\"paragraph.ept_micromodal.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_micromodal_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_quote.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"772993d5-eed2-4b18-a6f6-28eb39e116b4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:54:\"field.field.paragraph.ept_quote.field_ept_quote_author\";i:1;s:53:\"field.field.paragraph.ept_quote.field_ept_quote_image\";i:2;s:50:\"field.field.paragraph.ept_quote.field_ept_settings\";i:3;s:46:\"field.field.paragraph.ept_quote.field_ept_text\";i:4;s:47:\"field.field.paragraph.ept_quote.field_ept_title\";i:5;s:27:\"image.style.ept_quote_image\";i:6;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ng1DAFgz9gNcE0pRgTjrcZTjwRmCqpVhuWZM-gi-D3o\";}s:2:\"id\";s:27:\"paragraph.ept_quote.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:22:\"field_ept_quote_author\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_quote_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:15:\"ept_quote_image\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slick_slider.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"febc7649-4ada-4466-aea7-1872bc394145\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_slick_slider.field_ept_settings\";i:1;s:61:\"field.field.paragraph.ept_slick_slider.field_ept_slick_slider\";i:2;s:53:\"field.field.paragraph.ept_slick_slider.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_slick_slider.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"D6f-Fc2NAzWU9GdDBRkUKUZ-OufpE3B1nGAAJQhgO04\";}s:2:\"id\";s:34:\"paragraph.ept_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ept_slick_slider\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slick_slider_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e906e660-3e2c-436c-9fb5-1dc3aaa2d1a9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:72:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";i:1;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";i:2;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";i:3;s:33:\"image.style.ept_slick_slider_card\";i:4;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Yb25ejThf9Zw1K_1U4jgPEu6CXiu0AbCJlD9g9Lcjm0\";}s:2:\"id\";s:39:\"paragraph.ept_slick_slider_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ept_slick_slider_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:21:\"ept_slick_slider_card\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_slick_slider_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_slick_slider_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slideshow.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"113fc4a1-1a78-4da6-b222-3a4cd08a0def\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:54:\"field.field.paragraph.ept_slideshow.field_ept_settings\";i:1;s:55:\"field.field.paragraph.ept_slideshow.field_ept_slideshow\";i:2;s:50:\"field.field.paragraph.ept_slideshow.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_slideshow.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KtOxRXjaqWh0JTHfCOLP6aQSiruy6TgLL8zYom1n_L4\";}s:2:\"id\";s:31:\"paragraph.ept_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_slideshow\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slideshow_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c452f408-f85b-4944-a31e-1bbef7fcda71\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link\";i:1;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide\";i:2;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text\";i:3;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title\";i:4;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zuevQDEEiEAdPhigrWbhLZc3nvEGuKwsXeWbIT6VtyM\";}s:2:\"id\";s:36:\"paragraph.ept_slideshow_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_slideshow_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_slideshow_slide\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_slideshow_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_slideshow_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_stats.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"ec282fce-d81d-4383-9a77-3fb87be08553\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_stats.field_ept_settings\";i:1;s:47:\"field.field.paragraph.ept_stats.field_ept_stats\";i:2;s:46:\"field.field.paragraph.ept_stats.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_stats.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-R8qIR4yTFENexKPFy8GHPre8URllz01mM6cb0sIz_0\";}s:2:\"id\";s:27:\"paragraph.ept_stats.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_stats\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_stats_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8e1a5df7-4ec6-40ba-b5be-4d5d2b6f489f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_image\";i:1;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_link\";i:2;s:64:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_number\";i:3;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vJgoosAvhgFcK-LHabcOoXx3QTmG9TF7iqpHAxeUkkc\";}s:2:\"id\";s:32:\"paragraph.ept_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_stats_item_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_stats_item_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_stats_item_number\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_stats_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tabs.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"7da9a817-79f8-4bec-add7-e39bb0ba78c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:49:\"field.field.paragraph.ept_tabs.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_tabs.field_ept_tabs\";i:2;s:45:\"field.field.paragraph.ept_tabs.field_ept_text\";i:3;s:46:\"field.field.paragraph.ept_tabs.field_ept_title\";i:4;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VYYeF4flc_QYohV2FJfKsdYisMArL-b2-hY7et7ry_M\";}s:2:\"id\";s:26:\"paragraph.ept_tabs.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_tabs\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tabs_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"b90a3de2-2933-49e5-8726-03f0e73085fa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_block\";i:1;s:57:\"field.field.paragraph.ept_tabs_item.field_ept_tab_content\";i:2;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_page\";i:3;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_text\";i:4;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_title\";i:5;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_views\";i:6;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vm2AN2TrjyhMIpH3DLfldicz1qb1mSF0ykCyMxw9bmE\";}s:2:\"id\";s:31:\"paragraph.ept_tabs_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:19:\"field_ept_tab_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_tab_page\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_tab_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_tab_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_tab_views\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:21:\"field_ept_tab_content\";b:1;}}'),('','core.entity_view_display.paragraph.ept_text.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e06c8535-7973-44b5-8144-18baa167f488\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:49:\"field.field.paragraph.ept_text.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_text.field_ept_text\";i:2;s:46:\"field.field.paragraph.ept_text.field_ept_title\";i:3;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzCv1OpNW04_O7sRxZPIlh1_rvwxOvMIGOWK43XgmKg\";}s:2:\"id\";s:26:\"paragraph.ept_text.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tiles.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"153a53c8-5121-4586-9a2d-42dbb61c9965\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_tiles.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_tiles.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_tiles.field_ept_tiles\";i:3;s:47:\"field.field.paragraph.ept_tiles.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VFAqZYQk4Jf5mJN7H6sw-zAemRX1LtPDXAfRw5U6hjM\";}s:2:\"id\";s:27:\"paragraph.ept_tiles.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_tiles\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tiles_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"1e04e293-6847-44fd-816b-d0cafeb9bfb1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ept_tiles_item.field_ept_clickable_tile\";i:1;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_image\";i:2;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_link\";i:3;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_text\";i:4;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sd_Fv-1q9ZOgwmZ0ePkn9oBIqVaWhe4K8YL6VyUVSfE\";}s:2:\"id\";s:32:\"paragraph.ept_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ept_clickable_tile\";a:6:{s:4:\"type\";s:7:\"boolean\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:6:\"format\";s:7:\"default\";s:19:\"format_custom_false\";s:0:\"\";s:18:\"format_custom_true\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_tiles_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_tiles_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_tiles_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_tiles_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"4c097cad-2585-405b-86e6-5effe6d6f443\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_video.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_video.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_video.field_ept_title\";i:3;s:47:\"field.field.paragraph.ept_video.field_ept_video\";i:4;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XvS78XJNKdR81VHVUzs1PUhNwNWlMocd77YwIDcgRH0\";}s:2:\"id\";s:27:\"paragraph.ept_video.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_video\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:9:\"ept_video\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video_and_image_gallery.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"dfadbabc-626b-46a2-a063-3f65ad0c2b45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_settings\";i:1;s:64:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_text\";i:2;s:65:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_title\";i:3;s:77:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";i:4;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5dsKiTuP8c7klYOHnY_OBorbQ_YaHWXu4P_cKhDDKZE\";}s:2:\"id\";s:45:\"paragraph.ept_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_videos_and_images\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video_and_image_gallery_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"273d4d81-bc41-43e6-bbfd-346c986e0c86\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";i:1;s:82:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PB75oeGkZ1ajIp-S4ceLC_lub5_nmn_WU0f_7wBeOag\";}s:2:\"id\";s:50:\"paragraph.ept_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:22:\"field_ept_gallery_item\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_gallery_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_views.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d0875a9d-cb50-4731-ac2a-fb25c1858dae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_views.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_views.field_ept_title\";i:3;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";i:4;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HwJ8zDH-LTdrQbXrPD8P-vvx1n91p-8JocGN840XNUw\";}s:2:\"id\";s:27:\"paragraph.ept_views.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_views_view\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_webform.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"3c020353-d472-46d4-83e7-cc933ac7aa20\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:52:\"field.field.paragraph.ept_webform.field_ept_settings\";i:1;s:48:\"field.field.paragraph.ept_webform.field_ept_text\";i:2;s:49:\"field.field.paragraph.ept_webform.field_ept_title\";i:3;s:56:\"field.field.paragraph.ept_webform.field_ept_webform_form\";i:4;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qKreyfEKRanXLODEvzCYx-MTnJJqvunQWhAesISW900\";}s:2:\"id\";s:29:\"paragraph.ept_webform.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:22:\"field_ept_webform_form\";a:6:{s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:13:\"source_entity\";b:1;s:4:\"lazy\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_webform_popup.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2c82ecbc-46e1-498d-9678-2831bf2e17b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:58:\"field.field.paragraph.ept_webform_popup.field_ept_settings\";i:1;s:54:\"field.field.paragraph.ept_webform_popup.field_ept_text\";i:2;s:55:\"field.field.paragraph.ept_webform_popup.field_ept_title\";i:3;s:68:\"field.field.paragraph.ept_webform_popup.field_ept_webform_popup_form\";i:4;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"efbmchjdWgSaw7vpwBbIHKqkWA24YS9DUj9b-5P2jgY\";}s:2:\"id\";s:35:\"paragraph.ept_webform_popup.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:28:\"field_ept_webform_popup_form\";a:6:{s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:2:{s:13:\"source_entity\";b:1;s:4:\"lazy\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.user.user.compact',_binary 'a:11:{s:4:\"uuid\";s:36:\"fd378f17-2b7e-4025-89fa-c56cabc7bab2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:34:\"core.entity_view_mode.user.compact\";i:1;s:34:\"field.field.user.user.user_picture\";i:2;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"00zr_RBdTjPjBGITD3h4c1ESQZimjdVCcHGt1trLqIY\";}s:2:\"id\";s:17:\"user.user.compact\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"compact\";s:7:\"content\";a:1:{s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:10:\"member_for\";b:1;}}'),('','core.entity_view_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"afa0542b-6646-4a58-8063-b778fe6b3423\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mZLyuWM9CQx2ZJVqFGSbzgFnHzudVbHBYmdU256A5Wk\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:10:\"member_for\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_mode.block_content.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"3e515c12-bfb7-4a38-9360-e1bebd522e14\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q7yUUYeRLByl-MCGveKKF_KhAtNICLCMJuKWfugCvso\";}s:2:\"id\";s:18:\"block_content.full\";s:5:\"label\";s:4:\"Full\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.comment.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"aaef918d-7b8e-4ea0-822a-44703c28e61c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N4mUjXpPckUkVRY1PbKw4GGoL1i2ECU7PL3EreiKStk\";}s:2:\"id\";s:12:\"comment.full\";s:5:\"label\";s:12:\"Full comment\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:7:\"comment\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_image_gallery',_binary 'a:10:{s:4:\"uuid\";s:36:\"c2742453-7e21-4da9-b647-07ef5aca9cf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hrWZ2by9y8V27Hv_3EBEgSBPp_2-kB9fizZj-DLVRcQ\";}s:2:\"id\";s:23:\"media.ept_image_gallery\";s:5:\"label\";s:17:\"EPT Image Gallery\";s:11:\"description\";N;s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_video',_binary 'a:10:{s:4:\"uuid\";s:36:\"8ae8b19f-547b-42bd-9d8f-a88c05759d47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0wiLx1gaRcymNOKRYsVEppFtOWUHrgVQsi6qUlIr_TM\";}s:2:\"id\";s:15:\"media.ept_video\";s:5:\"label\";s:9:\"EPT Video\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_video_and_image_gallery_item',_binary 'a:10:{s:4:\"uuid\";s:36:\"56447995-bbf0-4a46-b361-7337f6962da6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QIGappKnnavEIRi1GzZ_dSeZaYoyiLSX-hOaXrOHbz8\";}s:2:\"id\";s:38:\"media.ept_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EPT Video and Image gallery item\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"976815c3-f2f0-4a48-82b3-fb4ee2924c88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dTfAUHooYV0uOVPO3saGpgv-c5PppJXDwxvwRTJOycM\";}s:2:\"id\";s:10:\"media.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.media_library',_binary 'a:10:{s:4:\"uuid\";s:36:\"4578cd26-ab79-41fc-b999-3224d7b96b78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"3096aebe-dabe-4849-b718-4be67ed1e0a2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QJ2aZ1xfVf59aq6Pz5X7fyUOa2HxuCoTwQ_RQjoulAU\";}s:2:\"id\";s:9:\"node.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.rss',_binary 'a:10:{s:4:\"uuid\";s:36:\"562fdf9e-431f-4436-87cc-5edcb21506bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l8fiAFE3Kng_6bhLlUDnVTkTDzXWxzYFrCWTrngVXEA\";}s:2:\"id\";s:8:\"node.rss\";s:5:\"label\";s:3:\"RSS\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_index',_binary 'a:10:{s:4:\"uuid\";s:36:\"edab19fa-a328-4f2e-a4a2-bce49808300d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_A0T3aTqGDwLyvoH7wLps-0PM--RHlS8UsiJe_Ac64\";}s:2:\"id\";s:17:\"node.search_index\";s:5:\"label\";s:12:\"Search index\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_result',_binary 'a:10:{s:4:\"uuid\";s:36:\"ac6b99d6-0ed0-46ea-97e8-2b17a00adab0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d8wBEm7XvJ6H3S0IneDD9PfTBklPIH7GMpxElVemPf8\";}s:2:\"id\";s:18:\"node.search_result\";s:5:\"label\";s:32:\"Search result highlighting input\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.teaser',_binary 'a:10:{s:4:\"uuid\";s:36:\"5eb23a5d-001b-4f18-b772-c45ec412d4a1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KgGJDZFpMaz_8bTv6fN1bXS3Qi5LWmRJI9R53kEGsNQ\";}s:2:\"id\";s:11:\"node.teaser\";s:5:\"label\";s:6:\"Teaser\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.paragraph.preview',_binary 'a:10:{s:4:\"uuid\";s:36:\"298a8e9e-ea9f-462a-9e62-03ff202ebda4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"h3BeHVei4Lnyqbkao3YiF4KqoY-DhRvUNfEgKG8Rgjg\";}s:2:\"id\";s:17:\"paragraph.preview\";s:5:\"label\";s:7:\"Preview\";s:11:\"description\";N;s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.paragraph.slider',_binary 'a:9:{s:4:\"uuid\";s:36:\"f0967983-7199-4bf7-8047-72fb6a840ca0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:2:\"id\";s:16:\"paragraph.slider\";s:5:\"label\";s:6:\"slider\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.taxonomy_term.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"c1d7c975-f7cc-4e65-a0b5-d7a0b84e6fed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iukUENpf8CFvjZbGGacKX_Ges0-lU9z6zvsd32P6kbo\";}s:2:\"id\";s:18:\"taxonomy_term.full\";s:5:\"label\";s:18:\"Taxonomy term page\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.compact',_binary 'a:10:{s:4:\"uuid\";s:36:\"3267d362-0cde-4190-8a4e-f368fdab39d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TtD7OuGskOsQfoGyxXkrdtllBpR37J19d5BMQDZWJgA\";}s:2:\"id\";s:12:\"user.compact\";s:5:\"label\";s:7:\"Compact\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"18890f85-c8b4-4c37-a805-81e116c96c33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZbXunWS_xAvMZXFfinyvClDAb_RCVLt7gAzE3v16E-Q\";}s:2:\"id\";s:9:\"user.full\";s:5:\"label\";s:12:\"User account\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.extension',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GIX5Esnc_umpXUBj4IIocRX7Mt5fPhm4AgXfE3E56E\";}s:6:\"module\";a:110:{s:13:\"admin_toolbar\";i:0;s:19:\"admin_toolbar_tools\";i:0;s:18:\"announcements_feed\";i:0;s:14:\"automated_cron\";i:0;s:22:\"better_exposed_filters\";i:0;s:8:\"big_pipe\";i:0;s:5:\"block\";i:0;s:13:\"block_content\";i:0;s:11:\"block_field\";i:0;s:10:\"breakpoint\";i:0;s:9:\"ckeditor5\";i:0;s:21:\"ckeditor5_plugin_pack\";i:0;s:32:\"ckeditor5_plugin_pack_auto_image\";i:0;s:38:\"ckeditor5_plugin_pack_find_and_replace\";i:0;s:26:\"ckeditor5_plugin_pack_font\";i:0;s:31:\"ckeditor5_plugin_pack_highlight\";i:0;s:34:\"ckeditor5_plugin_pack_indent_block\";i:0;s:37:\"ckeditor5_plugin_pack_link_attributes\";i:0;s:32:\"ckeditor5_plugin_pack_page_break\";i:0;s:32:\"ckeditor5_plugin_pack_select_all\";i:0;s:31:\"ckeditor5_plugin_pack_templates\";i:0;s:41:\"ckeditor5_plugin_pack_text_transformation\";i:0;s:40:\"ckeditor5_plugin_pack_todo_document_list\";i:0;s:37:\"ckeditor5_premium_features_fullscreen\";i:0;s:7:\"comment\";i:0;s:6:\"config\";i:0;s:7:\"contact\";i:0;s:10:\"contextual\";i:0;s:8:\"datetime\";i:0;s:5:\"dblog\";i:0;s:18:\"dynamic_page_cache\";i:0;s:6:\"editor\";i:0;s:26:\"entity_reference_revisions\";i:0;s:13:\"ept_accordion\";i:0;s:16:\"ept_basic_button\";i:0;s:9:\"ept_block\";i:0;s:20:\"ept_bootstrap_button\";i:0;s:12:\"ept_carousel\";i:0;s:11:\"ept_columns\";i:0;s:8:\"ept_core\";i:0;s:19:\"ept_core_starterkit\";i:0;s:13:\"ept_countdown\";i:0;s:11:\"ept_counter\";i:0;s:7:\"ept_cta\";i:0;s:8:\"ept_hero\";i:0;s:9:\"ept_image\";i:0;s:17:\"ept_image_gallery\";i:0;s:14:\"ept_micromodal\";i:0;s:9:\"ept_quote\";i:0;s:16:\"ept_slick_slider\";i:0;s:13:\"ept_slideshow\";i:0;s:9:\"ept_stats\";i:0;s:8:\"ept_tabs\";i:0;s:8:\"ept_text\";i:0;s:9:\"ept_tiles\";i:0;s:9:\"ept_video\";i:0;s:27:\"ept_video_and_image_gallery\";i:0;s:9:\"ept_views\";i:0;s:11:\"ept_webform\";i:0;s:17:\"ept_webform_popup\";i:0;s:5:\"field\";i:0;s:11:\"field_group\";i:0;s:8:\"field_ui\";i:0;s:4:\"file\";i:0;s:8:\"file_mdm\";i:0;s:13:\"file_mdm_exif\";i:0;s:13:\"file_mdm_font\";i:0;s:6:\"filter\";i:0;s:11:\"gin_toolbar\";i:0;s:9:\"glightbox\";i:0;s:21:\"glightbox_media_video\";i:0;s:4:\"help\";i:0;s:7:\"history\";i:0;s:5:\"image\";i:0;s:13:\"image_effects\";i:0;s:9:\"jquery_ui\";i:0;s:19:\"jquery_ui_accordion\";i:0;s:14:\"jquery_ui_tabs\";i:0;s:16:\"layout_discovery\";i:0;s:17:\"layout_paragraphs\";i:0;s:4:\"link\";i:0;s:15:\"link_attributes\";i:0;s:33:\"link_attributes_menu_link_content\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:18:\"media_library_edit\";i:0;s:26:\"media_library_form_element\";i:0;s:17:\"menu_link_content\";i:0;s:7:\"menu_ui\";i:0;s:4:\"node\";i:0;s:7:\"options\";i:0;s:10:\"page_cache\";i:0;s:4:\"path\";i:0;s:10:\"path_alias\";i:0;s:8:\"shortcut\";i:0;s:6:\"system\";i:0;s:8:\"taxonomy\";i:0;s:11:\"tb_megamenu\";i:0;s:4:\"text\";i:0;s:7:\"toolbar\";i:0;s:10:\"twig_tweak\";i:0;s:6:\"update\";i:0;s:4:\"user\";i:0;s:8:\"views_ui\";i:0;s:17:\"views_year_filter\";i:0;s:14:\"viewsreference\";i:0;s:7:\"webform\";i:0;s:5:\"views\";i:10;s:10:\"paragraphs\";i:11;s:4:\"fast\";i:1000;}s:5:\"theme\";a:5:{s:7:\"olivero\";i:0;s:5:\"claro\";i:0;s:3:\"gin\";i:0;s:7:\"stable9\";i:0;s:9:\"ept_light\";i:0;}s:7:\"profile\";s:4:\"fast\";}'),('','core.menu.static_menu_link_overrides',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CXhei_vpaZk-3f_Mj2cH0YmpK-ZpKHoSzVA3yZrDq0g\";}s:11:\"definitions\";a:4:{s:18:\"contact__site_page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:6:\"footer\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-50;}s:20:\"standard__front_page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-50;}s:10:\"user__page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:7:\"account\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-10;}s:12:\"user__logout\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:7:\"account\";s:6:\"parent\";s:0:\"\";s:6:\"weight\";i:10;s:8:\"expanded\";b:0;}}}'),('','dblog.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e883aGsrt1wFrsydlYU584PZONCSfRy0DtkZ9KzHb58\";}s:9:\"row_limit\";i:1000;}'),('','editor.editor.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"de26b70d-0b5e-4129-a929-f1de8a455f1b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qi2tIe-L97EutlMmhEvhsNxZOpOoA-RH82c4BQb5n4A\";}s:6:\"format\";s:10:\"basic_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:15:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:1:\"|\";i:3;s:4:\"link\";i:4;s:1:\"|\";i:5;s:12:\"bulletedList\";i:6;s:12:\"numberedList\";i:7;s:1:\"|\";i:8;s:10:\"blockQuote\";i:9;s:17:\"drupalInsertImage\";i:10;s:1:\"|\";i:11;s:7:\"heading\";i:12;s:4:\"code\";i:13;s:1:\"|\";i:14;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:4:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:0;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:13:{i:0;s:6:\"<cite>\";i:1;s:4:\"<dl>\";i:2;s:4:\"<dt>\";i:3;s:4:\"<dd>\";i:4;s:12:\"<a hreflang>\";i:5;s:17:\"<blockquote cite>\";i:6;s:9:\"<ul type>\";i:7;s:9:\"<ol type>\";i:8;s:7:\"<h2 id>\";i:9;s:7:\"<h3 id>\";i:10;s:7:\"<h4 id>\";i:11;s:7:\"<h5 id>\";i:12;s:7:\"<h6 id>\";}}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','editor.editor.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"5b65cbab-6e9a-450e-a54e-4c334c4ca75d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"filter.format.full_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lurcn8yf33g3Dkzdc55cTfJa9salGp9ytSYyG1s7QMI\";}s:6:\"format\";s:9:\"full_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:44:{i:0;s:4:\"undo\";i:1;s:4:\"redo\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:13:\"strikethrough\";i:5;s:9:\"underline\";i:6;s:11:\"superscript\";i:7;s:9:\"subscript\";i:8;s:12:\"removeFormat\";i:9;s:1:\"|\";i:10;s:4:\"link\";i:11;s:1:\"|\";i:12;s:5:\"style\";i:13;s:9:\"fontColor\";i:14;s:19:\"fontBackgroundColor\";i:15;s:9:\"highlight\";i:16;s:10:\"fontFamily\";i:17;s:8:\"fontSize\";i:18;s:1:\"-\";i:19;s:12:\"bulletedList\";i:20;s:12:\"numberedList\";i:21;s:6:\"indent\";i:22;s:7:\"outdent\";i:23;s:9:\"alignment\";i:24;s:1:\"|\";i:25;s:14:\"insertTemplate\";i:26;s:4:\"code\";i:27;s:10:\"blockQuote\";i:28;s:17:\"drupalInsertImage\";i:29;s:11:\"drupalMedia\";i:30;s:11:\"insertTable\";i:31;s:14:\"horizontalLine\";i:32;s:1:\"|\";i:33;s:7:\"heading\";i:34;s:14:\"findAndReplace\";i:35;s:1:\"-\";i:36;s:10:\"showBlocks\";i:37;s:17:\"specialCharacters\";i:38;s:9:\"codeBlock\";i:39;s:13:\"sourceEditing\";i:40;s:1:\"|\";i:41;s:9:\"pageBreak\";i:42;s:9:\"selectAll\";i:43;s:10:\"fullScreen\";}}s:7:\"plugins\";a:17:{s:19:\"ckeditor5_alignment\";a:1:{s:18:\"enabled_alignments\";a:4:{i:0;s:6:\"center\";i:1;s:7:\"justify\";i:2;s:4:\"left\";i:3;s:5:\"right\";}}s:19:\"ckeditor5_codeBlock\";a:1:{s:9:\"languages\";a:14:{i:0;a:2:{s:5:\"label\";s:10:\"Plain text\";s:8:\"language\";s:9:\"plaintext\";}i:1;a:2:{s:5:\"label\";s:1:\"C\";s:8:\"language\";s:1:\"c\";}i:2;a:2:{s:5:\"label\";s:2:\"C#\";s:8:\"language\";s:2:\"cs\";}i:3;a:2:{s:5:\"label\";s:3:\"C++\";s:8:\"language\";s:3:\"cpp\";}i:4;a:2:{s:5:\"label\";s:3:\"CSS\";s:8:\"language\";s:3:\"css\";}i:5;a:2:{s:5:\"label\";s:4:\"Diff\";s:8:\"language\";s:4:\"diff\";}i:6;a:2:{s:5:\"label\";s:4:\"HTML\";s:8:\"language\";s:4:\"html\";}i:7;a:2:{s:5:\"label\";s:4:\"Java\";s:8:\"language\";s:4:\"java\";}i:8;a:2:{s:5:\"label\";s:10:\"JavaScript\";s:8:\"language\";s:10:\"javascript\";}i:9;a:2:{s:5:\"label\";s:3:\"PHP\";s:8:\"language\";s:3:\"php\";}i:10;a:2:{s:5:\"label\";s:6:\"Python\";s:8:\"language\";s:6:\"python\";}i:11;a:2:{s:5:\"label\";s:4:\"Ruby\";s:8:\"language\";s:4:\"ruby\";}i:12;a:2:{s:5:\"label\";s:10:\"TypeScript\";s:8:\"language\";s:10:\"typescript\";}i:13;a:2:{s:5:\"label\";s:3:\"XML\";s:8:\"language\";s:3:\"xml\";}}}s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:6:{i:0;s:8:\"heading1\";i:1;s:8:\"heading2\";i:2;s:8:\"heading3\";i:3;s:8:\"heading4\";i:4;s:8:\"heading5\";i:5;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:44:\"ckeditor5_plugin_pack_auto_image__auto_image\";a:1:{s:7:\"enabled\";b:0;}s:56:\"ckeditor5_plugin_pack_find_and_replace__find_and_replace\";a:1:{s:7:\"ui_type\";s:6:\"dialog\";}s:38:\"ckeditor5_plugin_pack_font__font_color\";a:2:{s:6:\"colors\";a:0:{}s:18:\"use_default_colors\";b:1;}s:39:\"ckeditor5_plugin_pack_font__font_family\";a:1:{s:7:\"options\";s:0:\"\";}s:37:\"ckeditor5_plugin_pack_font__font_size\";a:1:{s:7:\"options\";s:0:\"\";}s:42:\"ckeditor5_plugin_pack_highlight__highlight\";a:2:{s:7:\"options\";a:0:{}s:19:\"use_default_markers\";b:1;}s:48:\"ckeditor5_plugin_pack_indent_block__indent_block\";a:1:{s:7:\"enabled\";b:1;}s:54:\"ckeditor5_plugin_pack_link_attributes__link_attributes\";a:1:{s:10:\"attributes\";a:1:{i:0;a:2:{s:5:\"label\";s:15:\"Link Attributes\";s:10:\"attributes\";s:27:\"target|_blank\r\nrel|nofollow\";}}}s:62:\"ckeditor5_plugin_pack_text_transformation__text_transformation\";a:4:{s:7:\"enabled\";b:1;s:21:\"extra_transformations\";s:0:\"\";s:27:\"extra_regex_transformations\";a:0:{}s:6:\"groups\";a:5:{s:10:\"typography\";a:2:{s:15:\"transformations\";a:3:{s:8:\"ellipsis\";a:1:{s:7:\"enabled\";i:1;}s:6:\"enDash\";a:1:{s:7:\"enabled\";i:1;}s:6:\"emDash\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:6:\"quotes\";a:2:{s:15:\"transformations\";a:2:{s:13:\"quotesPrimary\";a:1:{s:7:\"enabled\";i:1;}s:15:\"quotesSecondary\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:7:\"symbols\";a:2:{s:15:\"transformations\";a:3:{s:9:\"trademark\";a:1:{s:7:\"enabled\";i:1;}s:19:\"registeredTrademark\";a:1:{s:7:\"enabled\";i:1;}s:9:\"copyright\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:12:\"mathematical\";a:2:{s:15:\"transformations\";a:10:{s:7:\"oneHalf\";a:1:{s:7:\"enabled\";i:1;}s:8:\"oneThird\";a:1:{s:7:\"enabled\";i:1;}s:9:\"twoThirds\";a:1:{s:7:\"enabled\";i:1;}s:9:\"oneFourth\";a:1:{s:7:\"enabled\";i:1;}s:13:\"threeQuarters\";a:1:{s:7:\"enabled\";i:1;}s:15:\"lessThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:18:\"greaterThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:8:\"notEqual\";a:1:{s:7:\"enabled\";i:1;}s:9:\"arrowLeft\";a:1:{s:7:\"enabled\";i:1;}s:10:\"arrowRight\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:4:\"misc\";a:2:{s:15:\"transformations\";a:4:{s:17:\"quotesPrimaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:19:\"quotesSecondaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:15:\"quotesPrimaryPl\";a:1:{s:7:\"enabled\";i:0;}s:17:\"quotesSecondaryPl\";a:1:{s:7:\"enabled\";i:0;}}s:7:\"enabled\";i:0;}}}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}s:15:\"ckeditor5_style\";a:1:{s:6:\"styles\";a:2:{i:0;a:2:{s:5:\"label\";s:12:\"Title prefix\";s:7:\"element\";s:27:\"<span class=\"title-prefix\">\";}i:1;a:2:{s:5:\"label\";s:10:\"White text\";s:7:\"element\";s:25:\"<span class=\"white-text\">\";}}}s:11:\"media_media\";a:1:{s:24:\"allow_view_mode_override\";b:0;}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','editor.editor.webform_default',_binary 'a:8:{s:4:\"uuid\";s:36:\"a5122dd4-68d5-4282-a77b-0ad04cf12b8a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:6:\"format\";s:15:\"webform_default\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:20:{i:0;s:7:\"heading\";i:1;s:1:\"|\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:9:\"subscript\";i:5;s:11:\"superscript\";i:6;s:1:\"|\";i:7;s:17:\"specialCharacters\";i:8;s:1:\"|\";i:9;s:12:\"numberedList\";i:10;s:12:\"bulletedList\";i:11;s:1:\"|\";i:12;s:4:\"link\";i:13;s:1:\"|\";i:14;s:6:\"indent\";i:15;s:7:\"outdent\";i:16;s:1:\"|\";i:17;s:10:\"blockQuote\";i:18;s:1:\"|\";i:19;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:3:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}}}s:12:\"image_upload\";a:1:{s:6:\"status\";b:0;}}'),('','ept_core.settings',_binary 'a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYlqpNn_5W04WVeLB4bYW404IYbkVrx7N9zxzBAJ-Io\";}s:26:\"ept_core_mobile_breakpoint\";s:3:\"640\";s:26:\"ept_core_tablet_breakpoint\";s:4:\"1020\";s:27:\"ept_core_desktop_breakpoint\";s:4:\"1320\";s:22:\"ept_core_xxsmall_width\";s:3:\"480\";s:21:\"ept_core_xsmall_width\";s:3:\"640\";s:20:\"ept_core_small_width\";s:3:\"768\";s:22:\"ept_core_default_width\";s:3:\"960\";s:20:\"ept_core_large_width\";s:4:\"1100\";s:21:\"ept_core_xlarge_width\";s:4:\"1320\";s:22:\"ept_core_xxlarge_width\";s:4:\"1600\";s:25:\"ept_core_background_color\";s:7:\"#0d77b5\";}'),('','field.field.block_content.basic.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"8fecb003-ae49-44e1-ac0e-aeaebabeca06\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j00Gfs9AFqwK4x9RIsISLbPO7vA12psPR4s60wOIwQo\";}s:2:\"id\";s:24:\"block_content.basic.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.comment.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"2ea8eb6b-de2b-4de9-ac7c-5703ce8bc44f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:34:\"field.storage.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"62rlTOx3sPVrYhBnSBHZStXwiO02v1UpHSMrhWDsuG8\";}s:2:\"id\";s:28:\"comment.comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:5:\"label\";s:7:\"Comment\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.media.audio.field_media_audio_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"cccc3ad2-8bd3-4a0b-8777-2510ebee041b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UlZPIbHcLyNqGY5bvydCTijGcKDmwn4Fo8oYZT85wlk\";}s:2:\"id\";s:34:\"media.audio.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:5:\"label\";s:10:\"Audio file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:11:\"mp3 wav aac\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.media.document.field_media_document',_binary 'a:17:{s:4:\"uuid\";s:36:\"90b23d65-43c8-4f09-8924-c0be432e4510\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:40:\"field.storage.media.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DY5HtJTxUjFRGU_PaY6ifo2nhR-nAZ0y0s6kLmUbv5g\";}s:2:\"id\";s:35:\"media.document.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:96:\"txt rtf doc docx ppt pptx xls xlsx pdf odf odg odp ods odt fodt fods fodp fodg key numbers pages\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.media.image.field_media_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"410f42b6-e143-4eb8-9c88-c13fd9c4c17f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:37:\"field.storage.media.field_media_image\";i:1;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7CkVOgjDXiN26Fm2hniNei-XPK3iuZTlcBGqreTbJ0\";}s:2:\"id\";s:29:\"media.image.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.field.media.remote_video.field_media_oembed_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"4ed02114-671f-4880-bd68-143fe1b70c33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.media.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Eo4HHenV5iZat_kEWgr_wydD3TgwURMCzwt-7qIEyoM\";}s:2:\"id\";s:43:\"media.remote_video.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:5:\"label\";s:9:\"Video URL\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),('','field.field.media.video.field_media_video_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"0b1a6314-b982-4d68-89cc-0362ac441239\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6kMMjmk2r_csGQ52qI9BUaO8r_oAzNLbxlclaj-JlDQ\";}s:2:\"id\";s:34:\"media.video.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:5:\"label\";s:10:\"Video file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:3:\"mp4\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.node.article.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"ac9343a5-d157-4641-93f9-1b5bd7d0980f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Wxs1LseZ8JsNwD9uJVIbzZqG35yQXN8Eo1Hub6NMuI\";}s:2:\"id\";s:17:\"node.article.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.article.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"6c45f2f3-d271-4c13-b678-675fb9cbc261\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"field.storage.node.field_image\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j0riO_-77ZFWNLtj0iJ31HnohiNjdn8HUL86RueCF-M\";}s:2:\"id\";s:24:\"node.article.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.field.node.article.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"d3dcae7f-9494-4866-b051-d4817b208fd5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:29:\"field.storage.node.field_tags\";i:1;s:17:\"node.type.article\";i:2;s:24:\"taxonomy.vocabulary.tags\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QdUgf_beeoaPiyKorFv0q1fcJpWH_uZTqe_xoVJacrw\";}s:2:\"id\";s:23:\"node.article.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Tags\";s:11:\"description\";s:84:\"Enter a comma-separated list. For example: Amsterdam, Mexico City, \"Cleveland, Ohio\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:21:\"default:taxonomy_term\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.node.page.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"c7106e91-0b1d-44f0-82fc-584be35a29c2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KHu9I-pR4FnP79crRJ5gVD_1mKGSZcJsdIm9bn64iFg\";}s:2:\"id\";s:14:\"node.page.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.page.field_components',_binary 'a:16:{s:4:\"uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:27:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";i:25;s:38:\"paragraphs.paragraphs_type.ept_webform\";i:26;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:2:\"id\";s:26:\"node.page.field_components\";s:10:\"field_name\";s:16:\"field_components\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:10:\"Components\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:25:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:37:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:10:\"ept_bottle\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:0;}s:9:\"ept_cards\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:0;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:16:\"ept_super_slider\";a:2:{s:6:\"weight\";i:70;s:7:\"enabled\";b:1;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}s:11:\"ept_webform\";a:2:{s:6:\"weight\";i:73;s:7:\"enabled\";b:1;}s:17:\"ept_webform_popup\";a:2:{s:6:\"weight\";i:74;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_accordion.field_ept_accordion',_binary 'a:17:{s:4:\"uuid\";s:36:\"a6969ae3-e3c4-4adf-b115-07a5a0172b95\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:43:\"field.storage.paragraph.field_ept_accordion\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gyYZiR8Di3nPWs-p1SHNRU9nboJcW5hom8i6mSecVtc\";}s:2:\"id\";s:43:\"paragraph.ept_accordion.field_ept_accordion\";s:10:\"field_name\";s:19:\"field_ept_accordion\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:8:\"Sections\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:21:\"ept_accordion_section\";s:21:\"ept_accordion_section\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:23;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_accordion.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"71eb6510-d311-4704-9d7a-147c6ba1fca0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dFTek-2-VjYGV96ffjrJqRnc7cP8oR-xd4f0hA8JlyA\";}s:2:\"id\";s:42:\"paragraph.ept_accordion.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_accordion.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"38a67ca0-85d7-4dee-8871-eef6909b89f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7ILR55bNJzar89h8OPnJx-IpC8TrZBRKYFxLOI1p73c\";}s:2:\"id\";s:38:\"paragraph.ept_accordion.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"fa75defe-e7d5-4782-bedf-3d3107b3a40f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-fStMIM_IiXT6N43R2XfdUDoqFS_sK8AUA-WvSHfcwo\";}s:2:\"id\";s:39:\"paragraph.ept_accordion.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion_section.field_ept_accordion_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"3f86759a-0926-49a9-a1b3-ebe22666f4d8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_accordion_text\";i:1;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3d4EpzZAObqkHVq5leB4wQ_vhii4h9OoUdsxw0lZgfg\";}s:2:\"id\";s:56:\"paragraph.ept_accordion_section.field_ept_accordion_text\";s:10:\"field_name\";s:24:\"field_ept_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:5:\"label\";s:13:\"Text / Answer\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion_section.field_ept_accordion_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"5fd2a01d-4924-4824-af89-5638dcb01e07\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_accordion_title\";i:1;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1GJAw9hJcCS1kRz9iAwG1qqyJ5XL97F--Irgw6Ns0GY\";}s:2:\"id\";s:57:\"paragraph.ept_accordion_section.field_ept_accordion_title\";s:10:\"field_name\";s:25:\"field_ept_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:5:\"label\";s:16:\"Title / Question\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_basic_button.field_ept_basic_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"d95cc73b-b5b3-45bb-ab62-c70e8411b8e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_basic_button_link\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SCjKiIWEbPAkzMucyajmerVFBDbaKtjD3HukL942flo\";}s:2:\"id\";s:54:\"paragraph.ept_basic_button.field_ept_basic_button_link\";s:10:\"field_name\";s:27:\"field_ept_basic_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:11:\"Button Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_basic_button.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"0369fd76-8a03-4f51-98c8-2662289d77b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JzXRiuHUYaRtlmk8K0WT_Yp1_iUpogPj6XDbLmZ_hVA\";}s:2:\"id\";s:45:\"paragraph.ept_basic_button.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:18:\"Paragraph settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_basic_button.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"484e5ed3-f463-4d7b-b27a-25b553c3a82b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U4JGLZ-4C6DwE5xpnkLU2Ckqm-NdvOTgwe9gAMlW_Ls\";}s:2:\"id\";s:41:\"paragraph.ept_basic_button.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_basic_button.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"d5f47d43-c851-4f4d-a9bf-282937a2eb88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q6Cswt1AxNHLXzTfwWiWRP4dJwyasulFfWasATFZdrU\";}s:2:\"id\";s:42:\"paragraph.ept_basic_button.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_block.field_ept_block_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"9e49c287-a8e3-4673-b781-6db3e163c7f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_block_block\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Y5C1tDwIza9l7G1NAqWPtZndTwsI1uclqq7mOTUqmyg\";}s:2:\"id\";s:41:\"paragraph.ept_block.field_ept_block_block\";s:10:\"field_name\";s:21:\"field_ept_block_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:5:\"Block\";s:11:\"description\";s:25:\"Add existing Drupal Block\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:11:{s:5:\"Block\";s:5:\"Block\";s:4:\"core\";s:4:\"core\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:5:\"Menus\";s:5:\"Menus\";s:6:\"System\";s:6:\"System\";s:4:\"User\";s:4:\"User\";s:5:\"Views\";s:5:\"Views\";s:13:\"Announcements\";s:1:\"0\";s:12:\"TB Mega Menu\";s:1:\"0\";}}}s:10:\"field_type\";s:11:\"block_field\";}'),('','field.field.paragraph.ept_block.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"2d995ad8-7b72-4241-8c5b-bfb64c7a936a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o3fZQjNNObe_TkbgxMWmav7VePiJKizuqf7wQm1RqgQ\";}s:2:\"id\";s:38:\"paragraph.ept_block.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_block.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"440982f1-1d49-45ce-856f-cb3b95954c65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AhoRfTUTx6zdLkKC-tHQ_pZVKgtpGN452BRXc__PSgM\";}s:2:\"id\";s:34:\"paragraph.ept_block.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_block.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b40d62dd-ee5a-44cf-9983-6bbbd7667b68\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LoHBLk0u3sVMSi5c2wsK0PWLWQ1aM4uvkXBsu3odiYk\";}s:2:\"id\";s:35:\"paragraph.ept_block.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"28952958-350e-4fa8-b1bf-0526c52b982e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.storage.paragraph.field_ept_bootstrap_button_link\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-csuiRgrTiYqGIjfvXfzBJvGlaY5drE5fp2a_BZjuo\";}s:2:\"id\";s:62:\"paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ept_bootstrap_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"97adadda-941e-43f5-8c16-c2a84adbb6a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9H_JnoEbVvGC1ew0GhZEnKhJOj78OfksYHFErUsrtVw\";}s:2:\"id\";s:49:\"paragraph.ept_bootstrap_button.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9d80d485-b1e2-4fbf-ad86-60acbbdd3d92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YeaGECTvxFfymsGgUGC0AO8Uap3cVB1SFUvwKCEoP0c\";}s:2:\"id\";s:45:\"paragraph.ept_bootstrap_button.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:14:\"Paragraph Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9626d4b-c719-4c6c-bc96-f92de310cf2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IbyiiWXl-WZPf_JAHHt9YHqt7GAEtb8FBXpeQ3OXG8c\";}s:2:\"id\";s:46:\"paragraph.ept_bootstrap_button.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:15:\"Paragraph Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cards.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"a49781a9-d084-428f-b05d-d1b72c5a9c45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_cards\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SkX5mX8p25AwshKMZm_SxrYzoYPxeFv6dyD6iUJRu34\";}s:2:\"id\";s:38:\"paragraph.ept_cards.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_cards\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_cards.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"8c000a0e-d859-4bdb-9ddc-1c1c48e64c4b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_cards\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fZdJ5UZao73ExrG3Ut3gVIIk4Q8GwHRPSK1esBanvxo\";}s:2:\"id\";s:34:\"paragraph.ept_cards.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_cards\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cards.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"49f52820-ba38-497e-b59f-d89788210ff0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_cards\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hK-8gL2S45XI7zt5CeNNubXJjtgF081aIF64y15B3QU\";}s:2:\"id\";s:35:\"paragraph.ept_cards.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_cards\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel.field_ept_carousel',_binary 'a:17:{s:4:\"uuid\";s:36:\"d7d805e1-ee4a-4aeb-87d9-e74edbe4f1e7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ept_carousel\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aXX70EioyFtKtGWUZXGbeNLyjZK-M_6xbjrznbKBxsQ\";}s:2:\"id\";s:41:\"paragraph.ept_carousel.field_ept_carousel\";s:10:\"field_name\";s:18:\"field_ept_carousel\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:8:\"Carousel\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:17:\"ept_carousel_item\";s:17:\"ept_carousel_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:31;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_carousel.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9905b685-324b-4f6a-8423-5973b3364a40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_IVLsSToXRuYcAqksQE6q0UQCw5J0ys7z54fIX3Prcg\";}s:2:\"id\";s:41:\"paragraph.ept_carousel.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_carousel.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"e61c2ef3-bfa8-4a34-aa69-9a530904c063\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T9eYBrQXk7NZSU8LgCIvtf9ldAkjSDaUsIlMZK1m5ks\";}s:2:\"id\";s:37:\"paragraph.ept_carousel.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0f3cce54-16b4-433a-a3d8-f66dceadfb5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NN8UIWMU2GbeEUny8ga4lRNGGKi0sRnscgZKNOBUJbU\";}s:2:\"id\";s:38:\"paragraph.ept_carousel.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel_item.field_ept_carousel_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"f1e8eab0-49cf-40c1-a0c3-1c7c52bbcf18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_carousel_caption\";i:1;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2da0GoNsm_uJyuQNbeEacFu5K_me_-2I4TTM-UpRlLk\";}s:2:\"id\";s:54:\"paragraph.ept_carousel_item.field_ept_carousel_caption\";s:10:\"field_name\";s:26:\"field_ept_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:5:\"label\";s:13:\"Slide caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel_item.field_ept_carousel_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"8a07cecc-6fab-4d81-8cda-096df1dc73ab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:48:\"field.storage.paragraph.field_ept_carousel_image\";i:1;s:16:\"media.type.image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1qmbDr08-JuyqmRroyYKRiBXHMWBHN8Q8K3o4KxjQW0\";}s:2:\"id\";s:52:\"paragraph.ept_carousel_item.field_ept_carousel_image\";s:10:\"field_name\";s:24:\"field_ept_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:5:\"label\";s:11:\"Slide image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_columns.field_ept_columns',_binary 'a:17:{s:4:\"uuid\";s:36:\"e3f4b834-b3d2-43cf-8914-8378ae9e9f82\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:27:{i:0;s:41:\"field.storage.paragraph.field_ept_columns\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:2;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:3;s:36:\"paragraphs.paragraphs_type.ept_block\";i:4;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:5;s:36:\"paragraphs.paragraphs_type.ept_cards\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";i:25;s:38:\"paragraphs.paragraphs_type.ept_webform\";i:26;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R6rkX-mPMiS67Fz1NUwV172q4Get3igbZ_JqWTdWxKU\";}s:2:\"id\";s:39:\"paragraph.ept_columns.field_ept_columns\";s:10:\"field_name\";s:17:\"field_ept_columns\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:7:\"Columns\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:26:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:9:\"ept_cards\";s:9:\"ept_cards\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:37:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:10:\"ept_bottle\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:9:\"ept_cards\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:0;}s:16:\"ept_super_slider\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:65;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:66;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:67;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:68;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:69;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:70;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:71;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:72;s:7:\"enabled\";b:1;}s:11:\"ept_webform\";a:2:{s:6:\"weight\";i:73;s:7:\"enabled\";b:1;}s:17:\"ept_webform_popup\";a:2:{s:6:\"weight\";i:74;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_columns.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"77e74bf9-008e-4d96-9381-dc809ff7b841\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"v6ug86IR2khsDICnCIAdzPfNfLXmkeVFT9UqUTRCd9s\";}s:2:\"id\";s:40:\"paragraph.ept_columns.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_columns.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9935753-c052-4b7b-b23a-a14f2748a834\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E5a_LPXp_bizIM-GzrOKjXX53p0mj01R_Ljy3UhbYmc\";}s:2:\"id\";s:36:\"paragraph.ept_columns.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_columns.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"3988d015-d4a9-4560-9665-3defb0bfead9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LCIv3BxeR6WGu8S2T4pGT69kr4zPkUTHJk0ehJJqVjs\";}s:2:\"id\";s:37:\"paragraph.ept_columns.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_countdown.field_ept_countdown_date',_binary 'a:17:{s:4:\"uuid\";s:36:\"51db6984-7e76-4d6a-be3b-8f052f3bae29\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_countdown_date\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:8:\"datetime\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Tpuj04Fr7uNZO039Nd8J5cv4Ya-znGKtwNYc5cXn1gc\";}s:2:\"id\";s:48:\"paragraph.ept_countdown.field_ept_countdown_date\";s:10:\"field_name\";s:24:\"field_ept_countdown_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:14:\"Countdown date\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:8:\"datetime\";}'),('','field.field.paragraph.ept_countdown.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"991df58b-c253-4036-a94c-16bf928672f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ba5vspWY7pQHKiHMxUWsBgPe13kyadBUwXJG_mtVF04\";}s:2:\"id\";s:42:\"paragraph.ept_countdown.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:12:\"EPT Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_countdown.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"36557cf2-e64e-4835-ad8e-b5bbc8150e8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxnjRfw__e_lRLCA703BFzbVEExF3BkVWaY6sDGBfno\";}s:2:\"id\";s:38:\"paragraph.ept_countdown.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_countdown.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"ae2f7f13-51c7-4ea2-99c7-c5b6b22f7360\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hE1iEpJa-BGC9-RbtJz3GYEuzj1nOmJqKNp7bNq63v8\";}s:2:\"id\";s:39:\"paragraph.ept_countdown.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter.field_ept_counter_items',_binary 'a:17:{s:4:\"uuid\";s:36:\"53805c44-6771-4268-b091-a3f4f1269139\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_items\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:2;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1MfRaU5RDocEjlC7nyIwXtGJAd9zHFyzfmxMz3nhoL8\";}s:2:\"id\";s:45:\"paragraph.ept_counter.field_ept_counter_items\";s:10:\"field_name\";s:23:\"field_ept_counter_items\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:17:\"EPT Counter Items\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_counter.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"153fe814-ed15-45dd-ac36-e3166140cf03\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MNeAeSI8Y2lhDp_9PO88OMzAgUex8QzA7U6mYPsqZh4\";}s:2:\"id\";s:40:\"paragraph.ept_counter.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:12:\"EPT Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_counter.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"b4f633fb-12be-4793-b294-21badb491880\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_WgiVxSXXCkXpPedeKEQqBdTrL2yAV-R5njXnnWvkyQ\";}s:2:\"id\";s:36:\"paragraph.ept_counter.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"44deba9e-6935-4553-9ef0-ecc889381ae8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_A9WA0oPqrE9hJAdrstmGGAwR1IetKm59q9podeyJaI\";}s:2:\"id\";s:37:\"paragraph.ept_counter.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_description',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad867234-0316-48d0-bba3-4dcafd6d6091\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:53:\"field.storage.paragraph.field_ept_counter_description\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4-1RuE5rL9TNgTiA2lw7thDEjBhXTw_XAZuWfN21qY\";}s:2:\"id\";s:56:\"paragraph.ept_counter_item.field_ept_counter_description\";s:10:\"field_name\";s:29:\"field_ept_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:11:\"Description\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_icon',_binary 'a:17:{s:4:\"uuid\";s:36:\"94fe1479-276a-47c8-a255-ba6fdb6b874f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ept_counter_icon\";i:1;s:16:\"media.type.image\";i:2;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T7rXLcACaUML0NMksYsmdVF9_PA7XqFakcAdD0PuMKk\";}s:2:\"id\";s:49:\"paragraph.ept_counter_item.field_ept_counter_icon\";s:10:\"field_name\";s:22:\"field_ept_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:4:\"Icon\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"9857343f-763e-4b29-8143-ec3fb9d9963d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_counter_number\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NLE9w7TbjN5CmAnSSj-gSDT5bGz-IIqdEs-myskjLxo\";}s:2:\"id\";s:51:\"paragraph.ept_counter_item.field_ept_counter_number\";s:10:\"field_name\";s:24:\"field_ept_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:6:\"Number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:4:{s:3:\"min\";i:1;s:3:\"max\";N;s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"field_type\";s:7:\"integer\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"9d669ec1-badd-49d6-82c8-4a8eba8ca7da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1YYXmvZIdinNPPgOBzpsoa5rCIzMayt9KFg5Gp6aGxI\";}s:2:\"id\";s:50:\"paragraph.ept_counter_item.field_ept_counter_title\";s:10:\"field_name\";s:23:\"field_ept_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"40656cb2-323c-4502-b916-5613d935c06a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:50:\"field.storage.paragraph.field_ept_cta_column_image\";i:1;s:16:\"media.type.image\";i:2;s:34:\"paragraphs.paragraphs_type.ept_cta\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M6DPa4NxYRx2y48yZGbZgB9RXiUBCln4aFQ2BSQ1ZRo\";}s:2:\"id\";s:44:\"paragraph.ept_cta.field_ept_cta_column_image\";s:10:\"field_name\";s:26:\"field_ept_cta_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"a4f2e656-d59b-4df7-833b-709b38ab9360\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_cta_link\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"663HkJoryKb6fkU2dIBK7JnS0-v_HHMirdYKZ97PPXI\";}s:2:\"id\";s:36:\"paragraph.ept_cta.field_ept_cta_link\";s:10:\"field_name\";s:18:\"field_ept_cta_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"2eb61b2c-ee83-43b2-beb6-334f5562bc8c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_cta_second_link\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zqb9GkzwNjNvs2k4e9egdt1MT_D0YfyITXC4BVAQS3s\";}s:2:\"id\";s:43:\"paragraph.ept_cta.field_ept_cta_second_link\";s:10:\"field_name\";s:25:\"field_ept_cta_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:11:\"Second Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_cta.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"7a06dca5-73c0-4c47-a217-2f9d7f3b9d43\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdThFhM93LECXPeiHekVQZst4pAyaZauFLBc6ZZ2HJ0\";}s:2:\"id\";s:36:\"paragraph.ept_cta.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:18:\"Paragraph settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_cta.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a054c663-7358-4e24-99c7-7caa63091265\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QN1QM2C6SY_OR_LyAWi1j0iKDvbeAcJCe6s806EaZDo\";}s:2:\"id\";s:32:\"paragraph.ept_cta.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cta.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"e6f7cd85-741e-4d86-ae78-2eabee82b952\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_MAbOMwe1u3jdwZjUjmDHaxwmjIU-JGVZUkIUziPiQ\";}s:2:\"id\";s:33:\"paragraph.ept_cta.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"b46ea217-84f7-4321-912a-7446b534bb92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_column_image\";i:1;s:16:\"media.type.image\";i:2;s:35:\"paragraphs.paragraphs_type.ept_hero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3eydYXoFUtHpVqERbj-NUTxfjmRpY41GlotzDaiMHw\";}s:2:\"id\";s:46:\"paragraph.ept_hero.field_ept_hero_column_image\";s:10:\"field_name\";s:27:\"field_ept_hero_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"5dcc6a7e-0a0a-4b27-8ec1-fc41c3bb654a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_hero_link\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lxzpMFHK8I8nPXViJVyoXQFZitk8kttqyIRXSb9D1O0\";}s:2:\"id\";s:38:\"paragraph.ept_hero.field_ept_hero_link\";s:10:\"field_name\";s:19:\"field_ept_hero_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"93b358ac-f703-4792-a4cb-65cb87eb34aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_hero_second_link\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"69BKIyb4s5Y9A2Ehq5ew6h-2_suAuoW3onibd8wyXpI\";}s:2:\"id\";s:45:\"paragraph.ept_hero.field_ept_hero_second_link\";s:10:\"field_name\";s:26:\"field_ept_hero_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:11:\"Second link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_title_prefix',_binary 'a:17:{s:4:\"uuid\";s:36:\"00840cc4-7392-4663-a414-47758f14db31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_title_prefix\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"veAof1VE_5yLVqcM55gO7131zQkIVF8H4zYSRsZft-U\";}s:2:\"id\";s:46:\"paragraph.ept_hero.field_ept_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ept_hero_title_prefix\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:12:\"Title prefix\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9610a78c-d4d5-4d29-9221-2b862f3b5c9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jlfCaG2VGA8ar8Pw_-7SqeS8qRs_HrOK0KBRLdRLQGw\";}s:2:\"id\";s:37:\"paragraph.ept_hero.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_hero.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"eda0ee86-a9c6-40a3-90a6-52025f859080\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d6uOb6beHqZsXuoLFCkZ9d-OTiK3Lfl7WLMId5Ynb1o\";}s:2:\"id\";s:33:\"paragraph.ept_hero.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"9cd49d18-67b3-4776-ba0b-dda42289ac3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4ZRR07jQy0amtEk8dDsUh5TwD7BiPqLSfZ64qa1IkaE\";}s:2:\"id\";s:34:\"paragraph.ept_hero.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"123bb9be-f4f0-4e79-9c1f-5a74d1adc56a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_image\";i:1;s:16:\"media.type.image\";i:2;s:36:\"paragraphs.paragraphs_type.ept_image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jo3X0pnIHasz5kmaVrv_VxOnp5yor6wvZ68l7Hpg9nc\";}s:2:\"id\";s:35:\"paragraph.ept_image.field_ept_image\";s:10:\"field_name\";s:15:\"field_ept_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_image.field_ept_image_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"720ab2af-faa7-4459-84ec-84810093337c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ept_image_caption\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tA0YJl2CpERDaSbF2WLaH5CxWoJo4OUxxMw-Y_Z85KA\";}s:2:\"id\";s:43:\"paragraph.ept_image.field_ept_image_caption\";s:10:\"field_name\";s:23:\"field_ept_image_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:13:\"Image caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_image_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"e46eefbb-e77e-4dbb-b856-37283bfcbcf6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_image_link\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dmezv08ITbH8uMIaLoQS0_rAIw2TDc-iXuD0VCZW5q0\";}s:2:\"id\";s:40:\"paragraph.ept_image.field_ept_image_link\";s:10:\"field_name\";s:20:\"field_ept_image_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:10:\"Image Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_image.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"99ba3548-2963-43fc-9439-5c4981283ee3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"35ALufHFT-74ORycJJBebQ8dzd9UMefuOloBcGo5VZ0\";}s:2:\"id\";s:38:\"paragraph.ept_image.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_image.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ee4ec7f5-67b4-42d7-baf2-7aaee393847f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TQxr_NqYWOx6AZeW6vZ-pqzPYQhGvMxRwPcm_djydmY\";}s:2:\"id\";s:34:\"paragraph.ept_image.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b25f97c8-ef2e-408c-b977-6254d1414afe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"js6jXfcyujmxNS5eOXM-fX2nbJp4VUCmm_wWeBR272c\";}s:2:\"id\";s:35:\"paragraph.ept_image.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_image_gallery',_binary 'a:17:{s:4:\"uuid\";s:36:\"dfb637af-23af-4aa3-8753-1c3c1b41f2a4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:47:\"field.storage.paragraph.field_ept_image_gallery\";i:1;s:16:\"media.type.image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-waCmECFpztaOjQ1zzHETTjcKsonmUGYLmUUBB3P_K4\";}s:2:\"id\";s:51:\"paragraph.ept_image_gallery.field_ept_image_gallery\";s:10:\"field_name\";s:23:\"field_ept_image_gallery\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:13:\"Image Gallery\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"84658343-fa44-4fe9-acaa-5c0c2ff5f1d0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"guMxbDDWmEkT_hzhYXnmY2fyGUJMEPxeJW9uZmuIh7s\";}s:2:\"id\";s:46:\"paragraph.ept_image_gallery.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"3d160c57-3e25-403d-8a51-0a0b3397f5eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u25lX345GD4zaFxqQqboxwsRa0S9GMlNcD3drpGc6wE\";}s:2:\"id\";s:42:\"paragraph.ept_image_gallery.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"bbd8f0a6-7c0d-47e5-a62d-a2c5aed60232\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eKE4hyL1K1LGrcOlvyUoYrmTVsVfgHxMAfCbRZf4f5A\";}s:2:\"id\";s:43:\"paragraph.ept_image_gallery.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_micromodal_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"1003b7da-189c-4687-89e9-fe627bd2f746\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_micromodal_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jDNhkuS0vb097p4tXdHxr-ydSAj5cLsbKHtJJ8CC8A0\";}s:2:\"id\";s:51:\"paragraph.ept_micromodal.field_ept_micromodal_title\";s:10:\"field_name\";s:26:\"field_ept_micromodal_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:16:\"Micromodal Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"c3236ac3-dc6f-4f78-9199-3450f0c1f3b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nAJ_q4mUFfBF1PGkZwsvQdbCQKbSx6iW74pQQ8M2kaY\";}s:2:\"id\";s:43:\"paragraph.ept_micromodal.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_micromodal.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9453349-a4b8-4f21-ad48-735cb6bb9eca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"L9_i6zE8UlUJcopkepORHiE8I3C69iY3aeKe3A1jKDg\";}s:2:\"id\";s:39:\"paragraph.ept_micromodal.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b6314b7b-d04b-4c21-b388-edad4a320f8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GoRC0O7xqhZYbUT4g4Qv76pyVOo2S62CERLkOw5UcoU\";}s:2:\"id\";s:40:\"paragraph.ept_micromodal.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_quote_author',_binary 'a:17:{s:4:\"uuid\";s:36:\"819b216b-97f6-4f18-82b6-2074094a280f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.storage.paragraph.field_ept_quote_author\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oNI4JdVXun_FojU2-XZoJP9ztB3e4wWwPkZYgvGQGCg\";}s:2:\"id\";s:42:\"paragraph.ept_quote.field_ept_quote_author\";s:10:\"field_name\";s:22:\"field_ept_quote_author\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:12:\"Quote Author\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_quote_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"fe2fb5d1-bcf8-4e29-9e00-d600aab8954a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ept_quote_image\";i:1;s:16:\"media.type.image\";i:2;s:36:\"paragraphs.paragraphs_type.ept_quote\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YjnCUtsj4uSblj8ujLf9XPYiUCvxUQCzn6Si7IvFez0\";}s:2:\"id\";s:41:\"paragraph.ept_quote.field_ept_quote_image\";s:10:\"field_name\";s:21:\"field_ept_quote_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:11:\"Quote Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_quote.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"c4e09c22-0835-4bec-a402-756220f2e9f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t7gxB3ZTgUm7Yk0DbVkmAjHW8mI8AmfMf32Oxs3QZcI\";}s:2:\"id\";s:38:\"paragraph.ept_quote.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_quote.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f701ef4d-7de9-46b4-88f4-6995981e11ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"daebO4BuA3YZb6pUdTzPsiqUuJH_LDMHLJkxdMWVZSo\";}s:2:\"id\";s:34:\"paragraph.ept_quote.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:5:\"Quote\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a08772a7-ac82-466b-918c-b39c7f16c309\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QGR28IMOBB-lAS8KMdPI2PxLFhQ8APHB11vjkOzEybM\";}s:2:\"id\";s:35:\"paragraph.ept_quote.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9bf7105c-9c7f-493b-b93c-2ee846a91521\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"75Fj62yEPi_Tkndg_Fr-WT5Fn81YlgSw2oEee7jQnKg\";}s:2:\"id\";s:45:\"paragraph.ept_slick_slider.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_slick_slider',_binary 'a:17:{s:4:\"uuid\";s:36:\"c440db95-46b7-4316-8502-e20c900704c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ept_slick_slider\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:2;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VMJlv4iCLXipe6DB9Nw7mRcvCegf6AlaUe9pD4sFZw4\";}s:2:\"id\";s:49:\"paragraph.ept_slick_slider.field_ept_slick_slider\";s:10:\"field_name\";s:22:\"field_ept_slick_slider\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:12:\"Slick Slider\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:21:\"ept_slick_slider_item\";s:21:\"ept_slick_slider_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"4bad9ad2-5f7d-40ee-92a6-547badbee525\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qgc2mLoZ4HsNUAYaZCNUYpblK1Qy_Grwx-FiIrrd3fo\";}s:2:\"id\";s:41:\"paragraph.ept_slick_slider.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0570de2b-d581-4073-a8b0-0729eacf75eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8znZ6dLr4j9QA4jZnTSyprUdnZL0N8ZENTLNXvgPaFo\";}s:2:\"id\";s:42:\"paragraph.ept_slick_slider.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"1b1a1524-2e19-47c4-af5c-c693044a59e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:52:\"field.storage.paragraph.field_ept_slick_slider_image\";i:1;s:16:\"media.type.image\";i:2;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XlD11lUQ6pjHnXyA9Z5Z_lyj35bmUgn2C_2xUYcE2wI\";}s:2:\"id\";s:60:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ept_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"6d566515-d2a4-4ce3-96e1-678ae2feea9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_link\";i:1;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f47xjCX2OUOsteSKP2-Rqy9EJ1ZQWtGr2EmizJ0jwsQ\";}s:2:\"id\";s:59:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"532449b1-8d51-4c87-ad35-6a4555565967\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_text\";i:1;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dP7Z_3Sp9p8yprgyoPMwzTnDckg7oXVPKeGBpWi5yHs\";}s:2:\"id\";s:59:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"a98491aa-0091-4a36-af08-7e4f9e2a3554\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wDLAk6apIKl_k-WeYvw2Sx7NuPQrdbmVpPi_pcf6Ank\";}s:2:\"id\";s:42:\"paragraph.ept_slideshow.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_slideshow.field_ept_slideshow',_binary 'a:17:{s:4:\"uuid\";s:36:\"929dd04a-655a-436e-b9ec-8b400a26f596\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:43:\"field.storage.paragraph.field_ept_slideshow\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:2;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sl3hYGCV99Y8zdhisWkqHtWAR4cKtwAzRiAC8g8O_3w\";}s:2:\"id\";s:43:\"paragraph.ept_slideshow.field_ept_slideshow\";s:10:\"field_name\";s:19:\"field_ept_slideshow\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:9:\"Slideshow\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_slideshow.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"04f2459a-8250-49b8-9c26-a1bc5f23b1ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eFgq1F96D8Kk_yB-LhiHcUiv0NDGHiiESnrxKVotJ8M\";}s:2:\"id\";s:38:\"paragraph.ept_slideshow.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0a76e0e6-37a2-4e5e-a2ca-41101da17e1e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MaSZwNYeloEyTip3_uq3aYWI21fdjStPLv72a0OyAs0\";}s:2:\"id\";s:39:\"paragraph.ept_slideshow.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"6671231f-f98f-4ea0-a6ab-9bfe42290292\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_link\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sj-aXmpz4XSqjlnaG36lSUzZ8k1NxnbVupC-3jXoTh4\";}s:2:\"id\";s:53:\"paragraph.ept_slideshow_item.field_ept_slideshow_link\";s:10:\"field_name\";s:24:\"field_ept_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide',_binary 'a:17:{s:4:\"uuid\";s:36:\"6483f62f-11d2-44ea-bf5b-d0db486d3689\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_slide\";i:1;s:16:\"media.type.image\";i:2;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a66BmJCI3SYkj4hLc0icKJq37QzM84zA3q3tcAMeAqA\";}s:2:\"id\";s:54:\"paragraph.ept_slideshow_item.field_ept_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ept_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad96e4c6-579a-4465-ba2d-117890a7bff3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_text\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JIuZsvq1IySXyy86tHyxkIPZnRhYgEKfm5uNfN4Qgi8\";}s:2:\"id\";s:53:\"paragraph.ept_slideshow_item.field_ept_slideshow_text\";s:10:\"field_name\";s:24:\"field_ept_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"84bea7b4-b9e4-4cf4-8ec9-389dd6b02c10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_title\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"of2_NLVXcX_Tqy_oCPxWCKkqkVV1GMoDc32IPKj-uAs\";}s:2:\"id\";s:54:\"paragraph.ept_slideshow_item.field_ept_slideshow_title\";s:10:\"field_name\";s:25:\"field_ept_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:11:\"Slide Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"f00824ef-dc9b-4ba7-81ad-8e7910f662a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"w6dTziASV3O9e_SoQSGcA7y3KjBRRRFKEmxbhx_eOPY\";}s:2:\"id\";s:38:\"paragraph.ept_stats.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_stats.field_ept_stats',_binary 'a:17:{s:4:\"uuid\";s:36:\"cfaf7cc4-f386-4397-8876-cdcee33b93b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_stats\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:2;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ixjxb8WmNFSxd8n64WYGee4M8gw_ihsOSTkxejxBK7I\";}s:2:\"id\";s:35:\"paragraph.ept_stats.field_ept_stats\";s:10:\"field_name\";s:15:\"field_ept_stats\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:9:\"EPT Stats\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_stats.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a8fb2e31-9a7a-45bb-84f7-84bce2a8e256\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5DBGJho8oBlSjoM127v2kkKEhKXLsn2dYpC1Gj4wep8\";}s:2:\"id\";s:34:\"paragraph.ept_stats.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"1c882037-c7e3-42e4-9707-af10c5015ef2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T8Ioj6BqDtO5y16e6qpTBdiluC90CXivuhVNCfIlff8\";}s:2:\"id\";s:35:\"paragraph.ept_stats.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"48e0dea0-fc4d-4a86-8ed4-203f0efe3a52\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:50:\"field.storage.paragraph.field_ept_stats_item_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gQ-WN8Z7uMhqF7m3PcgLkMbssZvUuoZDru39piaWdaY\";}s:2:\"id\";s:51:\"paragraph.ept_stats_item.field_ept_stats_item_image\";s:10:\"field_name\";s:26:\"field_ept_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:16:\"Stats item image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"64aa7603-d2f0-4050-a82f-35b5ef3b978f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_link\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MnXt19dK8rTz4x1hRigyeVWiXn1o6VumcHTMqrFFk74\";}s:2:\"id\";s:50:\"paragraph.ept_stats_item.field_ept_stats_item_link\";s:10:\"field_name\";s:25:\"field_ept_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:15:\"Stats item link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"4be87c8b-a691-4546-9b46-8104a7920252\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_stats_item_number\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7DMKiTrisc5ETf4YO_Rg2a1hxbtze1sV29AulzJK_mo\";}s:2:\"id\";s:52:\"paragraph.ept_stats_item.field_ept_stats_item_number\";s:10:\"field_name\";s:27:\"field_ept_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:17:\"Stats item number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"7ab22f13-220c-400f-9f56-3043d91300ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"syABtrl4XuopN2UmpGpkCfjm8LZlB4zLjgHycG4AUww\";}s:2:\"id\";s:50:\"paragraph.ept_stats_item.field_ept_stats_item_text\";s:10:\"field_name\";s:25:\"field_ept_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:15:\"Stats item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"bcee11b6-9de3-4ea7-ab28-783aaf52a980\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7WAUPeogPEpndKAuLbuwHXSQX1_x1zQ1DkQgZ0xSJl8\";}s:2:\"id\";s:37:\"paragraph.ept_tabs.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_tabs.field_ept_tabs',_binary 'a:17:{s:4:\"uuid\";s:36:\"f3ed6271-02a1-49ae-87a5-dcbb0788200c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:38:\"field.storage.paragraph.field_ept_tabs\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:2;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oxGvFEmPYXx97wLochArKKDYG1lhbF0L77Sp4ki0K1I\";}s:2:\"id\";s:33:\"paragraph.ept_tabs.field_ept_tabs\";s:10:\"field_name\";s:14:\"field_ept_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"EPT Tabs\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_tabs.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"5d8d9518-713c-4c54-a1b1-e9255a1064cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxiqJRauMgF0Qzud0cz2Wj4-oLnMJ3Cr-bXZe_fdGC0\";}s:2:\"id\";s:33:\"paragraph.ept_tabs.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"3b694b0c-21b1-40f1-aab1-5f8f6b508006\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DehWRcrin5XDNZhAMoyHl3b5Vtw4Tpdijx5u8vCQ75Q\";}s:2:\"id\";s:34:\"paragraph.ept_tabs.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"c3f52d5a-54bd-4606-8b04-4a6c1e456a0b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_block\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Djebt4QCWYRzCydiBvhKgj0bMyEaWAKfY-YBAf7OX4Y\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_block\";s:10:\"field_name\";s:19:\"field_ept_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab Block\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:6:\"blocks\";s:18:\"selection_settings\";a:1:{s:10:\"plugin_ids\";a:0:{}}}s:10:\"field_type\";s:11:\"block_field\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_content',_binary 'a:17:{s:4:\"uuid\";s:36:\"8bd0ca98-8e9c-4dba-b1cf-ae98a043504f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_tab_content\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:7:\"options\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FHi-QeaCukjELTWL55S3DmUxMPC5qvpjm7YoUXlN2_k\";}s:2:\"id\";s:45:\"paragraph.ept_tabs_item.field_ept_tab_content\";s:10:\"field_name\";s:21:\"field_ept_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:11:\"Tab content\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:11:\"list_string\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_page',_binary 'a:17:{s:4:\"uuid\";s:36:\"15235fd9-9fad-4092-b19c-8e011debebfb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_page\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lSW-pbI_Dd3D3Pmk9Ey9S92Si1kgRJBouroj9i9FcxI\";}s:2:\"id\";s:42:\"paragraph.ept_tabs_item.field_ept_tab_page\";s:10:\"field_name\";s:18:\"field_ept_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:8:\"Tab page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:12:\"default:node\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:4:\"page\";s:4:\"page\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a059a1dc-b8c7-41a3-a0ba-57ef2b7c3ef2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UhI0Db-BZ8kkyso5fdxGaK2SLKXQOo3Tz91NfllT_zE\";}s:2:\"id\";s:42:\"paragraph.ept_tabs_item.field_ept_tab_text\";s:10:\"field_name\";s:18:\"field_ept_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:8:\"Tab text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0c7eb82c-6093-4901-bd0b-fd48f6eedcb2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"evBpqQnLlVSI7JzfhV_sYlfl4Xj_FMH8yjfAXa3TuNo\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_title\";s:10:\"field_name\";s:19:\"field_ept_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:4:\"text\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_views',_binary 'a:17:{s:4:\"uuid\";s:36:\"efd74810-b803-4db6-b891-9ea3905eb31d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_views\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I_C7XUVcXIbh_wxTumKceK8yBCxb_QVNvaycgNmZB20\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_views\";s:10:\"field_name\";s:19:\"field_ept_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab views\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";i:0;}s:12:\"plugin_types\";a:5:{s:5:\"block\";s:5:\"block\";s:7:\"default\";i:0;s:4:\"page\";i:0;s:4:\"feed\";i:0;s:5:\"embed\";i:0;}s:15:\"preselect_views\";a:15:{s:13:\"block_content\";i:0;s:7:\"comment\";i:0;s:15:\"comments_recent\";i:0;s:7:\"content\";i:0;s:14:\"content_recent\";i:0;s:5:\"files\";i:0;s:9:\"frontpage\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:13:\"taxonomy_term\";i:0;s:17:\"user_admin_people\";i:0;s:8:\"watchdog\";i:0;s:19:\"webform_submissions\";i:0;s:9:\"who_s_new\";i:0;s:12:\"who_s_online\";i:0;}s:16:\"enabled_settings\";a:5:{s:8:\"argument\";i:0;s:5:\"limit\";i:0;s:6:\"offset\";i:0;s:5:\"pager\";i:0;s:5:\"title\";i:0;}}s:10:\"field_type\";s:14:\"viewsreference\";}'),('','field.field.paragraph.ept_text.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"dd24c6a8-a5d2-434a-90d0-3a97c829c794\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zlnMwIZoq976NUR8ObTPmCmOG2YwYTmjc1fQpFhCzWs\";}s:2:\"id\";s:37:\"paragraph.ept_text.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:18:\"field_ept_settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_text.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"406dd338-600c-4eb2-841a-df635188cfb3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yIzbNDHidtMFArQQv6qO6cTkFBTnI6e02KK-xT8FOIM\";}s:2:\"id\";s:33:\"paragraph.ept_text.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_text.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"6902be14-683f-4f5a-8d50-8543bbf0aca5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DZTXvQuYpXkQt9q004RnVKvKTocT9hurW7VYy0As9Is\";}s:2:\"id\";s:34:\"paragraph.ept_text.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"ac698185-3f8a-4519-a9b7-29609da24892\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d-eKpx0qmCR-PZ85K0IfmM1LKHFjcx9xUcNT5mMFMuA\";}s:2:\"id\";s:38:\"paragraph.ept_tiles.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_tiles.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"7f39ca00-ae38-46ac-a2f2-ce0b4f545f9f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uGM6CpdmK0GJ5mrS4WHYG6QnXJLHx0fiEbs3D7e_iqE\";}s:2:\"id\";s:34:\"paragraph.ept_tiles.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles.field_ept_tiles',_binary 'a:17:{s:4:\"uuid\";s:36:\"254d23bc-cd9a-4186-b124-2f3fa923fc05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_tiles\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:2;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lii17sKUYm4ZAvrf-OKM8IF0auj5DIQWCMBUkdzT4BM\";}s:2:\"id\";s:35:\"paragraph.ept_tiles.field_ept_tiles\";s:10:\"field_name\";s:15:\"field_ept_tiles\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:5:\"Tiles\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:75;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_tiles.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"efadba67-9ef3-474a-8246-0e5a51d74660\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e58JwGJ1lDz1CUji4qvDlK_7WEadqaihU0jG6u0_10E\";}s:2:\"id\";s:35:\"paragraph.ept_tiles.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_clickable_tile',_binary 'a:17:{s:4:\"uuid\";s:36:\"29c56f04-456b-4f6f-87b5-6352ddaa6a51\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_clickable_tile\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BVIyqIinPodc30VYfLCsYHnMbl1U6L7LpKffkLNM6RY\";}s:2:\"id\";s:49:\"paragraph.ept_tiles_item.field_ept_clickable_tile\";s:10:\"field_name\";s:24:\"field_ept_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:14:\"Clickable Tile\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"af24502d-ca80-4229-bc11-8b9d175d53f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AnFN9yAGXXY3wn6XD_DMYj4H1UfZR6gt3lITV4L2Jy4\";}s:2:\"id\";s:46:\"paragraph.ept_tiles_item.field_ept_tiles_image\";s:10:\"field_name\";s:21:\"field_ept_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"77a71623-7050-467d-bbb6-f7e2b8e10f9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_link\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"c5x2tFCR-aDLFMCY5a0CDVK8OLjI-eH92z0w6wsbq7I\";}s:2:\"id\";s:45:\"paragraph.ept_tiles_item.field_ept_tiles_link\";s:10:\"field_name\";s:20:\"field_ept_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a96f802e-f6f6-415b-a00b-47d8e483f3c2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zLtl1oCO1H3AjX05GApCKNVIuZj-sWnEjN2TFBhgTpk\";}s:2:\"id\";s:45:\"paragraph.ept_tiles_item.field_ept_tiles_text\";s:10:\"field_name\";s:20:\"field_ept_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"60166fc5-cd70-42a2-ab4a-021bef6afcf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-RWZYOv7kMNcT6h0h3wa0LE8w3is_5A7gNJGRvk2Xh8\";}s:2:\"id\";s:46:\"paragraph.ept_tiles_item.field_ept_tiles_title\";s:10:\"field_name\";s:21:\"field_ept_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"65e27c50-82c3-46dd-ad6d-c95805dd83bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jKYz3Azrp1BbteF4w3ARDoD11HGUjD6Y1-Pi3j5bMMA\";}s:2:\"id\";s:38:\"paragraph.ept_video.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_video.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"de00022b-0652-4a4f-a13f-6d001b19f4c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rOcKKlFTqbEyP9jZpIA7FgAeEZVpAzkLMwyL7Ocl7ZA\";}s:2:\"id\";s:34:\"paragraph.ept_video.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"68fe7948-f81f-4f36-8ce6-3a736d2696be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"liOGejMkGS8WchkLMEwnO9OEFeI2CuDopa6y4ARi6R4\";}s:2:\"id\";s:35:\"paragraph.ept_video.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"5fbf0b1d-881b-44e3-9225-31e307913827\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_video\";i:1;s:23:\"media.type.remote_video\";i:2;s:36:\"paragraphs.paragraphs_type.ept_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"B2uO316aHzKE6mwH_4CehW7np6-M8ImTN-8E4ZUIOz4\";}s:2:\"id\";s:35:\"paragraph.ept_video.field_ept_video\";s:10:\"field_name\";s:15:\"field_ept_video\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"8b147c97-e78e-4773-a7dd-fbdd3db585a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A0AtClTrQ3Abbg6jEI-itnCAjYSI69l8ZIU5n6wGu-k\";}s:2:\"id\";s:56:\"paragraph.ept_video_and_image_gallery.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"5c1e6fab-0fe9-4952-a3c8-991a0f293a80\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iohq2efRKb05xjfjet4Iqszn41WFrfgfSMpBRl9I8EQ\";}s:2:\"id\";s:52:\"paragraph.ept_video_and_image_gallery.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"2bdd8485-4125-400d-b6ef-feffe57ca0b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nYAF3MHEVZhy6EJ7hiHDE82BlOyi6F94s9AtJa31HxY\";}s:2:\"id\";s:53:\"paragraph.ept_video_and_image_gallery.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9a94fcc-b813-47ed-9b68-5780ad0e270c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:51:\"field.storage.paragraph.field_ept_videos_and_images\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Md5TJXPOSzIMO3hzpok2uncR4UY-8oOvihBYAwl1UTE\";}s:2:\"id\";s:65:\"paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";s:10:\"field_name\";s:27:\"field_ept_videos_and_images\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:17:\"Videos and Images\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:32:\"ept_video_and_image_gallery_item\";s:32:\"ept_video_and_image_gallery_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:82;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item',_binary 'a:17:{s:4:\"uuid\";s:36:\"8e45972c-1dc7-444f-9475-a98aa5a83a12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:4:{i:0;s:46:\"field.storage.paragraph.field_ept_gallery_item\";i:1;s:16:\"media.type.image\";i:2;s:23:\"media.type.remote_video\";i:3;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIblYcf3rZ3cLp4a87dabiYrK0YFYOLsXZ8PPx7JD2w\";}s:2:\"id\";s:65:\"paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";s:10:\"field_name\";s:22:\"field_ept_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:12:\"Gallery Item\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:2:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:5:\"image\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9302769a-011f-4ea8-8a1a-82c6399fc628\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_gallery_item_text\";i:1;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rHN5K2dhzZ2JBJLK9KNsBbDp_D8-ug9T0oRgKfs_L_8\";}s:2:\"id\";s:70:\"paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";s:10:\"field_name\";s:27:\"field_ept_gallery_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:17:\"Gallery item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"0cd4c4a7-feca-4fb7-9e8b-02984559941b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qvGJxPRaclSHVbrfz5Je86o0KNtcIYQhWoZtkWbYOeY\";}s:2:\"id\";s:38:\"paragraph.ept_views.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_views.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9ef68e5-ed23-45fb-a5d1-bac433eeb379\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yroYplh-3xAoBiIIaPAFqecCgnt--hr4wQOE6pydZiw\";}s:2:\"id\";s:34:\"paragraph.ept_views.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0d3eae73-ae6d-4601-b1d4-4df1d7d62c53\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YN4Np9dhEdu3560d9b81PqIY6VAamYuCUEeaTR7MeA4\";}s:2:\"id\";s:35:\"paragraph.ept_views.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_views_view',_binary 'a:17:{s:4:\"uuid\";s:36:\"ef74c15e-0e9f-4f8c-82b1-f7cec4763c50\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_views_view\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qezCi3E0L14u6YMFPeJ3FisM_AyqNacTs3hFkLyN-Bk\";}s:2:\"id\";s:40:\"paragraph.ept_views.field_ept_views_view\";s:10:\"field_name\";s:20:\"field_ept_views_view\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:4:\"View\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}s:12:\"plugin_types\";a:1:{s:5:\"block\";s:5:\"block\";}s:15:\"preselect_views\";a:0:{}s:16:\"enabled_settings\";a:0:{}}s:10:\"field_type\";s:14:\"viewsreference\";}'),('','field.field.paragraph.ept_webform.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"70a56a53-e5dd-4fcf-99b5-29d8b6d4619b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ggBDqszw4QWAW0TCllQsKLBmK-bp0CiS6nqF7QWI7SY\";}s:2:\"id\";s:40:\"paragraph.ept_webform.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_webform.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"7c6589db-fb84-410a-a79c-846a25ff7d97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mYXqrew8efgRYMA2xp-KGRqB_dpPZNxoW56GUfOlWSI\";}s:2:\"id\";s:36:\"paragraph.ept_webform.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_webform.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"d157a78a-d59b-4666-8f4f-2c3fb507bb31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xY1lK8nuvMOzD3Z1ax_xyEM4en85W6tIiFiP8F2EctA\";}s:2:\"id\";s:37:\"paragraph.ept_webform.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_webform.field_ept_webform_form',_binary 'a:17:{s:4:\"uuid\";s:36:\"9e4cb219-cde1-47ad-8d3d-ff3a8093595a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.storage.paragraph.field_ept_webform_form\";i:1;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8HHpzIIgRSxpCUPa33P8cI2huYMKbyofPgO-afmbiHQ\";}s:2:\"id\";s:44:\"paragraph.ept_webform.field_ept_webform_form\";s:10:\"field_name\";s:22:\"field_ept_webform_form\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:5:\"label\";s:4:\"Form\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}}s:10:\"field_type\";s:7:\"webform\";}'),('','field.field.paragraph.ept_webform_popup.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"77455be2-5b47-46b9-a671-60e6534bb5da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Jp5ODXu51CF8H1fNuknzPsSR2mawxCqKDVa1n8OG-hE\";}s:2:\"id\";s:46:\"paragraph.ept_webform_popup.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_webform_popup.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"81f724c9-9e84-4627-825c-4d7ea016d18e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9B9chWVQ9ZVaf4luXVZnBfXiFnBLvZc-yW_PcWliZk0\";}s:2:\"id\";s:42:\"paragraph.ept_webform_popup.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_webform_popup.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"67b226bf-e2f6-418d-9999-d41f6b3d3825\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xFnjuZknMO_3KuT0h0sJfiwbMMmGteSA3oEDRgaUHBU\";}s:2:\"id\";s:43:\"paragraph.ept_webform_popup.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_webform_popup.field_ept_webform_popup_form',_binary 'a:17:{s:4:\"uuid\";s:36:\"f14e46f4-90c2-43c0-b2de-b00cf7ff030e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:52:\"field.storage.paragraph.field_ept_webform_popup_form\";i:1;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l5bQx5-y-4oiJvbjaplNL5aHTR0DF9BUcZMx7qli1WI\";}s:2:\"id\";s:56:\"paragraph.ept_webform_popup.field_ept_webform_popup_form\";s:10:\"field_name\";s:28:\"field_ept_webform_popup_form\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:5:\"label\";s:7:\"Webform\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}}s:10:\"field_type\";s:7:\"webform\";}'),('','field.field.user.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"27323f57-acfd-4aff-a508-544c6c8bdf3d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:31:\"field.storage.user.user_picture\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TE3gYVzd6g0deXqUl8SEu2azHwVG-SdXm3kwbrz0kHw\";}s:2:\"id\";s:22:\"user.user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:5:\"label\";s:7:\"Picture\";s:11:\"description\";s:29:\"Your virtual face or picture.\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:40:\"pictures/[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:0;s:18:\"alt_field_required\";b:0;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJk0TAQBzlNo52ehiHI7bIEPLGi0BYqZvPdEn7Chfu0\";}s:16:\"purge_batch_size\";i:50;}'),('','field.storage.block_content.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"05e5fd5b-7ad6-434e-99a8-8635a8fa97cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:2:\"id\";s:18:\"block_content.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"4a613783-5795-48bc-bd8e-e3fe3a00ea51\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw\";}s:2:\"id\";s:20:\"comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_audio_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"1295648c-a917-438e-a846-fd85d14ae8a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JCHoh95CpUeBx9ch24Tmi6ru0nwmNz8xWVH4Qs7RnTg\";}s:2:\"id\";s:28:\"media.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_document',_binary 'a:17:{s:4:\"uuid\";s:36:\"6b41e063-a182-4108-9b56-c0f4bb265180\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BdkTx7IL59MCw5a_fOZprPTOGM_wcjz-Fm8g7HV3vFk\";}s:2:\"id\";s:26:\"media.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"ae1f0138-a2f5-4881-bf90-0ade773b59b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0N0KSFk57p6qsq3qM4lYVGSuROvzXK-tSsdwByqUh3g\";}s:2:\"id\";s:23:\"media.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_oembed_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"b471db54-e924-4e9f-b6d7-c7e32f497206\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cNf_852Dq-fNnSaMI4LxL-J6N7bLkHuDbD9EUqOn4_U\";}s:2:\"id\";s:30:\"media.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;s:8:\"is_ascii\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_video_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"1567fe07-a329-492a-bc5f-d82e3865bd57\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z5mgbn1PIVZ5TNMByBmivqo_u3Rdk58UIzpyN4ypTeM\";}s:2:\"id\";s:28:\"media.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"26a81385-82de-46f0-8582-8c93b0fbcb01\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:2:\"id\";s:9:\"node.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_components',_binary 'a:16:{s:4:\"uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:2:\"id\";s:21:\"node.field_components\";s:10:\"field_name\";s:16:\"field_components\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"d9aff85c-3ad9-418b-b47e-58f08b64180e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:2:\"id\";s:16:\"node.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"81f6ea79-133f-4e53-bb0a-4169a69c4472\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:2:\"id\";s:15:\"node.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9282b5e-9cbb-4d37-84d7-b405cf59a041\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"99EX18edsQlLBda3J37pHASAxF4OUjSVJ4_nSq1pW94\";}s:2:\"id\";s:29:\"paragraph.field_ept_accordion\";s:10:\"field_name\";s:19:\"field_ept_accordion\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"177e4cd0-bbd1-44cd-9d3f-5b5dd4378ed4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l5c0DoOjgcErJEjFGkUqN_upYgubdHpE_MiwbMK2YRI\";}s:2:\"id\";s:34:\"paragraph.field_ept_accordion_text\";s:10:\"field_name\";s:24:\"field_ept_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"012f2184-9082-4983-9239-7dac48864d9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6S4PB05UjgSgHEDSalqgqkJHWyCcYsdkgPKTvGC2c8s\";}s:2:\"id\";s:35:\"paragraph.field_ept_accordion_title\";s:10:\"field_name\";s:25:\"field_ept_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_basic_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"360bef36-b4f7-492b-9677-6170eebdf2bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Tj1qQArNpaPeg2XmPed8WY2JiAk8p21-R1HVn28zVoY\";}s:2:\"id\";s:37:\"paragraph.field_ept_basic_button_link\";s:10:\"field_name\";s:27:\"field_ept_basic_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_block_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"58c5cc3e-9949-4686-882a-a56b59c60ea8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hAESsXJ5KZsWYKr-KB5wJoHNBdcOTlIFJUomBW8VxoU\";}s:2:\"id\";s:31:\"paragraph.field_ept_block_block\";s:10:\"field_name\";s:21:\"field_ept_block_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_bootstrap_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"bceb6f2f-b114-41f5-8b07-0ce990d0087a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BweaoyqqEqOIBPWV2qKw_2N4R6oBSudk91cCNPtz_iY\";}s:2:\"id\";s:41:\"paragraph.field_ept_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ept_bootstrap_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel',_binary 'a:17:{s:4:\"uuid\";s:36:\"fbb51140-67d8-4112-868c-19dd46c31b98\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RbALd0Xz78o-CtP2iD8j7s8h1scHn1lSdm-_EQqZyrY\";}s:2:\"id\";s:28:\"paragraph.field_ept_carousel\";s:10:\"field_name\";s:18:\"field_ept_carousel\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"4bdff313-152c-4ea9-ba49-6f433c48203a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HeWBlq69mptI0nGWU0dliRAS9rVOa2HzuJbUbzsJg4M\";}s:2:\"id\";s:36:\"paragraph.field_ept_carousel_caption\";s:10:\"field_name\";s:26:\"field_ept_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"1da3ad04-a3d6-45a2-8a2e-100f0d629948\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ViB2NrYfe_RWvrvvb9X_U6kuX0eI47m5Wpa6hCFqZWE\";}s:2:\"id\";s:34:\"paragraph.field_ept_carousel_image\";s:10:\"field_name\";s:24:\"field_ept_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_clickable_tile',_binary 'a:17:{s:4:\"uuid\";s:36:\"776f5eb1-0740-473f-b278-4678ab1e0a4e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKnQMenIUygu6qoP8n4_EzChFXMkjnwf78bFFBWCN0w\";}s:2:\"id\";s:34:\"paragraph.field_ept_clickable_tile\";s:10:\"field_name\";s:24:\"field_ept_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_columns',_binary 'a:17:{s:4:\"uuid\";s:36:\"7518ddce-1000-4e47-8c93-f8230ca40081\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lIenGVJ8vS3WAEr1xteI9sDUdCoc-UNgbf7xDipU4_s\";}s:2:\"id\";s:27:\"paragraph.field_ept_columns\";s:10:\"field_name\";s:17:\"field_ept_columns\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_countdown_date',_binary 'a:17:{s:4:\"uuid\";s:36:\"5741fa83-8e57-4e60-99ce-6e8bd5bf8b78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"datetime\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SWGbKy8XYRkCxbrmDvY2UYyxzAKxcSL7ouH4CljiXbY\";}s:2:\"id\";s:34:\"paragraph.field_ept_countdown_date\";s:10:\"field_name\";s:24:\"field_ept_countdown_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:8:\"datetime\";s:8:\"settings\";a:1:{s:13:\"datetime_type\";s:8:\"datetime\";}s:6:\"module\";s:8:\"datetime\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_description',_binary 'a:17:{s:4:\"uuid\";s:36:\"385056ad-483b-468c-8fc7-fa477f32138c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Vb_uSodiEH1YHgcoZFitK_cSCdO65_4U1fUOrl-0G-0\";}s:2:\"id\";s:39:\"paragraph.field_ept_counter_description\";s:10:\"field_name\";s:29:\"field_ept_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_icon',_binary 'a:17:{s:4:\"uuid\";s:36:\"bd174355-0ad0-4843-9909-9069e6e2eac2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0JA4V_sLzmSUMXzEuZ7m6J_MFEw5Nrb7bG9XU34Ucc\";}s:2:\"id\";s:32:\"paragraph.field_ept_counter_icon\";s:10:\"field_name\";s:22:\"field_ept_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_items',_binary 'a:17:{s:4:\"uuid\";s:36:\"fa2205d7-3b05-4d76-a029-30510c45d952\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vFwfw4KEUwjCwBs2-7ay4ctFQ2ObvCZYU16zxuQC5HM\";}s:2:\"id\";s:33:\"paragraph.field_ept_counter_items\";s:10:\"field_name\";s:23:\"field_ept_counter_items\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"072a57f4-9c76-4a9a-a3f4-f13ef03b81be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MzVJsn5k9Si1YXppdAIDnZzJ1W16U44-V2RnkeyaeyI\";}s:2:\"id\";s:34:\"paragraph.field_ept_counter_number\";s:10:\"field_name\";s:24:\"field_ept_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"integer\";s:8:\"settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a62c9e27-ad8b-430d-85ce-9db276ada8eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CTuSHda2RHGJciX7ZF12J7Y9A3TK_RrRj7CRxyKyNGA\";}s:2:\"id\";s:33:\"paragraph.field_ept_counter_title\";s:10:\"field_name\";s:23:\"field_ept_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"2545ccb9-b7f9-49f1-a002-1aa70a099849\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BVZIBdZwlh9CG5xDwjnekBIIuVdEEtKvFPci5rwGdA0\";}s:2:\"id\";s:36:\"paragraph.field_ept_cta_column_image\";s:10:\"field_name\";s:26:\"field_ept_cta_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"ef4b1edf-7e44-4fd4-9484-139b43615d23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LvryVrIdU5CC3UNEhpU7Vej6X8Y4RKKDsOdhseGGUVg\";}s:2:\"id\";s:28:\"paragraph.field_ept_cta_link\";s:10:\"field_name\";s:18:\"field_ept_cta_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"e5ac8a81-1f96-4b7d-b8e0-6d9b2c08fcbd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DHvUvJxjsMX4y4-L8sAyVpFvA0pptpqcHZ8p_EMBBdU\";}s:2:\"id\";s:35:\"paragraph.field_ept_cta_second_link\";s:10:\"field_name\";s:25:\"field_ept_cta_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_gallery_item',_binary 'a:17:{s:4:\"uuid\";s:36:\"a1361495-0a6d-4f18-8570-b713e198ddf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8JLKZdRZR-OD6hbmGc3VHufx5PLi683tbf4QM_K4ZAU\";}s:2:\"id\";s:32:\"paragraph.field_ept_gallery_item\";s:10:\"field_name\";s:22:\"field_ept_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_gallery_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ceb57be4-05e2-49c4-afad-48cb1341e682\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cWuIwOJOPOwoJ4OA0TCSko2wR73oMOOVlyC7clefebo\";}s:2:\"id\";s:37:\"paragraph.field_ept_gallery_item_text\";s:10:\"field_name\";s:27:\"field_ept_gallery_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"0bd5b0b1-4d3b-472e-ac51-086416f9360a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"knr6QfLVidPHSzwjlRdOZ6PqAiVNnXT73--qFC4pZqo\";}s:2:\"id\";s:37:\"paragraph.field_ept_hero_column_image\";s:10:\"field_name\";s:27:\"field_ept_hero_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"89e38776-3ba0-4f79-9023-af5e40b20171\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XgZuheOtVwvMdFAli6FX9XwC6jCtmfQsa4Y--V6AWLk\";}s:2:\"id\";s:29:\"paragraph.field_ept_hero_link\";s:10:\"field_name\";s:19:\"field_ept_hero_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"a51e7805-3dcf-415a-b08c-6e41b660115d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_LEdcxkwVZPMeBjAfFM_DTcqJxHu-SXmfvkzYA16OTE\";}s:2:\"id\";s:36:\"paragraph.field_ept_hero_second_link\";s:10:\"field_name\";s:26:\"field_ept_hero_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_title_prefix',_binary 'a:17:{s:4:\"uuid\";s:36:\"be93c2a2-2803-47c8-8cbb-88ab3561ae6c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HgeEpS7HHbPsoLeKHrpRrax2ttxvlJADvMU3R-HwVf4\";}s:2:\"id\";s:37:\"paragraph.field_ept_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ept_hero_title_prefix\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"a3a4414c-7488-42d9-ad4e-706dbb16b1da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t2q8Lh-nuJZ2Ozh8PR1_zVbozcHAD18kLOnsz0e4oxY\";}s:2:\"id\";s:25:\"paragraph.field_ept_image\";s:10:\"field_name\";s:15:\"field_ept_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"d90ba792-7242-4c28-a755-2203bfbd33dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-2PNM_k1cGXc-Q0fAWwWKl0WSoTksX8UcJ3-t0wUn1s\";}s:2:\"id\";s:33:\"paragraph.field_ept_image_caption\";s:10:\"field_name\";s:23:\"field_ept_image_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_gallery',_binary 'a:17:{s:4:\"uuid\";s:36:\"a25a51c6-fb73-441d-bfe4-baf60db380f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"42vUEff48hmnJOtdaZMLlF0wtf_QYb_mBJO5EVMCKBk\";}s:2:\"id\";s:33:\"paragraph.field_ept_image_gallery\";s:10:\"field_name\";s:23:\"field_ept_image_gallery\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"389f5e03-e7e9-4fb0-bdb5-618f4ada2579\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VKNAP2cuu9mjHYh_BiZTS3nC4gx2nPLjvdAFIHAhJs\";}s:2:\"id\";s:30:\"paragraph.field_ept_image_link\";s:10:\"field_name\";s:20:\"field_ept_image_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_micromodal_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"58a0c8d3-2aaa-43a3-af29-df451a7410e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9wlDgbRXeLI7j3BoH97N3phJfeK2l1E2osqZh_FRkh4\";}s:2:\"id\";s:36:\"paragraph.field_ept_micromodal_title\";s:10:\"field_name\";s:26:\"field_ept_micromodal_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_quote_author',_binary 'a:17:{s:4:\"uuid\";s:36:\"f68b8da9-803f-4c9b-8f4c-4fc24f899205\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yN0vOPqU28gSDN6dC5uNd2vwbTDVhm0njE_mJ2k_rCk\";}s:2:\"id\";s:32:\"paragraph.field_ept_quote_author\";s:10:\"field_name\";s:22:\"field_ept_quote_author\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_quote_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"39b9627d-fdb9-4ed9-afc4-0c4d133a92c6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tQ8LcsYTu_fXhMAvx5We58I0EB2mrFc9tC42tO2YpQ4\";}s:2:\"id\";s:31:\"paragraph.field_ept_quote_image\";s:10:\"field_name\";s:21:\"field_ept_quote_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"aed153c8-a66a-428a-be76-0d9ff9c57e30\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HvKMBmRf1ancerUpnNjtwfTeY-R4_vPBnsqEe9j-ovs\";}s:2:\"id\";s:28:\"paragraph.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:12:\"ept_settings\";s:8:\"settings\";a:0:{}s:6:\"module\";s:8:\"ept_core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider',_binary 'a:17:{s:4:\"uuid\";s:36:\"467150cb-7feb-412a-9426-4b2a3f4a1caa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"p4cFkBoz3tkJW1Ep5zM4g_f4mQ-XFHh3pShn7qHErpU\";}s:2:\"id\";s:32:\"paragraph.field_ept_slick_slider\";s:10:\"field_name\";s:22:\"field_ept_slick_slider\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"d985b37a-8f1d-4d3c-8d92-09cb8326cf66\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LzVCCy3JB_QNYYe-TIA7NOSStFsPdMhJRj2kRx6xp48\";}s:2:\"id\";s:38:\"paragraph.field_ept_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ept_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"3adc57b0-490d-4760-8c68-b19c339fedb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"urQvYyrbemmSrIdbqn5B3hiHO3OGBgCpwmTx0L9ipCM\";}s:2:\"id\";s:37:\"paragraph.field_ept_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"d8e5d125-f4f7-4c1d-ac26-f7468f91d3b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9lgsbO7ntDggj0S64_Kj04ysNSAJqsLLVWCg1sASI7o\";}s:2:\"id\";s:37:\"paragraph.field_ept_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow',_binary 'a:17:{s:4:\"uuid\";s:36:\"1a9f268a-efba-464e-854e-f46e7e1341e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNz95cfhiI0VPQ9jlgmyexwx_snf3hcYXB3N76R6FEg\";}s:2:\"id\";s:29:\"paragraph.field_ept_slideshow\";s:10:\"field_name\";s:19:\"field_ept_slideshow\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"08a96db8-eb88-4875-8250-d218a934e839\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j3IfmwQ3lYIJp87Put31sIn-_9bc3uFqZWFLa_w_9hk\";}s:2:\"id\";s:34:\"paragraph.field_ept_slideshow_link\";s:10:\"field_name\";s:24:\"field_ept_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_slide',_binary 'a:17:{s:4:\"uuid\";s:36:\"d704c8d4-b783-49b6-af10-1f4524374151\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qxeflsuOm7AVY0acEDYWC8RbV1WUHCbVdEWrV-i8xCU\";}s:2:\"id\";s:35:\"paragraph.field_ept_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ept_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"8f6db9bb-d214-4b8e-a41e-8e68af02013e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hf7ieZizeOOo0vAYdXIuWovA7ihSiu5RQ6PQD9LV27c\";}s:2:\"id\";s:34:\"paragraph.field_ept_slideshow_text\";s:10:\"field_name\";s:24:\"field_ept_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"c605bbbd-911f-4bca-9f1d-7575ba23063c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tyAlxAEOc2ScLxGA0DPp-lg0u4x8VXHrFuotd44B_SE\";}s:2:\"id\";s:35:\"paragraph.field_ept_slideshow_title\";s:10:\"field_name\";s:25:\"field_ept_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats',_binary 'a:17:{s:4:\"uuid\";s:36:\"54f29aab-0b38-45f1-bef4-33ea7848198c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A2WIvrY8Lq2oUgdXcZ6AeYNUvyM4mmPAuE7W3ZK_2Wc\";}s:2:\"id\";s:25:\"paragraph.field_ept_stats\";s:10:\"field_name\";s:15:\"field_ept_stats\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"32ff7444-1fb2-4c29-97a3-9e9f53ec491a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UoI74uzcaxvNAutge4YEMTgWFuRMeasXrgpq3PK1sVs\";}s:2:\"id\";s:36:\"paragraph.field_ept_stats_item_image\";s:10:\"field_name\";s:26:\"field_ept_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"48fc10e7-9c7a-4b33-8f60-3ce608c713c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r9tIHirJngA0lU8nZzF4zo3Sk3sZoNMDm7tn4Q8f6nU\";}s:2:\"id\";s:35:\"paragraph.field_ept_stats_item_link\";s:10:\"field_name\";s:25:\"field_ept_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"e0b4af62-c275-4029-b2a7-59ffabd9c786\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HhOT5HnntE62swJxbAxEUWcqiYJnPIfz8wawWbRbXDs\";}s:2:\"id\";s:37:\"paragraph.field_ept_stats_item_number\";s:10:\"field_name\";s:27:\"field_ept_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9bab1d24-d574-48e2-8d0e-4ab68fb47d98\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IMNMgfxAACwo5FdbEzobs2cmUZRx-IryVkWAVFd6jPc\";}s:2:\"id\";s:35:\"paragraph.field_ept_stats_item_text\";s:10:\"field_name\";s:25:\"field_ept_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tabs',_binary 'a:17:{s:4:\"uuid\";s:36:\"79fcf2b8-c7f0-45ad-b0c1-f2032eef3896\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NMqcA7Fqw60GbpdVeUtmztxo2zdXkrGvZx8twbTDDeU\";}s:2:\"id\";s:24:\"paragraph.field_ept_tabs\";s:10:\"field_name\";s:14:\"field_ept_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"14901660-c7de-459b-8e6b-6065e1894829\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mkRqIh2Wq5dPyqwbNdS4O7366xpiXfnEqoCKO_Dxil8\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_block\";s:10:\"field_name\";s:19:\"field_ept_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_content',_binary 'a:17:{s:4:\"uuid\";s:36:\"87c56ad4-62d6-4644-86c1-680e4755ff8b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"options\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fKb1I7aWTTDXPpSXxFasd3Do_zu03KEABHYH6l26zZU\";}s:2:\"id\";s:31:\"paragraph.field_ept_tab_content\";s:10:\"field_name\";s:21:\"field_ept_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"list_string\";s:8:\"settings\";a:2:{s:14:\"allowed_values\";a:4:{i:0;a:2:{s:5:\"value\";s:4:\"text\";s:5:\"label\";s:4:\"Text\";}i:1;a:2:{s:5:\"value\";s:4:\"page\";s:5:\"label\";s:4:\"Page\";}i:2;a:2:{s:5:\"value\";s:5:\"block\";s:5:\"label\";s:5:\"Block\";}i:3;a:2:{s:5:\"value\";s:5:\"views\";s:5:\"label\";s:5:\"Views\";}}s:23:\"allowed_values_function\";s:0:\"\";}s:6:\"module\";s:7:\"options\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_page',_binary 'a:17:{s:4:\"uuid\";s:36:\"dd8a6a77-dce1-4167-81fc-78b560cda129\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HG0HGpRQXhX56PVuj3x5C5jDc-vtEneALavRoeN1CvM\";}s:2:\"id\";s:28:\"paragraph.field_ept_tab_page\";s:10:\"field_name\";s:18:\"field_ept_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"node\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"843571d5-1f13-41be-91d6-4a2cdc24036d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-LqQ-u0-ZIOFFNbSXCCLceO2nHJcofY3jorF2Bo_oOs\";}s:2:\"id\";s:28:\"paragraph.field_ept_tab_text\";s:10:\"field_name\";s:18:\"field_ept_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"75781815-4f60-47eb-bdc4-255e273d1add\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jmZoEFoCrYRXWTQoBNH-lk2Jtzlrk1QgYJW-ZwiojjU\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_title\";s:10:\"field_name\";s:19:\"field_ept_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"text\";s:8:\"settings\";a:1:{s:10:\"max_length\";i:255;}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_views',_binary 'a:17:{s:4:\"uuid\";s:36:\"0210aa9b-f809-485d-9dc9-01d5b19a7a97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yuhCLkHFy1lOVHdkbi-9gSbiwW6Cz9cKfJdJaYwK_Pk\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_views\";s:10:\"field_name\";s:19:\"field_ept_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"e76f4c36-a02a-4c1e-b34f-cecbd30657dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7r3ygKhgvLH2hBQgQ6uizJgLea8q4TUMhKv9AysHhVw\";}s:2:\"id\";s:24:\"paragraph.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad3c2c1b-78c7-400a-a114-8f5a64daf409\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XenLJeS9-3QAxnei6iPwJsGOprgjG7bUCwDd60onVWw\";}s:2:\"id\";s:25:\"paragraph.field_ept_tiles\";s:10:\"field_name\";s:15:\"field_ept_tiles\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"c84089e9-ca27-4ede-81db-501ab243fe10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LTIRUfdCjzSopVuoQqk229l5haSvo7JDJ2W9r1MheDo\";}s:2:\"id\";s:31:\"paragraph.field_ept_tiles_image\";s:10:\"field_name\";s:21:\"field_ept_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"62135f80-efc0-4ec3-883a-ce4ccfe66aaa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ca5c5aWMZPNjvFUQqM813ltjPOGiBvCBP1o5N8IrcOM\";}s:2:\"id\";s:30:\"paragraph.field_ept_tiles_link\";s:10:\"field_name\";s:20:\"field_ept_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"095f6e1d-c38c-4e36-824d-929e502f2c16\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K1TV7SR5GOPQTJv3GF_zAIsJciKLKB5xd_eo3WUc5HA\";}s:2:\"id\";s:30:\"paragraph.field_ept_tiles_text\";s:10:\"field_name\";s:20:\"field_ept_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a21fa265-c368-46f8-b0bf-ccd4251290bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fWLTZKbXw0jB-UFCqh6l4jRNvxOPFhGWVUKUjcIHfEg\";}s:2:\"id\";s:31:\"paragraph.field_ept_tiles_title\";s:10:\"field_name\";s:21:\"field_ept_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"d142f67c-eb14-402b-8d63-83e817038f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjnRL-vwDWFKmoYTCU9jkwjIlui_gNnOJnIwnLo9m2k\";}s:2:\"id\";s:25:\"paragraph.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"30383ff9-015d-4872-a3cb-3c814a4683f6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WUq7ljAeKbQ5WQGxUm1FFT157H56wcSHSihAGR-RPhc\";}s:2:\"id\";s:25:\"paragraph.field_ept_video\";s:10:\"field_name\";s:15:\"field_ept_video\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_videos_and_images',_binary 'a:17:{s:4:\"uuid\";s:36:\"fb3b02a6-684b-4508-8b49-e87fa4e916c1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P8bQebl9F2OCnDtVw7LFuwUlmGfUGA7HLJaYolmUgpU\";}s:2:\"id\";s:37:\"paragraph.field_ept_videos_and_images\";s:10:\"field_name\";s:27:\"field_ept_videos_and_images\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_views_view',_binary 'a:17:{s:4:\"uuid\";s:36:\"8622c9ec-6687-4349-af19-885f22d99285\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GjkDxormsrh0OTX-iAPBLiJLIDg3h8b7yPlpgyt-kM\";}s:2:\"id\";s:30:\"paragraph.field_ept_views_view\";s:10:\"field_name\";s:20:\"field_ept_views_view\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_webform_form',_binary 'a:17:{s:4:\"uuid\";s:36:\"a88d5b44-1516-4b8b-96a9-776c192940bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PpYNq6QObTDp2wWrcCdc7DcYdgeYKcySPhoxN3JbQ0c\";}s:2:\"id\";s:32:\"paragraph.field_ept_webform_form\";s:10:\"field_name\";s:22:\"field_ept_webform_form\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_webform_popup_form',_binary 'a:17:{s:4:\"uuid\";s:36:\"5c2ba04c-75d7-42c4-b482-67caddfd5348\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0JLSwQyxgVansS3j_MWcmzVVNlzTh7AvepEBcn10Cyk\";}s:2:\"id\";s:38:\"paragraph.field_ept_webform_popup_form\";s:10:\"field_name\";s:28:\"field_ept_webform_popup_form\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"233edf85-6a6a-473c-933a-1a6a9015993a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:2:\"id\";s:17:\"user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1nMi90W6YQxKzZAgJQw7Ag9U4JrsEUwkomF0lhvbIM\";}s:12:\"field_prefix\";s:6:\"field_\";}'),('','file.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bwjZB1IjEYbppgZT3g7YW_5h_LDZYNa3DaDEfWX82U\";}s:11:\"description\";a:2:{s:4:\"type\";s:9:\"textfield\";s:6:\"length\";i:128;}s:4:\"icon\";a:1:{s:9:\"directory\";s:23:\"core/modules/file/icons\";}s:35:\"make_unused_managed_files_temporary\";b:0;s:21:\"filename_sanitization\";a:6:{s:13:\"transliterate\";b:0;s:18:\"replace_whitespace\";b:0;s:24:\"replace_non_alphanumeric\";b:0;s:22:\"deduplicate_separators\";b:0;s:9:\"lowercase\";b:0;s:21:\"replacement_character\";s:1:\"-\";}}'),('','file_mdm.file_metadata_plugin.getimagesize',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o53U_2I-21Es-9iqxeUMDRcRxN0spL1OiHuAVQhh2oI\";}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','file_mdm.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fOx6TBj_84WfX_a6JhuWiPQ-twAjHykvYsTvJAKbZsE\";}s:14:\"metadata_cache\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}s:22:\"missing_file_log_level\";i:3;}'),('','file_mdm_exif.file_metadata_plugin.exif',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u0ZqkNrnyVSnHXGBP0zlKY9dP1ZARzJZ9VSovzU_eDg\";}s:7:\"ifd_map\";a:5:{i:0;a:2:{s:4:\"type\";i:0;s:7:\"aliases\";a:3:{i:0;s:1:\"0\";i:1;s:4:\"IFD0\";i:2;s:4:\"Main\";}}i:1;a:2:{s:4:\"type\";i:1;s:7:\"aliases\";a:3:{i:0;s:1:\"1\";i:1;s:4:\"IFD1\";i:2;s:9:\"Thumbnail\";}}s:4:\"Exif\";a:2:{s:4:\"type\";i:2;s:7:\"aliases\";a:1:{i:0;s:4:\"Exif\";}}s:3:\"GPS\";a:2:{s:4:\"type\";i:3;s:7:\"aliases\";a:1:{i:0;s:3:\"GPS\";}}s:16:\"Interoperability\";a:2:{s:4:\"type\";i:4;s:7:\"aliases\";a:2:{i:0;s:16:\"Interoperability\";i:1;s:7:\"Interop\";}}}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','file_mdm_font.file_metadata_plugin.font',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o53U_2I-21Es-9iqxeUMDRcRxN0spL1OiHuAVQhh2oI\";}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','filter.format.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"9ffd8de5-5d95-4675-941e-b6205d96c828\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:6:\"editor\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mclCbTlJwWJORez4Y1eX2MqA0aGjSMAoJb3TaBABcK8\";}s:4:\"name\";s:10:\"Basic HTML\";s:6:\"format\";s:10:\"basic_html\";s:6:\"weight\";i:-9;s:7:\"filters\";a:6:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:7;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:243:\"<br> <p> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id> <cite> <dl> <dt> <dd> <a hreflang href> <blockquote cite> <ul type> <ol start type> <strong> <em> <code> <li> <img src alt data-entity-uuid data-entity-type height width data-caption data-align>\";s:16:\"filter_html_help\";b:0;s:20:\"filter_html_nofollow\";b:0;}}s:24:\"filter_html_image_secure\";a:5:{s:2:\"id\";s:24:\"filter_html_image_secure\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}}}'),('','filter.format.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"5837f230-16d1-4857-8f42-39560aa7f6bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:32:\"core.entity_view_mode.media.full\";}s:6:\"module\";a:2:{i:0;s:6:\"editor\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpZysv3RHJjhYzq7O_q5q8mVlHdrSzKELmXyiX6RtV0\";}s:4:\"name\";s:9:\"Full HTML\";s:6:\"format\";s:9:\"full_html\";s:6:\"weight\";i:-10;s:7:\"filters\";a:7:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:0;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:38:\"<span class=\"title-prefix white-text\">\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:20:\"filter_htmlcorrector\";a:5:{s:2:\"id\";s:20:\"filter_htmlcorrector\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}s:11:\"media_embed\";a:5:{s:2:\"id\";s:11:\"media_embed\";s:8:\"provider\";s:5:\"media\";s:6:\"status\";b:1;s:6:\"weight\";i:100;s:8:\"settings\";a:3:{s:17:\"default_view_mode\";s:7:\"default\";s:18:\"allowed_view_modes\";a:2:{s:7:\"default\";s:7:\"default\";s:4:\"full\";s:4:\"full\";}s:19:\"allowed_media_types\";a:3:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";s:5:\"video\";s:5:\"video\";}}}}}'),('','filter.format.plain_text',_binary 'a:9:{s:4:\"uuid\";s:36:\"e7b49ea5-e3d9-43a7-9355-811016606856\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JLMwODO0epnA_H-jFlH9ezVfa5YBJniRv3MmLqYNl_Q\";}s:4:\"name\";s:10:\"Plain text\";s:6:\"format\";s:10:\"plain_text\";s:6:\"weight\";i:-7;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:18:\"filter_html_escape\";a:5:{s:2:\"id\";s:18:\"filter_html_escape\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:0:{}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.format.restricted_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"b26630f8-bc66-410b-9271-2fd35673a39c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QiKqQS_YGAT3Qr4vaAgZICJknm-MGCzt_xBAMqg-tRM\";}s:4:\"name\";s:15:\"Restricted HTML\";s:6:\"format\";s:15:\"restricted_html\";s:6:\"weight\";i:-8;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:149:\"<a href hreflang> <em> <strong> <cite> <blockquote cite> <code> <ul type> <ol start type> <li> <dl> <dt> <dd> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id>\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.format.webform_default',_binary 'a:9:{s:4:\"uuid\";s:36:\"3692adcd-2f32-40f4-8ab0-3369f24cb8e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EeKp_M4Oid3erARiAam9rsgBKR91uEnFkEP3aZS2ol8\";}s:4:\"name\";s:31:\"Webform (Default) - DO NOT EDIT\";s:6:\"format\";s:15:\"webform_default\";s:6:\"weight\";i:100;s:7:\"filters\";a:0:{}}'),('','filter.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiPjM3WdB__ruFA7B6TLwni_UcZbmek5G4b2dxQItxA\";}s:15:\"fallback_format\";s:10:\"plain_text\";s:27:\"always_show_fallback_choice\";b:0;}'),('','gin.settings',_binary 'a:17:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ug4-rUG_KE9H5v1RaDLLpkSZsu70E9HnJp6sqFfjvHk\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:1;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:19:\"preset_accent_color\";s:4:\"blue\";s:18:\"preset_focus_color\";s:3:\"gin\";s:15:\"enable_darkmode\";s:1:\"0\";s:15:\"classic_toolbar\";s:7:\"classic\";s:26:\"secondary_toolbar_frontend\";b:1;s:18:\"high_contrast_mode\";b:0;s:12:\"accent_color\";s:0:\"\";s:11:\"focus_color\";s:0:\"\";s:14:\"layout_density\";s:7:\"default\";s:23:\"show_description_toggle\";b:0;s:24:\"show_user_theme_settings\";b:0;s:21:\"sticky_action_buttons\";b:0;}'),('','glightbox.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5G059LQS_7DV7oGUpxVTPM0aWtunW7bvDpRkgeb0KtE\";}s:6:\"custom\";a:17:{s:8:\"activate\";i:0;s:11:\"open_effect\";s:4:\"zoom\";s:12:\"close_effect\";s:4:\"zoom\";s:12:\"slide_effect\";s:5:\"slide\";s:5:\"width\";s:3:\"98%\";s:6:\"height\";s:3:\"98%\";s:11:\"videosWidth\";s:5:\"960px\";s:22:\"close_on_outside_click\";b:1;s:9:\"more_text\";s:8:\"See more\";s:11:\"more_length\";i:60;s:13:\"desc_position\";s:6:\"bottom\";s:4:\"loop\";b:0;s:8:\"zoomable\";b:1;s:9:\"draggable\";b:1;s:7:\"preload\";b:1;s:15:\"autoplay_videos\";b:1;s:16:\"autofocus_videos\";b:0;}s:8:\"advanced\";a:2:{s:12:\"unique_token\";i:0;s:16:\"compression_type\";s:8:\"minified\";}}'),('','image.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-yDFHbqNfpe-Srg4sdCSqaosCl2D8uwyEY5esF8gEw\";}s:13:\"preview_image\";s:29:\"core/modules/image/sample.png\";s:26:\"allow_insecure_derivatives\";b:0;s:20:\"suppress_itok_output\";b:0;}'),('','image.style.ept_gallery_image',_binary 'a:8:{s:4:\"uuid\";s:36:\"96327273-04cd-4db7-9889-976db88ae72b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"image_effects\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1Q9XGhzUPbe1wp53fxzN8EbXYFVVXfNTiWQshZB1x-o\";}s:4:\"name\";s:17:\"ept_gallery_image\";s:5:\"label\";s:17:\"EPT Gallery Image\";s:7:\"effects\";a:2:{s:36:\"5a3cbdd5-32d1-49cd-a00f-bbc716cc09ef\";a:4:{s:4:\"uuid\";s:36:\"5a3cbdd5-32d1-49cd-a00f-bbc716cc09ef\";s:2:\"id\";s:24:\"image_effects_set_canvas\";s:6:\"weight\";i:-8;s:4:\"data\";a:4:{s:11:\"canvas_size\";s:5:\"exact\";s:12:\"canvas_color\";s:9:\"#FFFFFFFF\";s:5:\"exact\";a:5:{s:5:\"width\";s:3:\"365\";s:6:\"height\";s:3:\"265\";s:9:\"placement\";s:13:\"center-center\";s:8:\"x_offset\";i:0;s:8:\"y_offset\";i:0;}s:8:\"relative\";a:4:{s:4:\"left\";i:0;s:5:\"right\";i:0;s:3:\"top\";i:0;s:6:\"bottom\";i:0;}}}s:36:\"7237f375-b695-4dca-8e1a-88b52b0437ea\";a:4:{s:4:\"uuid\";s:36:\"7237f375-b695-4dca-8e1a-88b52b0437ea\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:-9;s:4:\"data\";a:3:{s:5:\"width\";i:365;s:6:\"height\";i:265;s:7:\"upscale\";b:0;}}}}'),('','image.style.ept_quote_image',_binary 'a:8:{s:4:\"uuid\";s:36:\"8ad0f8e1-bf91-4861-b98d-bd4757ce19fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R8OkUD1v3lvqA1ihlprDbuQcs3MJp_s2N37cfrJuul8\";}s:4:\"name\";s:15:\"ept_quote_image\";s:5:\"label\";s:15:\"EPT Quote Image\";s:7:\"effects\";a:1:{s:36:\"c7e1a3e5-c5e1-4f6b-92f2-525a6f9ca013\";a:4:{s:4:\"uuid\";s:36:\"c7e1a3e5-c5e1-4f6b-92f2-525a6f9ca013\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:530;s:6:\"height\";N;s:7:\"upscale\";b:1;}}}}'),('','image.style.ept_slick_slider_card',_binary 'a:8:{s:4:\"uuid\";s:36:\"d5e3c8ee-d135-4d9b-87f8-3983d8804dd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TLssjGEnnOFSTHjAehxDElobDdWsdzT8XjjY2Ru_ZTQ\";}s:4:\"name\";s:21:\"ept_slick_slider_card\";s:5:\"label\";s:21:\"EPT Slick Slider card\";s:7:\"effects\";a:1:{s:36:\"55a5d05a-911b-44f6-8154-26bf4d5f89a2\";a:4:{s:4:\"uuid\";s:36:\"55a5d05a-911b-44f6-8154-26bf4d5f89a2\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:6:\"anchor\";s:13:\"center-center\";}}}}'),('','image.style.ept_video_and_image_gallery',_binary 'a:8:{s:4:\"uuid\";s:36:\"c7167138-d49d-4235-8671-ee7f0d2d2b21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VijhP4To3EdFocRuOjCdr8vV8fPomTYloLASZEYa0pc\";}s:4:\"name\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:27:\"EPT Video and Image gallery\";s:7:\"effects\";a:1:{s:36:\"dd219b2f-d95b-480c-83e9-b9b81fe45c90\";a:4:{s:4:\"uuid\";s:36:\"dd219b2f-d95b-480c-83e9-b9b81fe45c90\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:360;s:6:\"anchor\";s:13:\"center-center\";}}}}'),('','image.style.large',_binary 'a:8:{s:4:\"uuid\";s:36:\"1d081002-40ce-4508-b331-45087f55f851\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDR2BOewa2UFH9yG4tVvrGxEVv8U7LQo-RLkJhFpERs\";}s:4:\"name\";s:5:\"large\";s:5:\"label\";s:16:\"Large (480×480)\";s:7:\"effects\";a:2:{s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";a:4:{s:4:\"uuid\";s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:480;s:7:\"upscale\";b:0;}}s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";a:4:{s:4:\"uuid\";s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.media_library',_binary 'a:8:{s:4:\"uuid\";s:36:\"dce163df-e6d0-4a19-be9f-835d8fb9ad19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FxMdscEA4aDH0KPM73HIZtVn3zIAgC1kQ3CkBw26HYs\";}s:4:\"name\";s:13:\"media_library\";s:5:\"label\";s:34:\"Media Library thumbnail (220×220)\";s:7:\"effects\";a:2:{s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";a:4:{s:4:\"uuid\";s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";a:4:{s:4:\"uuid\";s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.medium',_binary 'a:8:{s:4:\"uuid\";s:36:\"cc99d86c-9cb9-4913-9000-8ea5ef978940\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dlar76VBuGj5iMGTruB_uMZX8VbivXt9_QLemaG2q4E\";}s:4:\"name\";s:6:\"medium\";s:5:\"label\";s:17:\"Medium (220×220)\";s:7:\"effects\";a:2:{s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";a:4:{s:4:\"uuid\";s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";a:4:{s:4:\"uuid\";s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.thumbnail',_binary 'a:8:{s:4:\"uuid\";s:36:\"45c23df0-c353-4723-86c7-ddfc29333553\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BgeBV-xOFINMsz-y2thm45EGesj6bRM6DTLZ6ce3V9I\";}s:4:\"name\";s:9:\"thumbnail\";s:5:\"label\";s:20:\"Thumbnail (100×100)\";s:7:\"effects\";a:2:{s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";a:4:{s:4:\"uuid\";s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:100;s:6:\"height\";i:100;s:7:\"upscale\";b:0;}}s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";a:4:{s:4:\"uuid\";s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.wide',_binary 'a:8:{s:4:\"uuid\";s:36:\"7407b366-d102-42ad-8d9b-28fc84ce386e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XHh3ATMH7z4ljwmzdndM47qNMkgLnoYsP98rGxVgCOw\";}s:4:\"name\";s:4:\"wide\";s:5:\"label\";s:11:\"Wide (1090)\";s:7:\"effects\";a:2:{s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";a:4:{s:4:\"uuid\";s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:1090;s:6:\"height\";N;s:7:\"upscale\";b:0;}}s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";a:4:{s:4:\"uuid\";s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image_effects.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eaXmaPSud65p-XhTwMIL9vKETD9zR3qNOMMa5EUuoNw\";}s:14:\"color_selector\";a:2:{s:9:\"plugin_id\";s:10:\"html_color\";s:15:\"plugin_settings\";a:1:{s:10:\"html_color\";a:0:{}}}s:14:\"image_selector\";a:2:{s:9:\"plugin_id\";s:5:\"basic\";s:15:\"plugin_settings\";a:1:{s:5:\"basic\";a:0:{}}}s:13:\"font_selector\";a:2:{s:9:\"plugin_id\";s:5:\"basic\";s:15:\"plugin_settings\";a:1:{s:5:\"basic\";a:0:{}}}}'),('','layout_paragraphs.modal_settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z9zmTNfo1bY0sbqYp1OAvqSynu_DXDRdJoZhi7oiS0I\";}s:5:\"width\";s:3:\"90%\";s:6:\"height\";s:4:\"auto\";s:10:\"autoresize\";b:1;}'),('','layout_paragraphs.settings',_binary 'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HBy2Jf-2HHsgvIjldhAl07r9vuy879dsx6Cm_LpbPrw\";}s:21:\"show_paragraph_labels\";i:0;s:18:\"show_layout_labels\";i:0;s:25:\"paragraph_behaviors_label\";s:9:\"Behaviors\";s:28:\"paragraph_behaviors_position\";i:-99;s:13:\"empty_message\";s:21:\"No components to add.\";}'),('','media.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WCFqLQAxMw1weToDJEhfnW1Z-iOF7cqMdL8X7YTFxBA\";}s:13:\"icon_base_uri\";s:28:\"public://media-icons/generic\";s:13:\"iframe_domain\";N;s:20:\"oembed_providers_url\";s:33:\"https://oembed.com/providers.json\";s:14:\"standalone_url\";b:0;}'),('','media.type.audio',_binary 'a:13:{s:4:\"uuid\";s:36:\"6a011382-b41c-428b-bec3-c2acb1a0b347\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJw8n6Tk2tO3ZysuEeGR1gZa1yRffaZzR4t0Q7iNurs\";}s:2:\"id\";s:5:\"audio\";s:5:\"label\";s:5:\"Audio\";s:11:\"description\";s:28:\"A locally hosted audio file.\";s:6:\"source\";s:10:\"audio_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_audio_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.document',_binary 'a:13:{s:4:\"uuid\";s:36:\"f7d4d4ed-07f1-4c0e-add0-5205dca6bb2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_D9q3XSnP6ik9we9UuoTvZsQKPuYNp_G9PfwVtWzgnQ\";}s:2:\"id\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:44:\"An uploaded file or document, such as a PDF.\";s:6:\"source\";s:4:\"file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:20:\"field_media_document\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.image',_binary 'a:13:{s:4:\"uuid\";s:36:\"0bf0a6ff-42d0-4443-95d9-32bb21b3d878\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Qope5wG7HUpV0tPOBMtDI_GZkHFcF1Xj4hgD9Cu_hM\";}s:2:\"id\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:36:\"Use local images for reusable media.\";s:6:\"source\";s:5:\"image\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:17:\"field_media_image\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.remote_video',_binary 'a:13:{s:4:\"uuid\";s:36:\"d833ee62-0e66-41f9-bc64-0ee184be48b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hIBTnDGgDKnCiP6HUZm1m7600DHUEpC6FN3LQ4sUgZ4\";}s:2:\"id\";s:12:\"remote_video\";s:5:\"label\";s:12:\"Remote video\";s:11:\"description\";s:46:\"A remotely hosted video from YouTube or Vimeo.\";s:6:\"source\";s:12:\"oembed:video\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:3:{s:12:\"source_field\";s:24:\"field_media_oembed_video\";s:20:\"thumbnails_directory\";s:44:\"public://oembed_thumbnails/[date:custom:Y-m]\";s:9:\"providers\";a:2:{i:0;s:7:\"YouTube\";i:1;s:5:\"Vimeo\";}}s:9:\"field_map\";a:1:{s:5:\"title\";s:4:\"name\";}}'),('','media.type.video',_binary 'a:13:{s:4:\"uuid\";s:36:\"f37b6fcf-a1f5-41c8-ad6b-ab36d7822130\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzgvcRgZHltqWf8hBmttoWh95tCJoPL25lPq9YSIRsY\";}s:2:\"id\";s:5:\"video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:28:\"A locally hosted video file.\";s:6:\"source\";s:10:\"video_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_video_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media_library.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3gQsCnZELUjUUqHk8SSh8bXnx7TZwN95vctAeVJG60\";}s:11:\"advanced_ui\";b:0;}'),('','menu_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SqMarzIjxC3F8dZo9FEOxfqDKD_sdW1tbcFTV1BA2zU\";}s:24:\"override_parent_selector\";b:0;}'),('','node.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W0cgFPhPJ3gAdqm06-az48BLf5MVcoZVS0HdByoofi0\";}s:15:\"use_admin_theme\";b:1;}'),('','node.type.article',_binary 'a:13:{s:4:\"uuid\";s:36:\"9597cbd8-ec71-47b6-98f5-c2eeebffff0e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"menu_ui\";}}s:20:\"third_party_settings\";a:1:{s:7:\"menu_ui\";a:2:{s:15:\"available_menus\";a:1:{i:0;s:4:\"main\";}s:6:\"parent\";s:5:\"main:\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fe3N1uqaAyyKJbVkqT-btXy3t98puW8GCRD822xjl10\";}s:4:\"name\";s:7:\"Article\";s:4:\"type\";s:7:\"article\";s:11:\"description\";s:89:\"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),('','node.type.page',_binary 'a:12:{s:4:\"uuid\";s:36:\"e24a8178-cabf-4c12-8439-99829f4ce10e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"i0snV8Wj--OkRW12UdachUiYiz3FbeMwHu_pZYfzKLc\";}s:4:\"name\";s:10:\"Basic page\";s:4:\"type\";s:4:\"page\";s:11:\"description\";s:77:\"Use <em>basic pages</em> for your static content, such as an \'About us\' page.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),('','olivero.settings',_binary 'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1TswGK46jyu77aIM7Z-0JVQs5bxHmo-gtgrvrQGMXxc\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:0;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:0;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:22:\"mobile_menu_all_widths\";i:0;s:22:\"site_branding_bg_color\";s:7:\"default\";s:18:\"base_primary_color\";s:7:\"#1b9ae4\";}'),('','paragraphs.paragraphs_type.ept_accordion',_binary 'a:11:{s:4:\"uuid\";s:36:\"3252260c-9d6c-4095-8836-d9e0aaa25dc6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7pqqqPfYwBkkvx32K8x5QoezX6vxHdseC3YV0ajDLEI\";}s:2:\"id\";s:13:\"ept_accordion\";s:5:\"label\";s:17:\"EPT Accordion/FAQ\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:41:\"Extra Paragraph Type (EPT): Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_accordion_section',_binary 'a:11:{s:4:\"uuid\";s:36:\"4290efa9-ba8f-4d75-8ae5-02743a3c35f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fmkcpDXAJK73b4nzzBnj4rVGpuHiDLrUxBK6rbvbQMY\";}s:2:\"id\";s:21:\"ept_accordion_section\";s:5:\"label\";s:35:\"EPT Accordion section / FAQ section\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:46:\"Accordion or FAQ section for EPT Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_basic_button',_binary 'a:11:{s:4:\"uuid\";s:36:\"29db5768-3c25-444b-84f5-1a0ab0ba6377\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gzUQpZ2WLaq6cYbIJG9au02yBTA2Hi4xUPtwlz0CRhU\";}s:2:\"id\";s:16:\"ept_basic_button\";s:5:\"label\";s:16:\"EPT Basic Button\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:39:\"Extra Paragraph Type (EPT) Basic Button\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_block',_binary 'a:11:{s:4:\"uuid\";s:36:\"698fe7c4-0789-4365-b3ce-d8bbd2d7d879\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hSup62OW-6glALkcPyijfub_HXz0FNzEQuWRhyhtdXk\";}s:2:\"id\";s:9:\"ept_block\";s:5:\"label\";s:9:\"EPT Block\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Block\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_bootstrap_button',_binary 'a:11:{s:4:\"uuid\";s:36:\"ffeadf94-a846-4eeb-af7e-504e5b867d19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4txRVN0PevwIGZwVEjxCxQoHq3fJGXNtgncbg5k5JDA\";}s:2:\"id\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:20:\"EPT Bootstrap Button\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:44:\"Extra Paragraph Type (EPT): Bootstrap Button\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_cards',_binary 'a:11:{s:4:\"uuid\";s:36:\"09477678-6921-49a1-a83f-aa21d8c811e4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O5-AP0c7q_30fQrLxjgjT1f3vqE1eDPHYVEJS53hyPQ\";}s:2:\"id\";s:9:\"ept_cards\";s:5:\"label\";s:9:\"EPT Cards\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:37:\"Extra Paragraph Type (EPT): EPT Cards\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_carousel',_binary 'a:11:{s:4:\"uuid\";s:36:\"0f8caf80-346b-4e13-bb09-4c47aafab045\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E7xdcbl_-Um-sC9AVRpej77V2ILldHA3_zXTVVCz1sY\";}s:2:\"id\";s:12:\"ept_carousel\";s:5:\"label\";s:12:\"EPT Carousel\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_carousel_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"07a0dbc7-10e5-4ae6-897e-e0a112e89e81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YtKbftJ20RlhAbMlxwbbttKpDr7oOd_NrNquqRUyXK8\";}s:2:\"id\";s:17:\"ept_carousel_item\";s:5:\"label\";s:17:\"EPT Carousel Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:30:\"Carousel item for EPT Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_columns',_binary 'a:11:{s:4:\"uuid\";s:36:\"e359103e-fb7d-4814-b51e-5b6eb0bf50cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fmkytBjjMOfcRpE_qi-piB3B8O6AiLkllwZyK_sI7Gw\";}s:2:\"id\";s:11:\"ept_columns\";s:5:\"label\";s:23:\"EPT Columns / Container\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_countdown',_binary 'a:11:{s:4:\"uuid\";s:36:\"d468b305-ccc4-4dd1-827a-5ac37883f188\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BqPVlvdHbcXEIez6BBufo--6hdhOwAkO8rjIkAK5jq4\";}s:2:\"id\";s:13:\"ept_countdown\";s:5:\"label\";s:13:\"EPT Countdown\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:37:\"Extra Paragraph Type (EPT): Countdown\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_counter',_binary 'a:11:{s:4:\"uuid\";s:36:\"fb9a64bf-58bb-4e29-a23f-83bc70d9958c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Seed1ZP-O7N7haFpWM63DgrcW90m0L3mwRpNqOVCvms\";}s:2:\"id\";s:11:\"ept_counter\";s:5:\"label\";s:11:\"EPT Counter\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:66:\"Adds Counter with coffee cups, projects, case studies number, etc.\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_counter_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"8fca0905-ad07-4e5a-b80e-a842bece8ab5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1DUe53zhmyI3hSvz4PGQ9EcXk8A47wdqyIrDi3aJmo8\";}s:2:\"id\";s:16:\"ept_counter_item\";s:5:\"label\";s:16:\"EPT Counter Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:64:\"Counter Items to be used inside of Paragraph Type: \"EPT Counter\"\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_cta',_binary 'a:11:{s:4:\"uuid\";s:36:\"5a3625a2-f528-429b-8415-b0b1eface1d4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-6Ujd6Cr-x8TD472fJ9SX66k2Pn7_uw07fVQWq1DXQk\";}s:2:\"id\";s:7:\"ept_cta\";s:5:\"label\";s:24:\"EPT Call to Action (CTA)\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:48:\"Extra Paragraph Type (EPT): Call to Action (CTA)\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_hero',_binary 'a:11:{s:4:\"uuid\";s:36:\"ced6180f-b154-47b8-a7b7-61647c71db48\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kps1UJbRPEF2GuSjDQDJFWWG5EZ6qTHII92BJxLlwTk\";}s:2:\"id\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"EPT Hero\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): EPT Hero\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_image',_binary 'a:11:{s:4:\"uuid\";s:36:\"f1d6ed2b-6a40-4f21-930f-5cd318945855\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GEIZEGHO5Mf_kO9Yek21HvRO-j_2fbPepBSsr35U_zY\";}s:2:\"id\";s:9:\"ept_image\";s:5:\"label\";s:9:\"EPT Image\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Image\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"ec405efa-b146-4a07-abc8-d507909706f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fQ2CW1Vm9f_8Xi0V4exsAGpv8RdV6Ptm-cjffg9lPyM\";}s:2:\"id\";s:17:\"ept_image_gallery\";s:5:\"label\";s:17:\"EPT Image Gallery\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:41:\"Extra Paragraph Type (EPT): Image Gallery\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_micromodal',_binary 'a:11:{s:4:\"uuid\";s:36:\"3188911c-48a1-42f6-8342-f2b8eb94edff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OvFmHRYOT8js98yougS_zy_ICFqOce54ziNcxoCbTq8\";}s:2:\"id\";s:14:\"ept_micromodal\";s:5:\"label\";s:14:\"EPT Micromodal\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:38:\"Extra Paragraph Type (EPT): Micromodal\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_quote',_binary 'a:11:{s:4:\"uuid\";s:36:\"e7cc4707-218e-4bb9-bcbe-65d47620375d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zd4SMxSGtEMXFqSse2TdY999VhcjYnraQj7qnFhHo6Q\";}s:2:\"id\";s:9:\"ept_quote\";s:5:\"label\";s:9:\"EPT Quote\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Quote\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slick_slider',_binary 'a:11:{s:4:\"uuid\";s:36:\"d1c90790-b1df-488f-a53e-bc8c9bbe2e9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kF1ktW9usSGMpm4KK6xObCSXk1ZU-mWLNc7N1B5IN3A\";}s:2:\"id\";s:16:\"ept_slick_slider\";s:5:\"label\";s:16:\"EPT Slick Slider\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:40:\"Extra Paragraph Type (EPT): Slick Slider\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slick_slider_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"41cd1373-cca3-46dc-87a0-714c7a1489bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JzEHRSTeS_5k9aQaMIQiZssckNv0akkT0UHkl8qu8TE\";}s:2:\"id\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:21:\"EPT Slick Slider Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:0:\"\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slideshow',_binary 'a:11:{s:4:\"uuid\";s:36:\"b702ec4e-c33c-4331-beff-6b5b7107cc9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KeaY7LvgW90UqWSbJG60DfX1q0Up4566bgG8p85U12U\";}s:2:\"id\";s:13:\"ept_slideshow\";s:5:\"label\";s:13:\"EPT Slideshow\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:37:\"Extra Paragraph Type (EPT): Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slideshow_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"9953b7d8-252b-4d78-9b63-08418e206990\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yz4xVMckzLbuIuqcq5CLDr2LZyc6GPHhiCkw_ygR1cM\";}s:2:\"id\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:18:\"EPT Slideshow Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:35:\"Slideshow section for EPT Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_stats',_binary 'a:11:{s:4:\"uuid\";s:36:\"6838ec7f-c8a4-4325-97a7-1021f1dfe5d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KAQ05Ri6j17FmntgY7SCHOgGFRtUqdJWrNKlBxVsBsI\";}s:2:\"id\";s:9:\"ept_stats\";s:5:\"label\";s:9:\"EPT Stats\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Stats\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_stats_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"1f202608-b028-44b4-99c0-312ebcadcb47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Be2-EmGyo2-KDBpxotaDl8GmJCgv5EKdsZNMXdWrM10\";}s:2:\"id\";s:14:\"ept_stats_item\";s:5:\"label\";s:14:\"EPT Stats Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:34:\"Stats Item for EPT Stats paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tabs',_binary 'a:11:{s:4:\"uuid\";s:36:\"d64be736-43ad-47c5-a174-0a5e19f4b24a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zt6Y01DpCpOfI3LIolOc9xk6SptdAkHJlZkEp2KhkRQ\";}s:2:\"id\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"EPT Tabs\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:32:\"Extra Paragraph Type (EPT): Tabs\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tabs_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"9e15e91a-5c5e-4c79-9e75-1386629a7208\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VixuGFI2mBIwt085I9X7vz9dq9H8dh0Bb20u-pT90X8\";}s:2:\"id\";s:13:\"ept_tabs_item\";s:5:\"label\";s:13:\"EPT Tabs Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:31:\"Tab item for EPT Tabs paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_text',_binary 'a:11:{s:4:\"uuid\";s:36:\"c76a9833-ec98-4fe9-9268-c55ecc6606f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fSKAEY0p1DQvC6AE_TEi0RWHmjahL13tHQTb3WVaVik\";}s:2:\"id\";s:8:\"ept_text\";s:5:\"label\";s:8:\"EPT Text\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:31:\"Extra Paragraph Type (EPT) Text\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tiles',_binary 'a:11:{s:4:\"uuid\";s:36:\"e1accd8b-a614-4659-8cf0-f0563effdfeb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AHyDurvHt3xm3keCp8kZSod4iM7Y1JlF1O0xivGQ7As\";}s:2:\"id\";s:9:\"ept_tiles\";s:5:\"label\";s:9:\"EPT Tiles\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tiles_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"ae747fa8-05f4-441a-92bd-76441012dd9b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q4wQLWgQpxsrvWKawlFVZnqSn8qCCPj4IOKPpn7O8Po\";}s:2:\"id\";s:14:\"ept_tiles_item\";s:5:\"label\";s:14:\"EPT Tiles Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:21:\"Section for EPT Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video',_binary 'a:11:{s:4:\"uuid\";s:36:\"e50ad18b-eff8-48a4-9102-1709c8e0bb40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FU0WTLBDpLuC53lMEuAJGnwlX6sqt0SutW7q0c-btWQ\";}s:2:\"id\";s:9:\"ept_video\";s:5:\"label\";s:9:\"EPT Video\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Video\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video_and_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"dee3b2de-c5f8-4d3f-8564-0f6f24943f59\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z1YuWpAuPdJe7k9v-67rALbAapgyfzwTi2cQLvreLbo\";}s:2:\"id\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:27:\"EPT Video and Image Gallery\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:51:\"Extra Paragraph Type (EPT): Video and Image Gallery\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"1a4319ac-f841-4112-85c5-2a1ab06cb4d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OrMDgoP5KHK7xLNhKOohBVVuqmo2J4D3YWH3a3Od1Dw\";}s:2:\"id\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EPT Video and Image gallery item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:62:\"Video and Image item for EPT Video and Image Gallery paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_views',_binary 'a:11:{s:4:\"uuid\";s:36:\"7ac88ec9-7da9-488c-ac70-492b5bcfde08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JfY6zZuA9cpemb4U-YVMX2rzmT1pm_Pr1YpT7xaSxeA\";}s:2:\"id\";s:9:\"ept_views\";s:5:\"label\";s:9:\"EPT Views\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Views\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_webform',_binary 'a:11:{s:4:\"uuid\";s:36:\"95226011-0193-4ef6-9af2-4f1df3457cea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kSie3I1RcWKYzZSDRYkUpzG0jh8nhFlbo3wJd18lKVc\";}s:2:\"id\";s:11:\"ept_webform\";s:5:\"label\";s:11:\"EPT Webform\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:35:\"Extra Paragraph Type (EPT): Webform\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_webform_popup',_binary 'a:11:{s:4:\"uuid\";s:36:\"3e07ff02-27c6-4d10-98ae-318109a50f36\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Nfgfk4KcPZeTvLQf2BL053XNap0XyXoq1BIWTixbwrg\";}s:2:\"id\";s:17:\"ept_webform_popup\";s:5:\"label\";s:17:\"EPT Webform Popup\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:41:\"Extra Paragraph Type (EPT): Webform Popup\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7eR0sk71Eol86r_A7BMqn5_46wzenh5J1O5vZRCGKv8\";}s:16:\"show_unpublished\";b:1;}'),('','shortcut.set.default',_binary 'a:7:{s:4:\"uuid\";s:36:\"2b149d5c-a926-4de8-aae7-b7f45081ccab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U5VlGjd_SfV0Qm_EfnaynOfc549cNscFAx48JfYoMRI\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";}'),('','system.action.comment_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"6f753574-2b6f-4e3a-87fd-04f281182309\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpBH8OmL4sdesCdeZLsW8KOutB5gkbreWJbfjhfFKaQ\";}s:2:\"id\";s:21:\"comment_delete_action\";s:5:\"label\";s:14:\"Delete comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:28:\"entity:delete_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c8e0fba3-a9ea-40bc-9886-42d52bf69615\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C00dyL_W_5M0nFlgUB3lWUTUs96jn51Jw1MLHVEHZD0\";}s:2:\"id\";s:22:\"comment_publish_action\";s:5:\"label\";s:15:\"Publish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:29:\"entity:publish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f2a7400a-fd44-4225-906e-c04f6f5f8944\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lfyE_snmvfg_EQ3VDyhUtGAXgmqtEiqa46I3bTMg8DU\";}s:2:\"id\";s:19:\"comment_save_action\";s:5:\"label\";s:12:\"Save comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:26:\"entity:save_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"a09349ec-38d9-4ee0-b772-074a9b406491\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tWOIjSMobEWOFZddMkNqb9JySbOVwE1diC6NRqcfLTk\";}s:2:\"id\";s:24:\"comment_unpublish_action\";s:5:\"label\";s:17:\"Unpublish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:31:\"entity:unpublish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f8932ff6-cc40-43b7-9cd8-7fefb06c44cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FrZy1tmuXJcOxhXlBoI1Hsnen5TT-9OCC1iolWH84go\";}s:2:\"id\";s:19:\"media_delete_action\";s:5:\"label\";s:12:\"Delete media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:26:\"entity:delete_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"5ee77a15-afb1-4e0c-bd3b-3e462abe568d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nh83qNNrmWE-CDdHz2MdFOAk60T9mzv3R-MaKfZR2jw\";}s:2:\"id\";s:20:\"media_publish_action\";s:5:\"label\";s:13:\"Publish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:27:\"entity:publish_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"9b97ffc0-0ba9-48fc-9e78-a23777ef7ff4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VVyUA6PIaVeGtcIbgEWqJ6SYDiJdReBeojFswURFpKs\";}s:2:\"id\";s:17:\"media_save_action\";s:5:\"label\";s:10:\"Save media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:24:\"entity:save_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"59cad6a4-a038-45d4-98e9-6ace07f80050\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CsK6TseQ2DatEbZgbd30swOlZ28_HHwAESU2LvEnWq0\";}s:2:\"id\";s:22:\"media_unpublish_action\";s:5:\"label\";s:15:\"Unpublish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:29:\"entity:unpublish_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"455e72bb-d5c2-4233-8fae-fe874a5aecde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t43OqwzP3CTbcAagSsWKNy6KwMm_zShXo3c4-So6rQg\";}s:2:\"id\";s:18:\"node_delete_action\";s:5:\"label\";s:14:\"Delete content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"entity:delete_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_sticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"2003aeb9-8fd3-4006-8c7f-9129bef1a808\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sOb26JSy3fGpWkvR0WYN6_hMqj_6d1rvbvrkzp1yya0\";}s:2:\"id\";s:23:\"node_make_sticky_action\";s:5:\"label\";s:19:\"Make content sticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"node_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_unsticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"0640984c-3787-4c25-8abe-073f6ff633cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lDM9mvIGAu8Sw8rt-uCO4Sr7yX5VPrDPxYcawkbKd6k\";}s:2:\"id\";s:25:\"node_make_unsticky_action\";s:5:\"label\";s:21:\"Make content unsticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"node_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_promote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"93459360-b66a-4249-92eb-59a0d4b9e585\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N0RDBTqiK4dKoN4p4oW2j0SGWycdHyALUe9M-Ofp89U\";}s:2:\"id\";s:19:\"node_promote_action\";s:5:\"label\";s:29:\"Promote content to front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:19:\"node_promote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"6e3d2ae5-f68b-4adb-8345-78fe6e53c835\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2B9uF8NL5gutNKSdPRAhhAsDWFZZG1PJOBmx0aBGd_0\";}s:2:\"id\";s:19:\"node_publish_action\";s:5:\"label\";s:15:\"Publish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:26:\"entity:publish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7ff39d45-7ef9-4e69-a87b-aa71ae0d4343\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LhdsoZPL_pFas2fjaAWue4zvrQ_tEVofLYtcNec-JGM\";}s:2:\"id\";s:16:\"node_save_action\";s:5:\"label\";s:12:\"Save content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"entity:save_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpromote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"29499598-fb70-43f6-a160-d2522304d4e7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JBptjnfuOMtsdKygklXxoOgeOCTMtQxlkymjnnj-cC0\";}s:2:\"id\";s:21:\"node_unpromote_action\";s:5:\"label\";s:30:\"Remove content from front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"node_unpromote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"34872d09-0b48-4090-a401-75dc2bd3358d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C7X8h9FWlwkQ9y5mnU2JzgaZICAdc6HFbPVbhvjlAYE\";}s:2:\"id\";s:21:\"node_unpublish_action\";s:5:\"label\";s:17:\"Unpublish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:28:\"entity:unpublish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"8509e01a-1fe0-4d2b-80fe-6292c7281beb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DoVt_VGgVLcDD4XmVbSFzr0K17SJy9imFiYusKkJBgY\";}s:2:\"id\";s:28:\"taxonomy_term_publish_action\";s:5:\"label\";s:21:\"Publish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:35:\"entity:publish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"07d84567-f6ce-480c-94fe-71f48ce157b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z2sNRM3ECa7FPCGnSNje_9SmZJQgwhD_6fG_L4Mr8zI\";}s:2:\"id\";s:30:\"taxonomy_term_unpublish_action\";s:5:\"label\";s:23:\"Unpublish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:37:\"entity:unpublish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_add_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"080a7d5c-2fda-47ed-b9aa-be9cb07b6d2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:34:\"user_add_role_action.administrator\";s:5:\"label\";s:50:\"Add the Administrator role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_add_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"e33f0ef8-e9df-400f-b24b-60c0f3497768\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:35:\"user_add_role_action.content_editor\";s:5:\"label\";s:51:\"Add the Content editor role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_block_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ec45edef-e3ef-44f8-87d8-428346ac0579\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DyypzTfThX10FFQw-399qPfEbLLyrhXgQrKPVsmAoJ4\";}s:2:\"id\";s:22:\"user_block_user_action\";s:5:\"label\";s:26:\"Block the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:22:\"user_block_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_cancel_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7317c388-dffd-422a-b041-7ef8597810b4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nvrL9bFilzBvm2bjO9rQnFDpBA7dBBUjShSSt6NS-DU\";}s:2:\"id\";s:23:\"user_cancel_user_action\";s:5:\"label\";s:35:\"Cancel the selected user account(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_cancel_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_remove_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"a3ac7eaa-5ae2-4c20-abbb-79b198424e39\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:37:\"user_remove_role_action.administrator\";s:5:\"label\";s:55:\"Remove the Administrator role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_remove_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"daca732c-22a4-42c1-a3c8-d54dae2a458c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:38:\"user_remove_role_action.content_editor\";s:5:\"label\";s:56:\"Remove the Content editor role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_unblock_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"879c5dbe-c854-4240-b44b-cc9946b7e95b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SPsUXsR3Rc8d1y3gewzaAKWa1ncea_ywXX3f7LTn7k0\";}s:2:\"id\";s:24:\"user_unblock_user_action\";s:5:\"label\";s:28:\"Unblock the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:24:\"user_unblock_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_archive_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ec2616be-d2d8-4d45-b01a-1ae5413b4160\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OmnschvBLb9ZJn0iVyBd2odf8U8Nt0INjRbRMixZw9U\";}s:2:\"id\";s:22:\"webform_archive_action\";s:5:\"label\";s:15:\"Archive webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:22:\"webform_archive_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_close_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"a0a0e6d5-cedc-45c4-8750-df65a9373a61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dl-1T9PDkraB7MyMUjTJAioPEx6UNvIB9gqmnB1CRkk\";}s:2:\"id\";s:20:\"webform_close_action\";s:5:\"label\";s:13:\"Close webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:20:\"webform_close_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"0619fb37-5dfd-48c9-b73d-4fce7ba4215b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e1bCTp0ryXZZtnS9nlVAbtoWz3-8fmbNlqKY3GHzbsM\";}s:2:\"id\";s:21:\"webform_delete_action\";s:5:\"label\";s:14:\"Delete webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:21:\"webform_delete_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_open_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"70329b07-23bf-43c7-837b-913d499e1542\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AK83C-dOZEPruvi6GbkuhihWLnO4VtrbesqSC6izf4o\";}s:2:\"id\";s:19:\"webform_open_action\";s:5:\"label\";s:12:\"Open webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:19:\"webform_open_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"3d61837a-a6e2-456c-856f-a7adae28d2bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBnl4vapW7sy5bRi7TcF-ueJnvz7aZNLif95ifvhfTQ\";}s:2:\"id\";s:32:\"webform_submission_delete_action\";s:5:\"label\";s:17:\"Delete submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:32:\"webform_submission_delete_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_lock_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"a37fdd16-b916-42c7-a79a-e453486aa560\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MKmZlPRk3OJKNcYdYxSeZGQUh7LMah6MRShfkzch4bk\";}s:2:\"id\";s:35:\"webform_submission_make_lock_action\";s:5:\"label\";s:15:\"Lock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:35:\"webform_submission_make_lock_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_sticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"d787e419-708a-4026-aecb-296369189495\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mPWBT52fKHyINRl9S3cCWFxY3rKbwkIRxaK6sIA26oo\";}s:2:\"id\";s:37:\"webform_submission_make_sticky_action\";s:5:\"label\";s:20:\"Star/flag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_unlock_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c5c70bbf-efd5-4883-84bc-42f7d15ffaff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"begZ0-RmTzO_zDAwEKA2lKvtGYw1vbFOzbQOJzUbZX0\";}s:2:\"id\";s:37:\"webform_submission_make_unlock_action\";s:5:\"label\";s:17:\"Unlock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_unlock_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_unsticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"d1026225-bc14-481f-8e03-d69eb659f34d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4gTFiUsdp7gw6yWUlDbKFEasZLCgXWWCmm7eJejay0\";}s:2:\"id\";s:39:\"webform_submission_make_unsticky_action\";s:5:\"label\";s:24:\"Unstar/unflag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:39:\"webform_submission_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_unarchive_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f1bc7d4d-af95-4d2e-86fe-74ba836349ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aqi5Ftlnhe9KyOowpK7CanEvJMBBo8xAR1dA99bKOuc\";}s:2:\"id\";s:24:\"webform_unarchive_action\";s:5:\"label\";s:15:\"Restore webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:24:\"webform_unarchive_action\";s:13:\"configuration\";a:0:{}}'),('','system.advisories',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x0FuQ_7Cg81mSDQwG028_Z0CjH3R9ib5IDlHeV2BbAo\";}s:7:\"enabled\";b:1;s:14:\"interval_hours\";i:6;}'),('','system.cron',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f3yToH8v8EaBZU0NFFw2qR8ogSCuWVmQaN0hpYR1BD8\";}s:9:\"threshold\";a:2:{s:20:\"requirements_warning\";i:172800;s:18:\"requirements_error\";i:1209600;}s:7:\"logging\";b:1;}'),('','system.date',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IVsFTD1mvR2NGBP_1myt9kFIFmGepH4PyaN5aQBYpno\";}s:9:\"first_day\";i:0;s:7:\"country\";a:1:{s:7:\"default\";N;}s:8:\"timezone\";a:2:{s:7:\"default\";s:15:\"Europe/Belgrade\";s:4:\"user\";a:3:{s:12:\"configurable\";b:1;s:7:\"default\";i:0;s:4:\"warn\";b:0;}}}'),('','system.diff',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1WanmaEhxW_vM8_5Ktsdntj8MaO9UBHXg0lN603PsWM\";}s:7:\"context\";a:2:{s:13:\"lines_leading\";i:2;s:14:\"lines_trailing\";i:2;}}'),('','system.feature_flags',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYyVj1FtPGV40Cf65YDVTUIc7YgLH6trXlotuevfs2I\";}s:16:\"linkset_endpoint\";b:0;}'),('','system.file',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mguGHCYb9Dw5EcpfjwoShGV1Vjkbz3QuPRCLfxiye-g\";}s:22:\"allow_insecure_uploads\";b:0;s:14:\"default_scheme\";s:6:\"public\";s:21:\"temporary_maximum_age\";i:21600;}'),('','system.image',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"durWHaKeBaq4d9Wpi4RqwADj1OufDepcnJuhVLmKN24\";}s:7:\"toolkit\";s:2:\"gd\";}'),('','system.image.gd',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNXaHfkJJUThHeF0nvkoXyPLRrKYGxgHRjORvT4F5rQ\";}s:12:\"jpeg_quality\";i:75;}'),('','system.logging',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u3-njszl92FaxjrCMiq0yDcjAfcdx72w1zT1O9dx6aA\";}s:11:\"error_level\";s:4:\"hide\";}'),('','system.mail',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5PvD9swkqWUeHkabdvbJ2SQqdhrzjkCT21wtD4BLfk4\";}s:9:\"interface\";a:2:{s:7:\"default\";s:8:\"php_mail\";s:7:\"webform\";s:16:\"webform_php_mail\";}s:10:\"mailer_dsn\";a:6:{s:6:\"scheme\";s:8:\"sendmail\";s:4:\"host\";s:7:\"default\";s:4:\"user\";N;s:8:\"password\";N;s:4:\"port\";N;s:7:\"options\";a:0:{}}}'),('','system.maintenance',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1SNdA25INsV5YjlgAJtfC-6AM8VcWe_00xneMLb2yFg\";}s:8:\"langcode\";s:2:\"en\";s:7:\"message\";s:93:\"@site is currently under maintenance. We should be back shortly. Thank you for your patience.\";}'),('','system.menu.account',_binary 'a:9:{s:4:\"uuid\";s:36:\"37d50e8a-b786-4ff3-a41f-5e41d67f88b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Bh81osDyUQ4wV0GgU_NdBNqkzM87sLxjaCdFj9mnw\";}s:2:\"id\";s:7:\"account\";s:5:\"label\";s:17:\"User account menu\";s:11:\"description\";s:40:\"Links related to the active user account\";s:6:\"locked\";b:1;}'),('','system.menu.admin',_binary 'a:9:{s:4:\"uuid\";s:36:\"cf474897-e948-4315-a183-5878deecdaf0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sapEi2YDGoI9yQIT_WgIV2vUdQ6DScH0V3fAyTadAL0\";}s:2:\"id\";s:5:\"admin\";s:5:\"label\";s:14:\"Administration\";s:11:\"description\";s:25:\"Administrative task links\";s:6:\"locked\";b:1;}'),('','system.menu.footer',_binary 'a:9:{s:4:\"uuid\";s:36:\"d761cbba-9ebe-4d52-96fc-79063bff0783\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7yrlW5z9zdg2eBucB2GPqXKSMQfH9lSRSO4DbWF7AFc\";}s:2:\"id\";s:6:\"footer\";s:5:\"label\";s:6:\"Footer\";s:11:\"description\";s:22:\"Site information links\";s:6:\"locked\";b:1;}'),('','system.menu.main',_binary 'a:9:{s:4:\"uuid\";s:36:\"4108c568-d39d-4283-8af4-4ce0601c49ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q2Ra3jfoIVk0f3SjxJX61byRQFVBAbpzYDQOiY-kno8\";}s:2:\"id\";s:4:\"main\";s:5:\"label\";s:15:\"Main navigation\";s:11:\"description\";s:18:\"Site section links\";s:6:\"locked\";b:1;}'),('','system.menu.tools',_binary 'a:9:{s:4:\"uuid\";s:36:\"6e91308b-4a52-440d-824d-e3b9fb3941e2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCM-vV1zzRaLHN18dqAR_CuGOj8AFJvTx7BKl_8Gcxc\";}s:2:\"id\";s:5:\"tools\";s:5:\"label\";s:5:\"Tools\";s:11:\"description\";s:39:\"User tool links, often added by modules\";s:6:\"locked\";b:1;}'),('','system.performance',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jtno5biznHZbrIgKwzq-ze-7XaQxLCGe6PeUOR7bRiQ\";}s:5:\"cache\";a:1:{s:4:\"page\";a:1:{s:7:\"max_age\";i:0;}}s:3:\"css\";a:2:{s:10:\"preprocess\";b:0;s:4:\"gzip\";b:1;}s:8:\"fast_404\";a:4:{s:7:\"enabled\";b:1;s:5:\"paths\";s:69:\"/\\.(?:txt|png|gif|jpe?g|css|js|ico|swf|flv|cgi|bat|pl|dll|exe|asp)$/i\";s:13:\"exclude_paths\";s:27:\"/\\/(?:styles|imagecache)\\//\";s:4:\"html\";s:162:\"<!DOCTYPE html><html><head><title>404 Not Found</title></head><body><h1>Not Found</h1><p>The requested URL \"@path\" was not found on this server.</p></body></html>\";}s:2:\"js\";a:2:{s:10:\"preprocess\";b:0;s:4:\"gzip\";b:1;}}'),('','system.rss',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MIpNzlG4gPunfS7vTCwUPum6QH3GUsEBMj-qS631Jw0\";}s:5:\"items\";a:1:{s:9:\"view_mode\";s:3:\"rss\";}}'),('','system.site',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ijfbzDTN4CbE7Sr-6ubWzy_t1vH4OtU1doNCLssVz-4\";}s:8:\"langcode\";s:2:\"en\";s:4:\"uuid\";s:36:\"78d4512f-043a-4ffe-b38d-c79b75c64b27\";s:4:\"name\";s:23:\"EPT Page Builder - Demo\";s:4:\"mail\";s:17:\"admin@example.com\";s:6:\"slogan\";s:0:\"\";s:4:\"page\";a:3:{i:403;s:0:\"\";i:404;s:0:\"\";s:5:\"front\";s:7:\"/node/1\";}s:18:\"admin_compact_mode\";b:0;s:17:\"weight_select_max\";i:100;s:16:\"default_langcode\";s:2:\"en\";s:17:\"mail_notification\";N;}'),('','system.theme',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJ529VM1gSIA_vgTy2PdiDvJuG0xhSxfQjCyl5WKlv4\";}s:5:\"admin\";s:3:\"gin\";s:7:\"default\";s:9:\"ept_light\";}'),('','system.theme.global',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KZiV2LB312xgJBphfq5BTjmp16xiR5KM8InBJ-pff7Y\";}s:7:\"favicon\";a:4:{s:8:\"mimetype\";s:24:\"image/vnd.microsoft.icon\";s:4:\"path\";s:0:\"\";s:3:\"url\";s:0:\"\";s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:3:{s:4:\"path\";s:0:\"\";s:3:\"url\";N;s:11:\"use_default\";b:1;}}'),('','taxonomy.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zKpaWT6cJc1tVQQaTqatGELaCqU_oyRym6zTl27Yias\";}s:20:\"maintain_index_table\";b:1;s:17:\"override_selector\";b:0;s:20:\"terms_per_page_admin\";i:100;}'),('','taxonomy.vocabulary.tags',_binary 'a:10:{s:4:\"uuid\";s:36:\"368fd9b7-ee40-4b51-8ac1-60f818b9f9f6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iTEzwrEQ_4JIb-OYGiqzyF2TmMgWyWayresXcWgwGWM\";}s:4:\"name\";s:4:\"Tags\";s:3:\"vid\";s:4:\"tags\";s:11:\"description\";s:61:\"Use tags to group articles on similar topics into categories.\";s:6:\"weight\";i:0;s:12:\"new_revision\";b:0;}'),('','tb_megamenu.menu_config.main__ept_light',_binary 'a:9:{s:4:\"uuid\";s:36:\"9a71f48f-4fa9-44ad-996b-21fe7ea77565\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}s:4:\"menu\";a:1:{i:0;s:4:\"main\";}}s:2:\"id\";s:15:\"main__ept_light\";s:4:\"menu\";s:4:\"main\";s:5:\"theme\";s:9:\"ept_light\";s:12:\"block_config\";s:120:\"{\"animation\":\"none\",\"duration\":400,\"delay\":200,\"style\":\"\",\"auto-arrow\":\"1\",\"always-show-submenu\":\"0\",\"number-columns\":1}\";s:11:\"menu_config\";s:707:\"{\"standard.front_page\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}},\"menu_link_content:d5043c53-9961-4a60-bb2a-a37bbaaa3961\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}},\"menu_link_content:addff990-0222-4099-9e61-5f98566f7f94\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}}}\";}'),('','text.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Bkewb77RBOK3_aXMPsp8p87gbc03NvmC5gBLzPl7hVA\";}s:22:\"default_summary_length\";i:600;}'),('','update.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xbYr66-g0FjNgVBkGypCuN46vBI2XHntXN1URawq1s4\";}s:5:\"check\";a:2:{s:19:\"disabled_extensions\";b:0;s:13:\"interval_days\";i:1;}s:5:\"fetch\";a:3:{s:3:\"url\";N;s:12:\"max_attempts\";i:2;s:7:\"timeout\";i:30;}s:12:\"notification\";a:2:{s:6:\"emails\";a:1:{i:0;s:17:\"admin@example.com\";}s:9:\"threshold\";s:3:\"all\";}}'),('','user.flood',_binary 'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UYfMzeP1S8jKm9PSvxf7nQNe8DsNS-3bc2WSNNXBQWs\";}s:8:\"uid_only\";b:0;s:8:\"ip_limit\";i:50;s:9:\"ip_window\";i:3600;s:10:\"user_limit\";i:5;s:11:\"user_window\";i:21600;}'),('','user.mail',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6CZIzFifRq3qbdq3n3nDpEOO4hWIQtKOAQNPvGNGKeM\";}s:8:\"langcode\";s:2:\"en\";s:14:\"cancel_confirm\";a:2:{s:7:\"subject\";s:67:\"Account cancellation request for [user:display-name] at [site:name]\";s:4:\"body\";s:376:\"[user:display-name]\n\nA request to cancel your account has been made at [site:name].\n\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\n\n[user:cancel-url]\n\nNOTE: The cancellation of your account is not reversible.\n\nThis link expires in one day and nothing will happen if it is not used.\n\n--  [site:name] team\";}s:14:\"password_reset\";a:2:{s:7:\"subject\";s:68:\"Replacement login information for [user:display-name] at [site:name]\";s:4:\"body\";s:407:\"[user:display-name],\n\nA request to reset the password for your account has been made at [site:name].\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it\'s not used.\n\n--  [site:name] team\";}s:22:\"register_admin_created\";a:2:{s:7:\"subject\";s:58:\"An administrator created an account for you at [site:name]\";s:4:\"body\";s:473:\"[user:display-name],\n\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:29:\"register_no_approval_required\";a:2:{s:7:\"subject\";s:54:\"Account details for [user:display-name] at [site:name]\";s:4:\"body\";s:447:\"[user:display-name],\n\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:25:\"register_pending_approval\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:288:\"[user:display-name],\n\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another email containing information about how to log in, set your password, and other details.\n\n--  [site:name] team\";}s:31:\"register_pending_approval_admin\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:64:\"[user:display-name] has applied for an account.\n\n[user:edit-url]\";}s:16:\"status_activated\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (approved)\";s:4:\"body\";s:462:\"[user:display-name],\n\nYour account at [site:name] has been activated.\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:account-name]\npassword: Your password\n\n--  [site:name] team\";}s:14:\"status_blocked\";a:2:{s:7:\"subject\";s:64:\"Account details for [user:display-name] at [site:name] (blocked)\";s:4:\"body\";s:89:\"[user:display-name],\n\nYour account on [site:name] has been blocked.\n\n--  [site:name] team\";}s:15:\"status_canceled\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (canceled)\";s:4:\"body\";s:90:\"[user:display-name],\n\nYour account on [site:name] has been canceled.\n\n--  [site:name] team\";}}'),('','user.role.administrator',_binary 'a:10:{s:4:\"uuid\";s:36:\"5f4748db-4b8a-4105-a888-23753782d022\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OeKGIkmZA_c-t6QLH81WNQx8gDCc1MRmxaTuQgxBByU\";}s:2:\"id\";s:13:\"administrator\";s:5:\"label\";s:13:\"Administrator\";s:6:\"weight\";i:3;s:8:\"is_admin\";b:1;s:11:\"permissions\";a:0:{}}'),('','user.role.anonymous',_binary 'a:10:{s:4:\"uuid\";s:36:\"eda565bf-dc62-4fa8-b48c-329d2d6fc492\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.restricted_html\";}s:6:\"module\";a:5:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:6:\"filter\";i:3;s:5:\"media\";i:4;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6WavjUYXIegP9AAg2zXGx54MWIVoomC3SZhNiqe-Dyk\";}s:2:\"id\";s:9:\"anonymous\";s:5:\"label\";s:14:\"Anonymous user\";s:6:\"weight\";i:0;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:5:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:29:\"access site-wide contact form\";i:3;s:31:\"use text format restricted_html\";i:4;s:10:\"view media\";}}'),('','user.role.authenticated',_binary 'a:10:{s:4:\"uuid\";s:36:\"369ad726-b0da-4331-8cb0-56ab9af109d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"filter.format.basic_html\";i:1;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:7:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:4:\"file\";i:3;s:6:\"filter\";i:4;s:5:\"media\";i:5;s:8:\"shortcut\";i:6;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFrlqjtkTfvY3RGccjJkPf1SGIfJ942IrxTLWAO4mgA\";}s:2:\"id\";s:13:\"authenticated\";s:5:\"label\";s:18:\"Authenticated user\";s:6:\"weight\";i:1;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:10:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:16:\"access shortcuts\";i:3;s:29:\"access site-wide contact form\";i:4;s:16:\"delete own files\";i:5;s:13:\"post comments\";i:6;s:21:\"skip comment approval\";i:7;s:26:\"use text format basic_html\";i:8;s:31:\"use text format webform_default\";i:9;s:10:\"view media\";}}'),('','user.role.content_editor',_binary 'a:10:{s:4:\"uuid\";s:36:\"e916801a-5024-47c1-b402-bb0bb1592d19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:17:\"node.type.article\";i:1;s:14:\"node.type.page\";i:2;s:24:\"taxonomy.vocabulary.tags\";}s:6:\"module\";a:9:{i:0;s:7:\"comment\";i:1;s:10:\"contextual\";i:2;s:4:\"file\";i:3;s:4:\"node\";i:4;s:4:\"path\";i:5;s:6:\"system\";i:6;s:8:\"taxonomy\";i:7;s:11:\"tb_megamenu\";i:8;s:7:\"toolbar\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e_wG1u7SrGaJbY2-Szgbgl-c8T3kdirU3uTNq2c_QJQ\";}s:2:\"id\";s:14:\"content_editor\";s:5:\"label\";s:14:\"Content editor\";s:6:\"weight\";i:2;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:24:{i:0;s:27:\"access administration pages\";i:1;s:23:\"access content overview\";i:2;s:23:\"access contextual links\";i:3;s:21:\"access files overview\";i:4;s:14:\"access toolbar\";i:5;s:22:\"administer tb_megamenu\";i:6;s:22:\"administer url aliases\";i:7;s:22:\"create article content\";i:8;s:19:\"create page content\";i:9;s:20:\"create terms in tags\";i:10;s:18:\"create url aliases\";i:11;s:24:\"delete article revisions\";i:12;s:26:\"delete own article content\";i:13;s:16:\"delete own files\";i:14;s:23:\"delete own page content\";i:15;s:21:\"delete page revisions\";i:16;s:24:\"edit own article content\";i:17;s:17:\"edit own comments\";i:18;s:21:\"edit own page content\";i:19;s:18:\"edit terms in tags\";i:20;s:20:\"revert all revisions\";i:21;s:18:\"view all revisions\";i:22;s:28:\"view own unpublished content\";i:23;s:29:\"view the administration theme\";}}'),('','user.settings',_binary 'a:9:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-htDFWUv1S4OlJMzta2nhFl4QbhJvu0D9xsJ-clxo-M\";}s:8:\"langcode\";s:2:\"en\";s:9:\"anonymous\";s:9:\"Anonymous\";s:11:\"verify_mail\";b:1;s:6:\"notify\";a:8:{s:14:\"cancel_confirm\";b:1;s:14:\"password_reset\";b:1;s:16:\"status_activated\";b:1;s:14:\"status_blocked\";b:0;s:15:\"status_canceled\";b:0;s:22:\"register_admin_created\";b:1;s:29:\"register_no_approval_required\";b:1;s:25:\"register_pending_approval\";b:1;}s:8:\"register\";s:23:\"visitors_admin_approval\";s:13:\"cancel_method\";s:17:\"user_cancel_block\";s:22:\"password_reset_timeout\";i:86400;s:17:\"password_strength\";b:1;}'),('','views.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8oDr9oPVb_ostrNnVV6V7VdphwoH_u-NqTS0u7SE7qc\";}s:17:\"display_extenders\";a:0:{}s:13:\"sql_signature\";b:0;s:2:\"ui\";a:3:{s:4:\"show\";a:7:{s:18:\"additional_queries\";b:0;s:15:\"advanced_column\";b:0;s:15:\"default_display\";b:0;s:22:\"performance_statistics\";b:0;s:19:\"preview_information\";b:1;s:9:\"sql_query\";a:2:{s:7:\"enabled\";b:0;s:5:\"where\";s:5:\"above\";}s:13:\"display_embed\";b:0;}s:19:\"always_live_preview\";b:1;s:24:\"exposed_filter_any_label\";s:7:\"old_any\";}s:22:\"field_rewrite_elements\";a:29:{s:3:\"div\";s:3:\"DIV\";s:4:\"span\";s:4:\"SPAN\";s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";s:2:\"h6\";s:2:\"H6\";s:1:\"p\";s:1:\"P\";s:6:\"header\";s:6:\"HEADER\";s:6:\"footer\";s:6:\"FOOTER\";s:7:\"article\";s:7:\"ARTICLE\";s:7:\"section\";s:7:\"SECTION\";s:5:\"aside\";s:5:\"ASIDE\";s:7:\"details\";s:7:\"DETAILS\";s:10:\"blockquote\";s:10:\"BLOCKQUOTE\";s:6:\"figure\";s:6:\"FIGURE\";s:7:\"address\";s:7:\"ADDRESS\";s:4:\"code\";s:4:\"CODE\";s:3:\"pre\";s:3:\"PRE\";s:3:\"var\";s:3:\"VAR\";s:4:\"samp\";s:4:\"SAMP\";s:3:\"kbd\";s:3:\"KBD\";s:6:\"strong\";s:6:\"STRONG\";s:2:\"em\";s:2:\"EM\";s:3:\"del\";s:3:\"DEL\";s:3:\"ins\";s:3:\"INS\";s:1:\"q\";s:1:\"Q\";s:1:\"s\";s:1:\"S\";}}'),('','views.view.archive',_binary 'a:13:{s:4:\"uuid\";s:36:\"f33400de-a3e8-4128-b4b9-8f10fc897a3f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"exIF08PTvYSK6tJCsAzBqMEKUBKIptPorMn74SVhevc\";}s:2:\"id\";s:7:\"archive\";s:5:\"label\";s:7:\"Archive\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:22:\"All content, by month.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:15:\"Monthly archive\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:2:{s:8:\"override\";b:1;s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:2:{s:10:\"sort_order\";s:4:\"desc\";s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:0;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:1:{s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"archive\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.block_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"f0a4d615-99cd-438c-a7fe-c2d84a594ee3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HfvTcWhiVuvxchoh4DjIkXhKkj9ow2TGgHkLHSvRLq8\";}s:2:\"id\";s:13:\"block_content\";s:5:\"label\";s:14:\"Content blocks\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:31:\"Find and manage content blocks.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:24:\"block_content_field_data\";s:10:\"base_field\";s:2:\"id\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:14:\"Content blocks\";s:6:\"fields\";a:4:{s:4:\"info\";a:37:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";N;s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:17:\"Block description\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Block type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access block library\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:2:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:38:\"There are no content blocks available.\";s:8:\"tokenize\";b:0;}s:27:\"block_content_listing_empty\";a:10:{s:2:\"id\";s:27:\"block_content_listing_empty\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:27:\"block_content_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:27:\"block_content_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:4:\"info\";a:16:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"info_op\";s:5:\"label\";s:17:\"Block description\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"info_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"info\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:10:\"Block type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"reusable\";a:16:{s:2:\"id\";s:8:\"reusable\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:8:\"reusable\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:8:\"reusable\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:4:\"info\";s:4:\"info\";s:4:\"type\";s:4:\"type\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:4:{s:4:\"info\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/block\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:6:\"Blocks\";s:11:\"description\";s:31:\"Create and edit content blocks.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:20:\"system.admin_content\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.comment',_binary 'a:13:{s:4:\"uuid\";s:36:\"e6cd565b-768b-47a9-b906-fe031ec4047e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"H6JHGXl97yOKmVaV62SoY1ki1tWVdyD44fgOkdmVyRM\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:8:\"Comments\";s:6:\"module\";s:7:\"comment\";s:11:\"description\";s:25:\"Find and manage comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:26:{s:5:\"title\";s:8:\"Comments\";s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:24:\"comment_unpublish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"next ›\";s:8:\"previous\";s:12:\"‹ previous\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"administer comments\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:17:\"comment_bulk_form\";s:17:\"comment_bulk_form\";s:7:\"subject\";s:7:\"subject\";s:3:\"uid\";s:3:\"uid\";s:9:\"entity_id\";s:9:\"entity_id\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:17:\"comment_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"subject\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"entity_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:1;s:13:\"use_more_text\";s:4:\"more\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:14:\"page_published\";a:6:{s:2:\"id\";s:14:\"page_published\";s:13:\"display_title\";s:18:\"Published comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:19:\"display_description\";s:30:\"The approved comments listing.\";s:15:\"display_comment\";s:0:\"\";s:13:\"exposed_block\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:21:\"admin/content/comment\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:8:\"Comments\";s:11:\"description\";s:18:\"Comments published\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:15:\"page_unapproved\";a:6:{s:2:\"id\";s:15:\"page_unapproved\";s:13:\"display_title\";s:19:\"Unapproved comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:8:{s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:22:\"comment_publish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:3:{s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:19:\"display_description\";s:32:\"The unapproved comments listing.\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:30:\"admin/content/comment/approval\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:19:\"Unapproved comments\";s:11:\"description\";s:19:\"Comments unapproved\";s:6:\"weight\";i:1;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}}}'),('','views.view.comments_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"b85b83ea-7ca6-4445-91d4-33ba3dff6403\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:7:\"comment\";i:1;s:4:\"node\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFOucxH8PAXDQ2kViCcAHgK-JMCcxVkpIMzD56EfpZo\";}s:2:\"id\";s:15:\"comments_recent\";s:5:\"label\";s:15:\"Recent comments\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:16:\"Recent comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:14:{s:5:\"title\";s:15:\"Recent comments\";s:6:\"fields\";a:2:{s:7:\"subject\";a:26:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:1:{s:4:\"type\";s:5:\"basic\";}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:15:\"access comments\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:2:{s:7:\"created\";a:12:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;}s:3:\"cid\";a:12:{s:2:\"id\";s:3:\"cid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"cid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"cid\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"cid\";}s:7:\"exposed\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:11:\"status_node\";a:10:{s:2:\"id\";s:11:\"status_node\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"node\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:2:{s:22:\"default_field_elements\";b:1;s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:4:\"node\";a:5:{s:2:\"id\";s:4:\"node\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"node\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:15:\"Recent comments\";s:14:\"block_category\";s:13:\"Lists (Views)\";s:5:\"allow\";a:1:{s:14:\"items_per_page\";b:1;}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content',_binary 'a:13:{s:4:\"uuid\";s:36:\"db9f543b-a00c-4765-a8dd-36dc8ebd091c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d7p-wwJZ_Wmz1gnvla9jDtRsjOaWAhPoIoW9w3vo4R4\";}s:2:\"id\";s:7:\"content\";s:5:\"label\";s:7:\"Content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:24:\"Find and manage content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:7:\"Content\";s:6:\"fields\";a:8:{s:14:\"node_bulk_form\";a:14:{s:2:\"id\";s:14:\"node_bulk_form\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:14:\"node_bulk_form\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:14:\"node_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"title\";a:17:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Content type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:17:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:17:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}}s:7:\"changed\";a:17:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:8:\"langcode\";a:37:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:14:\"field_language\";s:5:\"label\";s:8:\"Language\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:8:\"language\";s:8:\"settings\";a:2:{s:14:\"link_to_entity\";b:0;s:15:\"native_language\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:23:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:3:{s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:23:\"access content overview\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:5:\"title\";a:16:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:8:\"title_op\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:8:\"title_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:5:\"title\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:12:\"Content type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:12:\"status_extra\";a:9:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:6:\"expose\";a:2:{s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:10:{s:14:\"node_bulk_form\";s:14:\"node_bulk_form\";s:5:\"title\";s:5:\"title\";s:4:\"type\";s:4:\"type\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:7:\"changed\";s:7:\"changed\";s:9:\"edit_node\";s:9:\"edit_node\";s:11:\"delete_node\";s:11:\"delete_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";s:9:\"timestamp\";s:5:\"title\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:10:{s:14:\"node_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"title\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"delete_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:18:\"admin/content/node\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:23:\"Find and manage content\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"9dd1c55e-db52-4c19-aa0d-4c122baa71f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YqZN5rc7XDQcFcInc8wkzuaHJmC5YvirhTmDcrarT6M\";}s:2:\"id\";s:14:\"content_recent\";s:5:\"label\";s:14:\"Recent content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:15:\"Recent content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:22:{s:5:\"title\";s:14:\"Recent content\";s:6:\"fields\";a:2:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"More\";s:12:\"link_display\";s:1:\"0\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:1:{s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.files',_binary 'a:13:{s:4:\"uuid\";s:36:\"36db1296-d05c-4dd7-bda9-64d0981e2f85\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"blP1XdpU4RqVoA_8po7qnIokIbHB6DJt0lpilgY5ovM\";}s:2:\"id\";s:5:\"files\";s:5:\"label\";s:5:\"Files\";s:6:\"module\";s:4:\"file\";s:11:\"description\";s:22:\"Find and manage files.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:12:\"file_managed\";s:10:\"base_field\";s:3:\"fid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:5:\"Files\";s:6:\"fields\";a:9:{s:3:\"fid\";a:24:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:3:\"Fid\";s:7:\"exclude\";b:1;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"filename\";a:36:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"file_link\";s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:8:\"filemime\";a:25:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"MIME type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"file_filemime\";}s:8:\"filesize\";a:25:{s:2:\"id\";s:8:\"filesize\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filesize\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filesize\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Size\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"file_size\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:9:\"Temporary\";s:18:\"format_custom_true\";s:9:\"Permanent\";}}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Upload date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Changed date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:3:\"fid\";s:10:\"group_type\";s:3:\"sum\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:7:\"Used in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/content/files/usage/{{ fid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:1;s:20:\"format_plural_string\";s:21:\"1 place@count places\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access files overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No files available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:8:\"filename\";a:16:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:8:\"Filename\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filename_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filename\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"filemime\";a:16:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:9:\"MIME type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filemime_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filemime\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:11:\"file_status\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"status_op\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:3:\"fid\";s:3:\"fid\";s:8:\"filename\";s:8:\"filename\";s:8:\"filemime\";s:8:\"filemime\";s:8:\"filesize\";s:8:\"filesize\";s:6:\"status\";s:6:\"status\";s:7:\"created\";s:7:\"created\";s:7:\"changed\";s:7:\"changed\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:8:{s:3:\"fid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filename\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filemime\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:8:\"filesize\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:1;s:16:\"show_admin_links\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:14:\"Files overview\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:2:{s:5:\"pager\";b:1;s:13:\"relationships\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:0;}}s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/files\";s:4:\"menu\";a:6:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Files\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_2\";a:6:{s:2:\"id\";s:6:\"page_2\";s:13:\"display_title\";s:10:\"File usage\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:15:{s:5:\"title\";s:10:\"File usage\";s:6:\"fields\";a:4:{s:12:\"entity_label\";a:23:{s:2:\"id\";s:12:\"entity_label\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:12:\"entity_label\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"entity_label\";s:5:\"label\";s:6:\"Entity\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:14:\"link_to_entity\";b:1;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:11:\"Entity type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:6:\"module\";a:22:{s:2:\"id\";s:6:\"module\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:6:\"module\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:18:\"Registering module\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:9:\"Use count\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:0;s:20:\"format_plural_string\";s:8:\"1@count\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:5:\"empty\";a:0:{}s:9:\"arguments\";a:1:{s:3:\"fid\";a:22:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:8:\"file_fid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:46:\"File usage information for {{ arguments.fid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;}}s:7:\"filters\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:12:\"entity_label\";s:12:\"entity_label\";s:4:\"type\";s:4:\"type\";s:6:\"module\";s:6:\"module\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:12:\"entity_label\";s:4:\"info\";a:4:{s:12:\"entity_label\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:6:\"module\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:11:{s:5:\"empty\";b:0;s:5:\"title\";b:0;s:5:\"pager\";b:0;s:8:\"group_by\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:13:\"relationships\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:0;s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:27:\"admin/content/files/usage/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.frontpage',_binary 'a:13:{s:4:\"uuid\";s:36:\"899f634a-224d-4abf-ae01-81a9b3031896\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OEEnRQIjfIaCFRsz8U3VqDrE82ltQKlo8wNbQJRZXu0\";}s:2:\"id\";s:9:\"frontpage\";s:5:\"label\";s:9:\"Frontpage\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:39:\"All content promoted to the front page.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:0:\"\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:3:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:181:\"No front page content has been created yet.<br/>Follow the <a target=\"_blank\" href=\"https://www.drupal.org/docs/user_guide/en/index.html\">User Guide</a> to start building your site.\";s:8:\"tokenize\";b:0;}s:18:\"node_listing_empty\";a:10:{s:2:\"id\";s:18:\"node_listing_empty\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:18:\"node_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:18:\"node_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}s:5:\"title\";a:10:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"title\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:5:\"title\";s:8:\"Welcome!\";}}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:12:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:7:\"promote\";a:16:{s:2:\"id\";s:7:\"promote\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"promote\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"promote\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:3:\"rss\";}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"rss.xml\";s:14:\"sitename_title\";b:1;s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:28:\"languages:language_interface\";i:1;s:21:\"user.node_grants:view\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:4:\"node\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.glossary',_binary 'a:13:{s:4:\"uuid\";s:36:\"9a843b37-02d2-45c5-84e0-2cd85511ce42\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r-klgGeO4haVHqAwxW1HXZLzdzLSMUVC08OuTBrRh58\";}s:2:\"id\";s:8:\"glossary\";s:5:\"label\";s:8:\"Glossary\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:23:\"All content, by letter.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:6:\"fields\";a:3:{s:5:\"title\";a:24:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:36;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"default\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:0:{}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;s:7:\"columns\";a:3:{s:5:\"title\";s:5:\"title\";s:4:\"name\";s:4:\"name\";s:7:\"changed\";s:7:\"changed\";}s:7:\"default\";s:5:\"title\";s:4:\"info\";a:3:{s:5:\"title\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:4:\"name\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:7:\"changed\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:5:\"order\";s:3:\"asc\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"attachment_1\";a:6:{s:2:\"id\";s:12:\"attachment_1\";s:13:\"display_title\";s:10:\"Attachment\";s:14:\"display_plugin\";s:10:\"attachment\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:0;}}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:3:{s:14:\"items_per_page\";i:25;s:6:\"inline\";b:1;s:9:\"separator\";s:3:\" | \";}s:7:\"summary\";a:1:{s:6:\"format\";s:19:\"unformatted_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}s:8:\"displays\";a:2:{s:7:\"default\";s:7:\"default\";s:6:\"page_1\";s:6:\"page_1\";}s:17:\"inherit_arguments\";b:0;}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:8:\"glossary\";s:4:\"menu\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:8:\"Glossary\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.media',_binary 'a:13:{s:4:\"uuid\";s:36:\"7c06b5e5-ebff-4822-8688-54ce69b5a404\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kOTUk5XWeupgBOJuRRarCiDcFKVZcvaW-FT5MTzrML8\";}s:2:\"id\";s:5:\"media\";s:5:\"label\";s:5:\"Media\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:8:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:20:\"thumbnail__target_id\";a:37:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:5:\"media\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Media name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"bundle\";a:37:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"status\";a:37:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:10:\"Media name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:4:\"True\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:4:\"name\";s:4:\"name\";s:6:\"bundle\";s:6:\"bundle\";s:7:\"changed\";s:7:\"changed\";s:3:\"uid\";s:3:\"uid\";s:6:\"status\";s:6:\"status\";s:20:\"thumbnail__target_id\";s:20:\"thumbnail__target_id\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"bundle\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:15:\"media_page_list\";a:6:{s:2:\"id\";s:15:\"media_page_list\";s:13:\"display_title\";s:5:\"Media\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/media\";s:4:\"menu\";a:8:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Media\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.media_library',_binary 'a:13:{s:4:\"uuid\";s:36:\"74d36492-489a-4ac8-ab15-1c22af9e302b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:25:\"image.style.media_library\";}s:6:\"module\";a:4:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:13:\"media_library\";i:3;s:4:\"user\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9u9hwW-Q0-uQJz1vgenJTQhZGYN0FBZoOogwPD6kgkQ\";}s:2:\"id\";s:13:\"media_library\";s:5:\"label\";s:13:\"Media library\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:4:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:2:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:24;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"6, 12, 24, 48\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:13:\"Apply filters\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:3:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:12:\"Newest first\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:1;s:11:\"granularity\";s:6:\"second\";}s:4:\"name\";a:12:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:3:\"ASC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (A-Z)\";s:16:\"field_identifier\";s:4:\"name\";}s:7:\"exposed\";b:1;}s:6:\"name_1\";a:12:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (Z-A)\";s:16:\"field_identifier\";s:6:\"name_1\";}s:7:\"exposed\";b:1;}}s:7:\"filters\";a:5:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:17:\"Publishing status\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:9:\"Published\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:10:\"Media type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:10:\"Media type\";s:11:\"description\";N;s:10:\"identifier\";s:6:\"bundle\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:0:{}i:2;a:0:{}i:3;a:0:{}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:6:\"fields\";a:5:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"edit_media\";a:26:{s:2:\"id\";s:10:\"edit_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"edit_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:15:\"Edit {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:15:\"Edit {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"Edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:12:\"delete_media\";a:26:{s:2:\"id\";s:12:\"delete_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:12:\"delete_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:18:\"entity_link_delete\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:17:\"Delete {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:17:\"Delete {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:6:\"Delete\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:8:\"defaults\";a:1:{s:6:\"fields\";b:0;}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:24:\"admin/content/media-grid\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:22:\"url.query_args:sort_by\";i:5;s:4:\"user\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"widget\";a:6:{s:2:\"id\";s:6:\"widget\";s:13:\"display_title\";s:6:\"Widget\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:12:{s:6:\"fields\";a:2:{s:25:\"media_library_select_form\";a:23:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:7:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:19:\"display_description\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:26:\"admin/content/media-widget\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"widget_table\";a:6:{s:2:\"id\";s:12:\"widget_table\";s:13:\"display_title\";s:14:\"Widget (table)\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:3;s:15:\"display_options\";a:13:{s:6:\"fields\";a:5:{s:25:\"media_library_select_form\";a:9:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:10:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:13:\"media_library\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}}s:4:\"name\";a:10:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}}s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:20:\"media_field_revision\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}}s:7:\"changed\";a:10:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:2:{s:9:\"row_class\";s:85:\"media-library-item media-library-item--table js-media-library-item js-click-to-select\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:8:\"defaults\";a:9:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:32:\"admin/content/media-widget-table\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.taxonomy_term',_binary 'a:13:{s:4:\"uuid\";s:36:\"56651306-efed-4808-bbdc-d9cf02cff348\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:3:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KejdxDJQmx8SaO-t83OVekLw6ar4ldjmsJMGcotGxnQ\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:6:\"module\";s:8:\"taxonomy\";s:11:\"description\";s:45:\"Content belonging to a certain taxonomy term.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:10:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:11:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:3:\"tid\";a:22:{s:2:\"id\";s:3:\"tid\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:3:\"tid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:18:\"taxonomy_index_tid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:0:\"\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:19:\"{{ arguments.tid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:4:{s:7:\"bundles\";a:0:{}s:6:\"access\";b:1;s:9:\"operation\";s:4:\"view\";s:8:\"multiple\";i:0;}s:12:\"break_phrase\";b:0;s:9:\"add_table\";b:0;s:13:\"require_value\";b:0;s:17:\"reduce_duplicates\";b:0;}}s:7:\"filters\";a:2:{s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:14:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:1:{s:20:\"entity_taxonomy_term\";a:12:{s:2:\"id\";s:20:\"entity_taxonomy_term\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:20:\"entity_taxonomy_term\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"entity\";s:5:\"empty\";b:1;s:6:\"target\";s:23:\"{{ raw_arguments.tid }}\";s:9:\"view_mode\";s:4:\"full\";s:8:\"tokenize\";b:1;s:13:\"bypass_access\";b:0;}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:7:\"default\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:20:\"taxonomy/term/%/feed\";s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:15:\"taxonomy/term/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.user_admin_people',_binary 'a:13:{s:4:\"uuid\";s:36:\"66ac1092-d560-4cf9-a5d3-b1941a3311d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FFLg74mnzRE10lgg5fspPCZWLnIEcvCnJMlNzj8OEtw\";}s:2:\"id\";s:17:\"user_admin_people\";s:5:\"label\";s:6:\"People\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:25:{s:5:\"title\";s:6:\"People\";s:6:\"fields\";a:8:{s:14:\"user_bulk_form\";a:23:{s:2:\"id\";s:14:\"user_bulk_form\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:14:\"user_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:14:\"user_bulk_form\";s:5:\"label\";s:11:\"Bulk update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Username\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:7:\"Blocked\";s:18:\"format_custom_true\";s:6:\"Active\";}}s:15:\"roles_target_id\";a:24:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:5:\"label\";s:5:\"Roles\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:2:\"ul\";s:9:\"separator\";s:2:\", \";}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Member for\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:9:\"@interval\";s:11:\"past_format\";s:9:\"@interval\";s:11:\"granularity\";i:2;}}s:6:\"access\";a:26:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last access\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:4:\"mail\";a:37:{s:2:\"id\";s:4:\"mail\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"mail\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"mail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"basic_string\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:16:\"administer users\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:20:\"No people available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:7:\"filters\";a:6:{s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:22:\"Name or email contains\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"user\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:4:\"mail\";s:4:\"mail\";}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:6:\"Active\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:7:\"Blocked\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:15:\"roles_target_id\";a:15:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:18:\"roles_target_id_op\";s:5:\"label\";s:4:\"Role\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:18:\"roles_target_id_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"role\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:10:\"permission\";a:15:{s:2:\"id\";s:10:\"permission\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:10:\"permission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"user_permissions\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:13:\"permission_op\";s:5:\"label\";s:10:\"Permission\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:13:\"permission_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:10:\"permission\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"uid_raw\";a:15:{s:2:\"id\";s:7:\"uid_raw\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"uid_raw\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:7:\"numeric\";s:8:\"operator\";s:2:\"!=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:1:\"0\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:10:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:14:\"user_bulk_form\";s:14:\"user_bulk_form\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:3:\"rid\";s:3:\"rid\";s:7:\"created\";s:7:\"created\";s:6:\"access\";s:6:\"access\";s:9:\"edit_node\";s:9:\"edit_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";}s:7:\"default\";s:7:\"created\";s:4:\"info\";a:8:{s:14:\"user_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:3:\"rid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"access\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"more\";s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:15:\"display_comment\";s:0:\"\";s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:1:{s:16:\"show_admin_links\";b:0;}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:17:\"admin/people/list\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:4:\"List\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:6:\"People\";s:11:\"description\";s:45:\"Manage user accounts, roles, and permissions.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.watchdog',_binary 'a:13:{s:4:\"uuid\";s:36:\"25587939-259b-48aa-8c6c-dbd04aa5d800\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"dblog\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SR5P89f0vUTPC7WY2YpLAffkDx8-Ar8LKFfowVXeqNU\";}s:2:\"id\";s:8:\"watchdog\";s:5:\"label\";s:8:\"Watchdog\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:19:\"Recent log messages\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"watchdog\";s:10:\"base_field\";s:3:\"wid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:19:\"Recent log messages\";s:6:\"fields\";a:8:{s:7:\"nothing\";a:22:{s:2:\"id\";s:7:\"nothing\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"nothing\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"Icon\";s:9:\"plugin_id\";s:6:\"custom\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:4:\"icon\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:0;}s:3:\"wid\";a:22:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:3:\"WID\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"severity\";a:23:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"machine_name\";s:5:\"label\";s:8:\"Severity\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"machine_name\";b:0;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:9:\"timestamp\";a:25:{s:2:\"id\";s:9:\"timestamp\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:9:\"timestamp\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"label\";s:4:\"Date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:7:\"message\";a:23:{s:2:\"id\";s:7:\"message\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:7:\"message\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:13:\"dblog_message\";s:5:\"label\";s:7:\"Message\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/reports/dblog/event/{{ wid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:13:\"{{ message }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:56;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:1;s:4:\"trim\";b:1;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:1;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"replace_variables\";b:1;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"User\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"link\";a:22:{s:2:\"id\";s:4:\"link\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"link\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"dblog_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"access site reports\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:4:\"area\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:26:\"No log messages available.\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:26:\"No log messages available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:3:\"wid\";a:10:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"wid\";}s:7:\"exposed\";b:0;}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:4:\"type\";a:14:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"dblog_types\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"severity\";a:14:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"in_operator\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"severity_op\";s:5:\"label\";s:8:\"Severity\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"severity_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"severity\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:25:\"{{ type }} {{ severity }}\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:7:\"nothing\";s:7:\"nothing\";s:3:\"wid\";s:3:\"wid\";s:8:\"severity\";s:8:\"severity\";s:4:\"type\";s:4:\"type\";s:9:\"timestamp\";s:9:\"timestamp\";s:7:\"message\";s:7:\"message\";s:4:\"name\";s:4:\"name\";s:4:\"link\";s:4:\"link\";}s:7:\"default\";s:3:\"wid\";s:4:\"info\";a:8:{s:7:\"nothing\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:3:\"wid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:8:\"severity\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"message\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:4:\"link\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:0;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"User\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:11:\"admin-dblog\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/reports/dblog\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.webform_submissions',_binary 'a:13:{s:4:\"uuid\";s:36:\"38120747-e809-460c-aea2-fd8cea0574d7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"user\";i:1;s:7:\"webform\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uIuCYXi8Y6GTe4pKUxK2t9OjQEcrwvFJZFeitfnQ8Ys\";}s:2:\"id\";s:19:\"webform_submissions\";s:5:\"label\";s:19:\"Webform submissions\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:34:\"Default webform submissions views.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:18:\"webform_submission\";s:10:\"base_field\";s:3:\"sid\";s:7:\"display\";a:5:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:7:{s:14:\"items_per_page\";i:25;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:6:\"‹‹\";s:4:\"next\";s:6:\"››\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:23:\"5, 10, 25, 50, 100, 200\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"fields\";a:5:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:7:\"filters\";a:0:{}s:5:\"sorts\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:0;s:7:\"content\";s:34:\"Displaying @start - @end of @total\";s:9:\"plugin_id\";s:6:\"result\";}}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"No submissions available.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:5:{s:10:\"webform_id\";a:6:{s:2:\"id\";s:10:\"webform_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"webform_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:10:\"webform_id\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"entity_type\";a:6:{s:2:\"id\";s:11:\"entity_type\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"entity_type\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"entity_type\";s:9:\"plugin_id\";s:6:\"string\";}s:9:\"entity_id\";a:6:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"entity_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:6:\"string\";}s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"uid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:16:\"entity_target_id\";}s:8:\"in_draft\";a:22:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:14:\"items_per_page\";i:25;s:8:\"override\";b:0;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"numeric\";}}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"title\";s:19:\"Webform submissions\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:16:\"embed_administer\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:16:\"embed_administer\";s:13:\"display_title\";s:17:\"Embed: Administer\";s:8:\"position\";i:2;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:23:\"Administer submissions.\";s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:8:\"defaults\";a:6:{s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:29:\"administer webform submission\";}}s:6:\"fields\";a:9:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:10:\"operations\";a:25:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;s:11:\"entity_type\";N;s:12:\"entity_field\";N;s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:13:\"embed_default\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:13:\"embed_default\";s:13:\"display_title\";s:14:\"Embed: Default\";s:8:\"position\";i:1;s:15:\"display_options\";a:5:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:20:\"Display submissions.\";s:8:\"defaults\";a:5:{s:6:\"fields\";b:1;s:5:\"style\";b:0;s:3:\"row\";b:0;s:7:\"filters\";b:1;s:13:\"filter_groups\";b:1;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:5:{s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:7:\"created\";s:7:\"created\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:5:{s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_manage\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_manage\";s:13:\"display_title\";s:13:\"Embed: Manage\";s:8:\"position\";i:3;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Manage submissions.\";s:6:\"fields\";a:10:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:4:{i:0;s:35:\"webform_submission_make_lock_action\";i:1;s:37:\"webform_submission_make_sticky_action\";i:2;s:37:\"webform_submission_make_unlock_action\";i:3;s:39:\"webform_submission_make_unsticky_action\";}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}s:23:\"edit_webform_submission\";a:26:{s:2:\"id\";s:23:\"edit_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"edit_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"edit any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_review\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_review\";s:13:\"display_title\";s:13:\"Embed: Review\";s:8:\"position\";i:4;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Review submissions.\";s:6:\"fields\";a:8:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"view any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.what_s_new',_binary 'a:12:{s:4:\"uuid\";s:36:\"e1df6ee8-b831-49f1-9777-12d640e99636\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:22:\"better_exposed_filters\";i:1;s:4:\"node\";i:2;s:4:\"text\";i:3;s:4:\"user\";}}s:2:\"id\";s:10:\"what_s_new\";s:5:\"label\";s:10:\"What\'s New\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:0:\"\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:10:\"What\'s New\";s:6:\"fields\";a:2:{s:5:\"title\";a:35:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:20:\"<h3>{{ title }}</h3>\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"body\";a:35:{s:2:\"id\";s:4:\"body\";s:5:\"table\";s:10:\"node__body\";s:5:\"field\";s:4:\"body\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"text_default\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:3:\"bef\";s:7:\"options\";a:10:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";s:19:\"text_input_required\";s:51:\"Select any filter and click on Apply to see results\";s:26:\"text_input_required_format\";s:9:\"full_html\";s:3:\"bef\";a:2:{s:7:\"general\";a:10:{s:10:\"autosubmit\";b:1;s:28:\"autosubmit_exclude_textfield\";b:0;s:26:\"autosubmit_textfield_delay\";i:500;s:35:\"autosubmit_textfield_minimum_length\";i:3;s:15:\"autosubmit_hide\";b:0;s:14:\"input_required\";b:0;s:15:\"allow_secondary\";b:0;s:15:\"secondary_label\";s:16:\"Advanced options\";s:14:\"secondary_open\";b:0;s:24:\"reset_button_always_show\";b:0;}s:6:\"filter\";a:1:{s:7:\"created\";a:2:{s:9:\"plugin_id\";s:7:\"default\";s:8:\"advanced\";a:6:{s:16:\"placeholder_text\";s:0:\"\";s:7:\"rewrite\";a:2:{s:21:\"filter_rewrite_values\";s:0:\"\";s:25:\"filter_rewrite_values_key\";b:0;}s:11:\"collapsible\";b:0;s:34:\"collapsible_disable_automatic_open\";b:0;s:12:\"is_secondary\";b:0;s:10:\"hide_label\";b:0;}}}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:0:\"\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:1:{s:8:\"operator\";s:0:\"\";}}s:4:\"type\";a:7:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:5:\"value\";a:1:{s:7:\"article\";s:7:\"article\";}}s:7:\"created\";a:16:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:0:\"\";s:4:\"type\";s:9:\"date_year\";}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:15:{s:11:\"operator_id\";s:10:\"created_op\";s:5:\"label\";s:11:\"Authored on\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"created_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"created\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:14:\"content_editor\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:15:\"min_placeholder\";s:0:\"\";s:15:\"max_placeholder\";s:0:\"\";s:11:\"placeholder\";s:0:\"\";}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:5:\"Year \";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:7:\"created\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:3:{s:5:\"title\";s:4:\"2024\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2024\";s:4:\"type\";s:9:\"date_year\";}}i:2;a:3:{s:5:\"title\";s:4:\"2023\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2023\";s:4:\"type\";s:9:\"date_year\";}}i:3;a:3:{s:5:\"title\";s:4:\"2022\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2022\";s:4:\"type\";s:9:\"date_year\";}}}}}}s:5:\"style\";a:1:{s:4:\"type\";s:7:\"default\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:1:{i:0;s:30:\"config:field.storage.node.body\";}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:13:\"exposed_block\";b:1;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:1:{i:0;s:30:\"config:field.storage.node.body\";}}}}}'),('','views.view.who_s_new',_binary 'a:13:{s:4:\"uuid\";s:36:\"d9b64673-64f0-48bb-8588-e15e4bdacdbf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zji0_13MyVGK7Bn1lUMDeZyyOIZedWvqpYUeM_SioPI\";}s:2:\"id\";s:9:\"who_s_new\";s:5:\"label\";s:9:\"Who\'s new\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:53:\"Shows a list of the newest user accounts on the site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:9:\"Who\'s new\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:5;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\">\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:10:\"1970-01-01\";s:4:\"type\";s:4:\"date\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:1:{s:4:\"type\";s:9:\"html_list\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:9:\"Who\'s new\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:19:\"A list of new users\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:9:\"Who\'s new\";s:14:\"block_category\";s:4:\"User\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.who_s_online',_binary 'a:13:{s:4:\"uuid\";s:36:\"267c96ad-120e-49d6-9273-b49f1a603f01\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"suDsVMgawXoQt4rfmdfpr05EVX3z3KyfDDTYgeSM898\";}s:2:\"id\";s:12:\"who_s_online\";s:5:\"label\";s:18:\"Who\'s online block\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:93:\"Shows the user names of the most recently active users, and the total number of active users.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:12:\"Who\'s online\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access user profiles\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:35:\"There are currently 0 users online.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:6:\"access\";a:13:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"access\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:2:\">=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:11:\"-15 minutes\";s:4:\"type\";s:6:\"offset\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:9:\"access_op\";s:5:\"label\";s:11:\"Last access\";s:11:\"description\";s:77:\"A user is considered online for this long after they have last viewed a page.\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"access_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"access\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"result\";s:5:\"empty\";b:0;s:7:\"content\";s:40:\"There are currently @total users online.\";}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:18:\"who_s_online_block\";a:6:{s:2:\"id\";s:18:\"who_s_online_block\";s:13:\"display_title\";s:12:\"Who\'s online\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:19:\"display_description\";s:45:\"A list of users that are currently logged in.\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:12:\"Who\'s online\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','webform.settings',_binary 'a:20:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eZgcriT-utjDI1pjl-24jYFW2DmCxMXaFSnJd0XoU-0\";}s:8:\"settings\";a:73:{s:14:\"default_status\";s:4:\"open\";s:18:\"default_categories\";a:0:{}s:12:\"default_page\";b:1;s:22:\"default_page_base_path\";s:5:\"/form\";s:12:\"default_ajax\";b:0;s:19:\"default_ajax_effect\";s:4:\"fade\";s:18:\"default_ajax_speed\";i:500;s:26:\"default_ajax_progress_type\";s:8:\"throbber\";s:25:\"default_form_open_message\";s:49:\"This form has not yet been opened to submissions.\";s:26:\"default_form_close_message\";s:48:\"Sorry… This form is closed to new submissions.\";s:30:\"default_form_exception_message\";s:70:\"Unable to display this webform. Please contact the site administrator.\";s:27:\"default_submit_button_label\";s:6:\"Submit\";s:26:\"default_reset_button_label\";s:5:\"Reset\";s:27:\"default_delete_button_label\";s:6:\"Delete\";s:24:\"default_form_submit_once\";b:0;s:33:\"default_form_confidential_message\";s:135:\"This form is confidential. You must <a href=\"[site:login-url]/logout?destination=[current-page:url:relative]\">Log out</a> to submit it.\";s:34:\"default_form_access_denied_message\";s:34:\"Please log in to access this form.\";s:25:\"default_form_disable_back\";b:0;s:24:\"default_form_submit_back\";b:0;s:20:\"default_form_unsaved\";b:0;s:32:\"default_form_disable_remote_addr\";b:0;s:23:\"default_form_novalidate\";b:0;s:34:\"default_form_disable_inline_errors\";b:0;s:21:\"default_form_required\";b:0;s:27:\"default_form_required_label\";s:24:\"Indicates required field\";s:27:\"default_form_details_toggle\";b:1;s:23:\"default_form_file_limit\";s:0:\"\";s:12:\"form_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:14:\"button_classes\";s:0:\"\";s:32:\"default_wizard_prev_button_label\";s:10:\"< Previous\";s:32:\"default_wizard_next_button_label\";s:6:\"Next >\";s:26:\"default_wizard_start_label\";s:5:\"Start\";s:33:\"default_wizard_confirmation_label\";s:8:\"Complete\";s:32:\"default_wizard_toggle_show_label\";s:8:\"Show all\";s:32:\"default_wizard_toggle_hide_label\";s:8:\"Hide all\";s:33:\"default_preview_next_button_label\";s:7:\"Preview\";s:33:\"default_preview_prev_button_label\";s:10:\"< Previous\";s:21:\"default_preview_label\";s:7:\"Preview\";s:21:\"default_preview_title\";s:24:\"[webform:title]: Preview\";s:23:\"default_preview_message\";s:99:\"Please review your submission. Your submission is not complete until you press the \"Submit\" button!\";s:26:\"default_draft_button_label\";s:10:\"Save Draft\";s:27:\"default_draft_saved_message\";s:91:\"Submission saved. You may return to this form later and it will restore the current values.\";s:28:\"default_draft_loaded_message\";s:77:\"A partially-completed form was found. Please complete the remaining portions.\";s:36:\"default_draft_pending_single_message\";s:83:\"You have a pending draft for this webform. <a href=\"#\">Load your pending draft</a>.\";s:38:\"default_draft_pending_multiple_message\";s:83:\"You have pending drafts for this webform. <a href=\"#\">View your pending drafts</a>.\";s:28:\"default_confirmation_message\";s:40:\"New submission added to [webform:title].\";s:31:\"default_confirmation_back_label\";s:12:\"Back to form\";s:28:\"default_confirmation_noindex\";b:1;s:24:\"default_submission_label\";s:74:\"[webform_submission:submitted-to]: Submission #[webform_submission:serial]\";s:40:\"default_submission_access_denied_message\";s:40:\"Please log in to access this submission.\";s:36:\"default_submission_exception_message\";s:73:\"Unable to process this submission. Please contact the site administrator.\";s:33:\"default_submission_locked_message\";s:32:\"This submission has been locked.\";s:22:\"default_submission_log\";b:0;s:24:\"default_submission_views\";a:0:{}s:32:\"default_submission_views_replace\";a:3:{s:13:\"global_routes\";a:2:{i:0;s:36:\"entity.webform_submission.collection\";i:1;s:30:\"entity.webform_submission.user\";}s:14:\"webform_routes\";a:3:{i:0;s:34:\"entity.webform.results_submissions\";i:1;s:26:\"entity.webform.user.drafts\";i:2;s:31:\"entity.webform.user.submissions\";}s:11:\"node_routes\";a:3:{i:0;s:39:\"entity.node.webform.results_submissions\";i:1;s:31:\"entity.node.webform.user.drafts\";i:2;s:36:\"entity.node.webform.user.submissions\";}}s:25:\"default_results_customize\";b:0;s:35:\"default_previous_submission_message\";s:87:\"You have already submitted this webform. <a href=\"#\">View your previous submission</a>.\";s:36:\"default_previous_submissions_message\";s:88:\"You have already submitted this webform. <a href=\"#\">View your previous submissions</a>.\";s:24:\"default_autofill_message\";s:66:\"This submission has been autofilled with your previous submission.\";s:15:\"preview_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:20:\"confirmation_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:25:\"confirmation_back_classes\";s:7:\"button\n\";s:27:\"default_limit_total_message\";s:34:\"No more submissions are permitted.\";s:26:\"default_limit_user_message\";s:34:\"No more submissions are permitted.\";s:13:\"default_share\";b:0;s:18:\"default_share_node\";b:0;s:24:\"default_share_theme_name\";s:0:\"\";s:6:\"dialog\";b:0;s:14:\"dialog_options\";a:3:{s:6:\"narrow\";a:2:{s:5:\"title\";s:6:\"Narrow\";s:5:\"width\";i:600;}s:6:\"normal\";a:2:{s:5:\"title\";s:6:\"Normal\";s:5:\"width\";i:800;}s:4:\"wide\";a:2:{s:5:\"title\";s:4:\"Wide\";s:5:\"width\";i:1000;}}s:17:\"webform_bulk_form\";b:1;s:25:\"webform_bulk_form_actions\";a:5:{i:0;s:19:\"webform_open_action\";i:1;s:20:\"webform_close_action\";i:2;s:22:\"webform_archive_action\";i:3;s:24:\"webform_unarchive_action\";i:4;s:21:\"webform_delete_action\";}s:28:\"webform_submission_bulk_form\";b:1;s:36:\"webform_submission_bulk_form_actions\";a:5:{i:0;s:37:\"webform_submission_make_sticky_action\";i:1;s:39:\"webform_submission_make_unsticky_action\";i:2;s:35:\"webform_submission_make_lock_action\";i:3;s:37:\"webform_submission_make_unlock_action\";i:4;s:32:\"webform_submission_delete_action\";}}s:6:\"assets\";a:2:{s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";}s:7:\"handler\";a:1:{s:17:\"excluded_handlers\";a:0:{}}s:7:\"variant\";a:1:{s:17:\"excluded_variants\";a:0:{}}s:6:\"export\";a:18:{s:14:\"temp_directory\";s:0:\"\";s:8:\"exporter\";s:9:\"delimited\";s:18:\"multiple_delimiter\";s:1:\";\";s:13:\"header_format\";s:5:\"label\";s:13:\"header_prefix\";b:1;s:29:\"header_prefix_label_delimiter\";s:2:\": \";s:27:\"header_prefix_key_delimiter\";s:2:\"__\";s:29:\"composite_element_item_format\";s:5:\"label\";s:21:\"options_single_format\";s:7:\"compact\";s:23:\"options_multiple_format\";s:7:\"compact\";s:19:\"options_item_format\";s:5:\"label\";s:22:\"entity_reference_items\";a:3:{i:0;s:2:\"id\";i:1;s:5:\"title\";i:2;s:3:\"url\";}s:21:\"likert_answers_format\";s:5:\"label\";s:16:\"signature_format\";s:6:\"status\";s:9:\"delimiter\";s:1:\",\";s:5:\"excel\";b:0;s:12:\"archive_type\";s:3:\"tar\";s:18:\"excluded_exporters\";a:0:{}}s:5:\"batch\";a:5:{s:25:\"default_batch_export_size\";i:500;s:25:\"default_batch_import_size\";i:100;s:25:\"default_batch_update_size\";i:500;s:25:\"default_batch_delete_size\";i:500;s:24:\"default_batch_email_size\";i:500;}s:5:\"purge\";a:1:{s:9:\"cron_size\";i:100;}s:4:\"form\";a:3:{s:5:\"limit\";i:50;s:15:\"filter_category\";s:0:\"\";s:12:\"filter_state\";s:0:\"\";}s:7:\"element\";a:13:{s:20:\"machine_name_pattern\";s:7:\"a-z0-9_\";s:13:\"empty_message\";s:7:\"{Empty}\";s:12:\"allowed_tags\";s:5:\"admin\";s:15:\"wrapper_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:7:\"classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:23:\"horizontal_rule_classes\";s:286:\"webform-horizontal-rule--solid\nwebform-horizontal-rule--dashed\nwebform-horizontal-rule--dotted\nwebform-horizontal-rule--gradient\nwebform-horizontal-rule--thin\nwebform-horizontal-rule--medium\nwebform-horizontal-rule--thick\nwebform-horizontal-rule--flaired\nwebform-horizontal-rule--glyph\n\";s:27:\"default_description_display\";s:0:\"\";s:18:\"default_more_title\";s:4:\"More\";s:25:\"default_section_title_tag\";s:2:\"h2\";s:20:\"default_empty_option\";b:1;s:29:\"default_empty_option_required\";s:0:\"\";s:29:\"default_empty_option_optional\";s:0:\"\";s:17:\"excluded_elements\";a:2:{s:8:\"password\";s:8:\"password\";s:16:\"password_confirm\";s:16:\"password_confirm\";}}s:11:\"html_editor\";a:5:{s:8:\"disabled\";b:0;s:14:\"element_format\";s:15:\"webform_default\";s:11:\"mail_format\";s:15:\"webform_default\";s:4:\"tidy\";b:1;s:35:\"make_unused_managed_files_temporary\";b:1;}s:4:\"file\";a:11:{s:11:\"file_public\";b:0;s:21:\"file_private_redirect\";b:1;s:29:\"file_private_redirect_message\";s:42:\"Please log in to access the uploaded file.\";s:20:\"default_max_filesize\";s:0:\"\";s:31:\"default_managed_file_extensions\";s:148:\"gif jpg jpeg png bmp eps tif pict psd txt rtf html odf pdf doc docx ppt pptx xls xlsx xml avi mov mp3 mp4 ogg wav bz2 dmg gz jar rar sit svg tar zip\";s:29:\"default_audio_file_extensions\";s:11:\"mp3 ogg wav\";s:32:\"default_document_file_extensions\";s:50:\"txt rtf pdf doc docx odt ppt pptx odp xls xlsx ods\";s:29:\"default_image_file_extensions\";s:16:\"gif jpg jpeg png\";s:29:\"default_video_file_extensions\";s:24:\"avi mov mp4 ogg wav webm\";s:35:\"make_unused_managed_files_temporary\";b:1;s:30:\"delete_temporary_managed_files\";b:1;}s:6:\"format\";a:0:{}s:4:\"mail\";a:11:{s:15:\"default_to_mail\";s:11:\"[site:mail]\";s:17:\"default_from_mail\";s:11:\"[site:mail]\";s:17:\"default_from_name\";s:11:\"[site:name]\";s:16:\"default_reply_to\";s:0:\"\";s:19:\"default_return_path\";s:0:\"\";s:19:\"default_sender_mail\";s:0:\"\";s:19:\"default_sender_name\";s:0:\"\";s:15:\"default_subject\";s:58:\"Webform submission from: [webform_submission:source-title]\";s:17:\"default_body_text\";s:133:\"Submitted on [webform_submission:created]\nSubmitted by: [webform_submission:user]\n\nSubmitted values are:\n[webform_submission:values]\n\";s:17:\"default_body_html\";s:153:\"<p>Submitted on [webform_submission:created]</p>\n<p>Submitted by: [webform_submission:user]</p>\n<p>Submitted values are:</p>\n[webform_submission:values]\n\";s:5:\"roles\";a:0:{}}s:4:\"test\";a:2:{s:5:\"types\";s:3347:\"checkbox:\n  - true\ncolor:\n  - \'#ffffcc\'\n  - \'#ffffcc\'\n  - \'#ccffff\'\nemail:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nlanguage_select:\n  - en\nmachine_name:\n  - \'loremipsum\'\n  - \'oratione\'\n  - \'dixisset\'\ntel:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ntextarea:\n  - \'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.\'\n  - \'Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;\'\n  - \'Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.\'\ntext_format:\n  - value: \'<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.</p>\'\n  - value: \'<p>Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;</p>\'\n  - value: \'<p>Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.</p>\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\nwebform_email_confirm:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nwebform_email_multiple:\n  - \'example@example.com, test@test.com, random@random.com\'\nwebform_time:\n  - \'09:00\'\n  - \'17:00\'\n\";s:5:\"names\";s:547:\"first_name:\n  - \'John\'\n  - \'Paul\'\n  - \'Ringo\'\n  - \'George\'\nlast_name:\n  - \'Lennon\'\n  - \'McCartney\'\n  - \'Starr\'\n  - \'Harrison\'\naddress:\n  - \'10 Main Street\'\n  - \'11 Brook Alley Road. APT 1\'\nzip:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\npostal_code:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\nphone:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\nfax:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ncity:\n  - \'Springfield\'\n  - \'Pleasantville\'\n  - \'Hill Valley\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\ndefault:\n  - \'Loremipsum\'\n  - \'Oratione\'\n  - \'Dixisset\'\n\";}s:2:\"ui\";a:9:{s:13:\"video_display\";s:6:\"dialog\";s:12:\"details_save\";b:1;s:13:\"help_disabled\";b:0;s:15:\"dialog_disabled\";b:0;s:18:\"offcanvas_disabled\";b:0;s:19:\"promotions_disabled\";b:0;s:16:\"support_disabled\";b:0;s:16:\"description_help\";b:1;s:12:\"toolbar_item\";b:0;}s:9:\"libraries\";a:1:{s:18:\"excluded_libraries\";a:2:{i:0;s:7:\"choices\";i:1;s:13:\"jquery.chosen\";}}s:12:\"requirements\";a:4:{s:3:\"cdn\";b:1;s:9:\"bootstrap\";b:1;s:21:\"clientside_validation\";b:1;s:4:\"spam\";b:1;}s:8:\"langcode\";s:2:\"en\";s:20:\"third_party_settings\";a:1:{s:7:\"captcha\";a:1:{s:27:\"replace_administration_mode\";b:1;}}}'),('','webform.webform.contact',_binary 'a:22:{s:4:\"uuid\";s:36:\"8b8a523d-2f23-4a57-82e5-54fb22889c9f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";s:4:\"open\";s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_je-MWeeJB6gfm6iECiqjcyNetfMFbn-YIInYwZ1gIk\";}s:4:\"open\";N;s:5:\"close\";N;s:6:\"weight\";i:0;s:3:\"uid\";N;s:8:\"template\";b:0;s:7:\"archive\";b:0;s:2:\"id\";s:7:\"contact\";s:5:\"title\";s:7:\"Contact\";s:11:\"description\";s:28:\"Basic email contact webform.\";s:10:\"categories\";a:0:{}s:8:\"elements\";s:566:\"name:\n  \'#title\': \'Your Name\'\n  \'#type\': textfield\n  \'#required\': true\n  \'#default_value\': \'[current-user:display-name]\'\nemail:\n  \'#title\': \'Your Email\'\n  \'#type\': email\n  \'#required\': true\n  \'#default_value\': \'[current-user:mail]\'\nsubject:\n  \'#title\': Subject\n  \'#type\': textfield\n  \'#required\': true\n  \'#test\': \'Testing contact webform from [site:name]\'\nmessage:\n  \'#title\': Message\n  \'#type\': textarea\n  \'#required\': true\n  \'#test\': \'Please ignore this email.\'\nactions:\n  \'#type\': webform_actions\n  \'#title\': \'Submit button(s)\'\n  \'#submit__label\': \'Send message\'\n\";s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";s:8:\"settings\";a:133:{s:4:\"ajax\";b:0;s:15:\"ajax_scroll_top\";s:4:\"form\";s:18:\"ajax_progress_type\";s:0:\"\";s:11:\"ajax_effect\";s:0:\"\";s:10:\"ajax_speed\";N;s:4:\"page\";b:1;s:16:\"page_submit_path\";s:0:\"\";s:17:\"page_confirm_path\";s:0:\"\";s:15:\"page_theme_name\";s:0:\"\";s:10:\"form_title\";s:21:\"source_entity_webform\";s:16:\"form_submit_once\";b:0;s:22:\"form_exception_message\";s:0:\"\";s:17:\"form_open_message\";s:0:\"\";s:18:\"form_close_message\";s:0:\"\";s:25:\"form_previous_submissions\";b:1;s:17:\"form_confidential\";b:0;s:25:\"form_confidential_message\";s:0:\"\";s:24:\"form_disable_remote_addr\";b:0;s:22:\"form_convert_anonymous\";b:0;s:16:\"form_prepopulate\";b:0;s:30:\"form_prepopulate_source_entity\";b:0;s:39:\"form_prepopulate_source_entity_required\";b:0;s:35:\"form_prepopulate_source_entity_type\";s:0:\"\";s:10:\"form_reset\";b:0;s:25:\"form_disable_autocomplete\";b:0;s:15:\"form_novalidate\";b:0;s:26:\"form_disable_inline_errors\";b:0;s:13:\"form_required\";b:0;s:12:\"form_unsaved\";b:0;s:17:\"form_disable_back\";b:0;s:16:\"form_submit_back\";b:0;s:14:\"form_autofocus\";b:0;s:19:\"form_details_toggle\";b:0;s:18:\"form_access_denied\";s:7:\"default\";s:24:\"form_access_denied_title\";s:0:\"\";s:26:\"form_access_denied_message\";s:0:\"\";s:29:\"form_access_denied_attributes\";a:0:{}s:15:\"form_file_limit\";s:0:\"\";s:11:\"form_method\";s:0:\"\";s:11:\"form_action\";s:0:\"\";s:15:\"form_attributes\";a:0:{}s:5:\"share\";b:0;s:10:\"share_node\";b:0;s:16:\"share_theme_name\";s:0:\"\";s:11:\"share_title\";b:1;s:26:\"share_page_body_attributes\";a:0:{}s:16:\"submission_label\";s:0:\"\";s:14:\"submission_log\";b:0;s:16:\"submission_views\";a:0:{}s:24:\"submission_views_replace\";a:0:{}s:23:\"submission_user_columns\";a:0:{}s:25:\"submission_user_duplicate\";b:0;s:24:\"submission_access_denied\";s:7:\"default\";s:30:\"submission_access_denied_title\";s:0:\"\";s:32:\"submission_access_denied_message\";s:0:\"\";s:35:\"submission_access_denied_attributes\";a:0:{}s:28:\"submission_exception_message\";s:0:\"\";s:25:\"submission_locked_message\";s:0:\"\";s:28:\"submission_excluded_elements\";a:0:{}s:24:\"submission_exclude_empty\";b:0;s:33:\"submission_exclude_empty_checkbox\";b:0;s:27:\"previous_submission_message\";s:0:\"\";s:28:\"previous_submissions_message\";s:0:\"\";s:8:\"autofill\";b:0;s:16:\"autofill_message\";s:0:\"\";s:26:\"autofill_excluded_elements\";a:0:{}s:19:\"wizard_progress_bar\";b:1;s:21:\"wizard_progress_pages\";b:0;s:26:\"wizard_progress_percentage\";b:0;s:20:\"wizard_progress_link\";b:0;s:22:\"wizard_progress_states\";b:0;s:19:\"wizard_auto_forward\";b:1;s:36:\"wizard_auto_forward_hide_next_button\";b:0;s:15:\"wizard_keyboard\";b:1;s:18:\"wizard_start_label\";s:0:\"\";s:19:\"wizard_preview_link\";b:0;s:19:\"wizard_confirmation\";b:1;s:25:\"wizard_confirmation_label\";s:0:\"\";s:12:\"wizard_track\";s:0:\"\";s:24:\"wizard_prev_button_label\";s:0:\"\";s:24:\"wizard_next_button_label\";s:0:\"\";s:13:\"wizard_toggle\";b:0;s:24:\"wizard_toggle_show_label\";s:0:\"\";s:24:\"wizard_toggle_hide_label\";s:0:\"\";s:16:\"wizard_page_type\";s:9:\"container\";s:21:\"wizard_page_title_tag\";s:2:\"h2\";s:7:\"preview\";i:0;s:13:\"preview_label\";s:0:\"\";s:13:\"preview_title\";s:0:\"\";s:15:\"preview_message\";s:0:\"\";s:18:\"preview_attributes\";a:0:{}s:25:\"preview_excluded_elements\";a:0:{}s:21:\"preview_exclude_empty\";b:1;s:30:\"preview_exclude_empty_checkbox\";b:0;s:5:\"draft\";s:4:\"none\";s:14:\"draft_multiple\";b:0;s:15:\"draft_auto_save\";b:0;s:19:\"draft_saved_message\";s:0:\"\";s:20:\"draft_loaded_message\";s:0:\"\";s:28:\"draft_pending_single_message\";s:0:\"\";s:30:\"draft_pending_multiple_message\";s:0:\"\";s:17:\"confirmation_type\";s:11:\"url_message\";s:18:\"confirmation_title\";s:0:\"\";s:20:\"confirmation_message\";s:27:\"Your message has been sent.\";s:16:\"confirmation_url\";s:7:\"<front>\";s:23:\"confirmation_attributes\";a:0:{}s:17:\"confirmation_back\";b:1;s:23:\"confirmation_back_label\";s:0:\"\";s:28:\"confirmation_back_attributes\";a:0:{}s:26:\"confirmation_exclude_query\";b:0;s:26:\"confirmation_exclude_token\";b:0;s:19:\"confirmation_update\";b:0;s:11:\"limit_total\";N;s:20:\"limit_total_interval\";N;s:19:\"limit_total_message\";s:0:\"\";s:18:\"limit_total_unique\";b:0;s:10:\"limit_user\";N;s:19:\"limit_user_interval\";N;s:18:\"limit_user_message\";s:0:\"\";s:17:\"limit_user_unique\";b:0;s:18:\"entity_limit_total\";N;s:27:\"entity_limit_total_interval\";N;s:17:\"entity_limit_user\";N;s:26:\"entity_limit_user_interval\";N;s:5:\"purge\";s:4:\"none\";s:10:\"purge_days\";N;s:16:\"results_disabled\";b:0;s:23:\"results_disabled_ignore\";b:0;s:17:\"results_customize\";b:0;s:10:\"token_view\";b:0;s:12:\"token_update\";b:0;s:12:\"token_delete\";b:0;s:15:\"serial_disabled\";b:0;}s:6:\"access\";a:11:{s:6:\"create\";a:3:{s:5:\"roles\";a:2:{i:0;s:9:\"anonymous\";i:1;s:13:\"authenticated\";}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:9:\"purge_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"administer\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:4:\"test\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:13:\"configuration\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}}s:8:\"handlers\";a:2:{s:18:\"email_confirmation\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email confirmation\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_confirmation\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:1;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:19:\"[current-user:mail]\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:8:\"_default\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:8:\"_default\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}s:18:\"email_notification\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email notification\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_notification\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:2;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:8:\"_default\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:37:\"[webform_submission:values:email:raw]\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:36:\"[webform_submission:values:name:raw]\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}}s:8:\"variants\";a:0:{}}'),('','webform.webform_options.country_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"fcbe2856-cef2-499f-8ba0-fbc8ffac8fdd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"adQ16YGDPk7QfUKrfrC35o2sKdHEozdNtdpiH7CftQQ\";}s:2:\"id\";s:13:\"country_codes\";s:5:\"label\";s:13:\"Country codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.country_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"9354d04a-fde3-4871-958b-953be0d0a8c8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zsfFP124dAM-sJkuEfnwaA7DN6o3-IsaXLgdNmObbYg\";}s:2:\"id\";s:13:\"country_names\";s:5:\"label\";s:13:\"Country names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.days',_binary 'a:10:{s:4:\"uuid\";s:36:\"6408d5ed-d58e-4d75-a41e-8c2526f7d3ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNrKbYrWWjeubUUM8AsQ19KnX7cU1elACR14CZJHmdg\";}s:2:\"id\";s:4:\"days\";s:5:\"label\";s:4:\"Days\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:121:\"Sunday: Sunday\nMonday: Monday\nTuesday: Tuesday\nWednesday: Wednesday\nThursday: Thursday\nFriday: Friday\nSaturday: Saturday\n\";}'),('','webform.webform_options.education',_binary 'a:10:{s:4:\"uuid\";s:36:\"4639bce4-22a5-4e03-9cad-186c79584f07\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mII4acOv33s-j8PINywrCag4OITbeJGxdPO373dnHHw\";}s:2:\"id\";s:9:\"education\";s:5:\"label\";s:9:\"Education\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:152:\"High School: High School\nAssociate Degree: Associate Degree\nGraduate or Professional Degree: Graduate or Professional Degree\nSome College: Some College\n\";}'),('','webform.webform_options.employment_status',_binary 'a:10:{s:4:\"uuid\";s:36:\"329c38fd-eb24-471e-aa3d-b63a51b3a1d6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8MCmsz_csdJkVItxI8g_s4zp2PM285YqCy_gWTzOLPw\";}s:2:\"id\";s:17:\"employment_status\";s:5:\"label\";s:17:\"Employment status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:113:\"\'Full Time\': \'Full Time\'\n\'Part Time\': \'Part Time\'\n\'Military\': \'Military\'\nUnemployed: Unemployed\nRetired: Retired\n\";}'),('','webform.webform_options.ethnicity',_binary 'a:10:{s:4:\"uuid\";s:36:\"0df45fa9-e8c8-4d2f-ae91-771c2df5499d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIPgrAC82wE2GAk1mOv2UvMYv71YQe4VT8667QIYdvI\";}s:2:\"id\";s:9:\"ethnicity\";s:5:\"label\";s:9:\"Ethnicity\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:200:\"Caucasian: Caucasian\n\'Latino/Hispanic\': \'Latino/Hispanic\'\n\'Middle Eastern\': \'Middle Eastern\'\nAfrican: African\nCaribbean: Caribbean\n\'South Asian\': \'South Asian\'\n\'East Asian\': \'East Asian\'\nMixed: Mixed\n\";}'),('','webform.webform_options.gender',_binary 'a:10:{s:4:\"uuid\";s:36:\"1fcf461d-9e42-4571-b6cf-28abee7d1f9b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yxhG0JmQs2HT-Ro6ZeDQboDc9ZWR4GglflTtyoqxK4A\";}s:2:\"id\";s:6:\"gender\";s:5:\"label\";s:6:\"Gender\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:756:\"Man: Man\nWoman: Woman\nNon-binary: Non-binary\nAgender/Genderless: Agender/Genderless\nAndrogyne/Androgynous: Androgyne/Androgynous\nAporagender: Aporagender\nBigender: Bigender\nDemi-agender: Demi-agender\nDemi-boy: Demi-boy\nDemi-fluid: Demi-fluid\nDemi-girl: Demi-girl\nDemi-gender: Demi-gender\nDemi-non-binary: Demi-non-binary\nGenderqueer: Genderqueer\nGenderflux: Genderflux\nGenderfluid: Genderfluid\nGender-indifferent: Gender-indifferent\nGender-neutral: Gender-neutral\nGraygender: Graygender\nIntergender: Intergender\nMaverique: Maverique\nMaxigender: Maxigender\nMultigender/Polygender: Multigender/Polygender\nNeutrois: Neutrois\nPangender/Omnigender: Pangender/Omnigender\nTrigender: Trigender\nTwo-spirit: Two-spirit\n\'Prefer Not to Answer\': \'Prefer Not to Answer\'\n\";}'),('','webform.webform_options.industry',_binary 'a:10:{s:4:\"uuid\";s:36:\"93091529-37e9-4c06-afeb-b349faa470ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"s_SXZn2HbRGvTex-TLOCxz2oOnMYqtEZh8HD4_318QI\";}s:2:\"id\";s:8:\"industry\";s:5:\"label\";s:8:\"Industry\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1425:\"Accounting/Finance: Accounting/Finance\nAdvertising/Public Relations: Advertising/Public Relations\nAerospace/Aviation: Aerospace/Aviation\nArts/Entertainment/Publishing: Arts/Entertainment/Publishing\nAutomotive: Automotive\nBanking/Mortgage: Banking/Mortgage\nBusiness Development: Business Development\nBusiness Opportunity: Business Opportunity\nClerical/Administrative: Clerical/Administrative\nConstruction/Facilities: Construction/Facilities\nConsumer Goods: Consumer Goods\nCustomer Service: Customer Service\nEducation/Training: Education/Training\nEnergy/Utilities: Energy/Utilities\nEngineering: Engineering\nGovernment/Military: Government/Military\nHealthcare: Healthcare\nHospitality/Travel: Hospitality/Travel\nHuman Resources: Human Resources\nInstallation/Maintenance: Installation/Maintenance\nInsurance: Insurance\nInternet: Internet\nLaw Enforcement/Security: Law Enforcement/Security\nLegal: Legal\nManagement/Executive: Management/Executive\nManufacturing/Operations: Manufacturing/Operations\nMarketing: Marketing\nNon-Profit/Volunteer: Non-Profit/Volunteer\nPharmaceutical/Biotech: Pharmaceutical/Biotech\nProfessional Services: Professional Services\nReal Estate: Real Estate\nRestaurant/Food Service: Restaurant/Food Service\nRetail: Retail\nSales: Sales\nScience/Research: Science/Research\nSkilled Labor: Skilled Labor\nTechnology: Technology\nTelecommunications: Telecommunications\nTransportation/Logistics: Transportation/Logistics\n\";}'),('','webform.webform_options.languages',_binary 'a:10:{s:4:\"uuid\";s:36:\"b5b13230-e38a-46a3-950e-7fb23a36c978\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mYH14Vi65Ixj10c_GFa7CipxU3D0Bt9wgo8zE8zjOfE\";}s:2:\"id\";s:9:\"languages\";s:5:\"label\";s:9:\"Languages\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.likert_agreement',_binary 'a:10:{s:4:\"uuid\";s:36:\"85e67cce-5058-4806-85e0-7af5f9b85ac0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nPp-CfMKrP0yDMtyO0wQRwawEqaJVAPzQapinXmDgyU\";}s:2:\"id\";s:16:\"likert_agreement\";s:5:\"label\";s:17:\"Likert: Agreement\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:71:\"1: Strongly Disagree\n2: Disagree\n3: Neutral\n4: Agree\n5: Strongly Agree\n\";}'),('','webform.webform_options.likert_comparison',_binary 'a:10:{s:4:\"uuid\";s:36:\"b7c1b8ab-fa1a-40b6-99de-c764482a5e3d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DMG4TKTHEXtHN8ho_sG_GiZHgweZ6nrRm6BAjk0LZ_Y\";}s:2:\"id\";s:17:\"likert_comparison\";s:5:\"label\";s:18:\"Likert: Comparison\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:84:\"1: Much Worse\n2: Somewhat Worse\n3: About the Same\n4: Somewhat Better\n5: Much Better\n\";}'),('','webform.webform_options.likert_importance',_binary 'a:10:{s:4:\"uuid\";s:36:\"a7ba4359-4c6f-4830-8d8a-1b39544c95d7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hbc8n5HtVZVs5fSBSpSbuY07CVvqkKP76csvRHN9pK8\";}s:2:\"id\";s:17:\"likert_importance\";s:5:\"label\";s:18:\"Likert: Importance\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:88:\"1: Not at all Important\n2: Somewhat Important\n3: Neutral\n4: Important\n5: Very Important\n\";}'),('','webform.webform_options.likert_quality',_binary 'a:10:{s:4:\"uuid\";s:36:\"431a023e-67ab-48e5-8bac-a1572c14c19f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swmYtBVUbwq7aHJWWDN7ODByuvur9vMkexDC9h64NZ8\";}s:2:\"id\";s:14:\"likert_quality\";s:5:\"label\";s:15:\"Likert: Quality\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:50:\"1: Poor\n2: Fair\n3: Good\n4: Very good\n5: Excellent\n\";}'),('','webform.webform_options.likert_satisfaction',_binary 'a:10:{s:4:\"uuid\";s:36:\"f3e69acd-d88d-48a1-ae55-9997d56e4d8a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AKE2SNwCpl6Mu_cmbq9ZM2_cXxCikCVj1vcPE9oHWTs\";}s:2:\"id\";s:19:\"likert_satisfaction\";s:5:\"label\";s:20:\"Likert: Satisfaction\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:77:\"1: Very Unsatisfied\n2: Unsatisfied\n3: Neutral\n4: Satisfied\n5: Very Satisfied\n\";}'),('','webform.webform_options.likert_ten_scale',_binary 'a:10:{s:4:\"uuid\";s:36:\"d39bd682-6e68-4cbd-8ace-ae4db6b7d13f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zEZX8JSVqznnFtqFfpuC593h3t1JDAZhF0Q3pvA229o\";}s:2:\"id\";s:16:\"likert_ten_scale\";s:5:\"label\";s:17:\"Likert: Ten Scale\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:52:\"1: 1\n2: 2\n3: 3\n4: 4\n5: 5\n6: 6\n7: 7\n8: 8\n9: 9\n10: 10\n\";}'),('','webform.webform_options.likert_would_you',_binary 'a:10:{s:4:\"uuid\";s:36:\"da40135e-38ac-464f-8ee9-0a9085b6b37b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qBS2TmfAJB37Qn3TnrNM8x4AWimmDapcizzRllgo0fo\";}s:2:\"id\";s:16:\"likert_would_you\";s:5:\"label\";s:17:\"Likert: Would You\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:72:\"1: Definitely Not\n2: Probably Not\n3: Not Sure\n4: Probably\n5: Definitely\n\";}'),('','webform.webform_options.marital_status',_binary 'a:10:{s:4:\"uuid\";s:36:\"caf25914-1f32-4cc2-8565-20b048649e59\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cjVDbAE5BlopGrY-tfxsxMoyEibwBBNgdQwDdxOSkow\";}s:2:\"id\";s:14:\"marital_status\";s:5:\"label\";s:14:\"Marital status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:68:\"Single: Single\nMarried: Married\nDivorced: Divorced\nWidowed: Widowed\n\";}'),('','webform.webform_options.months',_binary 'a:10:{s:4:\"uuid\";s:36:\"b28be784-d785-41d2-b9a2-5b26173eb305\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pZJnuQkh9afNML5IcMuKTUC__vmHMFn66Qr5IWtedZ4\";}s:2:\"id\";s:6:\"months\";s:5:\"label\";s:6:\"Months\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:184:\"January: January\nFebruary: February\nMarch: March\nApril: April\nMay: May\nJune: June\nJuly: July\nAugust: August\nSeptember: September\nOctober: October\nNovember: November\nDecember: December\n\";}'),('','webform.webform_options.phone_types',_binary 'a:10:{s:4:\"uuid\";s:36:\"9fc50b5c-88f4-4154-ae56-ddbe476c4e3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LkO63Zl2cP_l9YdjzWI8dWoD9uD0pytkPiUiUM2bo9A\";}s:2:\"id\";s:11:\"phone_types\";s:5:\"label\";s:10:\"Phone type\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:37:\"Home: Home\nOffice: Office\nCell: Cell\n\";}'),('','webform.webform_options.province_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"7817e355-803d-4cdf-88a9-a3ab29e94c21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cR3A6XXinVGC9g5vLS-vVvTC2ppZXRNXLPWA8xBUMew\";}s:2:\"id\";s:14:\"province_codes\";s:5:\"label\";s:14:\"Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:237:\"AB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),('','webform.webform_options.province_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"be00197d-93d4-42c6-8d82-abc6357218e4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aaEeYBWoWETLKX2ivmZBpUAd3uPe2iPNydaxBuLPXKc\";}s:2:\"id\";s:14:\"province_names\";s:5:\"label\";s:14:\"Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:379:\"Alberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),('','webform.webform_options.relationship',_binary 'a:10:{s:4:\"uuid\";s:36:\"e7f91e1a-5e99-4f06-bd68-f4a6d8a72ad9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4J2RPG4JmsD4Fm1NlIQY0JHkrJ08UUl0qTF0_EjUxvw\";}s:2:\"id\";s:12:\"relationship\";s:5:\"label\";s:12:\"Relationship\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:101:\"Parent: Parent\n\'Significant Other\': \'Significant Other\'\nSibling: Sibling\nChild: Child\nFriend: Friend\n\";}'),('','webform.webform_options.sex',_binary 'a:10:{s:4:\"uuid\";s:36:\"554341f6-de3f-4da4-8d70-e2302b2d1a3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WRpxpwYpfcO_i0so7BV4QXxXlbPiSVppYmAV6DAz4c0\";}s:2:\"id\";s:3:\"sex\";s:5:\"label\";s:3:\"Sex\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:26:\"Male: Male\nFemale: Female\n\";}'),('','webform.webform_options.sex_icao',_binary 'a:10:{s:4:\"uuid\";s:36:\"fec065d0-b801-4d27-9b36-c4c20d17c22f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9mxo86dMII5OxkHl4mbe2l4AgQloOXuErOte57BU9IY\";}s:2:\"id\";s:8:\"sex_icao\";s:5:\"label\";s:54:\"Sex - International Civil Aviation Organization (ICAO)\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:33:\"M: Male\nF: Female\nX: Unspecified\n\";}'),('','webform.webform_options.size',_binary 'a:10:{s:4:\"uuid\";s:36:\"dcb23767-92c9-44f0-af6f-82142d05d7f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RKkc6tf1VudvYiOtwPCf3Tp_EoA6fov6BFC34D7gMoQ\";}s:2:\"id\";s:4:\"size\";s:5:\"label\";s:4:\"Size\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:91:\"Extra Small: Extra Small\nSmall: Small\nMedium: Medium\nLarge: Large\nExtra Large: Extra Large\n\";}'),('','webform.webform_options.state_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"d3af1e77-6eac-4403-a5fb-758c5365a402\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8mYO8ewsZX3LVfNga69jXa0RNO0LNN8-EGkXLhSAMBU\";}s:2:\"id\";s:11:\"state_codes\";s:5:\"label\";s:11:\"State codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:728:\"AL: Alabama\nAK: Alaska\nAZ: Arizona\nAR: Arkansas\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPA: Pennsylvania\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\n\";}'),('','webform.webform_options.state_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"294b5fc1-0d98-46dc-b941-253bcd531719\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KfYqMSrFJ5iGtDzvy_rGUeRUJ4KyM7Xt-tWtYx9WjiM\";}s:2:\"id\";s:11:\"state_names\";s:5:\"label\";s:11:\"State names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1081:\"Alabama: Alabama\nAlaska: Alaska\nArizona: Arizona\nArkansas: Arkansas\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\nFlorida: Florida\nGeorgia: Georgia\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPennsylvania: Pennsylvania\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\n\";}');
INSERT INTO `config` VALUES ('','webform.webform_options.state_province_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"6973c62d-f428-4205-934b-9559ce7d133c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ziWv9xVss1UBnP_R38EqduZOprwOAifpxjXhyOPzmys\";}s:2:\"id\";s:20:\"state_province_codes\";s:5:\"label\";s:20:\"State/Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1241:\"AL: Alabama\nAK: Alaska\nAS: \'American Samoa\'\nAZ: Arizona\nAR: Arkansas\nAE: \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\nAA: \'Armed Forces Americas\'\nAP: \'Armed Forces Pacific\'\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFM: \'Federated States of Micronesia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMH: \'Marshall Islands\'\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nMP: \'Northern Mariana Islands\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPW: Palau\nPA: Pennsylvania\nPR: \'Puerto Rico\'\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVI: \'Virgin Islands\'\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\nAB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),('','webform.webform_options.state_province_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"041d2cb0-73c1-4dd6-8388-5b44d924fd3f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d4mxS_CxdzHZK4WaGQf1H3m-Uubm5HPbu9U4ydzscuo\";}s:2:\"id\";s:20:\"state_province_names\";s:5:\"label\";s:20:\"State/Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1953:\"Alabama: Alabama\nAlaska: Alaska\n\'American Samoa\': \'American Samoa\'\nArizona: Arizona\nArkansas: Arkansas\n\'Armed Forces (Canada, Europe, Africa, or Middle East)\': \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\n\'Armed Forces Americas\': \'Armed Forces Americas\'\n\'Armed Forces Pacific\': \'Armed Forces Pacific\'\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\n\'Federated States of Micronesia\': \'Federated States of Micronesia\'\nFlorida: Florida\nGeorgia: Georgia\nGuam: Guam\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\n\'Marshall Islands\': \'Marshall Islands\'\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\n\'Northern Mariana Islands\': \'Northern Mariana Islands\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPalau: Palau\nPennsylvania: Pennsylvania\n\'Puerto Rico\': \'Puerto Rico\'\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\n\'Virgin Islands\': \'Virgin Islands\'\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\nAlberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),('','webform.webform_options.time_zones',_binary 'a:10:{s:4:\"uuid\";s:36:\"a170e99b-fa17-41e0-a271-10a7c2bb61f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8rVcRXLnTAEoWs7zl8du-7RIUnayqUcGYnvb3JT21-o\";}s:2:\"id\";s:10:\"time_zones\";s:5:\"label\";s:10:\"Time zones\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.titles',_binary 'a:10:{s:4:\"uuid\";s:36:\"428cbf5b-9239-4908-8e3c-1b29a9657d92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PEUoedWrfYEX7oZ8CcOukfBTVxar1cPSROX8534esuU\";}s:2:\"id\";s:6:\"titles\";s:5:\"label\";s:6:\"Titles\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:41:\"Miss: Miss\nMs: Ms\nMr: Mr\nMrs: Mrs\nDr: Dr\n\";}'),('','webform.webform_options.translations',_binary 'a:10:{s:4:\"uuid\";s:36:\"8c38f0bb-4da2-49a0-b196-c2d5c1ba66cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mb_L3vE-0IBZH5s2rjpk2LNn0QHClQP9AARQdCmVLt4\";}s:2:\"id\";s:12:\"translations\";s:5:\"label\";s:12:\"Translations\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.yes_no',_binary 'a:10:{s:4:\"uuid\";s:36:\"9d57dfd8-f21c-40ec-bbaa-57fe26b6397c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W88NYg31DbaVNQx1Uir_dwwXHVtF09QOq4VBGsH1Snk\";}s:2:\"id\";s:6:\"yes_no\";s:5:\"label\";s:6:\"Yes/No\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:16:\"Yes: Yes\nNo: No\n\";}');
/*!40000 ALTER TABLE `config` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `config_export`
--

DROP TABLE IF EXISTS `config_export`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `config_export` (
  `collection` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object collection.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object name.',
  `data` longblob COMMENT 'A serialized configuration object data.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for configuration data.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `config_export`
--

LOCK TABLES `config_export` WRITE;
/*!40000 ALTER TABLE `config_export` DISABLE KEYS */;
INSERT INTO `config_export` VALUES ('','admin_toolbar.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvTSppzcgH5wnzBhX5xnAExcp2I1CzkQ_aky65XNfYI\";}s:10:\"menu_depth\";i:4;}'),('','admin_toolbar_tools.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WgdZsrd_5w9jlmcHV4R9dD2tG9OZEkYo4I_O8h7Gq8Q\";}s:17:\"max_bundle_number\";i:20;s:25:\"hoverintent_functionality\";b:1;s:16:\"show_local_tasks\";b:0;}'),('','announcements_feed.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0G5pZBcxbg8ONYzNLd1RJIsvuFFewm9htnS4I-ABKJ8\";}s:7:\"max_age\";i:86400;s:13:\"cron_interval\";i:21600;s:5:\"limit\";i:10;}'),('','automated_cron.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fUksROt4FfkAU9BV4hV2XvhTBSS2nTNrZS4U7S-tKrs\";}s:8:\"interval\";i:10800;}'),('','block.block.claro_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"be976f48-8227-4e04-b46e-05849e446c76\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NjcxOBrPOiK5-38t56DwFBDVY4yer7YSlbRWXFuHe7A\";}s:2:\"id\";s:17:\"claro_breadcrumbs\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"ce83be5e-1fd7-4a0f-9b06-0a0d8710cb26\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a0Yyx1GeyKarZ4T_yXQBR_ZFKnXiFLtxAb6gWLd8nr0\";}s:2:\"id\";s:13:\"claro_content\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"d66baf8e-252f-4c79-acb6-b8b6d6b0a27a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jccFSSVqV0WCDb6NtML1VWAWTtDbZ-zn5YgTRMgMrIM\";}s:2:\"id\";s:10:\"claro_help\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_help_search',_binary 'a:13:{s:4:\"uuid\";s:36:\"05eb19c5-b411-47d2-b90a-e862156e9997\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"module\";a:2:{i:0;s:6:\"search\";i:1;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}s:8:\"enforced\";a:1:{s:6:\"config\";a:1:{i:0;s:23:\"search.page.help_search\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2ToeZLvlHKTeFY74gpgu1PejLoFyCECLO_gw6rAZwqw\";}s:2:\"id\";s:17:\"claro_help_search\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:11:\"Search help\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:11:\"help_search\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:4:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:0:{}s:5:\"pages\";s:11:\"/admin/help\";}}}'),('','block.block.claro_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"916365b2-7723-493b-8918-5f3ff7d57c7d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdXfDmRgAvms7EQovxxWPdYi0GitxeRbVtScYK16ZH0\";}s:2:\"id\";s:19:\"claro_local_actions\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"3b00e68f-1ed0-4482-b8b1-e496f1da9936\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Ac3ISpIT0PQ-whzD7_dw0SdKi6dAbRFNWdSjOiVDqg\";}s:2:\"id\";s:14:\"claro_messages\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"b76f1641-4f78-438e-a0fe-ce65bd7f9006\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNwDdW063tk_ktzSWzZVeQS9wzvLooVO280BQ9WrsIs\";}s:2:\"id\";s:16:\"claro_page_title\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"a8c9d41b-02e1-478d-85b3-fb3a1f815f49\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ACjBZI5shAMiiUpsz-inLYVXDqNNXRnSzAWV3kV_8Hw\";}s:2:\"id\";s:25:\"claro_primary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"bb1e9b33-93c2-4829-9613-e4ccc525f30b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2L0geP-ixCbCkEpW6BVF6H7vDUZN4ea07_Y9CociQm4\";}s:2:\"id\";s:27:\"claro_secondary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_account_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"f35c55e3-3d40-497f-9b7f-2896cbc2e345\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:22:\"ept_light_account_menu\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"7010f57e-634e-4b97-8a69-97b80a011cb4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:21:\"ept_light_breadcrumbs\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:3:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:1;s:5:\"pages\";s:10:\"/whats-new\";}}}'),('','block.block.ept_light_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"7b17ab28-0376-4ee3-91ee-5bd02432291e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:17:\"ept_light_content\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_footer',_binary 'a:12:{s:4:\"uuid\";s:36:\"a78731d9-6557-4805-9b50-71d93a910730\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:18:\"system.menu.footer\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:2:\"id\";s:16:\"ept_light_footer\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"footer\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:24:\"system_menu_block:footer\";s:8:\"settings\";a:7:{s:2:\"id\";s:24:\"system_menu_block:footer\";s:5:\"label\";s:24:\"Have a question or idea?\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:0;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"8edfdbdd-cd33-4ebe-b1d4-74fb38d1039e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:14:\"ept_light_help\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_main_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"736d4519-e22a-419a-87cd-009a768a73b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:19:\"ept_light_main_menu\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"c8fc509e-9767-4eae-81f5-6cdbe64aa2b3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:18:\"ept_light_messages\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"f45a0a49-c001-47cb-b97e-767aac0f24f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:20:\"ept_light_page_title\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:1:{s:18:\"entity_bundle:node\";a:4:{s:2:\"id\";s:18:\"entity_bundle:node\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:1:{s:4:\"node\";s:29:\"@node.node_route_context:node\";}s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}}}'),('','block.block.ept_light_primary_admin_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"feb5ed42-838e-41fe-bce3-ac32e38425f9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:31:\"ept_light_primary_admin_actions\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"56ef6a64-122b-4123-89be-e28c850c9ab5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:29:\"ept_light_primary_local_tasks\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_search_form_narrow',_binary 'a:13:{s:4:\"uuid\";s:36:\"ac6db2d5-4bab-486d-9cbd-5a8bc4c56df9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yEBET0cqDbk8dkWzaJw-8CKft0961VBflsISoSR6Lj8\";}s:2:\"id\";s:28:\"ept_light_search_form_narrow\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"hidden\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:20:\"Search form (narrow)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";N;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_search_form_wide',_binary 'a:13:{s:4:\"uuid\";s:36:\"682b08d1-3f45-4c13-974e-95552426afcd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"imMyHD6LYci0gtXq56qr9ZKGHzbEG9uFydrN5EhKtSU\";}s:2:\"id\";s:26:\"ept_light_search_form_wide\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"hidden\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:18:\"Search form (wide)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";N;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"901eabdd-054d-4bcb-9773-45c7fd010fdf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:31:\"ept_light_secondary_local_tasks\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-3;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_site_branding',_binary 'a:13:{s:4:\"uuid\";s:36:\"91c1ee17-a1ad-4235-992c-274ff1022382\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:23:\"ept_light_site_branding\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"906009a1-78bd-4b80-9f60-5260448561b2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"y9X3xgCsO59pQyzNLzY1D3SDJJxCHILLWkpPnmuTJ2E\";}s:2:\"id\";s:15:\"gin_breadcrumbs\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"38507368-0a7f-4498-a629-376fb4821455\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBHXB7hC05XU7pDYzETt-GUcpFlogK1gkjyAsg0Ym58\";}s:2:\"id\";s:11:\"gin_content\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"e3753ad7-7b76-4f93-add9-02296fe5a072\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8nOAry2oKqJOr0zbrlJ3sZHDFJLIO6j-0vT0K_TYca4\";}s:2:\"id\";s:8:\"gin_help\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"f127d369-8154-4de3-9366-638b32c1d495\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OQ9aJ-4qVwK1x00o9EOYK4eFDjQr_HLpbPiJaPSVZiQ\";}s:2:\"id\";s:17:\"gin_local_actions\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"302175a6-2514-4728-9834-feade3c1cb23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WvPhI8OwllG0gE69-F8qL3ai3nd5SbYD6JpmEuZcyok\";}s:2:\"id\";s:12:\"gin_messages\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"37f8f7d2-81b3-4c42-a9a4-84cb29380e2c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HLQY2xgby8K3vN_98hiOSasOhm9pdCsH234-s0duJ8Q\";}s:2:\"id\";s:14:\"gin_page_title\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"877e883f-c61a-49fd-bf14-7370c20fec8c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hh01DLj9k7UnNdPpOQXHZHW7GHf2OPNDQyCJF7_R9ac\";}s:2:\"id\";s:23:\"gin_primary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"11d088e1-eb0e-4d66-ac1d-c629d4c31759\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCWhood0xXFQYqxFgL1spXdb9KeIuXH1YvTdjIEedDg\";}s:2:\"id\";s:25:\"gin_secondary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_account_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"360ce22f-fdb1-4a74-baf4-b253df6d8b6d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:20:\"olivero_account_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"19cc65dc-0021-4f62-9692-28154e28e6d6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:19:\"olivero_breadcrumbs\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"45129ab9-c3af-46c1-b266-7caf3e552d05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:15:\"olivero_content\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"1f0cb4e0-55ff-4097-a00c-015a0892bae5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:12:\"olivero_help\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_main_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"447aab50-0670-4a09-ad2b-204da3cad682\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:17:\"olivero_main_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"07cc9530-0745-41b8-a927-b15f94d11bfb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:16:\"olivero_messages\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"8ed1a440-61c0-42d9-af64-c0573a386802\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:18:\"olivero_page_title\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_powered',_binary 'a:13:{s:4:\"uuid\";s:36:\"4e19c95d-851d-48dd-8e91-3df3501787a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYL19CLDyinGTWYQfBD1DswWzglEotE_kHnHx3AxTXM\";}s:2:\"id\";s:15:\"olivero_powered\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"footer_bottom\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_powered_by_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_powered_by_block\";s:5:\"label\";s:17:\"Powered by Drupal\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_admin_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"2889853d-c6c8-46fb-8345-4f1161d60b42\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:29:\"olivero_primary_admin_actions\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"4a702f15-1477-4e9c-a8bf-5c98f5bff5f5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:27:\"olivero_primary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_search_form_narrow',_binary 'a:13:{s:4:\"uuid\";s:36:\"8eba635a-7f03-408c-a4a4-28e12ca89e20\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yEBET0cqDbk8dkWzaJw-8CKft0961VBflsISoSR6Lj8\";}s:2:\"id\";s:26:\"olivero_search_form_narrow\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:20:\"Search form (narrow)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";N;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_search_form_wide',_binary 'a:13:{s:4:\"uuid\";s:36:\"decd9477-39d6-4529-94a3-8a2d5f064f46\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"imMyHD6LYci0gtXq56qr9ZKGHzbEG9uFydrN5EhKtSU\";}s:2:\"id\";s:24:\"olivero_search_form_wide\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:18:\"Search form (wide)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";N;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"b7350fce-d849-4243-936a-283b164fea04\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:29:\"olivero_secondary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-2;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_site_branding',_binary 'a:13:{s:4:\"uuid\";s:36:\"5e004719-546a-4a9e-8ed6-bce3b1438316\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:21:\"olivero_site_branding\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_syndicate',_binary 'a:13:{s:4:\"uuid\";s:36:\"b7ad69dc-b6ab-4ee3-ab50-2994b490c801\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0gq3VPg-_UM69FCCWurLFIrrnIjC2HLKhwo9iQNtcUo\";}s:2:\"id\";s:17:\"olivero_syndicate\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"social\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:20:\"node_syndicate_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:20:\"node_syndicate_block\";s:5:\"label\";s:8:\"RSS feed\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"node\";s:11:\"block_count\";i:10;}s:10:\"visibility\";a:0:{}}'),('','block_content.type.basic',_binary 'a:9:{s:4:\"uuid\";s:36:\"682f8d4b-7fbf-4b68-aeeb-78ff6ffa44c8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQP5iQy4SdhAMVcjDUncCfkJmTofnHVtXrsMzx4k6Yk\";}s:2:\"id\";s:5:\"basic\";s:5:\"label\";s:11:\"Basic block\";s:8:\"revision\";b:0;s:11:\"description\";s:42:\"A basic block contains a title and a body.\";}'),('','ckeditor5_plugin_pack.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uAMHMIBA-fCvlzeeOYZ4vKwSBXvThlEytdEKK_Ur8nI\";}s:12:\"dll_location\";s:0:\"\";}'),('','claro.settings',_binary 'a:1:{s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),('','comment.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNUW2Ij5uE7a4oaXp3i_2lvaFdYM1zNKPPfnEjB0jEc\";}s:16:\"log_ip_addresses\";b:0;}'),('','comment.type.comment',_binary 'a:9:{s:4:\"uuid\";s:36:\"33c6c326-f5e0-4ece-8508-28b245963a92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bqZsN31T2n0UjcbyCpOPi9D2iO0sAOHR7FnEs9qMvaA\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:16:\"Default comments\";s:21:\"target_entity_type_id\";s:4:\"node\";s:11:\"description\";s:28:\"Allows commenting on content\";}'),('','contact.form.feedback',_binary 'a:12:{s:4:\"uuid\";s:36:\"d9d62dfa-bada-46f4-869f-64b74f835a2f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vymHlgJy26BuI5GGj9-IXjwR3dRC5C0tij4BpWJnoqw\";}s:2:\"id\";s:8:\"feedback\";s:5:\"label\";s:16:\"Website feedback\";s:10:\"recipients\";a:1:{i:0;s:17:\"admin@example.com\";}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.form.personal',_binary 'a:12:{s:4:\"uuid\";s:36:\"3d45f5dc-8385-44e2-add9-10e58ad548b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jonvgt3CkUM2eMLTFwWfHileWWDC4YtXCuIlCahTk_I\";}s:2:\"id\";s:8:\"personal\";s:5:\"label\";s:21:\"Personal contact form\";s:10:\"recipients\";a:0:{}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U69DBeuvXuNVOC15rVNaBjDPK2fWFbo9v4takdYSSO8\";}s:12:\"default_form\";s:8:\"feedback\";s:5:\"flood\";a:2:{s:5:\"limit\";i:5;s:8:\"interval\";i:3600;}s:20:\"user_default_enabled\";b:1;}'),('','core.base_field_override.node.page.promote',_binary 'a:17:{s:4:\"uuid\";s:36:\"3818335f-a764-468f-ba14-8dbe325fa7f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:14:\"node.type.page\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fPUEnm4T5zfZRr3ttDUqq7yCDd2uW3clWD-pvos4tlQ\";}s:2:\"id\";s:17:\"node.page.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','core.date_format.fallback',_binary 'a:9:{s:4:\"uuid\";s:36:\"3d36a601-a518-4117-b489-72f027a4d007\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7klS5IWXrwzVaPpYZFAs6wcx8U2FF1X73OfrtTsvuvE\";}s:2:\"id\";s:8:\"fallback\";s:5:\"label\";s:20:\"Fallback date format\";s:6:\"locked\";b:1;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),('','core.date_format.html_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"1e7ea1cc-62aa-4605-b6b6-e50e8e13c716\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EOQltUQPmgc6UQ2rcJ4Xi_leCEJj5ui0TR-12duS-Tk\";}s:2:\"id\";s:9:\"html_date\";s:5:\"label\";s:9:\"HTML Date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-m-d\";}'),('','core.date_format.html_datetime',_binary 'a:9:{s:4:\"uuid\";s:36:\"c34d2a68-a9e5-40c6-8224-8940032e30eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxfClwZIRXIdcvMrE--WkcZxDGUVoOIE3Sm2NRZlFuE\";}s:2:\"id\";s:13:\"html_datetime\";s:5:\"label\";s:13:\"HTML Datetime\";s:6:\"locked\";b:1;s:7:\"pattern\";s:13:\"Y-m-d\\TH:i:sO\";}'),('','core.date_format.html_month',_binary 'a:9:{s:4:\"uuid\";s:36:\"1db472d5-aa8d-43d1-99f1-0718ae5620bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Z7KuCUwM_WdTNvLcoltuX3_8d-s-8FZkTN6KgNwF0eM\";}s:2:\"id\";s:10:\"html_month\";s:5:\"label\";s:10:\"HTML Month\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"Y-m\";}'),('','core.date_format.html_time',_binary 'a:9:{s:4:\"uuid\";s:36:\"504c65d8-2f56-4376-8b9b-e7ca5b007ba8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M7yqicYkU36hRy5p9drAaGBBihhUD1OyujFrAaQ93ZE\";}s:2:\"id\";s:9:\"html_time\";s:5:\"label\";s:9:\"HTML Time\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"H:i:s\";}'),('','core.date_format.html_week',_binary 'a:9:{s:4:\"uuid\";s:36:\"9c97ee83-74c2-4456-80d2-eb94e9ca333e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKD4WsoV_wFgv2vgI4mcAAFSIzrye17ykzdwrnApkfY\";}s:2:\"id\";s:9:\"html_week\";s:5:\"label\";s:9:\"HTML Week\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-\\WW\";}'),('','core.date_format.html_year',_binary 'a:9:{s:4:\"uuid\";s:36:\"045e5b96-3ec2-48a7-ba8c-c6cd6c3e6478\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjekiQuX9RbVQ2_8jOHBL94RgYLePqX7wpfNGgcQzrk\";}s:2:\"id\";s:9:\"html_year\";s:5:\"label\";s:9:\"HTML Year\";s:6:\"locked\";b:1;s:7:\"pattern\";s:1:\"Y\";}'),('','core.date_format.html_yearless_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"ebd666ec-7725-4d54-8907-f69b8c4e48ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VpawMrKPEPCkoO4YpPa0TDFO2dgiIHfTziJtwlmUxc\";}s:2:\"id\";s:18:\"html_yearless_date\";s:5:\"label\";s:18:\"HTML Yearless date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"m-d\";}'),('','core.date_format.long',_binary 'a:9:{s:4:\"uuid\";s:36:\"26c2a255-dd57-40de-9edb-d3ecd4eafa69\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"og8sWXhBuHbLMw3CoiBEZjgqSyhFBFmcbUW_wLcfNbo\";}s:2:\"id\";s:4:\"long\";s:5:\"label\";s:17:\"Default long date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:15:\"l, F j, Y - H:i\";}'),('','core.date_format.medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"b3b94f80-dd74-4a2f-b128-51de30c5e289\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nzL5d024NjXIX_8TlT6uFAu973lmfkmHklJC-2i9rAE\";}s:2:\"id\";s:6:\"medium\";s:5:\"label\";s:19:\"Default medium date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),('','core.date_format.olivero_medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"f5992887-d80e-47c5-bcb3-28c304448abb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mt6cmxUbDZ9XxD6p25WQ8tj3_JcX8ylfcddwZc8gcAE\";}s:2:\"id\";s:14:\"olivero_medium\";s:5:\"label\";s:14:\"Olivero Medium\";s:6:\"locked\";b:0;s:7:\"pattern\";s:8:\"j  F,  Y\";}'),('','core.date_format.short',_binary 'a:9:{s:4:\"uuid\";s:36:\"c5c2ce9a-1442-4bf1-a654-b45e23c4b6e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AlzeyytA8InBgxIG9H2UDJYs3CG98Zj6yRsDKmlbZwA\";}s:2:\"id\";s:5:\"short\";s:5:\"label\";s:18:\"Default short date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:11:\"m/d/Y - H:i\";}'),('','core.entity_form_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"21a9c7b6-423a-4c02-931a-6bb7c808ca5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jAps3FCxvKecABS_tgExbhCZrBLQB3bNPWw18WjE3ss\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"46bc1cc1-610e-4909-9538-f9f08a6a24c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0Pa0aQvT_jawlPo9oz4FE3h_ickc55dYKTPl6gILes\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:6:\"author\";a:2:{s:6:\"weight\";i:-2;s:6:\"region\";s:7:\"content\";}s:12:\"comment_body\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:7:\"subject\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.media.audio.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"1912a858-abb3-4ca8-aa94-e9265ace4567\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"G2_SKH3jmI9FQeXSUxo3KgQqiyF1hPDEkc7-3-rCSbc\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_audio_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.audio.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"4c160f87-d7c6-4dde-a9d2-878ce2336387\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:16:\"media.type.audio\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"28vwMIYtvyjPcD4RyciZXIztxtZgmuWRCNgYemr_SZE\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.document.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c24b87ec-64f6-4fa0-aed7-1c3d86160e5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aewrRkePgJzdD5kPOq8JeMcKHs6yat49nE7ZeCQzQZg\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_media_document\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.document.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"8323a260-ffc2-4476-8123-c40c72552a6e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:19:\"media.type.document\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dcpfpqyLXOSGpulacMAJW3H-G34_LeNsjdfxd1_oCfY\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f08ad847-8b1c-4396-9081-ca9a56f6b01a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:21:\"image.style.thumbnail\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JSY4-JPyNZBiYYo6imdRYF6_SdtWQexPndrLvn3-vw4\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.image.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"91fbcfb7-0a83-434f-99ac-c23c349657be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BMLrK4zKp8-FFnMseBdT_6h6YipUsKRfbDf_3WUB5HA\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:5:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.remote_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"97a32351-c013-445a-af13-08939389c3b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pM8mGlwfpvfG_y5tZn0lGAXFLXz2_yKkL7MvWZsRqdA\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_media_oembed_video\";a:5:{s:4:\"type\";s:16:\"oembed_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.remote_video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"47cd5408-95d9-4b89-a9c5-7d8aedd625f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBgPW-uaXRaICBwLaVc16rXpRiLSknDIdF9q0XL7qso\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"7c5e18c3-3d08-4151-8d31-a9d9a597a5ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0kIIaDTt6dixXy8TZkat2MNGZJ6vkRG8TaBWTy3E1bM\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_video_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"3d683f4e-cbb1-4a0e-b1df-f9f9c87e4284\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:16:\"media.type.video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kGv8YsopqHvzTzb7QTINWcv0fnNa5ZDQyZxpOQR2vro\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"de67467e-664b-4fd4-b096-f4f20912ea91\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:35:\"field.field.node.article.field_tags\";i:3;s:21:\"image.style.thumbnail\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ewbd6G2uX456-bgwseM2Q-KQG3RkASoyHmTh-XR3oLU\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:10:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:11:\"field_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:10:\"field_tags\";a:5:{s:4:\"type\";s:34:\"entity_reference_autocomplete_tags\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c6ec1d38-d434-4a7d-be65-080873fd0aff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:38:\"field.field.node.page.field_components\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:3:{i:0;s:17:\"layout_paragraphs\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:9:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:31;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:16:\"field_components\";a:5:{s:4:\"type\";s:17:\"layout_paragraphs\";s:6:\"weight\";i:121;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:10;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.paragraph.ept_accordion.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"bcf372a8-c025-4ef1-bc1e-7467ead740ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:55:\"field.field.paragraph.ept_accordion.field_ept_accordion\";i:1;s:54:\"field.field.paragraph.ept_accordion.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_accordion.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_accordion.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:4:{i:0;s:13:\"ept_accordion\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:19:\"field_ept_accordion\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0pJauu3QzSH4aBsmd_KTxzf59AWAoqGvmpFOuI3phow\";}s:2:\"id\";s:31:\"paragraph.ept_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:19:\"field_ept_accordion\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_accordion\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_accordion_section.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a18df3e8-1c60-449a-81fb-3d8f4dc347dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:68:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_text\";i:1;s:69:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_title\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-D0_ofC0E9vG5JgJKn-KVVKS8EddSulFMva-vLSGBq4\";}s:2:\"id\";s:39:\"paragraph.ept_accordion_section.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ept_accordion_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_accordion_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_basic_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"3bbc19b5-b8d1-4737-93da-814614ad0da5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:66:\"field.field.paragraph.ept_basic_button.field_ept_basic_button_link\";i:1;s:57:\"field.field.paragraph.ept_basic_button.field_ept_settings\";i:2;s:53:\"field.field.paragraph.ept_basic_button.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_basic_button.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:3:{i:0;s:16:\"ept_basic_button\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BDM_dmNUeNyOV7_jEouKixGZvfGdfIYFnegSbt0TFUk\";}s:2:\"id\";s:34:\"paragraph.ept_basic_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:27:\"field_ept_basic_button_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:25:\"ept_settings_basic_button\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_block.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"063fafbf-a44a-44d9-b44e-e6b7f1c968f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";i:1;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";i:2;s:46:\"field.field.paragraph.ept_block.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_block.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:8:\"ept_core\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:21:\"field_ept_block_block\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kf0CKi0lVMCHZKEFVJNSYNl5CpKFKRH7JLsGDr_mt24\";}s:2:\"id\";s:27:\"paragraph.ept_block.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:21:\"field_ept_block_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_bootstrap_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"39e1a15a-eab7-4dcc-af37-af10f81e96dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:74:\"field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";i:1;s:61:\"field.field.paragraph.ept_bootstrap_button.field_ept_settings\";i:2;s:57:\"field.field.paragraph.ept_bootstrap_button.field_ept_text\";i:3;s:58:\"field.field.paragraph.ept_bootstrap_button.field_ept_title\";i:4;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:3:{i:0;s:20:\"ept_bootstrap_button\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WwkZbBHhL-k1BpcZgfCET2hj9ScPYC5rcs4an-tHYB4\";}s:2:\"id\";s:38:\"paragraph.ept_bootstrap_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:31:\"field_ept_bootstrap_button_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:29:\"ept_settings_bootstrap_button\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_cards.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"343bdaca-8837-45f9-9879-bc37b630068f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:50:\"field.field.paragraph.ept_cards.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_cards.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_cards.field_ept_title\";i:3;s:36:\"paragraphs.paragraphs_type.ept_cards\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bsDZ_W6zC0Z-XF3k1wOPjfyjNZZTDsDa88bWGz-XWpM\";}s:2:\"id\";s:27:\"paragraph.ept_cards.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_cards\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_carousel.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"3b42b32b-b440-4ab8-9a73-96284648f0b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_carousel\";i:1;s:53:\"field.field.paragraph.ept_carousel.field_ept_settings\";i:2;s:49:\"field.field.paragraph.ept_carousel.field_ept_text\";i:3;s:50:\"field.field.paragraph.ept_carousel.field_ept_title\";i:4;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:4:{i:0;s:12:\"ept_carousel\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:18:\"field_ept_carousel\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9B69asgWfAo5TT1550-4nwxxD-NZ9b_eK0DwrqjPbAI\";}s:2:\"id\";s:30:\"paragraph.ept_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_carousel\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:21:\"ept_settings_carousel\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_carousel_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"209743da-7b46-410c-8256-e9acf9b4200b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:1;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0MubGNP7-aRTqqknjrXSWiyr6o87xC8YYQSjnFL1qMA\";}s:2:\"id\";s:35:\"paragraph.ept_carousel_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_carousel_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_columns.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"4fadf498-bcbb-44d6-b829-6d1abdabf326\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:51:\"field.field.paragraph.ept_columns.field_ept_columns\";i:1;s:52:\"field.field.paragraph.ept_columns.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_columns.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_columns.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:4:{i:0;s:11:\"ept_columns\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:17:\"field_ept_columns\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MfVgHlmnR_bb8akzrozdi7R7KwnEOtq9cQ0OpHkngMs\";}s:2:\"id\";s:29:\"paragraph.ept_columns.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:17:\"field_ept_columns\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_columns\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_countdown.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"ed55009f-a01e-42ae-987d-b5ccc04e073b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ept_countdown.field_ept_countdown_date\";i:1;s:54:\"field.field.paragraph.ept_countdown.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_countdown.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_countdown.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:4:{i:0;s:8:\"datetime\";i:1;s:13:\"ept_countdown\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:24:\"field_ept_countdown_date\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZxcirB8U5v0ZYrJRdwsxmS_1WIhbNwZMbBqsAz988cQ\";}s:2:\"id\";s:31:\"paragraph.ept_countdown.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_countdown_date\";a:5:{s:4:\"type\";s:16:\"datetime_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_countdown\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_counter.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"6e0ad4c3-90f1-4e63-9ad2-e7c012a124d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_counter.field_ept_counter_items\";i:1;s:52:\"field.field.paragraph.ept_counter.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_counter.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_counter.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:4:{i:0;s:11:\"ept_counter\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:23:\"field_ept_counter_items\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:9;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eaw1Ar6YTSIRF829Uy9SPd0v5CFQ_XobGxIEZV3aq_Q\";}s:2:\"id\";s:29:\"paragraph.ept_counter.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_counter_items\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_counter\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_counter_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8c95a60e-1c70-45a6-b8a2-c4d53b93ce5d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_counter_item.field_ept_counter_description\";i:1;s:61:\"field.field.paragraph.ept_counter_item.field_ept_counter_icon\";i:2;s:63:\"field.field.paragraph.ept_counter_item.field_ept_counter_number\";i:3;s:62:\"field.field.paragraph.ept_counter_item.field_ept_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HdOx-dFGYXleAxDzMra4AkSnLaUMOZ6Sgl69k93sJcg\";}s:2:\"id\";s:34:\"paragraph.ept_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ept_counter_description\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ept_counter_icon\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_counter_number\";a:5:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ept_counter_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_cta.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"8a29f047-88c0-4af9-8cd2-705177201f7a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:56:\"field.field.paragraph.ept_cta.field_ept_cta_column_image\";i:1;s:48:\"field.field.paragraph.ept_cta.field_ept_cta_link\";i:2;s:55:\"field.field.paragraph.ept_cta.field_ept_cta_second_link\";i:3;s:48:\"field.field.paragraph.ept_cta.field_ept_settings\";i:4;s:44:\"field.field.paragraph.ept_cta.field_ept_text\";i:5;s:45:\"field.field.paragraph.ept_cta.field_ept_title\";i:6;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:5:{i:0;s:7:\"ept_cta\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:26:\"field_ept_cta_column_image\";i:3;s:18:\"field_ept_cta_link\";i:4;s:25:\"field_ept_cta_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4FYtKN9WoslLXaZoBk3fkuVx6aDPk0YoM6rC8pnsieA\";}s:2:\"id\";s:25:\"paragraph.ept_cta.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:26:\"field_ept_cta_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_cta_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_cta_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:16:\"ept_settings_cta\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_hero.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"be53fd67-518c-4b3c-ac43-3b2c15a8d954\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";i:1;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";i:2;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";i:3;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";i:4;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";i:5;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";i:6;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";i:7;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:5:{i:0;s:8:\"ept_hero\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:6:{i:0;s:15:\"field_ept_title\";i:1;s:27:\"field_ept_hero_title_prefix\";i:2;s:14:\"field_ept_text\";i:3;s:27:\"field_ept_hero_column_image\";i:4;s:19:\"field_ept_hero_link\";i:5;s:26:\"field_ept_hero_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jU5fU7CphqYF6ZSn4c9q-QZ0_XHfDeFV936TKmTKPIM\";}s:2:\"id\";s:26:\"paragraph.ept_hero.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:27:\"field_ept_hero_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_hero_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ept_hero_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_hero_title_prefix\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:17:\"ept_settings_hero\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_image.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a60ae7a6-353d-412e-81ca-b8eff5eb6f78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_image\";i:1;s:55:\"field.field.paragraph.ept_image.field_ept_image_caption\";i:2;s:52:\"field.field.paragraph.ept_image.field_ept_image_link\";i:3;s:50:\"field.field.paragraph.ept_image.field_ept_settings\";i:4;s:46:\"field.field.paragraph.ept_image.field_ept_text\";i:5;s:47:\"field.field.paragraph.ept_image.field_ept_title\";i:6;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:5:{i:0;s:9:\"ept_image\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_image\";i:3;s:23:\"field_ept_image_caption\";i:4;s:20:\"field_ept_image_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6-OjP-OV8uHyYxN_ycg0WCoPJRu34t3ix7LwCCNbTzE\";}s:2:\"id\";s:27:\"paragraph.ept_image.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:15:\"field_ept_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ept_image_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_image_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_image\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_image_gallery.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"bd32a1a0-f63c-4e6b-b14f-7dfa6323a07a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_image_gallery.field_ept_image_gallery\";i:1;s:58:\"field.field.paragraph.ept_image_gallery.field_ept_settings\";i:2;s:54:\"field.field.paragraph.ept_image_gallery.field_ept_text\";i:3;s:55:\"field.field.paragraph.ept_image_gallery.field_ept_title\";i:4;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:4:{i:0;s:17:\"ept_image_gallery\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:23:\"field_ept_image_gallery\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9b_KN3kBrDhBERN17M7jxBYPF-IXaw1nLONpCw4Dtzo\";}s:2:\"id\";s:35:\"paragraph.ept_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_image_gallery\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:26:\"ept_settings_image_gallery\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_micromodal.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"c0e1ca3f-d656-43c4-a362-86c7cb0ac490\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_micromodal.field_ept_micromodal_title\";i:1;s:55:\"field.field.paragraph.ept_micromodal.field_ept_settings\";i:2;s:51:\"field.field.paragraph.ept_micromodal.field_ept_text\";i:3;s:52:\"field.field.paragraph.ept_micromodal.field_ept_title\";i:4;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:3:{i:0;s:14:\"ept_micromodal\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:14:\"group_settings\";i:1;s:13:\"group_content\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:26:\"field_ept_micromodal_title\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:6:\"hidden\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ynF9PLVVYG00_7Br42jxgJ02cMPPwmtf3jssH3Gx9T8\";}s:2:\"id\";s:32:\"paragraph.ept_micromodal.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_micromodal_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:23:\"ept_settings_micromodal\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_quote.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"62a89609-5a89-4eb4-a5a2-c3c58c93480d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:54:\"field.field.paragraph.ept_quote.field_ept_quote_author\";i:1;s:53:\"field.field.paragraph.ept_quote.field_ept_quote_image\";i:2;s:50:\"field.field.paragraph.ept_quote.field_ept_settings\";i:3;s:46:\"field.field.paragraph.ept_quote.field_ept_text\";i:4;s:47:\"field.field.paragraph.ept_quote.field_ept_title\";i:5;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_quote\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:4:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:22:\"field_ept_quote_author\";i:3;s:21:\"field_ept_quote_image\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rMIoq7ATvLm5GYUegulzLGA67l1jIqNeN1Vma_Calus\";}s:2:\"id\";s:27:\"paragraph.ept_quote.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:22:\"field_ept_quote_author\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_quote_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_quote\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slick_slider.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"6b2455af-c7c1-4faf-ae2f-5faf8b33c82d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_slick_slider.field_ept_settings\";i:1;s:61:\"field.field.paragraph.ept_slick_slider.field_ept_slick_slider\";i:2;s:53:\"field.field.paragraph.ept_slick_slider.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_slick_slider.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:4:{i:0;s:16:\"ept_slick_slider\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:22:\"field_ept_slick_slider\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hDbTWzuXu3VZtJk1OkYoVRSHUWjZQRwzNKl8MSfnHZo\";}s:2:\"id\";s:34:\"paragraph.ept_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:25:\"ept_settings_slick_slider\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ept_slick_slider\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slick_slider_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"0e9a2579-f110-4139-81b2-dc1025db5053\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:72:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";i:1;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";i:2;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";i:3;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CjC8L66tFduxz7PpSEZ_n5Vewr_T4E3BXo6iZw5cPjs\";}s:2:\"id\";s:39:\"paragraph.ept_slick_slider_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ept_slick_slider_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_slick_slider_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_slick_slider_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slideshow.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"1003a694-14ea-404d-bf58-34d4ad51a83c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:54:\"field.field.paragraph.ept_slideshow.field_ept_settings\";i:1;s:55:\"field.field.paragraph.ept_slideshow.field_ept_slideshow\";i:2;s:50:\"field.field.paragraph.ept_slideshow.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_slideshow.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:4:{i:0;s:13:\"ept_slideshow\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:19:\"field_ept_slideshow\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tILUBTEfzAAfH3RNpAfKLafcB4BQ1rEs4TXsefzXpz8\";}s:2:\"id\";s:31:\"paragraph.ept_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_slideshow\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_slideshow\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slideshow_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"483f7e15-2bcb-4ed9-952b-548c4960e622\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link\";i:1;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide\";i:2;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text\";i:3;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title\";i:4;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wXdtnml8iEI3B2hPt_jBFMcr9wunJPj97vsPtPVoSlI\";}s:2:\"id\";s:36:\"paragraph.ept_slideshow_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_slideshow_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_slideshow_slide\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_slideshow_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_slideshow_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_stats.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a9e1d9c8-64cb-4c33-ae6e-7c4617fa82d4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_stats.field_ept_settings\";i:1;s:47:\"field.field.paragraph.ept_stats.field_ept_stats\";i:2;s:46:\"field.field.paragraph.ept_stats.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_stats.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_stats\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_stats\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iULioKDpET9pDqjdWoX6RbIYNdzK6nuBHJbWBY8s8hw\";}s:2:\"id\";s:27:\"paragraph.ept_stats.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_stats\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_stats\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_stats_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"11f77720-51d3-4dc6-b653-b86d5771046b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_image\";i:1;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_link\";i:2;s:64:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_number\";i:3;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wF_mUJwfQr8bsVI-d3u1R2W8PUu9gazphbDkBAY2SEk\";}s:2:\"id\";s:32:\"paragraph.ept_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_stats_item_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_stats_item_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_stats_item_number\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_stats_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tabs.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"e1a6c8e5-95b1-4c04-8b08-798a42e3f990\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:49:\"field.field.paragraph.ept_tabs.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_tabs.field_ept_tabs\";i:2;s:45:\"field.field.paragraph.ept_tabs.field_ept_text\";i:3;s:46:\"field.field.paragraph.ept_tabs.field_ept_title\";i:4;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_tabs\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:14:\"field_ept_tabs\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qwxwo_7tJPCVoTpGT3EGZT8rcmOT-hnPcBxVGLjPG78\";}s:2:\"id\";s:26:\"paragraph.ept_tabs.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:17:\"ept_settings_tabs\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_tabs\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tabs_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2ba6d267-9074-4e3c-a4c5-e392e2e1b8ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_block\";i:1;s:57:\"field.field.paragraph.ept_tabs_item.field_ept_tab_content\";i:2;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_page\";i:3;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_text\";i:4;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_title\";i:5;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_views\";i:6;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oVvZoAPE_jk4D2dNYM8_LohZLLeaIQBnleftotvYd7o\";}s:2:\"id\";s:31:\"paragraph.ept_tabs_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:19:\"field_ept_tab_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tab_content\";a:5:{s:4:\"type\";s:14:\"options_select\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_tab_page\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_tab_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_tab_title\";a:5:{s:4:\"type\";s:14:\"text_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_tab_views\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_text.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"0a168361-abfe-403a-8922-8305dbbef7af\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:49:\"field.field.paragraph.ept_text.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_text.field_ept_text\";i:2;s:46:\"field.field.paragraph.ept_text.field_ept_title\";i:3;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:6:\"hidden\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"shyYm2rY3OjdKeiRCtoWJpvauXuaTQJb8xb0cyNYRM8\";}s:2:\"id\";s:26:\"paragraph.ept_text.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:21;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:23;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:22;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tiles.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a5784c00-a16b-4f3b-91dd-568be1356d3a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_tiles.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_tiles.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_tiles.field_ept_tiles\";i:3;s:47:\"field.field.paragraph.ept_tiles.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_tiles\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_tiles\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:11;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:12;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fub48PSonCbwVzLnLvqqeYQk1wGzEf65HefNdP-qQaQ\";}s:2:\"id\";s:27:\"paragraph.ept_tiles.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_tiles\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_tiles\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tiles_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"45b2e5a1-2031-4177-b3c2-580549849e46\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ept_tiles_item.field_ept_clickable_tile\";i:1;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_image\";i:2;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_link\";i:3;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_text\";i:4;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U9PXobBv4clQdnuyNB31xyZFAqJ5NgK_WHOSbnw6g98\";}s:2:\"id\";s:32:\"paragraph.ept_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ept_clickable_tile\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tiles_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_tiles_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_tiles_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tiles_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"fe1a956f-1eb5-49f4-8ccd-d852faeeea9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_video.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_video.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_video.field_ept_title\";i:3;s:47:\"field.field.paragraph.ept_video.field_ept_video\";i:4;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_video\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:15:\"field_ept_video\";i:2;s:14:\"field_ept_text\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uWfzDvi2652DPEZs_2EApToxb-ZwFGKVzEDZ3Jd27xU\";}s:2:\"id\";s:27:\"paragraph.ept_video.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_video\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_video\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video_and_image_gallery.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"2a6ec3c5-051d-451f-bfa5-ae16ca4d9cc1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_settings\";i:1;s:64:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_text\";i:2;s:65:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_title\";i:3;s:77:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";i:4;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:4:{i:0;s:27:\"ept_video_and_image_gallery\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:27:\"field_ept_videos_and_images\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rOQ-MHiLNktgV1oHnzDodKFBNZKJGnpQ_jcoXGPWl3s\";}s:2:\"id\";s:45:\"paragraph.ept_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:36:\"ept_settings_video_and_image_gallery\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_videos_and_images\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video_and_image_gallery_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"5a1fd1b5-9098-41dc-99e7-65246d6fe6da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";i:1;s:82:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-EpWxbfVxkolF4xO3v_gR4i7gLA_X1pxspQ3sm0jgQY\";}s:2:\"id\";s:50:\"paragraph.ept_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:22:\"field_ept_gallery_item\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_gallery_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_views.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"5f9fd1ed-53a9-4349-8202-c90230a11f12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_views.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_views.field_ept_title\";i:3;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";i:4;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";i:3;s:14:\"viewsreference\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:20:\"field_ept_views_view\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_i5XjlBN7MBo2rHWjbgIick135me8C2QqOcKTkr7Sx0\";}s:2:\"id\";s:27:\"paragraph.ept_views.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_views_view\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_webform.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d798701f-5b10-44f6-b850-ac38718396b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:52:\"field.field.paragraph.ept_webform.field_ept_settings\";i:1;s:48:\"field.field.paragraph.ept_webform.field_ept_text\";i:2;s:49:\"field.field.paragraph.ept_webform.field_ept_title\";i:3;s:56:\"field.field.paragraph.ept_webform.field_ept_webform_form\";i:4;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E0IjG-r8QfTmGUoGidNGmC64-k8eCONH_yhAUTGU9ZE\";}s:2:\"id\";s:29:\"paragraph.ept_webform.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ept_webform_form\";a:5:{s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:12:\"default_data\";b:1;s:8:\"webforms\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_webform_popup.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"71680c26-8af6-49c5-94f2-7276e46d9545\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:58:\"field.field.paragraph.ept_webform_popup.field_ept_settings\";i:1;s:54:\"field.field.paragraph.ept_webform_popup.field_ept_text\";i:2;s:55:\"field.field.paragraph.ept_webform_popup.field_ept_title\";i:3;s:68:\"field.field.paragraph.ept_webform_popup.field_ept_webform_popup_form\";i:4;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:3:{i:0;s:17:\"ept_webform_popup\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gxEA8BYs6sWNkpdD8h1XtwAUuUMpWV8fj1lzvtOLatM\";}s:2:\"id\";s:35:\"paragraph.ept_webform_popup.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:26:\"ept_settings_webform_popup\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:28:\"field_ept_webform_popup_form\";a:5:{s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:12:\"default_data\";b:1;s:8:\"webforms\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8eb5837f-793f-476b-8d5b-8eb1ea190520\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FaQ9Ptcpxpg30AtiqRDtl_8zbJArHP1LPfug_s59TOA\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"account\";a:2:{s:6:\"weight\";i:-10;s:6:\"region\";s:7:\"content\";}s:7:\"contact\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:8:\"language\";a:2:{s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:8:\"timezone\";a:2:{s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_mode.media.media_library',_binary 'a:10:{s:4:\"uuid\";s:36:\"94fd7791-9806-4755-a50f-91d35400a4cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_form_mode.user.register',_binary 'a:10:{s:4:\"uuid\";s:36:\"ef62034d-b624-4a32-9e4a-54a2baf7fa78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5pE_4hurqtIlZN3XDi7eTo5RG13BMG0Rh9HYlRI3h8U\";}s:2:\"id\";s:13:\"user.register\";s:5:\"label\";s:8:\"Register\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"53a48e63-4272-4544-9051-7617915e3d41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBNNDTFwakREOTa6GGMqN899Iyrii0hInwSJtQ7Kj30\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"da002566-b092-4563-9d08-c4b5c52593e5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aBQUGsQ46M4048fIlFuTXwl2zV0j2cJX89CTUobh9hA\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:12:\"comment_body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.media.audio.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"87bcc8b2-7f6c-4c74-800a-a87d1b94f5f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AS765MdDfNpK6K5eE7WVnBvpynClz_havy1R3bO3gVo\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_audio_file\";a:6:{s:4:\"type\";s:10:\"file_audio\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:4:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.audio.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"fd3c8ee0-7347-4825-a6ac-e712dc98946b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tcAUW1Xzq5Tjw5jomR6XKGSgfiXO7QiRAHJBF-n0akg\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.document.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"af3b0da5-5654-474f-b056-1b7fe53c1991\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XxUyhaTuM0OUUZpr8G6jdrFBEh5eag7auWxBKhm6cvY\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:20:\"field_media_document\";a:6:{s:4:\"type\";s:12:\"file_default\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.document.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"3027dd27-1f17-44e8-84f5-7366b5d87788\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:21:\"image.style.thumbnail\";i:3;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YcWqjhIlo-2RZUM5ogvRsrKB7M3voF2XB3lVLwgOlLU\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"19dfadc9-d9a4-4d4c-9953-240f406fe79c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:17:\"image.style.large\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"73xaTNkI5J6sfFcBmNYeuk070X3mQS_iwwWaPYyfG2M\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:5:\"large\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.ept_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"4f8ec3e2-1797-492f-8b2d-8ce7545d59bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:45:\"core.entity_view_mode.media.ept_image_gallery\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:29:\"image.style.ept_gallery_image\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n90nNuXho9mrkYYsIQ1XTO6AvAhpgl2KtPDCGCOnGhM\";}s:2:\"id\";s:29:\"media.image.ept_image_gallery\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:17:\"ept_image_gallery\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:17:\"ept_gallery_image\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:6:\"parent\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"c47a77e8-55b1-49a2-adeb-dc69b79b24e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:60:\"core.entity_view_mode.media.ept_video_and_image_gallery_item\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:39:\"image.style.ept_video_and_image_gallery\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rH_qHt_lYqhJQjixn1J6qIQ6Nll3micOpoBEVEtJ4CA\";}s:2:\"id\";s:44:\"media.image.ept_video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:32:\"ept_video_and_image_gallery_item\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:27:\"ept_video_and_image_gallery\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"1053ac57-9af0-4e5b-ba2f-c5695c62ef08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:18:\"image.style.medium\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ILLWu5KFvbsX6J7sh2Itd4w8-lBBRhR_H8ZrmQiN2yo\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:17:\"field_media_image\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"9ecc7509-3522-45c5-bda4-7ed77885a161\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZdPcl2hPxl5pgv3pI-07R7h51OjeUeKJTy-ab1NfM34\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:6:\"oembed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:9:\"max_width\";i:0;s:10:\"max_height\";i:0;s:7:\"loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.ept_video',_binary 'a:11:{s:4:\"uuid\";s:36:\"51e43f2e-4f69-45a1-95c7-5ecf07778894\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:37:\"core.entity_view_mode.media.ept_video\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1KlyRkRbqUbxJgk8eo1S40_quArKzT_wKaIMWWlaSoU\";}s:2:\"id\";s:28:\"media.remote_video.ept_video\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:9:\"ept_video\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:4:\"post\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"72019611-98d6-4f86-81ec-768c71520e64\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:60:\"core.entity_view_mode.media.ept_video_and_image_gallery_item\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3xEp_ZELSvrqfzLRi2XtfPP7KVrHNdRe-XdyCYK3Jc8\";}s:2:\"id\";s:51:\"media.remote_video.ept_video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:32:\"ept_video_and_image_gallery_item\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:27:\"ept_video_and_image_gallery\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"b0bc3306-d88a-4581-af6c-2a1f29aac6ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:18:\"image.style.medium\";i:3;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PGGoP-hVkXe_S-GiJRAub4PHDu0KhMExylclrqjdJb4\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"63fe648a-c5c1-42b9-8b04-7bb9db119166\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxvbuGh-6cQMxl9bBV27-hGI46u7ZvwlMm5ObaJMNnw\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_video_file\";a:6:{s:4:\"type\";s:10:\"file_video\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";s:5:\"muted\";b:0;s:5:\"width\";i:640;s:6:\"height\";i:480;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"5672ce5e-9fb4-4800-8c9d-3b15ca3f7fde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_fnkUKwQYHkXO1Ngmq9nE6FqWUNAmkddOxAH1h5aiKg\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"0f767bd2-1919-4166-8346-62c5fc895c81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:35:\"field.field.node.article.field_tags\";i:3;s:16:\"image.style.wide\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"br6izr-iGEu--JvNbCJNtOBpRnxpFLXfoV5y61U9Nqc\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.node.article.rss',_binary 'a:11:{s:4:\"uuid\";s:36:\"bad692de-34e5-483c-9717-c610a77e5be5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2rIr6K5Q0UQ9khg0zE_CK-PtJH76UL-BDDZcZnZzwCc\";}s:2:\"id\";s:16:\"node.article.rss\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:3:\"rss\";s:7:\"content\";a:1:{s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:3:{s:4:\"body\";b:1;s:11:\"field_image\";b:1;s:10:\"field_tags\";b:1;}}'),('','core.entity_view_display.node.article.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"b696c09e-d916-4b49-a1c2-566c781bf923\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:18:\"image.style.medium\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O8PxzfG8DOHHRu6M23kwR6TDPq_MNfYQ10Mp367ICUQ\";}s:2:\"id\";s:19:\"node.article.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"bc183acd-cdee-4366-86c4-4db46beceef3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:38:\"field.field.node.page.field_components\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Y8L5tfmhx7DR143E05YyZSpvgil6VFvqcfBWykalg\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:16:\"field_components\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:4:\"body\";b:1;}}'),('','core.entity_view_display.node.page.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"b64bcaef-5bd0-446f-a6d5-7096df12851d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:26:\"field.field.node.page.body\";i:2;s:38:\"field.field.node.page.field_components\";i:3;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8BgdRtLbtQ0F__o0FHSH0Mx5fvXOra9tfT1GmNKbRYw\";}s:2:\"id\";s:16:\"node.page.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:16:\"field_components\";b:1;}}'),('','core.entity_view_display.paragraph.ept_accordion.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f60b271e-f09b-45a9-8e92-1ae341b267f5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:55:\"field.field.paragraph.ept_accordion.field_ept_accordion\";i:1;s:54:\"field.field.paragraph.ept_accordion.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_accordion.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_accordion.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PJi5yKQ_AuFiKp81hRO_aQKSuuwBJkStIGM6f0wBBX8\";}s:2:\"id\";s:31:\"paragraph.ept_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:19:\"field_ept_accordion\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_accordion_section.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d4e6aedc-c8f3-451b-94d6-cd44fc4b6c11\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:68:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_text\";i:1;s:69:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_title\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UjA4zXZ3oMZFxRvkNrsM94SAiqKznnxAtCPUVIC6MT0\";}s:2:\"id\";s:39:\"paragraph.ept_accordion_section.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ept_accordion_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_accordion_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_basic_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f4454fef-a659-4b88-9579-11ba22f32177\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:66:\"field.field.paragraph.ept_basic_button.field_ept_basic_button_link\";i:1;s:57:\"field.field.paragraph.ept_basic_button.field_ept_settings\";i:2;s:53:\"field.field.paragraph.ept_basic_button.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_basic_button.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4gJX4ZzysdJ_kzlqlJAB2uqXRXQJi3VjikD1N3iepgA\";}s:2:\"id\";s:34:\"paragraph.ept_basic_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:27:\"field_ept_basic_button_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_block.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e7417c73-82e0-49a6-b66c-942b3596d612\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";i:1;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";i:2;s:46:\"field.field.paragraph.ept_block.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_block.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BFcfVmJHF2899wHjHN2VFWpiUyRAjvacvce9Cfs79BY\";}s:2:\"id\";s:27:\"paragraph.ept_block.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:21:\"field_ept_block_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_bootstrap_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a806c6af-6b6a-4398-a270-06147cb09d21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:74:\"field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";i:1;s:61:\"field.field.paragraph.ept_bootstrap_button.field_ept_settings\";i:2;s:57:\"field.field.paragraph.ept_bootstrap_button.field_ept_text\";i:3;s:58:\"field.field.paragraph.ept_bootstrap_button.field_ept_title\";i:4;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1s6HjRSAsva6N8IAwlMIIoLxlmMtVw7ygPp4U_Z7_1I\";}s:2:\"id\";s:38:\"paragraph.ept_bootstrap_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:31:\"field_ept_bootstrap_button_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_cards.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8ee3416a-ed7c-41d9-a9fd-2b0aca7d452b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:50:\"field.field.paragraph.ept_cards.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_cards.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_cards.field_ept_title\";i:3;s:36:\"paragraphs.paragraphs_type.ept_cards\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kx91MDtB9twVA76JC_brbEdU-Fwbok0L76fdkEmYqYI\";}s:2:\"id\";s:27:\"paragraph.ept_cards.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_cards\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a34b4adb-f67d-4569-90a5-e74b6a28bcdb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_carousel\";i:1;s:53:\"field.field.paragraph.ept_carousel.field_ept_settings\";i:2;s:49:\"field.field.paragraph.ept_carousel.field_ept_text\";i:3;s:50:\"field.field.paragraph.ept_carousel.field_ept_title\";i:4;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hW53xnntQ786Y9Dng5tbHj61F_Xq405ejwkoK9cGxUg\";}s:2:\"id\";s:30:\"paragraph.ept_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_carousel\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"95f5dba7-e075-42d7-bb71-a987d5625124\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:1;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:2;s:18:\"image.style.medium\";i:3;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kypuOk2yxicxTkEhw3Xo0FLPQXZVoNvTgwtmyMtUUKk\";}s:2:\"id\";s:35:\"paragraph.ept_carousel_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel_item.slider',_binary 'a:11:{s:4:\"uuid\";s:36:\"fa961609-f5ef-403a-8089-73f33b1e73f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:38:\"core.entity_view_mode.paragraph.slider\";i:1;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:2;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:3;s:18:\"image.style.medium\";i:4;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kypuOk2yxicxTkEhw3Xo0FLPQXZVoNvTgwtmyMtUUKk\";}s:2:\"id\";s:34:\"paragraph.ept_carousel_item.slider\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:6:\"slider\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_columns.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"83448cb5-91c5-4a34-a576-3ea914fa7d6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:51:\"field.field.paragraph.ept_columns.field_ept_columns\";i:1;s:52:\"field.field.paragraph.ept_columns.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_columns.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_columns.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vOC7NP0p0aXc-869ZBnA91HhUz6DjvKa3lJQB7amMmo\";}s:2:\"id\";s:29:\"paragraph.ept_columns.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:17:\"field_ept_columns\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_countdown.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"08b2118c-18b9-4669-b9e4-0786d49af6ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ept_countdown.field_ept_countdown_date\";i:1;s:54:\"field.field.paragraph.ept_countdown.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_countdown.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_countdown.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:3:{i:0;s:8:\"datetime\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0tZvxTE9_SxYclV0-qXTYzgXSfZoC1elFCKHb9scTG4\";}s:2:\"id\";s:31:\"paragraph.ept_countdown.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_countdown_date\";a:6:{s:4:\"type\";s:16:\"datetime_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:17:\"timezone_override\";s:0:\"\";s:11:\"format_type\";s:6:\"medium\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_counter.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"ad408e08-db1a-47df-8098-0b2a61f16481\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_counter.field_ept_counter_items\";i:1;s:52:\"field.field.paragraph.ept_counter.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_counter.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_counter.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eZqA1TwH5tWY55LrWFHFJQ_5F6K3z2LZAXPoKY6znBw\";}s:2:\"id\";s:29:\"paragraph.ept_counter.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_counter_items\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_counter_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"077ee820-2041-4778-8135-0fc65cd20cb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_counter_item.field_ept_counter_description\";i:1;s:61:\"field.field.paragraph.ept_counter_item.field_ept_counter_icon\";i:2;s:63:\"field.field.paragraph.ept_counter_item.field_ept_counter_number\";i:3;s:62:\"field.field.paragraph.ept_counter_item.field_ept_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7The1phmhJ8Ls_nSR64aLtEXudYALjs5Zzdf10AFuA\";}s:2:\"id\";s:34:\"paragraph.ept_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ept_counter_description\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ept_counter_icon\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_counter_number\";a:6:{s:4:\"type\";s:14:\"number_integer\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:23:\"field_ept_counter_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_cta.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"4bf53171-20df-4e38-bb87-a451cfc4aa6c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:56:\"field.field.paragraph.ept_cta.field_ept_cta_column_image\";i:1;s:48:\"field.field.paragraph.ept_cta.field_ept_cta_link\";i:2;s:55:\"field.field.paragraph.ept_cta.field_ept_cta_second_link\";i:3;s:48:\"field.field.paragraph.ept_cta.field_ept_settings\";i:4;s:44:\"field.field.paragraph.ept_cta.field_ept_text\";i:5;s:45:\"field.field.paragraph.ept_cta.field_ept_title\";i:6;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LbUDjHCE5jPK-SF4gEbg6BwzdKjd1y4Wm5lHH77LQHE\";}s:2:\"id\";s:25:\"paragraph.ept_cta.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:26:\"field_ept_cta_column_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_cta_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_cta_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_hero.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2727e08a-658f-4ab5-b47b-287082974eca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";i:1;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";i:2;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";i:3;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";i:4;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";i:5;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";i:6;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";i:7;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RyJFBZtpPZyel78RpfsF1AiH8hwBQOOxLrAmCsQUA3E\";}s:2:\"id\";s:26:\"paragraph.ept_hero.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:27:\"field_ept_hero_column_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_hero_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:26:\"field_ept_hero_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_hero_title_prefix\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a5054ddd-1cf1-49bf-bb8f-790f40e08130\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_image\";i:1;s:55:\"field.field.paragraph.ept_image.field_ept_image_caption\";i:2;s:52:\"field.field.paragraph.ept_image.field_ept_image_link\";i:3;s:50:\"field.field.paragraph.ept_image.field_ept_settings\";i:4;s:46:\"field.field.paragraph.ept_image.field_ept_text\";i:5;s:47:\"field.field.paragraph.ept_image.field_ept_title\";i:6;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DTOYjl8a1qPkDZ2tUSk7QmiHQ0xgbKAbv7qw0jY4LTE\";}s:2:\"id\";s:27:\"paragraph.ept_image.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:15:\"field_ept_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:23:\"field_ept_image_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_image_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_image_gallery.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"49052cac-09f9-471f-8cc0-d9c144baf2ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_image_gallery.field_ept_image_gallery\";i:1;s:58:\"field.field.paragraph.ept_image_gallery.field_ept_settings\";i:2;s:54:\"field.field.paragraph.ept_image_gallery.field_ept_text\";i:3;s:55:\"field.field.paragraph.ept_image_gallery.field_ept_title\";i:4;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"baNfcT8hwfXqGdk9GFr_Uo5DAZw65OmnpJIPGu7rwLU\";}s:2:\"id\";s:35:\"paragraph.ept_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_image_gallery\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:17:\"ept_image_gallery\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_micromodal.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2b90284a-5b66-4a1f-8feb-f7da7fba402f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_micromodal.field_ept_micromodal_title\";i:1;s:55:\"field.field.paragraph.ept_micromodal.field_ept_settings\";i:2;s:51:\"field.field.paragraph.ept_micromodal.field_ept_text\";i:3;s:52:\"field.field.paragraph.ept_micromodal.field_ept_title\";i:4;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3RH7OegTiWFWXapSfExaq4iTqsXp0J-FoDgKn3BLvug\";}s:2:\"id\";s:32:\"paragraph.ept_micromodal.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_micromodal_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_quote.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"772993d5-eed2-4b18-a6f6-28eb39e116b4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:54:\"field.field.paragraph.ept_quote.field_ept_quote_author\";i:1;s:53:\"field.field.paragraph.ept_quote.field_ept_quote_image\";i:2;s:50:\"field.field.paragraph.ept_quote.field_ept_settings\";i:3;s:46:\"field.field.paragraph.ept_quote.field_ept_text\";i:4;s:47:\"field.field.paragraph.ept_quote.field_ept_title\";i:5;s:27:\"image.style.ept_quote_image\";i:6;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ng1DAFgz9gNcE0pRgTjrcZTjwRmCqpVhuWZM-gi-D3o\";}s:2:\"id\";s:27:\"paragraph.ept_quote.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:22:\"field_ept_quote_author\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_quote_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:15:\"ept_quote_image\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slick_slider.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"febc7649-4ada-4466-aea7-1872bc394145\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_slick_slider.field_ept_settings\";i:1;s:61:\"field.field.paragraph.ept_slick_slider.field_ept_slick_slider\";i:2;s:53:\"field.field.paragraph.ept_slick_slider.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_slick_slider.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"D6f-Fc2NAzWU9GdDBRkUKUZ-OufpE3B1nGAAJQhgO04\";}s:2:\"id\";s:34:\"paragraph.ept_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ept_slick_slider\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slick_slider_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e906e660-3e2c-436c-9fb5-1dc3aaa2d1a9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:72:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";i:1;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";i:2;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";i:3;s:33:\"image.style.ept_slick_slider_card\";i:4;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Yb25ejThf9Zw1K_1U4jgPEu6CXiu0AbCJlD9g9Lcjm0\";}s:2:\"id\";s:39:\"paragraph.ept_slick_slider_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ept_slick_slider_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:21:\"ept_slick_slider_card\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_slick_slider_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_slick_slider_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slideshow.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"113fc4a1-1a78-4da6-b222-3a4cd08a0def\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:54:\"field.field.paragraph.ept_slideshow.field_ept_settings\";i:1;s:55:\"field.field.paragraph.ept_slideshow.field_ept_slideshow\";i:2;s:50:\"field.field.paragraph.ept_slideshow.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_slideshow.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KtOxRXjaqWh0JTHfCOLP6aQSiruy6TgLL8zYom1n_L4\";}s:2:\"id\";s:31:\"paragraph.ept_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_slideshow\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slideshow_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c452f408-f85b-4944-a31e-1bbef7fcda71\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link\";i:1;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide\";i:2;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text\";i:3;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title\";i:4;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zuevQDEEiEAdPhigrWbhLZc3nvEGuKwsXeWbIT6VtyM\";}s:2:\"id\";s:36:\"paragraph.ept_slideshow_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_slideshow_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_slideshow_slide\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_slideshow_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_slideshow_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_stats.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"ec282fce-d81d-4383-9a77-3fb87be08553\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_stats.field_ept_settings\";i:1;s:47:\"field.field.paragraph.ept_stats.field_ept_stats\";i:2;s:46:\"field.field.paragraph.ept_stats.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_stats.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-R8qIR4yTFENexKPFy8GHPre8URllz01mM6cb0sIz_0\";}s:2:\"id\";s:27:\"paragraph.ept_stats.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_stats\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_stats_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8e1a5df7-4ec6-40ba-b5be-4d5d2b6f489f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_image\";i:1;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_link\";i:2;s:64:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_number\";i:3;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vJgoosAvhgFcK-LHabcOoXx3QTmG9TF7iqpHAxeUkkc\";}s:2:\"id\";s:32:\"paragraph.ept_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_stats_item_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_stats_item_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_stats_item_number\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_stats_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tabs.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"7da9a817-79f8-4bec-add7-e39bb0ba78c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:49:\"field.field.paragraph.ept_tabs.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_tabs.field_ept_tabs\";i:2;s:45:\"field.field.paragraph.ept_tabs.field_ept_text\";i:3;s:46:\"field.field.paragraph.ept_tabs.field_ept_title\";i:4;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VYYeF4flc_QYohV2FJfKsdYisMArL-b2-hY7et7ry_M\";}s:2:\"id\";s:26:\"paragraph.ept_tabs.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_tabs\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tabs_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"b90a3de2-2933-49e5-8726-03f0e73085fa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_block\";i:1;s:57:\"field.field.paragraph.ept_tabs_item.field_ept_tab_content\";i:2;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_page\";i:3;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_text\";i:4;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_title\";i:5;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_views\";i:6;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vm2AN2TrjyhMIpH3DLfldicz1qb1mSF0ykCyMxw9bmE\";}s:2:\"id\";s:31:\"paragraph.ept_tabs_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:19:\"field_ept_tab_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_tab_page\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_tab_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_tab_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_tab_views\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:21:\"field_ept_tab_content\";b:1;}}'),('','core.entity_view_display.paragraph.ept_text.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e06c8535-7973-44b5-8144-18baa167f488\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:49:\"field.field.paragraph.ept_text.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_text.field_ept_text\";i:2;s:46:\"field.field.paragraph.ept_text.field_ept_title\";i:3;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzCv1OpNW04_O7sRxZPIlh1_rvwxOvMIGOWK43XgmKg\";}s:2:\"id\";s:26:\"paragraph.ept_text.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tiles.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"153a53c8-5121-4586-9a2d-42dbb61c9965\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_tiles.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_tiles.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_tiles.field_ept_tiles\";i:3;s:47:\"field.field.paragraph.ept_tiles.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VFAqZYQk4Jf5mJN7H6sw-zAemRX1LtPDXAfRw5U6hjM\";}s:2:\"id\";s:27:\"paragraph.ept_tiles.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_tiles\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tiles_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"1e04e293-6847-44fd-816b-d0cafeb9bfb1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ept_tiles_item.field_ept_clickable_tile\";i:1;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_image\";i:2;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_link\";i:3;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_text\";i:4;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sd_Fv-1q9ZOgwmZ0ePkn9oBIqVaWhe4K8YL6VyUVSfE\";}s:2:\"id\";s:32:\"paragraph.ept_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ept_clickable_tile\";a:6:{s:4:\"type\";s:7:\"boolean\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:6:\"format\";s:7:\"default\";s:19:\"format_custom_false\";s:0:\"\";s:18:\"format_custom_true\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_tiles_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_tiles_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_tiles_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_tiles_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"4c097cad-2585-405b-86e6-5effe6d6f443\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_video.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_video.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_video.field_ept_title\";i:3;s:47:\"field.field.paragraph.ept_video.field_ept_video\";i:4;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XvS78XJNKdR81VHVUzs1PUhNwNWlMocd77YwIDcgRH0\";}s:2:\"id\";s:27:\"paragraph.ept_video.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_video\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:9:\"ept_video\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video_and_image_gallery.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"dfadbabc-626b-46a2-a063-3f65ad0c2b45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_settings\";i:1;s:64:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_text\";i:2;s:65:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_title\";i:3;s:77:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";i:4;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5dsKiTuP8c7klYOHnY_OBorbQ_YaHWXu4P_cKhDDKZE\";}s:2:\"id\";s:45:\"paragraph.ept_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_videos_and_images\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video_and_image_gallery_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"273d4d81-bc41-43e6-bbfd-346c986e0c86\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";i:1;s:82:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PB75oeGkZ1ajIp-S4ceLC_lub5_nmn_WU0f_7wBeOag\";}s:2:\"id\";s:50:\"paragraph.ept_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:22:\"field_ept_gallery_item\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_gallery_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_views.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d0875a9d-cb50-4731-ac2a-fb25c1858dae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_views.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_views.field_ept_title\";i:3;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";i:4;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HwJ8zDH-LTdrQbXrPD8P-vvx1n91p-8JocGN840XNUw\";}s:2:\"id\";s:27:\"paragraph.ept_views.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_views_view\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_webform.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"3c020353-d472-46d4-83e7-cc933ac7aa20\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:52:\"field.field.paragraph.ept_webform.field_ept_settings\";i:1;s:48:\"field.field.paragraph.ept_webform.field_ept_text\";i:2;s:49:\"field.field.paragraph.ept_webform.field_ept_title\";i:3;s:56:\"field.field.paragraph.ept_webform.field_ept_webform_form\";i:4;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qKreyfEKRanXLODEvzCYx-MTnJJqvunQWhAesISW900\";}s:2:\"id\";s:29:\"paragraph.ept_webform.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:22:\"field_ept_webform_form\";a:6:{s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:13:\"source_entity\";b:1;s:4:\"lazy\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_webform_popup.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2c82ecbc-46e1-498d-9678-2831bf2e17b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:58:\"field.field.paragraph.ept_webform_popup.field_ept_settings\";i:1;s:54:\"field.field.paragraph.ept_webform_popup.field_ept_text\";i:2;s:55:\"field.field.paragraph.ept_webform_popup.field_ept_title\";i:3;s:68:\"field.field.paragraph.ept_webform_popup.field_ept_webform_popup_form\";i:4;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"efbmchjdWgSaw7vpwBbIHKqkWA24YS9DUj9b-5P2jgY\";}s:2:\"id\";s:35:\"paragraph.ept_webform_popup.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:28:\"field_ept_webform_popup_form\";a:6:{s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:2:{s:13:\"source_entity\";b:1;s:4:\"lazy\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.user.user.compact',_binary 'a:11:{s:4:\"uuid\";s:36:\"fd378f17-2b7e-4025-89fa-c56cabc7bab2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:34:\"core.entity_view_mode.user.compact\";i:1;s:34:\"field.field.user.user.user_picture\";i:2;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"00zr_RBdTjPjBGITD3h4c1ESQZimjdVCcHGt1trLqIY\";}s:2:\"id\";s:17:\"user.user.compact\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"compact\";s:7:\"content\";a:1:{s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:10:\"member_for\";b:1;}}'),('','core.entity_view_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"afa0542b-6646-4a58-8063-b778fe6b3423\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mZLyuWM9CQx2ZJVqFGSbzgFnHzudVbHBYmdU256A5Wk\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:10:\"member_for\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_mode.block_content.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"3e515c12-bfb7-4a38-9360-e1bebd522e14\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q7yUUYeRLByl-MCGveKKF_KhAtNICLCMJuKWfugCvso\";}s:2:\"id\";s:18:\"block_content.full\";s:5:\"label\";s:4:\"Full\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.comment.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"aaef918d-7b8e-4ea0-822a-44703c28e61c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N4mUjXpPckUkVRY1PbKw4GGoL1i2ECU7PL3EreiKStk\";}s:2:\"id\";s:12:\"comment.full\";s:5:\"label\";s:12:\"Full comment\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:7:\"comment\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_image_gallery',_binary 'a:10:{s:4:\"uuid\";s:36:\"c2742453-7e21-4da9-b647-07ef5aca9cf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hrWZ2by9y8V27Hv_3EBEgSBPp_2-kB9fizZj-DLVRcQ\";}s:2:\"id\";s:23:\"media.ept_image_gallery\";s:5:\"label\";s:17:\"EPT Image Gallery\";s:11:\"description\";N;s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_video',_binary 'a:10:{s:4:\"uuid\";s:36:\"8ae8b19f-547b-42bd-9d8f-a88c05759d47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0wiLx1gaRcymNOKRYsVEppFtOWUHrgVQsi6qUlIr_TM\";}s:2:\"id\";s:15:\"media.ept_video\";s:5:\"label\";s:9:\"EPT Video\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_video_and_image_gallery_item',_binary 'a:10:{s:4:\"uuid\";s:36:\"56447995-bbf0-4a46-b361-7337f6962da6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QIGappKnnavEIRi1GzZ_dSeZaYoyiLSX-hOaXrOHbz8\";}s:2:\"id\";s:38:\"media.ept_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EPT Video and Image gallery item\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"976815c3-f2f0-4a48-82b3-fb4ee2924c88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dTfAUHooYV0uOVPO3saGpgv-c5PppJXDwxvwRTJOycM\";}s:2:\"id\";s:10:\"media.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.media_library',_binary 'a:10:{s:4:\"uuid\";s:36:\"4578cd26-ab79-41fc-b999-3224d7b96b78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"3096aebe-dabe-4849-b718-4be67ed1e0a2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QJ2aZ1xfVf59aq6Pz5X7fyUOa2HxuCoTwQ_RQjoulAU\";}s:2:\"id\";s:9:\"node.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.rss',_binary 'a:10:{s:4:\"uuid\";s:36:\"562fdf9e-431f-4436-87cc-5edcb21506bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l8fiAFE3Kng_6bhLlUDnVTkTDzXWxzYFrCWTrngVXEA\";}s:2:\"id\";s:8:\"node.rss\";s:5:\"label\";s:3:\"RSS\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_index',_binary 'a:10:{s:4:\"uuid\";s:36:\"edab19fa-a328-4f2e-a4a2-bce49808300d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_A0T3aTqGDwLyvoH7wLps-0PM--RHlS8UsiJe_Ac64\";}s:2:\"id\";s:17:\"node.search_index\";s:5:\"label\";s:12:\"Search index\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_result',_binary 'a:10:{s:4:\"uuid\";s:36:\"ac6b99d6-0ed0-46ea-97e8-2b17a00adab0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d8wBEm7XvJ6H3S0IneDD9PfTBklPIH7GMpxElVemPf8\";}s:2:\"id\";s:18:\"node.search_result\";s:5:\"label\";s:32:\"Search result highlighting input\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.teaser',_binary 'a:10:{s:4:\"uuid\";s:36:\"5eb23a5d-001b-4f18-b772-c45ec412d4a1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KgGJDZFpMaz_8bTv6fN1bXS3Qi5LWmRJI9R53kEGsNQ\";}s:2:\"id\";s:11:\"node.teaser\";s:5:\"label\";s:6:\"Teaser\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.paragraph.preview',_binary 'a:10:{s:4:\"uuid\";s:36:\"298a8e9e-ea9f-462a-9e62-03ff202ebda4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"h3BeHVei4Lnyqbkao3YiF4KqoY-DhRvUNfEgKG8Rgjg\";}s:2:\"id\";s:17:\"paragraph.preview\";s:5:\"label\";s:7:\"Preview\";s:11:\"description\";N;s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.paragraph.slider',_binary 'a:9:{s:4:\"uuid\";s:36:\"f0967983-7199-4bf7-8047-72fb6a840ca0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:2:\"id\";s:16:\"paragraph.slider\";s:5:\"label\";s:6:\"slider\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.taxonomy_term.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"c1d7c975-f7cc-4e65-a0b5-d7a0b84e6fed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iukUENpf8CFvjZbGGacKX_Ges0-lU9z6zvsd32P6kbo\";}s:2:\"id\";s:18:\"taxonomy_term.full\";s:5:\"label\";s:18:\"Taxonomy term page\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.compact',_binary 'a:10:{s:4:\"uuid\";s:36:\"3267d362-0cde-4190-8a4e-f368fdab39d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TtD7OuGskOsQfoGyxXkrdtllBpR37J19d5BMQDZWJgA\";}s:2:\"id\";s:12:\"user.compact\";s:5:\"label\";s:7:\"Compact\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"18890f85-c8b4-4c37-a805-81e116c96c33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZbXunWS_xAvMZXFfinyvClDAb_RCVLt7gAzE3v16E-Q\";}s:2:\"id\";s:9:\"user.full\";s:5:\"label\";s:12:\"User account\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.extension',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GIX5Esnc_umpXUBj4IIocRX7Mt5fPhm4AgXfE3E56E\";}s:6:\"module\";a:111:{s:13:\"admin_toolbar\";i:0;s:19:\"admin_toolbar_tools\";i:0;s:18:\"announcements_feed\";i:0;s:14:\"automated_cron\";i:0;s:22:\"better_exposed_filters\";i:0;s:8:\"big_pipe\";i:0;s:5:\"block\";i:0;s:13:\"block_content\";i:0;s:11:\"block_field\";i:0;s:10:\"breakpoint\";i:0;s:9:\"ckeditor5\";i:0;s:21:\"ckeditor5_plugin_pack\";i:0;s:32:\"ckeditor5_plugin_pack_auto_image\";i:0;s:38:\"ckeditor5_plugin_pack_find_and_replace\";i:0;s:26:\"ckeditor5_plugin_pack_font\";i:0;s:31:\"ckeditor5_plugin_pack_highlight\";i:0;s:34:\"ckeditor5_plugin_pack_indent_block\";i:0;s:37:\"ckeditor5_plugin_pack_link_attributes\";i:0;s:32:\"ckeditor5_plugin_pack_page_break\";i:0;s:32:\"ckeditor5_plugin_pack_select_all\";i:0;s:31:\"ckeditor5_plugin_pack_templates\";i:0;s:41:\"ckeditor5_plugin_pack_text_transformation\";i:0;s:40:\"ckeditor5_plugin_pack_todo_document_list\";i:0;s:37:\"ckeditor5_premium_features_fullscreen\";i:0;s:7:\"comment\";i:0;s:6:\"config\";i:0;s:7:\"contact\";i:0;s:10:\"contextual\";i:0;s:8:\"datetime\";i:0;s:5:\"dblog\";i:0;s:18:\"dynamic_page_cache\";i:0;s:6:\"editor\";i:0;s:26:\"entity_reference_revisions\";i:0;s:13:\"ept_accordion\";i:0;s:16:\"ept_basic_button\";i:0;s:9:\"ept_block\";i:0;s:20:\"ept_bootstrap_button\";i:0;s:12:\"ept_carousel\";i:0;s:11:\"ept_columns\";i:0;s:8:\"ept_core\";i:0;s:19:\"ept_core_starterkit\";i:0;s:13:\"ept_countdown\";i:0;s:11:\"ept_counter\";i:0;s:7:\"ept_cta\";i:0;s:8:\"ept_hero\";i:0;s:9:\"ept_image\";i:0;s:17:\"ept_image_gallery\";i:0;s:14:\"ept_micromodal\";i:0;s:9:\"ept_quote\";i:0;s:16:\"ept_slick_slider\";i:0;s:13:\"ept_slideshow\";i:0;s:9:\"ept_stats\";i:0;s:8:\"ept_tabs\";i:0;s:8:\"ept_text\";i:0;s:9:\"ept_tiles\";i:0;s:9:\"ept_video\";i:0;s:27:\"ept_video_and_image_gallery\";i:0;s:9:\"ept_views\";i:0;s:11:\"ept_webform\";i:0;s:17:\"ept_webform_popup\";i:0;s:5:\"field\";i:0;s:11:\"field_group\";i:0;s:8:\"field_ui\";i:0;s:4:\"file\";i:0;s:8:\"file_mdm\";i:0;s:13:\"file_mdm_exif\";i:0;s:13:\"file_mdm_font\";i:0;s:6:\"filter\";i:0;s:11:\"gin_toolbar\";i:0;s:9:\"glightbox\";i:0;s:21:\"glightbox_media_video\";i:0;s:4:\"help\";i:0;s:7:\"history\";i:0;s:5:\"image\";i:0;s:13:\"image_effects\";i:0;s:9:\"jquery_ui\";i:0;s:19:\"jquery_ui_accordion\";i:0;s:14:\"jquery_ui_tabs\";i:0;s:16:\"layout_discovery\";i:0;s:17:\"layout_paragraphs\";i:0;s:4:\"link\";i:0;s:15:\"link_attributes\";i:0;s:33:\"link_attributes_menu_link_content\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:18:\"media_library_edit\";i:0;s:26:\"media_library_form_element\";i:0;s:17:\"menu_link_content\";i:0;s:7:\"menu_ui\";i:0;s:4:\"node\";i:0;s:7:\"options\";i:0;s:10:\"page_cache\";i:0;s:4:\"path\";i:0;s:10:\"path_alias\";i:0;s:6:\"search\";i:0;s:8:\"shortcut\";i:0;s:6:\"system\";i:0;s:8:\"taxonomy\";i:0;s:11:\"tb_megamenu\";i:0;s:4:\"text\";i:0;s:7:\"toolbar\";i:0;s:10:\"twig_tweak\";i:0;s:6:\"update\";i:0;s:4:\"user\";i:0;s:8:\"views_ui\";i:0;s:17:\"views_year_filter\";i:0;s:14:\"viewsreference\";i:0;s:7:\"webform\";i:0;s:5:\"views\";i:10;s:10:\"paragraphs\";i:11;s:4:\"fast\";i:1000;}s:5:\"theme\";a:5:{s:7:\"olivero\";i:0;s:5:\"claro\";i:0;s:3:\"gin\";i:0;s:7:\"stable9\";i:0;s:9:\"ept_light\";i:0;}s:7:\"profile\";s:4:\"fast\";}'),('','core.menu.static_menu_link_overrides',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CXhei_vpaZk-3f_Mj2cH0YmpK-ZpKHoSzVA3yZrDq0g\";}s:11:\"definitions\";a:4:{s:18:\"contact__site_page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:6:\"footer\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-50;}s:20:\"standard__front_page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-50;}s:10:\"user__page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:7:\"account\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-10;}s:12:\"user__logout\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:7:\"account\";s:6:\"parent\";s:0:\"\";s:6:\"weight\";i:10;s:8:\"expanded\";b:0;}}}'),('','dblog.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e883aGsrt1wFrsydlYU584PZONCSfRy0DtkZ9KzHb58\";}s:9:\"row_limit\";i:1000;}'),('','editor.editor.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"de26b70d-0b5e-4129-a929-f1de8a455f1b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qi2tIe-L97EutlMmhEvhsNxZOpOoA-RH82c4BQb5n4A\";}s:6:\"format\";s:10:\"basic_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:15:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:1:\"|\";i:3;s:4:\"link\";i:4;s:1:\"|\";i:5;s:12:\"bulletedList\";i:6;s:12:\"numberedList\";i:7;s:1:\"|\";i:8;s:10:\"blockQuote\";i:9;s:17:\"drupalInsertImage\";i:10;s:1:\"|\";i:11;s:7:\"heading\";i:12;s:4:\"code\";i:13;s:1:\"|\";i:14;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:4:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:0;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:13:{i:0;s:6:\"<cite>\";i:1;s:4:\"<dl>\";i:2;s:4:\"<dt>\";i:3;s:4:\"<dd>\";i:4;s:12:\"<a hreflang>\";i:5;s:17:\"<blockquote cite>\";i:6;s:9:\"<ul type>\";i:7;s:9:\"<ol type>\";i:8;s:7:\"<h2 id>\";i:9;s:7:\"<h3 id>\";i:10;s:7:\"<h4 id>\";i:11;s:7:\"<h5 id>\";i:12;s:7:\"<h6 id>\";}}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','editor.editor.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"5b65cbab-6e9a-450e-a54e-4c334c4ca75d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"filter.format.full_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lurcn8yf33g3Dkzdc55cTfJa9salGp9ytSYyG1s7QMI\";}s:6:\"format\";s:9:\"full_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:44:{i:0;s:4:\"undo\";i:1;s:4:\"redo\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:13:\"strikethrough\";i:5;s:9:\"underline\";i:6;s:11:\"superscript\";i:7;s:9:\"subscript\";i:8;s:12:\"removeFormat\";i:9;s:1:\"|\";i:10;s:4:\"link\";i:11;s:1:\"|\";i:12;s:5:\"style\";i:13;s:9:\"fontColor\";i:14;s:19:\"fontBackgroundColor\";i:15;s:9:\"highlight\";i:16;s:10:\"fontFamily\";i:17;s:8:\"fontSize\";i:18;s:1:\"-\";i:19;s:12:\"bulletedList\";i:20;s:12:\"numberedList\";i:21;s:6:\"indent\";i:22;s:7:\"outdent\";i:23;s:9:\"alignment\";i:24;s:1:\"|\";i:25;s:14:\"insertTemplate\";i:26;s:4:\"code\";i:27;s:10:\"blockQuote\";i:28;s:17:\"drupalInsertImage\";i:29;s:11:\"drupalMedia\";i:30;s:11:\"insertTable\";i:31;s:14:\"horizontalLine\";i:32;s:1:\"|\";i:33;s:7:\"heading\";i:34;s:14:\"findAndReplace\";i:35;s:1:\"-\";i:36;s:10:\"showBlocks\";i:37;s:17:\"specialCharacters\";i:38;s:9:\"codeBlock\";i:39;s:13:\"sourceEditing\";i:40;s:1:\"|\";i:41;s:9:\"pageBreak\";i:42;s:9:\"selectAll\";i:43;s:10:\"fullScreen\";}}s:7:\"plugins\";a:17:{s:19:\"ckeditor5_alignment\";a:1:{s:18:\"enabled_alignments\";a:4:{i:0;s:6:\"center\";i:1;s:7:\"justify\";i:2;s:4:\"left\";i:3;s:5:\"right\";}}s:19:\"ckeditor5_codeBlock\";a:1:{s:9:\"languages\";a:14:{i:0;a:2:{s:5:\"label\";s:10:\"Plain text\";s:8:\"language\";s:9:\"plaintext\";}i:1;a:2:{s:5:\"label\";s:1:\"C\";s:8:\"language\";s:1:\"c\";}i:2;a:2:{s:5:\"label\";s:2:\"C#\";s:8:\"language\";s:2:\"cs\";}i:3;a:2:{s:5:\"label\";s:3:\"C++\";s:8:\"language\";s:3:\"cpp\";}i:4;a:2:{s:5:\"label\";s:3:\"CSS\";s:8:\"language\";s:3:\"css\";}i:5;a:2:{s:5:\"label\";s:4:\"Diff\";s:8:\"language\";s:4:\"diff\";}i:6;a:2:{s:5:\"label\";s:4:\"HTML\";s:8:\"language\";s:4:\"html\";}i:7;a:2:{s:5:\"label\";s:4:\"Java\";s:8:\"language\";s:4:\"java\";}i:8;a:2:{s:5:\"label\";s:10:\"JavaScript\";s:8:\"language\";s:10:\"javascript\";}i:9;a:2:{s:5:\"label\";s:3:\"PHP\";s:8:\"language\";s:3:\"php\";}i:10;a:2:{s:5:\"label\";s:6:\"Python\";s:8:\"language\";s:6:\"python\";}i:11;a:2:{s:5:\"label\";s:4:\"Ruby\";s:8:\"language\";s:4:\"ruby\";}i:12;a:2:{s:5:\"label\";s:10:\"TypeScript\";s:8:\"language\";s:10:\"typescript\";}i:13;a:2:{s:5:\"label\";s:3:\"XML\";s:8:\"language\";s:3:\"xml\";}}}s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:6:{i:0;s:8:\"heading1\";i:1;s:8:\"heading2\";i:2;s:8:\"heading3\";i:3;s:8:\"heading4\";i:4;s:8:\"heading5\";i:5;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:44:\"ckeditor5_plugin_pack_auto_image__auto_image\";a:1:{s:7:\"enabled\";b:0;}s:56:\"ckeditor5_plugin_pack_find_and_replace__find_and_replace\";a:1:{s:7:\"ui_type\";s:6:\"dialog\";}s:38:\"ckeditor5_plugin_pack_font__font_color\";a:2:{s:6:\"colors\";a:0:{}s:18:\"use_default_colors\";b:1;}s:39:\"ckeditor5_plugin_pack_font__font_family\";a:1:{s:7:\"options\";s:0:\"\";}s:37:\"ckeditor5_plugin_pack_font__font_size\";a:1:{s:7:\"options\";s:0:\"\";}s:42:\"ckeditor5_plugin_pack_highlight__highlight\";a:2:{s:7:\"options\";a:0:{}s:19:\"use_default_markers\";b:1;}s:48:\"ckeditor5_plugin_pack_indent_block__indent_block\";a:1:{s:7:\"enabled\";b:1;}s:54:\"ckeditor5_plugin_pack_link_attributes__link_attributes\";a:1:{s:10:\"attributes\";a:1:{i:0;a:2:{s:5:\"label\";s:15:\"Link Attributes\";s:10:\"attributes\";s:27:\"target|_blank\r\nrel|nofollow\";}}}s:62:\"ckeditor5_plugin_pack_text_transformation__text_transformation\";a:4:{s:7:\"enabled\";b:1;s:21:\"extra_transformations\";s:0:\"\";s:27:\"extra_regex_transformations\";a:0:{}s:6:\"groups\";a:5:{s:10:\"typography\";a:2:{s:15:\"transformations\";a:3:{s:8:\"ellipsis\";a:1:{s:7:\"enabled\";i:1;}s:6:\"enDash\";a:1:{s:7:\"enabled\";i:1;}s:6:\"emDash\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:6:\"quotes\";a:2:{s:15:\"transformations\";a:2:{s:13:\"quotesPrimary\";a:1:{s:7:\"enabled\";i:1;}s:15:\"quotesSecondary\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:7:\"symbols\";a:2:{s:15:\"transformations\";a:3:{s:9:\"trademark\";a:1:{s:7:\"enabled\";i:1;}s:19:\"registeredTrademark\";a:1:{s:7:\"enabled\";i:1;}s:9:\"copyright\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:12:\"mathematical\";a:2:{s:15:\"transformations\";a:10:{s:7:\"oneHalf\";a:1:{s:7:\"enabled\";i:1;}s:8:\"oneThird\";a:1:{s:7:\"enabled\";i:1;}s:9:\"twoThirds\";a:1:{s:7:\"enabled\";i:1;}s:9:\"oneFourth\";a:1:{s:7:\"enabled\";i:1;}s:13:\"threeQuarters\";a:1:{s:7:\"enabled\";i:1;}s:15:\"lessThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:18:\"greaterThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:8:\"notEqual\";a:1:{s:7:\"enabled\";i:1;}s:9:\"arrowLeft\";a:1:{s:7:\"enabled\";i:1;}s:10:\"arrowRight\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:4:\"misc\";a:2:{s:15:\"transformations\";a:4:{s:17:\"quotesPrimaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:19:\"quotesSecondaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:15:\"quotesPrimaryPl\";a:1:{s:7:\"enabled\";i:0;}s:17:\"quotesSecondaryPl\";a:1:{s:7:\"enabled\";i:0;}}s:7:\"enabled\";i:0;}}}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}s:15:\"ckeditor5_style\";a:1:{s:6:\"styles\";a:2:{i:0;a:2:{s:5:\"label\";s:12:\"Title prefix\";s:7:\"element\";s:27:\"<span class=\"title-prefix\">\";}i:1;a:2:{s:5:\"label\";s:10:\"White text\";s:7:\"element\";s:25:\"<span class=\"white-text\">\";}}}s:11:\"media_media\";a:1:{s:24:\"allow_view_mode_override\";b:0;}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','editor.editor.webform_default',_binary 'a:8:{s:4:\"uuid\";s:36:\"a5122dd4-68d5-4282-a77b-0ad04cf12b8a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:6:\"format\";s:15:\"webform_default\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:20:{i:0;s:7:\"heading\";i:1;s:1:\"|\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:9:\"subscript\";i:5;s:11:\"superscript\";i:6;s:1:\"|\";i:7;s:17:\"specialCharacters\";i:8;s:1:\"|\";i:9;s:12:\"numberedList\";i:10;s:12:\"bulletedList\";i:11;s:1:\"|\";i:12;s:4:\"link\";i:13;s:1:\"|\";i:14;s:6:\"indent\";i:15;s:7:\"outdent\";i:16;s:1:\"|\";i:17;s:10:\"blockQuote\";i:18;s:1:\"|\";i:19;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:3:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}}}s:12:\"image_upload\";a:1:{s:6:\"status\";b:0;}}'),('','ept_core.settings',_binary 'a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYlqpNn_5W04WVeLB4bYW404IYbkVrx7N9zxzBAJ-Io\";}s:26:\"ept_core_mobile_breakpoint\";s:3:\"640\";s:26:\"ept_core_tablet_breakpoint\";s:4:\"1020\";s:27:\"ept_core_desktop_breakpoint\";s:4:\"1320\";s:22:\"ept_core_xxsmall_width\";s:3:\"480\";s:21:\"ept_core_xsmall_width\";s:3:\"640\";s:20:\"ept_core_small_width\";s:3:\"768\";s:22:\"ept_core_default_width\";s:3:\"960\";s:20:\"ept_core_large_width\";s:4:\"1100\";s:21:\"ept_core_xlarge_width\";s:4:\"1320\";s:22:\"ept_core_xxlarge_width\";s:4:\"1600\";s:25:\"ept_core_background_color\";s:7:\"#0d77b5\";}'),('','field.field.block_content.basic.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"8fecb003-ae49-44e1-ac0e-aeaebabeca06\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j00Gfs9AFqwK4x9RIsISLbPO7vA12psPR4s60wOIwQo\";}s:2:\"id\";s:24:\"block_content.basic.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.comment.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"2ea8eb6b-de2b-4de9-ac7c-5703ce8bc44f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:34:\"field.storage.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"62rlTOx3sPVrYhBnSBHZStXwiO02v1UpHSMrhWDsuG8\";}s:2:\"id\";s:28:\"comment.comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:5:\"label\";s:7:\"Comment\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.media.audio.field_media_audio_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"cccc3ad2-8bd3-4a0b-8777-2510ebee041b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UlZPIbHcLyNqGY5bvydCTijGcKDmwn4Fo8oYZT85wlk\";}s:2:\"id\";s:34:\"media.audio.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:5:\"label\";s:10:\"Audio file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:11:\"mp3 wav aac\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.media.document.field_media_document',_binary 'a:17:{s:4:\"uuid\";s:36:\"90b23d65-43c8-4f09-8924-c0be432e4510\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:40:\"field.storage.media.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DY5HtJTxUjFRGU_PaY6ifo2nhR-nAZ0y0s6kLmUbv5g\";}s:2:\"id\";s:35:\"media.document.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:96:\"txt rtf doc docx ppt pptx xls xlsx pdf odf odg odp ods odt fodt fods fodp fodg key numbers pages\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.media.image.field_media_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"410f42b6-e143-4eb8-9c88-c13fd9c4c17f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:37:\"field.storage.media.field_media_image\";i:1;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7CkVOgjDXiN26Fm2hniNei-XPK3iuZTlcBGqreTbJ0\";}s:2:\"id\";s:29:\"media.image.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.field.media.remote_video.field_media_oembed_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"4ed02114-671f-4880-bd68-143fe1b70c33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.media.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Eo4HHenV5iZat_kEWgr_wydD3TgwURMCzwt-7qIEyoM\";}s:2:\"id\";s:43:\"media.remote_video.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:5:\"label\";s:9:\"Video URL\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),('','field.field.media.video.field_media_video_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"0b1a6314-b982-4d68-89cc-0362ac441239\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6kMMjmk2r_csGQ52qI9BUaO8r_oAzNLbxlclaj-JlDQ\";}s:2:\"id\";s:34:\"media.video.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:5:\"label\";s:10:\"Video file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:3:\"mp4\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.node.article.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"ac9343a5-d157-4641-93f9-1b5bd7d0980f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Wxs1LseZ8JsNwD9uJVIbzZqG35yQXN8Eo1Hub6NMuI\";}s:2:\"id\";s:17:\"node.article.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.article.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"6c45f2f3-d271-4c13-b678-675fb9cbc261\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"field.storage.node.field_image\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j0riO_-77ZFWNLtj0iJ31HnohiNjdn8HUL86RueCF-M\";}s:2:\"id\";s:24:\"node.article.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.field.node.article.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"d3dcae7f-9494-4866-b051-d4817b208fd5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:29:\"field.storage.node.field_tags\";i:1;s:17:\"node.type.article\";i:2;s:24:\"taxonomy.vocabulary.tags\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QdUgf_beeoaPiyKorFv0q1fcJpWH_uZTqe_xoVJacrw\";}s:2:\"id\";s:23:\"node.article.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Tags\";s:11:\"description\";s:84:\"Enter a comma-separated list. For example: Amsterdam, Mexico City, \"Cleveland, Ohio\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:21:\"default:taxonomy_term\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.node.page.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"c7106e91-0b1d-44f0-82fc-584be35a29c2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KHu9I-pR4FnP79crRJ5gVD_1mKGSZcJsdIm9bn64iFg\";}s:2:\"id\";s:14:\"node.page.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.page.field_components',_binary 'a:16:{s:4:\"uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:27:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";i:25;s:38:\"paragraphs.paragraphs_type.ept_webform\";i:26;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:2:\"id\";s:26:\"node.page.field_components\";s:10:\"field_name\";s:16:\"field_components\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:10:\"Components\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:25:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:37:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:10:\"ept_bottle\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:0;}s:9:\"ept_cards\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:0;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:16:\"ept_super_slider\";a:2:{s:6:\"weight\";i:70;s:7:\"enabled\";b:1;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}s:11:\"ept_webform\";a:2:{s:6:\"weight\";i:73;s:7:\"enabled\";b:1;}s:17:\"ept_webform_popup\";a:2:{s:6:\"weight\";i:74;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_accordion.field_ept_accordion',_binary 'a:17:{s:4:\"uuid\";s:36:\"a6969ae3-e3c4-4adf-b115-07a5a0172b95\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:43:\"field.storage.paragraph.field_ept_accordion\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gyYZiR8Di3nPWs-p1SHNRU9nboJcW5hom8i6mSecVtc\";}s:2:\"id\";s:43:\"paragraph.ept_accordion.field_ept_accordion\";s:10:\"field_name\";s:19:\"field_ept_accordion\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:8:\"Sections\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:21:\"ept_accordion_section\";s:21:\"ept_accordion_section\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:23;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_accordion.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"71eb6510-d311-4704-9d7a-147c6ba1fca0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dFTek-2-VjYGV96ffjrJqRnc7cP8oR-xd4f0hA8JlyA\";}s:2:\"id\";s:42:\"paragraph.ept_accordion.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_accordion.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"38a67ca0-85d7-4dee-8871-eef6909b89f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7ILR55bNJzar89h8OPnJx-IpC8TrZBRKYFxLOI1p73c\";}s:2:\"id\";s:38:\"paragraph.ept_accordion.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"fa75defe-e7d5-4782-bedf-3d3107b3a40f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-fStMIM_IiXT6N43R2XfdUDoqFS_sK8AUA-WvSHfcwo\";}s:2:\"id\";s:39:\"paragraph.ept_accordion.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion_section.field_ept_accordion_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"3f86759a-0926-49a9-a1b3-ebe22666f4d8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_accordion_text\";i:1;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3d4EpzZAObqkHVq5leB4wQ_vhii4h9OoUdsxw0lZgfg\";}s:2:\"id\";s:56:\"paragraph.ept_accordion_section.field_ept_accordion_text\";s:10:\"field_name\";s:24:\"field_ept_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:5:\"label\";s:13:\"Text / Answer\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion_section.field_ept_accordion_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"5fd2a01d-4924-4824-af89-5638dcb01e07\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_accordion_title\";i:1;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1GJAw9hJcCS1kRz9iAwG1qqyJ5XL97F--Irgw6Ns0GY\";}s:2:\"id\";s:57:\"paragraph.ept_accordion_section.field_ept_accordion_title\";s:10:\"field_name\";s:25:\"field_ept_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:5:\"label\";s:16:\"Title / Question\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_basic_button.field_ept_basic_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"d95cc73b-b5b3-45bb-ab62-c70e8411b8e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_basic_button_link\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SCjKiIWEbPAkzMucyajmerVFBDbaKtjD3HukL942flo\";}s:2:\"id\";s:54:\"paragraph.ept_basic_button.field_ept_basic_button_link\";s:10:\"field_name\";s:27:\"field_ept_basic_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:11:\"Button Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_basic_button.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"0369fd76-8a03-4f51-98c8-2662289d77b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JzXRiuHUYaRtlmk8K0WT_Yp1_iUpogPj6XDbLmZ_hVA\";}s:2:\"id\";s:45:\"paragraph.ept_basic_button.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:18:\"Paragraph settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_basic_button.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"484e5ed3-f463-4d7b-b27a-25b553c3a82b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U4JGLZ-4C6DwE5xpnkLU2Ckqm-NdvOTgwe9gAMlW_Ls\";}s:2:\"id\";s:41:\"paragraph.ept_basic_button.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_basic_button.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"d5f47d43-c851-4f4d-a9bf-282937a2eb88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q6Cswt1AxNHLXzTfwWiWRP4dJwyasulFfWasATFZdrU\";}s:2:\"id\";s:42:\"paragraph.ept_basic_button.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_block.field_ept_block_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"9e49c287-a8e3-4673-b781-6db3e163c7f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_block_block\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Y5C1tDwIza9l7G1NAqWPtZndTwsI1uclqq7mOTUqmyg\";}s:2:\"id\";s:41:\"paragraph.ept_block.field_ept_block_block\";s:10:\"field_name\";s:21:\"field_ept_block_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:5:\"Block\";s:11:\"description\";s:25:\"Add existing Drupal Block\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:11:{s:5:\"Block\";s:5:\"Block\";s:4:\"core\";s:4:\"core\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:5:\"Menus\";s:5:\"Menus\";s:6:\"System\";s:6:\"System\";s:4:\"User\";s:4:\"User\";s:5:\"Views\";s:5:\"Views\";s:13:\"Announcements\";s:1:\"0\";s:12:\"TB Mega Menu\";s:1:\"0\";}}}s:10:\"field_type\";s:11:\"block_field\";}'),('','field.field.paragraph.ept_block.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"2d995ad8-7b72-4241-8c5b-bfb64c7a936a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o3fZQjNNObe_TkbgxMWmav7VePiJKizuqf7wQm1RqgQ\";}s:2:\"id\";s:38:\"paragraph.ept_block.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_block.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"440982f1-1d49-45ce-856f-cb3b95954c65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AhoRfTUTx6zdLkKC-tHQ_pZVKgtpGN452BRXc__PSgM\";}s:2:\"id\";s:34:\"paragraph.ept_block.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_block.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b40d62dd-ee5a-44cf-9983-6bbbd7667b68\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LoHBLk0u3sVMSi5c2wsK0PWLWQ1aM4uvkXBsu3odiYk\";}s:2:\"id\";s:35:\"paragraph.ept_block.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"28952958-350e-4fa8-b1bf-0526c52b982e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.storage.paragraph.field_ept_bootstrap_button_link\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-csuiRgrTiYqGIjfvXfzBJvGlaY5drE5fp2a_BZjuo\";}s:2:\"id\";s:62:\"paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ept_bootstrap_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"97adadda-941e-43f5-8c16-c2a84adbb6a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9H_JnoEbVvGC1ew0GhZEnKhJOj78OfksYHFErUsrtVw\";}s:2:\"id\";s:49:\"paragraph.ept_bootstrap_button.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9d80d485-b1e2-4fbf-ad86-60acbbdd3d92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YeaGECTvxFfymsGgUGC0AO8Uap3cVB1SFUvwKCEoP0c\";}s:2:\"id\";s:45:\"paragraph.ept_bootstrap_button.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:14:\"Paragraph Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9626d4b-c719-4c6c-bc96-f92de310cf2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IbyiiWXl-WZPf_JAHHt9YHqt7GAEtb8FBXpeQ3OXG8c\";}s:2:\"id\";s:46:\"paragraph.ept_bootstrap_button.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:15:\"Paragraph Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cards.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"a49781a9-d084-428f-b05d-d1b72c5a9c45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_cards\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SkX5mX8p25AwshKMZm_SxrYzoYPxeFv6dyD6iUJRu34\";}s:2:\"id\";s:38:\"paragraph.ept_cards.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_cards\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_cards.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"8c000a0e-d859-4bdb-9ddc-1c1c48e64c4b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_cards\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fZdJ5UZao73ExrG3Ut3gVIIk4Q8GwHRPSK1esBanvxo\";}s:2:\"id\";s:34:\"paragraph.ept_cards.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_cards\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cards.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"49f52820-ba38-497e-b59f-d89788210ff0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_cards\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hK-8gL2S45XI7zt5CeNNubXJjtgF081aIF64y15B3QU\";}s:2:\"id\";s:35:\"paragraph.ept_cards.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_cards\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel.field_ept_carousel',_binary 'a:17:{s:4:\"uuid\";s:36:\"d7d805e1-ee4a-4aeb-87d9-e74edbe4f1e7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ept_carousel\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aXX70EioyFtKtGWUZXGbeNLyjZK-M_6xbjrznbKBxsQ\";}s:2:\"id\";s:41:\"paragraph.ept_carousel.field_ept_carousel\";s:10:\"field_name\";s:18:\"field_ept_carousel\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:8:\"Carousel\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:17:\"ept_carousel_item\";s:17:\"ept_carousel_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:31;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_carousel.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9905b685-324b-4f6a-8423-5973b3364a40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_IVLsSToXRuYcAqksQE6q0UQCw5J0ys7z54fIX3Prcg\";}s:2:\"id\";s:41:\"paragraph.ept_carousel.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_carousel.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"e61c2ef3-bfa8-4a34-aa69-9a530904c063\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T9eYBrQXk7NZSU8LgCIvtf9ldAkjSDaUsIlMZK1m5ks\";}s:2:\"id\";s:37:\"paragraph.ept_carousel.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0f3cce54-16b4-433a-a3d8-f66dceadfb5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NN8UIWMU2GbeEUny8ga4lRNGGKi0sRnscgZKNOBUJbU\";}s:2:\"id\";s:38:\"paragraph.ept_carousel.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel_item.field_ept_carousel_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"f1e8eab0-49cf-40c1-a0c3-1c7c52bbcf18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_carousel_caption\";i:1;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2da0GoNsm_uJyuQNbeEacFu5K_me_-2I4TTM-UpRlLk\";}s:2:\"id\";s:54:\"paragraph.ept_carousel_item.field_ept_carousel_caption\";s:10:\"field_name\";s:26:\"field_ept_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:5:\"label\";s:13:\"Slide caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel_item.field_ept_carousel_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"8a07cecc-6fab-4d81-8cda-096df1dc73ab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:48:\"field.storage.paragraph.field_ept_carousel_image\";i:1;s:16:\"media.type.image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1qmbDr08-JuyqmRroyYKRiBXHMWBHN8Q8K3o4KxjQW0\";}s:2:\"id\";s:52:\"paragraph.ept_carousel_item.field_ept_carousel_image\";s:10:\"field_name\";s:24:\"field_ept_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:5:\"label\";s:11:\"Slide image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_columns.field_ept_columns',_binary 'a:17:{s:4:\"uuid\";s:36:\"e3f4b834-b3d2-43cf-8914-8378ae9e9f82\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:27:{i:0;s:41:\"field.storage.paragraph.field_ept_columns\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:2;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:3;s:36:\"paragraphs.paragraphs_type.ept_block\";i:4;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:5;s:36:\"paragraphs.paragraphs_type.ept_cards\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";i:25;s:38:\"paragraphs.paragraphs_type.ept_webform\";i:26;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R6rkX-mPMiS67Fz1NUwV172q4Get3igbZ_JqWTdWxKU\";}s:2:\"id\";s:39:\"paragraph.ept_columns.field_ept_columns\";s:10:\"field_name\";s:17:\"field_ept_columns\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:7:\"Columns\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:26:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:9:\"ept_cards\";s:9:\"ept_cards\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:37:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:10:\"ept_bottle\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:9:\"ept_cards\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:0;}s:16:\"ept_super_slider\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:65;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:66;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:67;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:68;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:69;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:70;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:71;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:72;s:7:\"enabled\";b:1;}s:11:\"ept_webform\";a:2:{s:6:\"weight\";i:73;s:7:\"enabled\";b:1;}s:17:\"ept_webform_popup\";a:2:{s:6:\"weight\";i:74;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_columns.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"77e74bf9-008e-4d96-9381-dc809ff7b841\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"v6ug86IR2khsDICnCIAdzPfNfLXmkeVFT9UqUTRCd9s\";}s:2:\"id\";s:40:\"paragraph.ept_columns.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_columns.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9935753-c052-4b7b-b23a-a14f2748a834\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E5a_LPXp_bizIM-GzrOKjXX53p0mj01R_Ljy3UhbYmc\";}s:2:\"id\";s:36:\"paragraph.ept_columns.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_columns.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"3988d015-d4a9-4560-9665-3defb0bfead9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LCIv3BxeR6WGu8S2T4pGT69kr4zPkUTHJk0ehJJqVjs\";}s:2:\"id\";s:37:\"paragraph.ept_columns.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_countdown.field_ept_countdown_date',_binary 'a:17:{s:4:\"uuid\";s:36:\"51db6984-7e76-4d6a-be3b-8f052f3bae29\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_countdown_date\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:8:\"datetime\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Tpuj04Fr7uNZO039Nd8J5cv4Ya-znGKtwNYc5cXn1gc\";}s:2:\"id\";s:48:\"paragraph.ept_countdown.field_ept_countdown_date\";s:10:\"field_name\";s:24:\"field_ept_countdown_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:14:\"Countdown date\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:8:\"datetime\";}'),('','field.field.paragraph.ept_countdown.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"991df58b-c253-4036-a94c-16bf928672f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ba5vspWY7pQHKiHMxUWsBgPe13kyadBUwXJG_mtVF04\";}s:2:\"id\";s:42:\"paragraph.ept_countdown.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:12:\"EPT Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_countdown.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"36557cf2-e64e-4835-ad8e-b5bbc8150e8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxnjRfw__e_lRLCA703BFzbVEExF3BkVWaY6sDGBfno\";}s:2:\"id\";s:38:\"paragraph.ept_countdown.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_countdown.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"ae2f7f13-51c7-4ea2-99c7-c5b6b22f7360\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hE1iEpJa-BGC9-RbtJz3GYEuzj1nOmJqKNp7bNq63v8\";}s:2:\"id\";s:39:\"paragraph.ept_countdown.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter.field_ept_counter_items',_binary 'a:17:{s:4:\"uuid\";s:36:\"53805c44-6771-4268-b091-a3f4f1269139\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_items\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:2;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1MfRaU5RDocEjlC7nyIwXtGJAd9zHFyzfmxMz3nhoL8\";}s:2:\"id\";s:45:\"paragraph.ept_counter.field_ept_counter_items\";s:10:\"field_name\";s:23:\"field_ept_counter_items\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:17:\"EPT Counter Items\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_counter.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"153fe814-ed15-45dd-ac36-e3166140cf03\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MNeAeSI8Y2lhDp_9PO88OMzAgUex8QzA7U6mYPsqZh4\";}s:2:\"id\";s:40:\"paragraph.ept_counter.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:12:\"EPT Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_counter.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"b4f633fb-12be-4793-b294-21badb491880\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_WgiVxSXXCkXpPedeKEQqBdTrL2yAV-R5njXnnWvkyQ\";}s:2:\"id\";s:36:\"paragraph.ept_counter.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"44deba9e-6935-4553-9ef0-ecc889381ae8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_A9WA0oPqrE9hJAdrstmGGAwR1IetKm59q9podeyJaI\";}s:2:\"id\";s:37:\"paragraph.ept_counter.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_description',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad867234-0316-48d0-bba3-4dcafd6d6091\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:53:\"field.storage.paragraph.field_ept_counter_description\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4-1RuE5rL9TNgTiA2lw7thDEjBhXTw_XAZuWfN21qY\";}s:2:\"id\";s:56:\"paragraph.ept_counter_item.field_ept_counter_description\";s:10:\"field_name\";s:29:\"field_ept_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:11:\"Description\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_icon',_binary 'a:17:{s:4:\"uuid\";s:36:\"94fe1479-276a-47c8-a255-ba6fdb6b874f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ept_counter_icon\";i:1;s:16:\"media.type.image\";i:2;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T7rXLcACaUML0NMksYsmdVF9_PA7XqFakcAdD0PuMKk\";}s:2:\"id\";s:49:\"paragraph.ept_counter_item.field_ept_counter_icon\";s:10:\"field_name\";s:22:\"field_ept_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:4:\"Icon\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"9857343f-763e-4b29-8143-ec3fb9d9963d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_counter_number\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NLE9w7TbjN5CmAnSSj-gSDT5bGz-IIqdEs-myskjLxo\";}s:2:\"id\";s:51:\"paragraph.ept_counter_item.field_ept_counter_number\";s:10:\"field_name\";s:24:\"field_ept_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:6:\"Number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:4:{s:3:\"min\";i:1;s:3:\"max\";N;s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"field_type\";s:7:\"integer\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"9d669ec1-badd-49d6-82c8-4a8eba8ca7da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1YYXmvZIdinNPPgOBzpsoa5rCIzMayt9KFg5Gp6aGxI\";}s:2:\"id\";s:50:\"paragraph.ept_counter_item.field_ept_counter_title\";s:10:\"field_name\";s:23:\"field_ept_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"40656cb2-323c-4502-b916-5613d935c06a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:50:\"field.storage.paragraph.field_ept_cta_column_image\";i:1;s:16:\"media.type.image\";i:2;s:34:\"paragraphs.paragraphs_type.ept_cta\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M6DPa4NxYRx2y48yZGbZgB9RXiUBCln4aFQ2BSQ1ZRo\";}s:2:\"id\";s:44:\"paragraph.ept_cta.field_ept_cta_column_image\";s:10:\"field_name\";s:26:\"field_ept_cta_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"a4f2e656-d59b-4df7-833b-709b38ab9360\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_cta_link\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"663HkJoryKb6fkU2dIBK7JnS0-v_HHMirdYKZ97PPXI\";}s:2:\"id\";s:36:\"paragraph.ept_cta.field_ept_cta_link\";s:10:\"field_name\";s:18:\"field_ept_cta_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"2eb61b2c-ee83-43b2-beb6-334f5562bc8c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_cta_second_link\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zqb9GkzwNjNvs2k4e9egdt1MT_D0YfyITXC4BVAQS3s\";}s:2:\"id\";s:43:\"paragraph.ept_cta.field_ept_cta_second_link\";s:10:\"field_name\";s:25:\"field_ept_cta_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:11:\"Second Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_cta.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"7a06dca5-73c0-4c47-a217-2f9d7f3b9d43\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdThFhM93LECXPeiHekVQZst4pAyaZauFLBc6ZZ2HJ0\";}s:2:\"id\";s:36:\"paragraph.ept_cta.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:18:\"Paragraph settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_cta.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a054c663-7358-4e24-99c7-7caa63091265\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QN1QM2C6SY_OR_LyAWi1j0iKDvbeAcJCe6s806EaZDo\";}s:2:\"id\";s:32:\"paragraph.ept_cta.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cta.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"e6f7cd85-741e-4d86-ae78-2eabee82b952\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_MAbOMwe1u3jdwZjUjmDHaxwmjIU-JGVZUkIUziPiQ\";}s:2:\"id\";s:33:\"paragraph.ept_cta.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"b46ea217-84f7-4321-912a-7446b534bb92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_column_image\";i:1;s:16:\"media.type.image\";i:2;s:35:\"paragraphs.paragraphs_type.ept_hero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3eydYXoFUtHpVqERbj-NUTxfjmRpY41GlotzDaiMHw\";}s:2:\"id\";s:46:\"paragraph.ept_hero.field_ept_hero_column_image\";s:10:\"field_name\";s:27:\"field_ept_hero_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"5dcc6a7e-0a0a-4b27-8ec1-fc41c3bb654a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_hero_link\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lxzpMFHK8I8nPXViJVyoXQFZitk8kttqyIRXSb9D1O0\";}s:2:\"id\";s:38:\"paragraph.ept_hero.field_ept_hero_link\";s:10:\"field_name\";s:19:\"field_ept_hero_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"93b358ac-f703-4792-a4cb-65cb87eb34aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_hero_second_link\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"69BKIyb4s5Y9A2Ehq5ew6h-2_suAuoW3onibd8wyXpI\";}s:2:\"id\";s:45:\"paragraph.ept_hero.field_ept_hero_second_link\";s:10:\"field_name\";s:26:\"field_ept_hero_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:11:\"Second link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_title_prefix',_binary 'a:17:{s:4:\"uuid\";s:36:\"00840cc4-7392-4663-a414-47758f14db31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_title_prefix\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"veAof1VE_5yLVqcM55gO7131zQkIVF8H4zYSRsZft-U\";}s:2:\"id\";s:46:\"paragraph.ept_hero.field_ept_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ept_hero_title_prefix\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:12:\"Title prefix\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9610a78c-d4d5-4d29-9221-2b862f3b5c9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jlfCaG2VGA8ar8Pw_-7SqeS8qRs_HrOK0KBRLdRLQGw\";}s:2:\"id\";s:37:\"paragraph.ept_hero.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_hero.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"eda0ee86-a9c6-40a3-90a6-52025f859080\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d6uOb6beHqZsXuoLFCkZ9d-OTiK3Lfl7WLMId5Ynb1o\";}s:2:\"id\";s:33:\"paragraph.ept_hero.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"9cd49d18-67b3-4776-ba0b-dda42289ac3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4ZRR07jQy0amtEk8dDsUh5TwD7BiPqLSfZ64qa1IkaE\";}s:2:\"id\";s:34:\"paragraph.ept_hero.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"123bb9be-f4f0-4e79-9c1f-5a74d1adc56a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_image\";i:1;s:16:\"media.type.image\";i:2;s:36:\"paragraphs.paragraphs_type.ept_image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jo3X0pnIHasz5kmaVrv_VxOnp5yor6wvZ68l7Hpg9nc\";}s:2:\"id\";s:35:\"paragraph.ept_image.field_ept_image\";s:10:\"field_name\";s:15:\"field_ept_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_image.field_ept_image_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"720ab2af-faa7-4459-84ec-84810093337c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ept_image_caption\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tA0YJl2CpERDaSbF2WLaH5CxWoJo4OUxxMw-Y_Z85KA\";}s:2:\"id\";s:43:\"paragraph.ept_image.field_ept_image_caption\";s:10:\"field_name\";s:23:\"field_ept_image_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:13:\"Image caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_image_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"e46eefbb-e77e-4dbb-b856-37283bfcbcf6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_image_link\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dmezv08ITbH8uMIaLoQS0_rAIw2TDc-iXuD0VCZW5q0\";}s:2:\"id\";s:40:\"paragraph.ept_image.field_ept_image_link\";s:10:\"field_name\";s:20:\"field_ept_image_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:10:\"Image Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_image.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"99ba3548-2963-43fc-9439-5c4981283ee3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"35ALufHFT-74ORycJJBebQ8dzd9UMefuOloBcGo5VZ0\";}s:2:\"id\";s:38:\"paragraph.ept_image.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_image.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ee4ec7f5-67b4-42d7-baf2-7aaee393847f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TQxr_NqYWOx6AZeW6vZ-pqzPYQhGvMxRwPcm_djydmY\";}s:2:\"id\";s:34:\"paragraph.ept_image.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b25f97c8-ef2e-408c-b977-6254d1414afe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"js6jXfcyujmxNS5eOXM-fX2nbJp4VUCmm_wWeBR272c\";}s:2:\"id\";s:35:\"paragraph.ept_image.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_image_gallery',_binary 'a:17:{s:4:\"uuid\";s:36:\"dfb637af-23af-4aa3-8753-1c3c1b41f2a4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:47:\"field.storage.paragraph.field_ept_image_gallery\";i:1;s:16:\"media.type.image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-waCmECFpztaOjQ1zzHETTjcKsonmUGYLmUUBB3P_K4\";}s:2:\"id\";s:51:\"paragraph.ept_image_gallery.field_ept_image_gallery\";s:10:\"field_name\";s:23:\"field_ept_image_gallery\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:13:\"Image Gallery\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"84658343-fa44-4fe9-acaa-5c0c2ff5f1d0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"guMxbDDWmEkT_hzhYXnmY2fyGUJMEPxeJW9uZmuIh7s\";}s:2:\"id\";s:46:\"paragraph.ept_image_gallery.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"3d160c57-3e25-403d-8a51-0a0b3397f5eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u25lX345GD4zaFxqQqboxwsRa0S9GMlNcD3drpGc6wE\";}s:2:\"id\";s:42:\"paragraph.ept_image_gallery.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"bbd8f0a6-7c0d-47e5-a62d-a2c5aed60232\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eKE4hyL1K1LGrcOlvyUoYrmTVsVfgHxMAfCbRZf4f5A\";}s:2:\"id\";s:43:\"paragraph.ept_image_gallery.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_micromodal_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"1003b7da-189c-4687-89e9-fe627bd2f746\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_micromodal_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jDNhkuS0vb097p4tXdHxr-ydSAj5cLsbKHtJJ8CC8A0\";}s:2:\"id\";s:51:\"paragraph.ept_micromodal.field_ept_micromodal_title\";s:10:\"field_name\";s:26:\"field_ept_micromodal_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:16:\"Micromodal Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"c3236ac3-dc6f-4f78-9199-3450f0c1f3b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nAJ_q4mUFfBF1PGkZwsvQdbCQKbSx6iW74pQQ8M2kaY\";}s:2:\"id\";s:43:\"paragraph.ept_micromodal.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_micromodal.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9453349-a4b8-4f21-ad48-735cb6bb9eca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"L9_i6zE8UlUJcopkepORHiE8I3C69iY3aeKe3A1jKDg\";}s:2:\"id\";s:39:\"paragraph.ept_micromodal.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b6314b7b-d04b-4c21-b388-edad4a320f8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GoRC0O7xqhZYbUT4g4Qv76pyVOo2S62CERLkOw5UcoU\";}s:2:\"id\";s:40:\"paragraph.ept_micromodal.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_quote_author',_binary 'a:17:{s:4:\"uuid\";s:36:\"819b216b-97f6-4f18-82b6-2074094a280f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.storage.paragraph.field_ept_quote_author\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oNI4JdVXun_FojU2-XZoJP9ztB3e4wWwPkZYgvGQGCg\";}s:2:\"id\";s:42:\"paragraph.ept_quote.field_ept_quote_author\";s:10:\"field_name\";s:22:\"field_ept_quote_author\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:12:\"Quote Author\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_quote_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"fe2fb5d1-bcf8-4e29-9e00-d600aab8954a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ept_quote_image\";i:1;s:16:\"media.type.image\";i:2;s:36:\"paragraphs.paragraphs_type.ept_quote\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YjnCUtsj4uSblj8ujLf9XPYiUCvxUQCzn6Si7IvFez0\";}s:2:\"id\";s:41:\"paragraph.ept_quote.field_ept_quote_image\";s:10:\"field_name\";s:21:\"field_ept_quote_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:11:\"Quote Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_quote.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"c4e09c22-0835-4bec-a402-756220f2e9f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t7gxB3ZTgUm7Yk0DbVkmAjHW8mI8AmfMf32Oxs3QZcI\";}s:2:\"id\";s:38:\"paragraph.ept_quote.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_quote.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f701ef4d-7de9-46b4-88f4-6995981e11ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"daebO4BuA3YZb6pUdTzPsiqUuJH_LDMHLJkxdMWVZSo\";}s:2:\"id\";s:34:\"paragraph.ept_quote.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:5:\"Quote\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a08772a7-ac82-466b-918c-b39c7f16c309\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QGR28IMOBB-lAS8KMdPI2PxLFhQ8APHB11vjkOzEybM\";}s:2:\"id\";s:35:\"paragraph.ept_quote.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9bf7105c-9c7f-493b-b93c-2ee846a91521\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"75Fj62yEPi_Tkndg_Fr-WT5Fn81YlgSw2oEee7jQnKg\";}s:2:\"id\";s:45:\"paragraph.ept_slick_slider.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_slick_slider',_binary 'a:17:{s:4:\"uuid\";s:36:\"c440db95-46b7-4316-8502-e20c900704c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ept_slick_slider\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:2;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VMJlv4iCLXipe6DB9Nw7mRcvCegf6AlaUe9pD4sFZw4\";}s:2:\"id\";s:49:\"paragraph.ept_slick_slider.field_ept_slick_slider\";s:10:\"field_name\";s:22:\"field_ept_slick_slider\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:12:\"Slick Slider\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:21:\"ept_slick_slider_item\";s:21:\"ept_slick_slider_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"4bad9ad2-5f7d-40ee-92a6-547badbee525\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qgc2mLoZ4HsNUAYaZCNUYpblK1Qy_Grwx-FiIrrd3fo\";}s:2:\"id\";s:41:\"paragraph.ept_slick_slider.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0570de2b-d581-4073-a8b0-0729eacf75eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8znZ6dLr4j9QA4jZnTSyprUdnZL0N8ZENTLNXvgPaFo\";}s:2:\"id\";s:42:\"paragraph.ept_slick_slider.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"1b1a1524-2e19-47c4-af5c-c693044a59e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:52:\"field.storage.paragraph.field_ept_slick_slider_image\";i:1;s:16:\"media.type.image\";i:2;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XlD11lUQ6pjHnXyA9Z5Z_lyj35bmUgn2C_2xUYcE2wI\";}s:2:\"id\";s:60:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ept_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"6d566515-d2a4-4ce3-96e1-678ae2feea9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_link\";i:1;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f47xjCX2OUOsteSKP2-Rqy9EJ1ZQWtGr2EmizJ0jwsQ\";}s:2:\"id\";s:59:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"532449b1-8d51-4c87-ad35-6a4555565967\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_text\";i:1;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dP7Z_3Sp9p8yprgyoPMwzTnDckg7oXVPKeGBpWi5yHs\";}s:2:\"id\";s:59:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"a98491aa-0091-4a36-af08-7e4f9e2a3554\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wDLAk6apIKl_k-WeYvw2Sx7NuPQrdbmVpPi_pcf6Ank\";}s:2:\"id\";s:42:\"paragraph.ept_slideshow.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_slideshow.field_ept_slideshow',_binary 'a:17:{s:4:\"uuid\";s:36:\"929dd04a-655a-436e-b9ec-8b400a26f596\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:43:\"field.storage.paragraph.field_ept_slideshow\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:2;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sl3hYGCV99Y8zdhisWkqHtWAR4cKtwAzRiAC8g8O_3w\";}s:2:\"id\";s:43:\"paragraph.ept_slideshow.field_ept_slideshow\";s:10:\"field_name\";s:19:\"field_ept_slideshow\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:9:\"Slideshow\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_slideshow.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"04f2459a-8250-49b8-9c26-a1bc5f23b1ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eFgq1F96D8Kk_yB-LhiHcUiv0NDGHiiESnrxKVotJ8M\";}s:2:\"id\";s:38:\"paragraph.ept_slideshow.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0a76e0e6-37a2-4e5e-a2ca-41101da17e1e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MaSZwNYeloEyTip3_uq3aYWI21fdjStPLv72a0OyAs0\";}s:2:\"id\";s:39:\"paragraph.ept_slideshow.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"6671231f-f98f-4ea0-a6ab-9bfe42290292\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_link\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sj-aXmpz4XSqjlnaG36lSUzZ8k1NxnbVupC-3jXoTh4\";}s:2:\"id\";s:53:\"paragraph.ept_slideshow_item.field_ept_slideshow_link\";s:10:\"field_name\";s:24:\"field_ept_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide',_binary 'a:17:{s:4:\"uuid\";s:36:\"6483f62f-11d2-44ea-bf5b-d0db486d3689\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_slide\";i:1;s:16:\"media.type.image\";i:2;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a66BmJCI3SYkj4hLc0icKJq37QzM84zA3q3tcAMeAqA\";}s:2:\"id\";s:54:\"paragraph.ept_slideshow_item.field_ept_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ept_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad96e4c6-579a-4465-ba2d-117890a7bff3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_text\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JIuZsvq1IySXyy86tHyxkIPZnRhYgEKfm5uNfN4Qgi8\";}s:2:\"id\";s:53:\"paragraph.ept_slideshow_item.field_ept_slideshow_text\";s:10:\"field_name\";s:24:\"field_ept_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"84bea7b4-b9e4-4cf4-8ec9-389dd6b02c10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_title\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"of2_NLVXcX_Tqy_oCPxWCKkqkVV1GMoDc32IPKj-uAs\";}s:2:\"id\";s:54:\"paragraph.ept_slideshow_item.field_ept_slideshow_title\";s:10:\"field_name\";s:25:\"field_ept_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:11:\"Slide Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"f00824ef-dc9b-4ba7-81ad-8e7910f662a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"w6dTziASV3O9e_SoQSGcA7y3KjBRRRFKEmxbhx_eOPY\";}s:2:\"id\";s:38:\"paragraph.ept_stats.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_stats.field_ept_stats',_binary 'a:17:{s:4:\"uuid\";s:36:\"cfaf7cc4-f386-4397-8876-cdcee33b93b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_stats\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:2;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ixjxb8WmNFSxd8n64WYGee4M8gw_ihsOSTkxejxBK7I\";}s:2:\"id\";s:35:\"paragraph.ept_stats.field_ept_stats\";s:10:\"field_name\";s:15:\"field_ept_stats\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:9:\"EPT Stats\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_stats.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a8fb2e31-9a7a-45bb-84f7-84bce2a8e256\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5DBGJho8oBlSjoM127v2kkKEhKXLsn2dYpC1Gj4wep8\";}s:2:\"id\";s:34:\"paragraph.ept_stats.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"1c882037-c7e3-42e4-9707-af10c5015ef2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T8Ioj6BqDtO5y16e6qpTBdiluC90CXivuhVNCfIlff8\";}s:2:\"id\";s:35:\"paragraph.ept_stats.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"48e0dea0-fc4d-4a86-8ed4-203f0efe3a52\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:50:\"field.storage.paragraph.field_ept_stats_item_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gQ-WN8Z7uMhqF7m3PcgLkMbssZvUuoZDru39piaWdaY\";}s:2:\"id\";s:51:\"paragraph.ept_stats_item.field_ept_stats_item_image\";s:10:\"field_name\";s:26:\"field_ept_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:16:\"Stats item image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"64aa7603-d2f0-4050-a82f-35b5ef3b978f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_link\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MnXt19dK8rTz4x1hRigyeVWiXn1o6VumcHTMqrFFk74\";}s:2:\"id\";s:50:\"paragraph.ept_stats_item.field_ept_stats_item_link\";s:10:\"field_name\";s:25:\"field_ept_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:15:\"Stats item link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"4be87c8b-a691-4546-9b46-8104a7920252\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_stats_item_number\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7DMKiTrisc5ETf4YO_Rg2a1hxbtze1sV29AulzJK_mo\";}s:2:\"id\";s:52:\"paragraph.ept_stats_item.field_ept_stats_item_number\";s:10:\"field_name\";s:27:\"field_ept_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:17:\"Stats item number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"7ab22f13-220c-400f-9f56-3043d91300ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"syABtrl4XuopN2UmpGpkCfjm8LZlB4zLjgHycG4AUww\";}s:2:\"id\";s:50:\"paragraph.ept_stats_item.field_ept_stats_item_text\";s:10:\"field_name\";s:25:\"field_ept_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:15:\"Stats item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"bcee11b6-9de3-4ea7-ab28-783aaf52a980\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7WAUPeogPEpndKAuLbuwHXSQX1_x1zQ1DkQgZ0xSJl8\";}s:2:\"id\";s:37:\"paragraph.ept_tabs.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_tabs.field_ept_tabs',_binary 'a:17:{s:4:\"uuid\";s:36:\"f3ed6271-02a1-49ae-87a5-dcbb0788200c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:38:\"field.storage.paragraph.field_ept_tabs\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:2;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oxGvFEmPYXx97wLochArKKDYG1lhbF0L77Sp4ki0K1I\";}s:2:\"id\";s:33:\"paragraph.ept_tabs.field_ept_tabs\";s:10:\"field_name\";s:14:\"field_ept_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"EPT Tabs\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_tabs.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"5d8d9518-713c-4c54-a1b1-e9255a1064cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxiqJRauMgF0Qzud0cz2Wj4-oLnMJ3Cr-bXZe_fdGC0\";}s:2:\"id\";s:33:\"paragraph.ept_tabs.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"3b694b0c-21b1-40f1-aab1-5f8f6b508006\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DehWRcrin5XDNZhAMoyHl3b5Vtw4Tpdijx5u8vCQ75Q\";}s:2:\"id\";s:34:\"paragraph.ept_tabs.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"c3f52d5a-54bd-4606-8b04-4a6c1e456a0b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_block\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Djebt4QCWYRzCydiBvhKgj0bMyEaWAKfY-YBAf7OX4Y\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_block\";s:10:\"field_name\";s:19:\"field_ept_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab Block\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:6:\"blocks\";s:18:\"selection_settings\";a:1:{s:10:\"plugin_ids\";a:0:{}}}s:10:\"field_type\";s:11:\"block_field\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_content',_binary 'a:17:{s:4:\"uuid\";s:36:\"8bd0ca98-8e9c-4dba-b1cf-ae98a043504f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_tab_content\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:7:\"options\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FHi-QeaCukjELTWL55S3DmUxMPC5qvpjm7YoUXlN2_k\";}s:2:\"id\";s:45:\"paragraph.ept_tabs_item.field_ept_tab_content\";s:10:\"field_name\";s:21:\"field_ept_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:11:\"Tab content\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:11:\"list_string\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_page',_binary 'a:17:{s:4:\"uuid\";s:36:\"15235fd9-9fad-4092-b19c-8e011debebfb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_page\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lSW-pbI_Dd3D3Pmk9Ey9S92Si1kgRJBouroj9i9FcxI\";}s:2:\"id\";s:42:\"paragraph.ept_tabs_item.field_ept_tab_page\";s:10:\"field_name\";s:18:\"field_ept_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:8:\"Tab page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:12:\"default:node\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:4:\"page\";s:4:\"page\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a059a1dc-b8c7-41a3-a0ba-57ef2b7c3ef2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UhI0Db-BZ8kkyso5fdxGaK2SLKXQOo3Tz91NfllT_zE\";}s:2:\"id\";s:42:\"paragraph.ept_tabs_item.field_ept_tab_text\";s:10:\"field_name\";s:18:\"field_ept_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:8:\"Tab text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0c7eb82c-6093-4901-bd0b-fd48f6eedcb2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"evBpqQnLlVSI7JzfhV_sYlfl4Xj_FMH8yjfAXa3TuNo\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_title\";s:10:\"field_name\";s:19:\"field_ept_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:4:\"text\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_views',_binary 'a:17:{s:4:\"uuid\";s:36:\"efd74810-b803-4db6-b891-9ea3905eb31d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_views\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I_C7XUVcXIbh_wxTumKceK8yBCxb_QVNvaycgNmZB20\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_views\";s:10:\"field_name\";s:19:\"field_ept_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab views\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";i:0;}s:12:\"plugin_types\";a:5:{s:5:\"block\";s:5:\"block\";s:7:\"default\";i:0;s:4:\"page\";i:0;s:4:\"feed\";i:0;s:5:\"embed\";i:0;}s:15:\"preselect_views\";a:15:{s:13:\"block_content\";i:0;s:7:\"comment\";i:0;s:15:\"comments_recent\";i:0;s:7:\"content\";i:0;s:14:\"content_recent\";i:0;s:5:\"files\";i:0;s:9:\"frontpage\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:13:\"taxonomy_term\";i:0;s:17:\"user_admin_people\";i:0;s:8:\"watchdog\";i:0;s:19:\"webform_submissions\";i:0;s:9:\"who_s_new\";i:0;s:12:\"who_s_online\";i:0;}s:16:\"enabled_settings\";a:5:{s:8:\"argument\";i:0;s:5:\"limit\";i:0;s:6:\"offset\";i:0;s:5:\"pager\";i:0;s:5:\"title\";i:0;}}s:10:\"field_type\";s:14:\"viewsreference\";}'),('','field.field.paragraph.ept_text.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"dd24c6a8-a5d2-434a-90d0-3a97c829c794\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zlnMwIZoq976NUR8ObTPmCmOG2YwYTmjc1fQpFhCzWs\";}s:2:\"id\";s:37:\"paragraph.ept_text.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:18:\"field_ept_settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_text.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"406dd338-600c-4eb2-841a-df635188cfb3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yIzbNDHidtMFArQQv6qO6cTkFBTnI6e02KK-xT8FOIM\";}s:2:\"id\";s:33:\"paragraph.ept_text.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_text.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"6902be14-683f-4f5a-8d50-8543bbf0aca5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DZTXvQuYpXkQt9q004RnVKvKTocT9hurW7VYy0As9Is\";}s:2:\"id\";s:34:\"paragraph.ept_text.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"ac698185-3f8a-4519-a9b7-29609da24892\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d-eKpx0qmCR-PZ85K0IfmM1LKHFjcx9xUcNT5mMFMuA\";}s:2:\"id\";s:38:\"paragraph.ept_tiles.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_tiles.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"7f39ca00-ae38-46ac-a2f2-ce0b4f545f9f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uGM6CpdmK0GJ5mrS4WHYG6QnXJLHx0fiEbs3D7e_iqE\";}s:2:\"id\";s:34:\"paragraph.ept_tiles.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles.field_ept_tiles',_binary 'a:17:{s:4:\"uuid\";s:36:\"254d23bc-cd9a-4186-b124-2f3fa923fc05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_tiles\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:2;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lii17sKUYm4ZAvrf-OKM8IF0auj5DIQWCMBUkdzT4BM\";}s:2:\"id\";s:35:\"paragraph.ept_tiles.field_ept_tiles\";s:10:\"field_name\";s:15:\"field_ept_tiles\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:5:\"Tiles\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:75;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_tiles.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"efadba67-9ef3-474a-8246-0e5a51d74660\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e58JwGJ1lDz1CUji4qvDlK_7WEadqaihU0jG6u0_10E\";}s:2:\"id\";s:35:\"paragraph.ept_tiles.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_clickable_tile',_binary 'a:17:{s:4:\"uuid\";s:36:\"29c56f04-456b-4f6f-87b5-6352ddaa6a51\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_clickable_tile\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BVIyqIinPodc30VYfLCsYHnMbl1U6L7LpKffkLNM6RY\";}s:2:\"id\";s:49:\"paragraph.ept_tiles_item.field_ept_clickable_tile\";s:10:\"field_name\";s:24:\"field_ept_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:14:\"Clickable Tile\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"af24502d-ca80-4229-bc11-8b9d175d53f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AnFN9yAGXXY3wn6XD_DMYj4H1UfZR6gt3lITV4L2Jy4\";}s:2:\"id\";s:46:\"paragraph.ept_tiles_item.field_ept_tiles_image\";s:10:\"field_name\";s:21:\"field_ept_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"77a71623-7050-467d-bbb6-f7e2b8e10f9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_link\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"c5x2tFCR-aDLFMCY5a0CDVK8OLjI-eH92z0w6wsbq7I\";}s:2:\"id\";s:45:\"paragraph.ept_tiles_item.field_ept_tiles_link\";s:10:\"field_name\";s:20:\"field_ept_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a96f802e-f6f6-415b-a00b-47d8e483f3c2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zLtl1oCO1H3AjX05GApCKNVIuZj-sWnEjN2TFBhgTpk\";}s:2:\"id\";s:45:\"paragraph.ept_tiles_item.field_ept_tiles_text\";s:10:\"field_name\";s:20:\"field_ept_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"60166fc5-cd70-42a2-ab4a-021bef6afcf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-RWZYOv7kMNcT6h0h3wa0LE8w3is_5A7gNJGRvk2Xh8\";}s:2:\"id\";s:46:\"paragraph.ept_tiles_item.field_ept_tiles_title\";s:10:\"field_name\";s:21:\"field_ept_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"65e27c50-82c3-46dd-ad6d-c95805dd83bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jKYz3Azrp1BbteF4w3ARDoD11HGUjD6Y1-Pi3j5bMMA\";}s:2:\"id\";s:38:\"paragraph.ept_video.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_video.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"de00022b-0652-4a4f-a13f-6d001b19f4c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rOcKKlFTqbEyP9jZpIA7FgAeEZVpAzkLMwyL7Ocl7ZA\";}s:2:\"id\";s:34:\"paragraph.ept_video.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"68fe7948-f81f-4f36-8ce6-3a736d2696be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"liOGejMkGS8WchkLMEwnO9OEFeI2CuDopa6y4ARi6R4\";}s:2:\"id\";s:35:\"paragraph.ept_video.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"5fbf0b1d-881b-44e3-9225-31e307913827\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_video\";i:1;s:23:\"media.type.remote_video\";i:2;s:36:\"paragraphs.paragraphs_type.ept_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"B2uO316aHzKE6mwH_4CehW7np6-M8ImTN-8E4ZUIOz4\";}s:2:\"id\";s:35:\"paragraph.ept_video.field_ept_video\";s:10:\"field_name\";s:15:\"field_ept_video\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"8b147c97-e78e-4773-a7dd-fbdd3db585a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A0AtClTrQ3Abbg6jEI-itnCAjYSI69l8ZIU5n6wGu-k\";}s:2:\"id\";s:56:\"paragraph.ept_video_and_image_gallery.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"5c1e6fab-0fe9-4952-a3c8-991a0f293a80\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iohq2efRKb05xjfjet4Iqszn41WFrfgfSMpBRl9I8EQ\";}s:2:\"id\";s:52:\"paragraph.ept_video_and_image_gallery.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"2bdd8485-4125-400d-b6ef-feffe57ca0b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nYAF3MHEVZhy6EJ7hiHDE82BlOyi6F94s9AtJa31HxY\";}s:2:\"id\";s:53:\"paragraph.ept_video_and_image_gallery.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9a94fcc-b813-47ed-9b68-5780ad0e270c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:51:\"field.storage.paragraph.field_ept_videos_and_images\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Md5TJXPOSzIMO3hzpok2uncR4UY-8oOvihBYAwl1UTE\";}s:2:\"id\";s:65:\"paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";s:10:\"field_name\";s:27:\"field_ept_videos_and_images\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:17:\"Videos and Images\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:32:\"ept_video_and_image_gallery_item\";s:32:\"ept_video_and_image_gallery_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:82;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item',_binary 'a:17:{s:4:\"uuid\";s:36:\"8e45972c-1dc7-444f-9475-a98aa5a83a12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:4:{i:0;s:46:\"field.storage.paragraph.field_ept_gallery_item\";i:1;s:16:\"media.type.image\";i:2;s:23:\"media.type.remote_video\";i:3;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIblYcf3rZ3cLp4a87dabiYrK0YFYOLsXZ8PPx7JD2w\";}s:2:\"id\";s:65:\"paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";s:10:\"field_name\";s:22:\"field_ept_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:12:\"Gallery Item\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:2:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:5:\"image\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9302769a-011f-4ea8-8a1a-82c6399fc628\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_gallery_item_text\";i:1;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rHN5K2dhzZ2JBJLK9KNsBbDp_D8-ug9T0oRgKfs_L_8\";}s:2:\"id\";s:70:\"paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";s:10:\"field_name\";s:27:\"field_ept_gallery_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:17:\"Gallery item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"0cd4c4a7-feca-4fb7-9e8b-02984559941b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qvGJxPRaclSHVbrfz5Je86o0KNtcIYQhWoZtkWbYOeY\";}s:2:\"id\";s:38:\"paragraph.ept_views.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_views.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9ef68e5-ed23-45fb-a5d1-bac433eeb379\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yroYplh-3xAoBiIIaPAFqecCgnt--hr4wQOE6pydZiw\";}s:2:\"id\";s:34:\"paragraph.ept_views.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0d3eae73-ae6d-4601-b1d4-4df1d7d62c53\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YN4Np9dhEdu3560d9b81PqIY6VAamYuCUEeaTR7MeA4\";}s:2:\"id\";s:35:\"paragraph.ept_views.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_views_view',_binary 'a:17:{s:4:\"uuid\";s:36:\"ef74c15e-0e9f-4f8c-82b1-f7cec4763c50\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_views_view\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qezCi3E0L14u6YMFPeJ3FisM_AyqNacTs3hFkLyN-Bk\";}s:2:\"id\";s:40:\"paragraph.ept_views.field_ept_views_view\";s:10:\"field_name\";s:20:\"field_ept_views_view\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:4:\"View\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}s:12:\"plugin_types\";a:1:{s:5:\"block\";s:5:\"block\";}s:15:\"preselect_views\";a:0:{}s:16:\"enabled_settings\";a:0:{}}s:10:\"field_type\";s:14:\"viewsreference\";}'),('','field.field.paragraph.ept_webform.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"70a56a53-e5dd-4fcf-99b5-29d8b6d4619b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ggBDqszw4QWAW0TCllQsKLBmK-bp0CiS6nqF7QWI7SY\";}s:2:\"id\";s:40:\"paragraph.ept_webform.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_webform.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"7c6589db-fb84-410a-a79c-846a25ff7d97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mYXqrew8efgRYMA2xp-KGRqB_dpPZNxoW56GUfOlWSI\";}s:2:\"id\";s:36:\"paragraph.ept_webform.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_webform.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"d157a78a-d59b-4666-8f4f-2c3fb507bb31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xY1lK8nuvMOzD3Z1ax_xyEM4en85W6tIiFiP8F2EctA\";}s:2:\"id\";s:37:\"paragraph.ept_webform.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_webform.field_ept_webform_form',_binary 'a:17:{s:4:\"uuid\";s:36:\"9e4cb219-cde1-47ad-8d3d-ff3a8093595a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.storage.paragraph.field_ept_webform_form\";i:1;s:38:\"paragraphs.paragraphs_type.ept_webform\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8HHpzIIgRSxpCUPa33P8cI2huYMKbyofPgO-afmbiHQ\";}s:2:\"id\";s:44:\"paragraph.ept_webform.field_ept_webform_form\";s:10:\"field_name\";s:22:\"field_ept_webform_form\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_webform\";s:5:\"label\";s:4:\"Form\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}}s:10:\"field_type\";s:7:\"webform\";}'),('','field.field.paragraph.ept_webform_popup.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"77455be2-5b47-46b9-a671-60e6534bb5da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Jp5ODXu51CF8H1fNuknzPsSR2mawxCqKDVa1n8OG-hE\";}s:2:\"id\";s:46:\"paragraph.ept_webform_popup.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_webform_popup.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"81f724c9-9e84-4627-825c-4d7ea016d18e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9B9chWVQ9ZVaf4luXVZnBfXiFnBLvZc-yW_PcWliZk0\";}s:2:\"id\";s:42:\"paragraph.ept_webform_popup.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_webform_popup.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"67b226bf-e2f6-418d-9999-d41f6b3d3825\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xFnjuZknMO_3KuT0h0sJfiwbMMmGteSA3oEDRgaUHBU\";}s:2:\"id\";s:43:\"paragraph.ept_webform_popup.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_webform_popup.field_ept_webform_popup_form',_binary 'a:17:{s:4:\"uuid\";s:36:\"f14e46f4-90c2-43c0-b2de-b00cf7ff030e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:52:\"field.storage.paragraph.field_ept_webform_popup_form\";i:1;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l5bQx5-y-4oiJvbjaplNL5aHTR0DF9BUcZMx7qli1WI\";}s:2:\"id\";s:56:\"paragraph.ept_webform_popup.field_ept_webform_popup_form\";s:10:\"field_name\";s:28:\"field_ept_webform_popup_form\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_webform_popup\";s:5:\"label\";s:7:\"Webform\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}}s:10:\"field_type\";s:7:\"webform\";}'),('','field.field.user.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"27323f57-acfd-4aff-a508-544c6c8bdf3d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:31:\"field.storage.user.user_picture\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TE3gYVzd6g0deXqUl8SEu2azHwVG-SdXm3kwbrz0kHw\";}s:2:\"id\";s:22:\"user.user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:5:\"label\";s:7:\"Picture\";s:11:\"description\";s:29:\"Your virtual face or picture.\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:40:\"pictures/[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:0;s:18:\"alt_field_required\";b:0;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJk0TAQBzlNo52ehiHI7bIEPLGi0BYqZvPdEn7Chfu0\";}s:16:\"purge_batch_size\";i:50;}'),('','field.storage.block_content.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"05e5fd5b-7ad6-434e-99a8-8635a8fa97cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:2:\"id\";s:18:\"block_content.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"4a613783-5795-48bc-bd8e-e3fe3a00ea51\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw\";}s:2:\"id\";s:20:\"comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_audio_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"1295648c-a917-438e-a846-fd85d14ae8a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JCHoh95CpUeBx9ch24Tmi6ru0nwmNz8xWVH4Qs7RnTg\";}s:2:\"id\";s:28:\"media.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_document',_binary 'a:17:{s:4:\"uuid\";s:36:\"6b41e063-a182-4108-9b56-c0f4bb265180\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BdkTx7IL59MCw5a_fOZprPTOGM_wcjz-Fm8g7HV3vFk\";}s:2:\"id\";s:26:\"media.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"ae1f0138-a2f5-4881-bf90-0ade773b59b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0N0KSFk57p6qsq3qM4lYVGSuROvzXK-tSsdwByqUh3g\";}s:2:\"id\";s:23:\"media.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_oembed_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"b471db54-e924-4e9f-b6d7-c7e32f497206\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cNf_852Dq-fNnSaMI4LxL-J6N7bLkHuDbD9EUqOn4_U\";}s:2:\"id\";s:30:\"media.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;s:8:\"is_ascii\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_video_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"1567fe07-a329-492a-bc5f-d82e3865bd57\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z5mgbn1PIVZ5TNMByBmivqo_u3Rdk58UIzpyN4ypTeM\";}s:2:\"id\";s:28:\"media.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"26a81385-82de-46f0-8582-8c93b0fbcb01\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:2:\"id\";s:9:\"node.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_components',_binary 'a:16:{s:4:\"uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:2:\"id\";s:21:\"node.field_components\";s:10:\"field_name\";s:16:\"field_components\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"d9aff85c-3ad9-418b-b47e-58f08b64180e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:2:\"id\";s:16:\"node.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"81f6ea79-133f-4e53-bb0a-4169a69c4472\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:2:\"id\";s:15:\"node.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9282b5e-9cbb-4d37-84d7-b405cf59a041\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"99EX18edsQlLBda3J37pHASAxF4OUjSVJ4_nSq1pW94\";}s:2:\"id\";s:29:\"paragraph.field_ept_accordion\";s:10:\"field_name\";s:19:\"field_ept_accordion\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"177e4cd0-bbd1-44cd-9d3f-5b5dd4378ed4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l5c0DoOjgcErJEjFGkUqN_upYgubdHpE_MiwbMK2YRI\";}s:2:\"id\";s:34:\"paragraph.field_ept_accordion_text\";s:10:\"field_name\";s:24:\"field_ept_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"012f2184-9082-4983-9239-7dac48864d9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6S4PB05UjgSgHEDSalqgqkJHWyCcYsdkgPKTvGC2c8s\";}s:2:\"id\";s:35:\"paragraph.field_ept_accordion_title\";s:10:\"field_name\";s:25:\"field_ept_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_basic_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"360bef36-b4f7-492b-9677-6170eebdf2bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Tj1qQArNpaPeg2XmPed8WY2JiAk8p21-R1HVn28zVoY\";}s:2:\"id\";s:37:\"paragraph.field_ept_basic_button_link\";s:10:\"field_name\";s:27:\"field_ept_basic_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_block_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"58c5cc3e-9949-4686-882a-a56b59c60ea8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hAESsXJ5KZsWYKr-KB5wJoHNBdcOTlIFJUomBW8VxoU\";}s:2:\"id\";s:31:\"paragraph.field_ept_block_block\";s:10:\"field_name\";s:21:\"field_ept_block_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_bootstrap_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"bceb6f2f-b114-41f5-8b07-0ce990d0087a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BweaoyqqEqOIBPWV2qKw_2N4R6oBSudk91cCNPtz_iY\";}s:2:\"id\";s:41:\"paragraph.field_ept_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ept_bootstrap_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel',_binary 'a:17:{s:4:\"uuid\";s:36:\"fbb51140-67d8-4112-868c-19dd46c31b98\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RbALd0Xz78o-CtP2iD8j7s8h1scHn1lSdm-_EQqZyrY\";}s:2:\"id\";s:28:\"paragraph.field_ept_carousel\";s:10:\"field_name\";s:18:\"field_ept_carousel\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"4bdff313-152c-4ea9-ba49-6f433c48203a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HeWBlq69mptI0nGWU0dliRAS9rVOa2HzuJbUbzsJg4M\";}s:2:\"id\";s:36:\"paragraph.field_ept_carousel_caption\";s:10:\"field_name\";s:26:\"field_ept_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"1da3ad04-a3d6-45a2-8a2e-100f0d629948\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ViB2NrYfe_RWvrvvb9X_U6kuX0eI47m5Wpa6hCFqZWE\";}s:2:\"id\";s:34:\"paragraph.field_ept_carousel_image\";s:10:\"field_name\";s:24:\"field_ept_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_clickable_tile',_binary 'a:17:{s:4:\"uuid\";s:36:\"776f5eb1-0740-473f-b278-4678ab1e0a4e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKnQMenIUygu6qoP8n4_EzChFXMkjnwf78bFFBWCN0w\";}s:2:\"id\";s:34:\"paragraph.field_ept_clickable_tile\";s:10:\"field_name\";s:24:\"field_ept_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_columns',_binary 'a:17:{s:4:\"uuid\";s:36:\"7518ddce-1000-4e47-8c93-f8230ca40081\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lIenGVJ8vS3WAEr1xteI9sDUdCoc-UNgbf7xDipU4_s\";}s:2:\"id\";s:27:\"paragraph.field_ept_columns\";s:10:\"field_name\";s:17:\"field_ept_columns\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_countdown_date',_binary 'a:17:{s:4:\"uuid\";s:36:\"5741fa83-8e57-4e60-99ce-6e8bd5bf8b78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"datetime\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SWGbKy8XYRkCxbrmDvY2UYyxzAKxcSL7ouH4CljiXbY\";}s:2:\"id\";s:34:\"paragraph.field_ept_countdown_date\";s:10:\"field_name\";s:24:\"field_ept_countdown_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:8:\"datetime\";s:8:\"settings\";a:1:{s:13:\"datetime_type\";s:8:\"datetime\";}s:6:\"module\";s:8:\"datetime\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_description',_binary 'a:17:{s:4:\"uuid\";s:36:\"385056ad-483b-468c-8fc7-fa477f32138c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Vb_uSodiEH1YHgcoZFitK_cSCdO65_4U1fUOrl-0G-0\";}s:2:\"id\";s:39:\"paragraph.field_ept_counter_description\";s:10:\"field_name\";s:29:\"field_ept_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_icon',_binary 'a:17:{s:4:\"uuid\";s:36:\"bd174355-0ad0-4843-9909-9069e6e2eac2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0JA4V_sLzmSUMXzEuZ7m6J_MFEw5Nrb7bG9XU34Ucc\";}s:2:\"id\";s:32:\"paragraph.field_ept_counter_icon\";s:10:\"field_name\";s:22:\"field_ept_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_items',_binary 'a:17:{s:4:\"uuid\";s:36:\"fa2205d7-3b05-4d76-a029-30510c45d952\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vFwfw4KEUwjCwBs2-7ay4ctFQ2ObvCZYU16zxuQC5HM\";}s:2:\"id\";s:33:\"paragraph.field_ept_counter_items\";s:10:\"field_name\";s:23:\"field_ept_counter_items\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"072a57f4-9c76-4a9a-a3f4-f13ef03b81be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MzVJsn5k9Si1YXppdAIDnZzJ1W16U44-V2RnkeyaeyI\";}s:2:\"id\";s:34:\"paragraph.field_ept_counter_number\";s:10:\"field_name\";s:24:\"field_ept_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"integer\";s:8:\"settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a62c9e27-ad8b-430d-85ce-9db276ada8eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CTuSHda2RHGJciX7ZF12J7Y9A3TK_RrRj7CRxyKyNGA\";}s:2:\"id\";s:33:\"paragraph.field_ept_counter_title\";s:10:\"field_name\";s:23:\"field_ept_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"2545ccb9-b7f9-49f1-a002-1aa70a099849\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BVZIBdZwlh9CG5xDwjnekBIIuVdEEtKvFPci5rwGdA0\";}s:2:\"id\";s:36:\"paragraph.field_ept_cta_column_image\";s:10:\"field_name\";s:26:\"field_ept_cta_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"ef4b1edf-7e44-4fd4-9484-139b43615d23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LvryVrIdU5CC3UNEhpU7Vej6X8Y4RKKDsOdhseGGUVg\";}s:2:\"id\";s:28:\"paragraph.field_ept_cta_link\";s:10:\"field_name\";s:18:\"field_ept_cta_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"e5ac8a81-1f96-4b7d-b8e0-6d9b2c08fcbd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DHvUvJxjsMX4y4-L8sAyVpFvA0pptpqcHZ8p_EMBBdU\";}s:2:\"id\";s:35:\"paragraph.field_ept_cta_second_link\";s:10:\"field_name\";s:25:\"field_ept_cta_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_gallery_item',_binary 'a:17:{s:4:\"uuid\";s:36:\"a1361495-0a6d-4f18-8570-b713e198ddf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8JLKZdRZR-OD6hbmGc3VHufx5PLi683tbf4QM_K4ZAU\";}s:2:\"id\";s:32:\"paragraph.field_ept_gallery_item\";s:10:\"field_name\";s:22:\"field_ept_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_gallery_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ceb57be4-05e2-49c4-afad-48cb1341e682\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cWuIwOJOPOwoJ4OA0TCSko2wR73oMOOVlyC7clefebo\";}s:2:\"id\";s:37:\"paragraph.field_ept_gallery_item_text\";s:10:\"field_name\";s:27:\"field_ept_gallery_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"0bd5b0b1-4d3b-472e-ac51-086416f9360a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"knr6QfLVidPHSzwjlRdOZ6PqAiVNnXT73--qFC4pZqo\";}s:2:\"id\";s:37:\"paragraph.field_ept_hero_column_image\";s:10:\"field_name\";s:27:\"field_ept_hero_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"89e38776-3ba0-4f79-9023-af5e40b20171\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XgZuheOtVwvMdFAli6FX9XwC6jCtmfQsa4Y--V6AWLk\";}s:2:\"id\";s:29:\"paragraph.field_ept_hero_link\";s:10:\"field_name\";s:19:\"field_ept_hero_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"a51e7805-3dcf-415a-b08c-6e41b660115d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_LEdcxkwVZPMeBjAfFM_DTcqJxHu-SXmfvkzYA16OTE\";}s:2:\"id\";s:36:\"paragraph.field_ept_hero_second_link\";s:10:\"field_name\";s:26:\"field_ept_hero_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_title_prefix',_binary 'a:17:{s:4:\"uuid\";s:36:\"be93c2a2-2803-47c8-8cbb-88ab3561ae6c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HgeEpS7HHbPsoLeKHrpRrax2ttxvlJADvMU3R-HwVf4\";}s:2:\"id\";s:37:\"paragraph.field_ept_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ept_hero_title_prefix\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"a3a4414c-7488-42d9-ad4e-706dbb16b1da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t2q8Lh-nuJZ2Ozh8PR1_zVbozcHAD18kLOnsz0e4oxY\";}s:2:\"id\";s:25:\"paragraph.field_ept_image\";s:10:\"field_name\";s:15:\"field_ept_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"d90ba792-7242-4c28-a755-2203bfbd33dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-2PNM_k1cGXc-Q0fAWwWKl0WSoTksX8UcJ3-t0wUn1s\";}s:2:\"id\";s:33:\"paragraph.field_ept_image_caption\";s:10:\"field_name\";s:23:\"field_ept_image_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_gallery',_binary 'a:17:{s:4:\"uuid\";s:36:\"a25a51c6-fb73-441d-bfe4-baf60db380f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"42vUEff48hmnJOtdaZMLlF0wtf_QYb_mBJO5EVMCKBk\";}s:2:\"id\";s:33:\"paragraph.field_ept_image_gallery\";s:10:\"field_name\";s:23:\"field_ept_image_gallery\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"389f5e03-e7e9-4fb0-bdb5-618f4ada2579\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VKNAP2cuu9mjHYh_BiZTS3nC4gx2nPLjvdAFIHAhJs\";}s:2:\"id\";s:30:\"paragraph.field_ept_image_link\";s:10:\"field_name\";s:20:\"field_ept_image_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_micromodal_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"58a0c8d3-2aaa-43a3-af29-df451a7410e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9wlDgbRXeLI7j3BoH97N3phJfeK2l1E2osqZh_FRkh4\";}s:2:\"id\";s:36:\"paragraph.field_ept_micromodal_title\";s:10:\"field_name\";s:26:\"field_ept_micromodal_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_quote_author',_binary 'a:17:{s:4:\"uuid\";s:36:\"f68b8da9-803f-4c9b-8f4c-4fc24f899205\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yN0vOPqU28gSDN6dC5uNd2vwbTDVhm0njE_mJ2k_rCk\";}s:2:\"id\";s:32:\"paragraph.field_ept_quote_author\";s:10:\"field_name\";s:22:\"field_ept_quote_author\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_quote_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"39b9627d-fdb9-4ed9-afc4-0c4d133a92c6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tQ8LcsYTu_fXhMAvx5We58I0EB2mrFc9tC42tO2YpQ4\";}s:2:\"id\";s:31:\"paragraph.field_ept_quote_image\";s:10:\"field_name\";s:21:\"field_ept_quote_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"aed153c8-a66a-428a-be76-0d9ff9c57e30\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HvKMBmRf1ancerUpnNjtwfTeY-R4_vPBnsqEe9j-ovs\";}s:2:\"id\";s:28:\"paragraph.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:12:\"ept_settings\";s:8:\"settings\";a:0:{}s:6:\"module\";s:8:\"ept_core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider',_binary 'a:17:{s:4:\"uuid\";s:36:\"467150cb-7feb-412a-9426-4b2a3f4a1caa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"p4cFkBoz3tkJW1Ep5zM4g_f4mQ-XFHh3pShn7qHErpU\";}s:2:\"id\";s:32:\"paragraph.field_ept_slick_slider\";s:10:\"field_name\";s:22:\"field_ept_slick_slider\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"d985b37a-8f1d-4d3c-8d92-09cb8326cf66\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LzVCCy3JB_QNYYe-TIA7NOSStFsPdMhJRj2kRx6xp48\";}s:2:\"id\";s:38:\"paragraph.field_ept_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ept_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"3adc57b0-490d-4760-8c68-b19c339fedb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"urQvYyrbemmSrIdbqn5B3hiHO3OGBgCpwmTx0L9ipCM\";}s:2:\"id\";s:37:\"paragraph.field_ept_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"d8e5d125-f4f7-4c1d-ac26-f7468f91d3b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9lgsbO7ntDggj0S64_Kj04ysNSAJqsLLVWCg1sASI7o\";}s:2:\"id\";s:37:\"paragraph.field_ept_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow',_binary 'a:17:{s:4:\"uuid\";s:36:\"1a9f268a-efba-464e-854e-f46e7e1341e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNz95cfhiI0VPQ9jlgmyexwx_snf3hcYXB3N76R6FEg\";}s:2:\"id\";s:29:\"paragraph.field_ept_slideshow\";s:10:\"field_name\";s:19:\"field_ept_slideshow\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"08a96db8-eb88-4875-8250-d218a934e839\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j3IfmwQ3lYIJp87Put31sIn-_9bc3uFqZWFLa_w_9hk\";}s:2:\"id\";s:34:\"paragraph.field_ept_slideshow_link\";s:10:\"field_name\";s:24:\"field_ept_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_slide',_binary 'a:17:{s:4:\"uuid\";s:36:\"d704c8d4-b783-49b6-af10-1f4524374151\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qxeflsuOm7AVY0acEDYWC8RbV1WUHCbVdEWrV-i8xCU\";}s:2:\"id\";s:35:\"paragraph.field_ept_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ept_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"8f6db9bb-d214-4b8e-a41e-8e68af02013e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hf7ieZizeOOo0vAYdXIuWovA7ihSiu5RQ6PQD9LV27c\";}s:2:\"id\";s:34:\"paragraph.field_ept_slideshow_text\";s:10:\"field_name\";s:24:\"field_ept_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"c605bbbd-911f-4bca-9f1d-7575ba23063c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tyAlxAEOc2ScLxGA0DPp-lg0u4x8VXHrFuotd44B_SE\";}s:2:\"id\";s:35:\"paragraph.field_ept_slideshow_title\";s:10:\"field_name\";s:25:\"field_ept_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats',_binary 'a:17:{s:4:\"uuid\";s:36:\"54f29aab-0b38-45f1-bef4-33ea7848198c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A2WIvrY8Lq2oUgdXcZ6AeYNUvyM4mmPAuE7W3ZK_2Wc\";}s:2:\"id\";s:25:\"paragraph.field_ept_stats\";s:10:\"field_name\";s:15:\"field_ept_stats\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"32ff7444-1fb2-4c29-97a3-9e9f53ec491a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UoI74uzcaxvNAutge4YEMTgWFuRMeasXrgpq3PK1sVs\";}s:2:\"id\";s:36:\"paragraph.field_ept_stats_item_image\";s:10:\"field_name\";s:26:\"field_ept_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"48fc10e7-9c7a-4b33-8f60-3ce608c713c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r9tIHirJngA0lU8nZzF4zo3Sk3sZoNMDm7tn4Q8f6nU\";}s:2:\"id\";s:35:\"paragraph.field_ept_stats_item_link\";s:10:\"field_name\";s:25:\"field_ept_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"e0b4af62-c275-4029-b2a7-59ffabd9c786\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HhOT5HnntE62swJxbAxEUWcqiYJnPIfz8wawWbRbXDs\";}s:2:\"id\";s:37:\"paragraph.field_ept_stats_item_number\";s:10:\"field_name\";s:27:\"field_ept_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9bab1d24-d574-48e2-8d0e-4ab68fb47d98\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IMNMgfxAACwo5FdbEzobs2cmUZRx-IryVkWAVFd6jPc\";}s:2:\"id\";s:35:\"paragraph.field_ept_stats_item_text\";s:10:\"field_name\";s:25:\"field_ept_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tabs',_binary 'a:17:{s:4:\"uuid\";s:36:\"79fcf2b8-c7f0-45ad-b0c1-f2032eef3896\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NMqcA7Fqw60GbpdVeUtmztxo2zdXkrGvZx8twbTDDeU\";}s:2:\"id\";s:24:\"paragraph.field_ept_tabs\";s:10:\"field_name\";s:14:\"field_ept_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"14901660-c7de-459b-8e6b-6065e1894829\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mkRqIh2Wq5dPyqwbNdS4O7366xpiXfnEqoCKO_Dxil8\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_block\";s:10:\"field_name\";s:19:\"field_ept_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_content',_binary 'a:17:{s:4:\"uuid\";s:36:\"87c56ad4-62d6-4644-86c1-680e4755ff8b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"options\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fKb1I7aWTTDXPpSXxFasd3Do_zu03KEABHYH6l26zZU\";}s:2:\"id\";s:31:\"paragraph.field_ept_tab_content\";s:10:\"field_name\";s:21:\"field_ept_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"list_string\";s:8:\"settings\";a:2:{s:14:\"allowed_values\";a:4:{i:0;a:2:{s:5:\"value\";s:4:\"text\";s:5:\"label\";s:4:\"Text\";}i:1;a:2:{s:5:\"value\";s:4:\"page\";s:5:\"label\";s:4:\"Page\";}i:2;a:2:{s:5:\"value\";s:5:\"block\";s:5:\"label\";s:5:\"Block\";}i:3;a:2:{s:5:\"value\";s:5:\"views\";s:5:\"label\";s:5:\"Views\";}}s:23:\"allowed_values_function\";s:0:\"\";}s:6:\"module\";s:7:\"options\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_page',_binary 'a:17:{s:4:\"uuid\";s:36:\"dd8a6a77-dce1-4167-81fc-78b560cda129\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HG0HGpRQXhX56PVuj3x5C5jDc-vtEneALavRoeN1CvM\";}s:2:\"id\";s:28:\"paragraph.field_ept_tab_page\";s:10:\"field_name\";s:18:\"field_ept_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"node\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"843571d5-1f13-41be-91d6-4a2cdc24036d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-LqQ-u0-ZIOFFNbSXCCLceO2nHJcofY3jorF2Bo_oOs\";}s:2:\"id\";s:28:\"paragraph.field_ept_tab_text\";s:10:\"field_name\";s:18:\"field_ept_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"75781815-4f60-47eb-bdc4-255e273d1add\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jmZoEFoCrYRXWTQoBNH-lk2Jtzlrk1QgYJW-ZwiojjU\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_title\";s:10:\"field_name\";s:19:\"field_ept_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"text\";s:8:\"settings\";a:1:{s:10:\"max_length\";i:255;}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_views',_binary 'a:17:{s:4:\"uuid\";s:36:\"0210aa9b-f809-485d-9dc9-01d5b19a7a97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yuhCLkHFy1lOVHdkbi-9gSbiwW6Cz9cKfJdJaYwK_Pk\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_views\";s:10:\"field_name\";s:19:\"field_ept_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"e76f4c36-a02a-4c1e-b34f-cecbd30657dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7r3ygKhgvLH2hBQgQ6uizJgLea8q4TUMhKv9AysHhVw\";}s:2:\"id\";s:24:\"paragraph.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad3c2c1b-78c7-400a-a114-8f5a64daf409\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XenLJeS9-3QAxnei6iPwJsGOprgjG7bUCwDd60onVWw\";}s:2:\"id\";s:25:\"paragraph.field_ept_tiles\";s:10:\"field_name\";s:15:\"field_ept_tiles\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"c84089e9-ca27-4ede-81db-501ab243fe10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LTIRUfdCjzSopVuoQqk229l5haSvo7JDJ2W9r1MheDo\";}s:2:\"id\";s:31:\"paragraph.field_ept_tiles_image\";s:10:\"field_name\";s:21:\"field_ept_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"62135f80-efc0-4ec3-883a-ce4ccfe66aaa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ca5c5aWMZPNjvFUQqM813ltjPOGiBvCBP1o5N8IrcOM\";}s:2:\"id\";s:30:\"paragraph.field_ept_tiles_link\";s:10:\"field_name\";s:20:\"field_ept_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"095f6e1d-c38c-4e36-824d-929e502f2c16\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K1TV7SR5GOPQTJv3GF_zAIsJciKLKB5xd_eo3WUc5HA\";}s:2:\"id\";s:30:\"paragraph.field_ept_tiles_text\";s:10:\"field_name\";s:20:\"field_ept_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a21fa265-c368-46f8-b0bf-ccd4251290bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fWLTZKbXw0jB-UFCqh6l4jRNvxOPFhGWVUKUjcIHfEg\";}s:2:\"id\";s:31:\"paragraph.field_ept_tiles_title\";s:10:\"field_name\";s:21:\"field_ept_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"d142f67c-eb14-402b-8d63-83e817038f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjnRL-vwDWFKmoYTCU9jkwjIlui_gNnOJnIwnLo9m2k\";}s:2:\"id\";s:25:\"paragraph.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"30383ff9-015d-4872-a3cb-3c814a4683f6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WUq7ljAeKbQ5WQGxUm1FFT157H56wcSHSihAGR-RPhc\";}s:2:\"id\";s:25:\"paragraph.field_ept_video\";s:10:\"field_name\";s:15:\"field_ept_video\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_videos_and_images',_binary 'a:17:{s:4:\"uuid\";s:36:\"fb3b02a6-684b-4508-8b49-e87fa4e916c1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P8bQebl9F2OCnDtVw7LFuwUlmGfUGA7HLJaYolmUgpU\";}s:2:\"id\";s:37:\"paragraph.field_ept_videos_and_images\";s:10:\"field_name\";s:27:\"field_ept_videos_and_images\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_views_view',_binary 'a:17:{s:4:\"uuid\";s:36:\"8622c9ec-6687-4349-af19-885f22d99285\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GjkDxormsrh0OTX-iAPBLiJLIDg3h8b7yPlpgyt-kM\";}s:2:\"id\";s:30:\"paragraph.field_ept_views_view\";s:10:\"field_name\";s:20:\"field_ept_views_view\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_webform_form',_binary 'a:17:{s:4:\"uuid\";s:36:\"a88d5b44-1516-4b8b-96a9-776c192940bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PpYNq6QObTDp2wWrcCdc7DcYdgeYKcySPhoxN3JbQ0c\";}s:2:\"id\";s:32:\"paragraph.field_ept_webform_form\";s:10:\"field_name\";s:22:\"field_ept_webform_form\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_webform_popup_form',_binary 'a:17:{s:4:\"uuid\";s:36:\"5c2ba04c-75d7-42c4-b482-67caddfd5348\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0JLSwQyxgVansS3j_MWcmzVVNlzTh7AvepEBcn10Cyk\";}s:2:\"id\";s:38:\"paragraph.field_ept_webform_popup_form\";s:10:\"field_name\";s:28:\"field_ept_webform_popup_form\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"233edf85-6a6a-473c-933a-1a6a9015993a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:2:\"id\";s:17:\"user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1nMi90W6YQxKzZAgJQw7Ag9U4JrsEUwkomF0lhvbIM\";}s:12:\"field_prefix\";s:6:\"field_\";}'),('','file.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bwjZB1IjEYbppgZT3g7YW_5h_LDZYNa3DaDEfWX82U\";}s:11:\"description\";a:2:{s:4:\"type\";s:9:\"textfield\";s:6:\"length\";i:128;}s:4:\"icon\";a:1:{s:9:\"directory\";s:23:\"core/modules/file/icons\";}s:35:\"make_unused_managed_files_temporary\";b:0;s:21:\"filename_sanitization\";a:6:{s:13:\"transliterate\";b:0;s:18:\"replace_whitespace\";b:0;s:24:\"replace_non_alphanumeric\";b:0;s:22:\"deduplicate_separators\";b:0;s:9:\"lowercase\";b:0;s:21:\"replacement_character\";s:1:\"-\";}}'),('','file_mdm.file_metadata_plugin.getimagesize',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o53U_2I-21Es-9iqxeUMDRcRxN0spL1OiHuAVQhh2oI\";}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','file_mdm.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fOx6TBj_84WfX_a6JhuWiPQ-twAjHykvYsTvJAKbZsE\";}s:14:\"metadata_cache\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}s:22:\"missing_file_log_level\";i:3;}'),('','file_mdm_exif.file_metadata_plugin.exif',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u0ZqkNrnyVSnHXGBP0zlKY9dP1ZARzJZ9VSovzU_eDg\";}s:7:\"ifd_map\";a:5:{i:0;a:2:{s:4:\"type\";i:0;s:7:\"aliases\";a:3:{i:0;s:1:\"0\";i:1;s:4:\"IFD0\";i:2;s:4:\"Main\";}}i:1;a:2:{s:4:\"type\";i:1;s:7:\"aliases\";a:3:{i:0;s:1:\"1\";i:1;s:4:\"IFD1\";i:2;s:9:\"Thumbnail\";}}s:4:\"Exif\";a:2:{s:4:\"type\";i:2;s:7:\"aliases\";a:1:{i:0;s:4:\"Exif\";}}s:3:\"GPS\";a:2:{s:4:\"type\";i:3;s:7:\"aliases\";a:1:{i:0;s:3:\"GPS\";}}s:16:\"Interoperability\";a:2:{s:4:\"type\";i:4;s:7:\"aliases\";a:2:{i:0;s:16:\"Interoperability\";i:1;s:7:\"Interop\";}}}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','file_mdm_font.file_metadata_plugin.font',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o53U_2I-21Es-9iqxeUMDRcRxN0spL1OiHuAVQhh2oI\";}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','filter.format.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"9ffd8de5-5d95-4675-941e-b6205d96c828\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:6:\"editor\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mclCbTlJwWJORez4Y1eX2MqA0aGjSMAoJb3TaBABcK8\";}s:4:\"name\";s:10:\"Basic HTML\";s:6:\"format\";s:10:\"basic_html\";s:6:\"weight\";i:-9;s:7:\"filters\";a:6:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:7;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:243:\"<br> <p> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id> <cite> <dl> <dt> <dd> <a hreflang href> <blockquote cite> <ul type> <ol start type> <strong> <em> <code> <li> <img src alt data-entity-uuid data-entity-type height width data-caption data-align>\";s:16:\"filter_html_help\";b:0;s:20:\"filter_html_nofollow\";b:0;}}s:24:\"filter_html_image_secure\";a:5:{s:2:\"id\";s:24:\"filter_html_image_secure\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}}}'),('','filter.format.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"5837f230-16d1-4857-8f42-39560aa7f6bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:32:\"core.entity_view_mode.media.full\";}s:6:\"module\";a:2:{i:0;s:6:\"editor\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpZysv3RHJjhYzq7O_q5q8mVlHdrSzKELmXyiX6RtV0\";}s:4:\"name\";s:9:\"Full HTML\";s:6:\"format\";s:9:\"full_html\";s:6:\"weight\";i:-10;s:7:\"filters\";a:7:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:0;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:38:\"<span class=\"title-prefix white-text\">\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:20:\"filter_htmlcorrector\";a:5:{s:2:\"id\";s:20:\"filter_htmlcorrector\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}s:11:\"media_embed\";a:5:{s:2:\"id\";s:11:\"media_embed\";s:8:\"provider\";s:5:\"media\";s:6:\"status\";b:1;s:6:\"weight\";i:100;s:8:\"settings\";a:3:{s:17:\"default_view_mode\";s:7:\"default\";s:18:\"allowed_view_modes\";a:2:{s:7:\"default\";s:7:\"default\";s:4:\"full\";s:4:\"full\";}s:19:\"allowed_media_types\";a:3:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";s:5:\"video\";s:5:\"video\";}}}}}'),('','filter.format.plain_text',_binary 'a:9:{s:4:\"uuid\";s:36:\"e7b49ea5-e3d9-43a7-9355-811016606856\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JLMwODO0epnA_H-jFlH9ezVfa5YBJniRv3MmLqYNl_Q\";}s:4:\"name\";s:10:\"Plain text\";s:6:\"format\";s:10:\"plain_text\";s:6:\"weight\";i:-7;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:18:\"filter_html_escape\";a:5:{s:2:\"id\";s:18:\"filter_html_escape\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:0:{}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.format.restricted_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"b26630f8-bc66-410b-9271-2fd35673a39c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QiKqQS_YGAT3Qr4vaAgZICJknm-MGCzt_xBAMqg-tRM\";}s:4:\"name\";s:15:\"Restricted HTML\";s:6:\"format\";s:15:\"restricted_html\";s:6:\"weight\";i:-8;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:149:\"<a href hreflang> <em> <strong> <cite> <blockquote cite> <code> <ul type> <ol start type> <li> <dl> <dt> <dd> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id>\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.format.webform_default',_binary 'a:9:{s:4:\"uuid\";s:36:\"3692adcd-2f32-40f4-8ab0-3369f24cb8e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EeKp_M4Oid3erARiAam9rsgBKR91uEnFkEP3aZS2ol8\";}s:4:\"name\";s:31:\"Webform (Default) - DO NOT EDIT\";s:6:\"format\";s:15:\"webform_default\";s:6:\"weight\";i:100;s:7:\"filters\";a:0:{}}'),('','filter.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiPjM3WdB__ruFA7B6TLwni_UcZbmek5G4b2dxQItxA\";}s:15:\"fallback_format\";s:10:\"plain_text\";s:27:\"always_show_fallback_choice\";b:0;}'),('','gin.settings',_binary 'a:17:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ug4-rUG_KE9H5v1RaDLLpkSZsu70E9HnJp6sqFfjvHk\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:1;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:19:\"preset_accent_color\";s:4:\"blue\";s:18:\"preset_focus_color\";s:3:\"gin\";s:15:\"enable_darkmode\";s:1:\"0\";s:15:\"classic_toolbar\";s:7:\"classic\";s:26:\"secondary_toolbar_frontend\";b:1;s:18:\"high_contrast_mode\";b:0;s:12:\"accent_color\";s:0:\"\";s:11:\"focus_color\";s:0:\"\";s:14:\"layout_density\";s:7:\"default\";s:23:\"show_description_toggle\";b:0;s:24:\"show_user_theme_settings\";b:0;s:21:\"sticky_action_buttons\";b:0;}'),('','glightbox.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5G059LQS_7DV7oGUpxVTPM0aWtunW7bvDpRkgeb0KtE\";}s:6:\"custom\";a:17:{s:8:\"activate\";i:0;s:11:\"open_effect\";s:4:\"zoom\";s:12:\"close_effect\";s:4:\"zoom\";s:12:\"slide_effect\";s:5:\"slide\";s:5:\"width\";s:3:\"98%\";s:6:\"height\";s:3:\"98%\";s:11:\"videosWidth\";s:5:\"960px\";s:22:\"close_on_outside_click\";b:1;s:9:\"more_text\";s:8:\"See more\";s:11:\"more_length\";i:60;s:13:\"desc_position\";s:6:\"bottom\";s:4:\"loop\";b:0;s:8:\"zoomable\";b:1;s:9:\"draggable\";b:1;s:7:\"preload\";b:1;s:15:\"autoplay_videos\";b:1;s:16:\"autofocus_videos\";b:0;}s:8:\"advanced\";a:2:{s:12:\"unique_token\";i:0;s:16:\"compression_type\";s:8:\"minified\";}}'),('','image.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-yDFHbqNfpe-Srg4sdCSqaosCl2D8uwyEY5esF8gEw\";}s:13:\"preview_image\";s:29:\"core/modules/image/sample.png\";s:26:\"allow_insecure_derivatives\";b:0;s:20:\"suppress_itok_output\";b:0;}'),('','image.style.ept_gallery_image',_binary 'a:8:{s:4:\"uuid\";s:36:\"96327273-04cd-4db7-9889-976db88ae72b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"image_effects\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1Q9XGhzUPbe1wp53fxzN8EbXYFVVXfNTiWQshZB1x-o\";}s:4:\"name\";s:17:\"ept_gallery_image\";s:5:\"label\";s:17:\"EPT Gallery Image\";s:7:\"effects\";a:2:{s:36:\"5a3cbdd5-32d1-49cd-a00f-bbc716cc09ef\";a:4:{s:4:\"uuid\";s:36:\"5a3cbdd5-32d1-49cd-a00f-bbc716cc09ef\";s:2:\"id\";s:24:\"image_effects_set_canvas\";s:6:\"weight\";i:-8;s:4:\"data\";a:4:{s:11:\"canvas_size\";s:5:\"exact\";s:12:\"canvas_color\";s:9:\"#FFFFFFFF\";s:5:\"exact\";a:5:{s:5:\"width\";s:3:\"365\";s:6:\"height\";s:3:\"265\";s:9:\"placement\";s:13:\"center-center\";s:8:\"x_offset\";i:0;s:8:\"y_offset\";i:0;}s:8:\"relative\";a:4:{s:4:\"left\";i:0;s:5:\"right\";i:0;s:3:\"top\";i:0;s:6:\"bottom\";i:0;}}}s:36:\"7237f375-b695-4dca-8e1a-88b52b0437ea\";a:4:{s:4:\"uuid\";s:36:\"7237f375-b695-4dca-8e1a-88b52b0437ea\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:-9;s:4:\"data\";a:3:{s:5:\"width\";i:365;s:6:\"height\";i:265;s:7:\"upscale\";b:0;}}}}'),('','image.style.ept_quote_image',_binary 'a:8:{s:4:\"uuid\";s:36:\"8ad0f8e1-bf91-4861-b98d-bd4757ce19fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R8OkUD1v3lvqA1ihlprDbuQcs3MJp_s2N37cfrJuul8\";}s:4:\"name\";s:15:\"ept_quote_image\";s:5:\"label\";s:15:\"EPT Quote Image\";s:7:\"effects\";a:1:{s:36:\"c7e1a3e5-c5e1-4f6b-92f2-525a6f9ca013\";a:4:{s:4:\"uuid\";s:36:\"c7e1a3e5-c5e1-4f6b-92f2-525a6f9ca013\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:530;s:6:\"height\";N;s:7:\"upscale\";b:1;}}}}'),('','image.style.ept_slick_slider_card',_binary 'a:8:{s:4:\"uuid\";s:36:\"d5e3c8ee-d135-4d9b-87f8-3983d8804dd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TLssjGEnnOFSTHjAehxDElobDdWsdzT8XjjY2Ru_ZTQ\";}s:4:\"name\";s:21:\"ept_slick_slider_card\";s:5:\"label\";s:21:\"EPT Slick Slider card\";s:7:\"effects\";a:1:{s:36:\"55a5d05a-911b-44f6-8154-26bf4d5f89a2\";a:4:{s:4:\"uuid\";s:36:\"55a5d05a-911b-44f6-8154-26bf4d5f89a2\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:6:\"anchor\";s:13:\"center-center\";}}}}'),('','image.style.ept_video_and_image_gallery',_binary 'a:8:{s:4:\"uuid\";s:36:\"c7167138-d49d-4235-8671-ee7f0d2d2b21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VijhP4To3EdFocRuOjCdr8vV8fPomTYloLASZEYa0pc\";}s:4:\"name\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:27:\"EPT Video and Image gallery\";s:7:\"effects\";a:1:{s:36:\"dd219b2f-d95b-480c-83e9-b9b81fe45c90\";a:4:{s:4:\"uuid\";s:36:\"dd219b2f-d95b-480c-83e9-b9b81fe45c90\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:360;s:6:\"anchor\";s:13:\"center-center\";}}}}'),('','image.style.large',_binary 'a:8:{s:4:\"uuid\";s:36:\"1d081002-40ce-4508-b331-45087f55f851\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDR2BOewa2UFH9yG4tVvrGxEVv8U7LQo-RLkJhFpERs\";}s:4:\"name\";s:5:\"large\";s:5:\"label\";s:16:\"Large (480×480)\";s:7:\"effects\";a:2:{s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";a:4:{s:4:\"uuid\";s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:480;s:7:\"upscale\";b:0;}}s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";a:4:{s:4:\"uuid\";s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.media_library',_binary 'a:8:{s:4:\"uuid\";s:36:\"dce163df-e6d0-4a19-be9f-835d8fb9ad19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FxMdscEA4aDH0KPM73HIZtVn3zIAgC1kQ3CkBw26HYs\";}s:4:\"name\";s:13:\"media_library\";s:5:\"label\";s:34:\"Media Library thumbnail (220×220)\";s:7:\"effects\";a:2:{s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";a:4:{s:4:\"uuid\";s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";a:4:{s:4:\"uuid\";s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.medium',_binary 'a:8:{s:4:\"uuid\";s:36:\"cc99d86c-9cb9-4913-9000-8ea5ef978940\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dlar76VBuGj5iMGTruB_uMZX8VbivXt9_QLemaG2q4E\";}s:4:\"name\";s:6:\"medium\";s:5:\"label\";s:17:\"Medium (220×220)\";s:7:\"effects\";a:2:{s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";a:4:{s:4:\"uuid\";s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";a:4:{s:4:\"uuid\";s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.thumbnail',_binary 'a:8:{s:4:\"uuid\";s:36:\"45c23df0-c353-4723-86c7-ddfc29333553\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BgeBV-xOFINMsz-y2thm45EGesj6bRM6DTLZ6ce3V9I\";}s:4:\"name\";s:9:\"thumbnail\";s:5:\"label\";s:20:\"Thumbnail (100×100)\";s:7:\"effects\";a:2:{s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";a:4:{s:4:\"uuid\";s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:100;s:6:\"height\";i:100;s:7:\"upscale\";b:0;}}s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";a:4:{s:4:\"uuid\";s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.wide',_binary 'a:8:{s:4:\"uuid\";s:36:\"7407b366-d102-42ad-8d9b-28fc84ce386e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XHh3ATMH7z4ljwmzdndM47qNMkgLnoYsP98rGxVgCOw\";}s:4:\"name\";s:4:\"wide\";s:5:\"label\";s:11:\"Wide (1090)\";s:7:\"effects\";a:2:{s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";a:4:{s:4:\"uuid\";s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:1090;s:6:\"height\";N;s:7:\"upscale\";b:0;}}s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";a:4:{s:4:\"uuid\";s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image_effects.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eaXmaPSud65p-XhTwMIL9vKETD9zR3qNOMMa5EUuoNw\";}s:14:\"color_selector\";a:2:{s:9:\"plugin_id\";s:10:\"html_color\";s:15:\"plugin_settings\";a:1:{s:10:\"html_color\";a:0:{}}}s:14:\"image_selector\";a:2:{s:9:\"plugin_id\";s:5:\"basic\";s:15:\"plugin_settings\";a:1:{s:5:\"basic\";a:0:{}}}s:13:\"font_selector\";a:2:{s:9:\"plugin_id\";s:5:\"basic\";s:15:\"plugin_settings\";a:1:{s:5:\"basic\";a:0:{}}}}'),('','layout_paragraphs.modal_settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z9zmTNfo1bY0sbqYp1OAvqSynu_DXDRdJoZhi7oiS0I\";}s:5:\"width\";s:3:\"90%\";s:6:\"height\";s:4:\"auto\";s:10:\"autoresize\";b:1;}'),('','layout_paragraphs.settings',_binary 'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HBy2Jf-2HHsgvIjldhAl07r9vuy879dsx6Cm_LpbPrw\";}s:21:\"show_paragraph_labels\";i:0;s:18:\"show_layout_labels\";i:0;s:25:\"paragraph_behaviors_label\";s:9:\"Behaviors\";s:28:\"paragraph_behaviors_position\";i:-99;s:13:\"empty_message\";s:21:\"No components to add.\";}'),('','media.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WCFqLQAxMw1weToDJEhfnW1Z-iOF7cqMdL8X7YTFxBA\";}s:13:\"icon_base_uri\";s:28:\"public://media-icons/generic\";s:13:\"iframe_domain\";N;s:20:\"oembed_providers_url\";s:33:\"https://oembed.com/providers.json\";s:14:\"standalone_url\";b:0;}'),('','media.type.audio',_binary 'a:13:{s:4:\"uuid\";s:36:\"6a011382-b41c-428b-bec3-c2acb1a0b347\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJw8n6Tk2tO3ZysuEeGR1gZa1yRffaZzR4t0Q7iNurs\";}s:2:\"id\";s:5:\"audio\";s:5:\"label\";s:5:\"Audio\";s:11:\"description\";s:28:\"A locally hosted audio file.\";s:6:\"source\";s:10:\"audio_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_audio_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.document',_binary 'a:13:{s:4:\"uuid\";s:36:\"f7d4d4ed-07f1-4c0e-add0-5205dca6bb2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_D9q3XSnP6ik9we9UuoTvZsQKPuYNp_G9PfwVtWzgnQ\";}s:2:\"id\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:44:\"An uploaded file or document, such as a PDF.\";s:6:\"source\";s:4:\"file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:20:\"field_media_document\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.image',_binary 'a:13:{s:4:\"uuid\";s:36:\"0bf0a6ff-42d0-4443-95d9-32bb21b3d878\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Qope5wG7HUpV0tPOBMtDI_GZkHFcF1Xj4hgD9Cu_hM\";}s:2:\"id\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:36:\"Use local images for reusable media.\";s:6:\"source\";s:5:\"image\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:17:\"field_media_image\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.remote_video',_binary 'a:13:{s:4:\"uuid\";s:36:\"d833ee62-0e66-41f9-bc64-0ee184be48b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hIBTnDGgDKnCiP6HUZm1m7600DHUEpC6FN3LQ4sUgZ4\";}s:2:\"id\";s:12:\"remote_video\";s:5:\"label\";s:12:\"Remote video\";s:11:\"description\";s:46:\"A remotely hosted video from YouTube or Vimeo.\";s:6:\"source\";s:12:\"oembed:video\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:3:{s:12:\"source_field\";s:24:\"field_media_oembed_video\";s:20:\"thumbnails_directory\";s:44:\"public://oembed_thumbnails/[date:custom:Y-m]\";s:9:\"providers\";a:2:{i:0;s:7:\"YouTube\";i:1;s:5:\"Vimeo\";}}s:9:\"field_map\";a:1:{s:5:\"title\";s:4:\"name\";}}'),('','media.type.video',_binary 'a:13:{s:4:\"uuid\";s:36:\"f37b6fcf-a1f5-41c8-ad6b-ab36d7822130\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzgvcRgZHltqWf8hBmttoWh95tCJoPL25lPq9YSIRsY\";}s:2:\"id\";s:5:\"video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:28:\"A locally hosted video file.\";s:6:\"source\";s:10:\"video_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_video_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media_library.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3gQsCnZELUjUUqHk8SSh8bXnx7TZwN95vctAeVJG60\";}s:11:\"advanced_ui\";b:0;}'),('','menu_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SqMarzIjxC3F8dZo9FEOxfqDKD_sdW1tbcFTV1BA2zU\";}s:24:\"override_parent_selector\";b:0;}'),('','node.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W0cgFPhPJ3gAdqm06-az48BLf5MVcoZVS0HdByoofi0\";}s:15:\"use_admin_theme\";b:1;}'),('','node.type.article',_binary 'a:13:{s:4:\"uuid\";s:36:\"9597cbd8-ec71-47b6-98f5-c2eeebffff0e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"menu_ui\";}}s:20:\"third_party_settings\";a:1:{s:7:\"menu_ui\";a:2:{s:15:\"available_menus\";a:1:{i:0;s:4:\"main\";}s:6:\"parent\";s:5:\"main:\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fe3N1uqaAyyKJbVkqT-btXy3t98puW8GCRD822xjl10\";}s:4:\"name\";s:7:\"Article\";s:4:\"type\";s:7:\"article\";s:11:\"description\";s:89:\"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),('','node.type.page',_binary 'a:12:{s:4:\"uuid\";s:36:\"e24a8178-cabf-4c12-8439-99829f4ce10e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"i0snV8Wj--OkRW12UdachUiYiz3FbeMwHu_pZYfzKLc\";}s:4:\"name\";s:10:\"Basic page\";s:4:\"type\";s:4:\"page\";s:11:\"description\";s:77:\"Use <em>basic pages</em> for your static content, such as an \'About us\' page.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),('','olivero.settings',_binary 'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1TswGK46jyu77aIM7Z-0JVQs5bxHmo-gtgrvrQGMXxc\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:0;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:0;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:22:\"mobile_menu_all_widths\";i:0;s:22:\"site_branding_bg_color\";s:7:\"default\";s:18:\"base_primary_color\";s:7:\"#1b9ae4\";}'),('','paragraphs.paragraphs_type.ept_accordion',_binary 'a:11:{s:4:\"uuid\";s:36:\"3252260c-9d6c-4095-8836-d9e0aaa25dc6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7pqqqPfYwBkkvx32K8x5QoezX6vxHdseC3YV0ajDLEI\";}s:2:\"id\";s:13:\"ept_accordion\";s:5:\"label\";s:17:\"EPT Accordion/FAQ\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:41:\"Extra Paragraph Type (EPT): Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_accordion_section',_binary 'a:11:{s:4:\"uuid\";s:36:\"4290efa9-ba8f-4d75-8ae5-02743a3c35f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fmkcpDXAJK73b4nzzBnj4rVGpuHiDLrUxBK6rbvbQMY\";}s:2:\"id\";s:21:\"ept_accordion_section\";s:5:\"label\";s:35:\"EPT Accordion section / FAQ section\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:46:\"Accordion or FAQ section for EPT Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_basic_button',_binary 'a:11:{s:4:\"uuid\";s:36:\"29db5768-3c25-444b-84f5-1a0ab0ba6377\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gzUQpZ2WLaq6cYbIJG9au02yBTA2Hi4xUPtwlz0CRhU\";}s:2:\"id\";s:16:\"ept_basic_button\";s:5:\"label\";s:16:\"EPT Basic Button\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:39:\"Extra Paragraph Type (EPT) Basic Button\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_block',_binary 'a:11:{s:4:\"uuid\";s:36:\"698fe7c4-0789-4365-b3ce-d8bbd2d7d879\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hSup62OW-6glALkcPyijfub_HXz0FNzEQuWRhyhtdXk\";}s:2:\"id\";s:9:\"ept_block\";s:5:\"label\";s:9:\"EPT Block\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Block\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_bootstrap_button',_binary 'a:11:{s:4:\"uuid\";s:36:\"ffeadf94-a846-4eeb-af7e-504e5b867d19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4txRVN0PevwIGZwVEjxCxQoHq3fJGXNtgncbg5k5JDA\";}s:2:\"id\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:20:\"EPT Bootstrap Button\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:44:\"Extra Paragraph Type (EPT): Bootstrap Button\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_cards',_binary 'a:11:{s:4:\"uuid\";s:36:\"09477678-6921-49a1-a83f-aa21d8c811e4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O5-AP0c7q_30fQrLxjgjT1f3vqE1eDPHYVEJS53hyPQ\";}s:2:\"id\";s:9:\"ept_cards\";s:5:\"label\";s:9:\"EPT Cards\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:37:\"Extra Paragraph Type (EPT): EPT Cards\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_carousel',_binary 'a:11:{s:4:\"uuid\";s:36:\"0f8caf80-346b-4e13-bb09-4c47aafab045\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E7xdcbl_-Um-sC9AVRpej77V2ILldHA3_zXTVVCz1sY\";}s:2:\"id\";s:12:\"ept_carousel\";s:5:\"label\";s:12:\"EPT Carousel\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_carousel_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"07a0dbc7-10e5-4ae6-897e-e0a112e89e81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YtKbftJ20RlhAbMlxwbbttKpDr7oOd_NrNquqRUyXK8\";}s:2:\"id\";s:17:\"ept_carousel_item\";s:5:\"label\";s:17:\"EPT Carousel Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:30:\"Carousel item for EPT Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_columns',_binary 'a:11:{s:4:\"uuid\";s:36:\"e359103e-fb7d-4814-b51e-5b6eb0bf50cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fmkytBjjMOfcRpE_qi-piB3B8O6AiLkllwZyK_sI7Gw\";}s:2:\"id\";s:11:\"ept_columns\";s:5:\"label\";s:23:\"EPT Columns / Container\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_countdown',_binary 'a:11:{s:4:\"uuid\";s:36:\"d468b305-ccc4-4dd1-827a-5ac37883f188\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BqPVlvdHbcXEIez6BBufo--6hdhOwAkO8rjIkAK5jq4\";}s:2:\"id\";s:13:\"ept_countdown\";s:5:\"label\";s:13:\"EPT Countdown\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:37:\"Extra Paragraph Type (EPT): Countdown\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_counter',_binary 'a:11:{s:4:\"uuid\";s:36:\"fb9a64bf-58bb-4e29-a23f-83bc70d9958c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Seed1ZP-O7N7haFpWM63DgrcW90m0L3mwRpNqOVCvms\";}s:2:\"id\";s:11:\"ept_counter\";s:5:\"label\";s:11:\"EPT Counter\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:66:\"Adds Counter with coffee cups, projects, case studies number, etc.\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_counter_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"8fca0905-ad07-4e5a-b80e-a842bece8ab5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1DUe53zhmyI3hSvz4PGQ9EcXk8A47wdqyIrDi3aJmo8\";}s:2:\"id\";s:16:\"ept_counter_item\";s:5:\"label\";s:16:\"EPT Counter Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:64:\"Counter Items to be used inside of Paragraph Type: \"EPT Counter\"\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_cta',_binary 'a:11:{s:4:\"uuid\";s:36:\"5a3625a2-f528-429b-8415-b0b1eface1d4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-6Ujd6Cr-x8TD472fJ9SX66k2Pn7_uw07fVQWq1DXQk\";}s:2:\"id\";s:7:\"ept_cta\";s:5:\"label\";s:24:\"EPT Call to Action (CTA)\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:48:\"Extra Paragraph Type (EPT): Call to Action (CTA)\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_hero',_binary 'a:11:{s:4:\"uuid\";s:36:\"ced6180f-b154-47b8-a7b7-61647c71db48\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kps1UJbRPEF2GuSjDQDJFWWG5EZ6qTHII92BJxLlwTk\";}s:2:\"id\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"EPT Hero\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): EPT Hero\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_image',_binary 'a:11:{s:4:\"uuid\";s:36:\"f1d6ed2b-6a40-4f21-930f-5cd318945855\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GEIZEGHO5Mf_kO9Yek21HvRO-j_2fbPepBSsr35U_zY\";}s:2:\"id\";s:9:\"ept_image\";s:5:\"label\";s:9:\"EPT Image\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Image\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"ec405efa-b146-4a07-abc8-d507909706f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fQ2CW1Vm9f_8Xi0V4exsAGpv8RdV6Ptm-cjffg9lPyM\";}s:2:\"id\";s:17:\"ept_image_gallery\";s:5:\"label\";s:17:\"EPT Image Gallery\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:41:\"Extra Paragraph Type (EPT): Image Gallery\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_micromodal',_binary 'a:11:{s:4:\"uuid\";s:36:\"3188911c-48a1-42f6-8342-f2b8eb94edff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OvFmHRYOT8js98yougS_zy_ICFqOce54ziNcxoCbTq8\";}s:2:\"id\";s:14:\"ept_micromodal\";s:5:\"label\";s:14:\"EPT Micromodal\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:38:\"Extra Paragraph Type (EPT): Micromodal\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_quote',_binary 'a:11:{s:4:\"uuid\";s:36:\"e7cc4707-218e-4bb9-bcbe-65d47620375d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zd4SMxSGtEMXFqSse2TdY999VhcjYnraQj7qnFhHo6Q\";}s:2:\"id\";s:9:\"ept_quote\";s:5:\"label\";s:9:\"EPT Quote\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Quote\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slick_slider',_binary 'a:11:{s:4:\"uuid\";s:36:\"d1c90790-b1df-488f-a53e-bc8c9bbe2e9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kF1ktW9usSGMpm4KK6xObCSXk1ZU-mWLNc7N1B5IN3A\";}s:2:\"id\";s:16:\"ept_slick_slider\";s:5:\"label\";s:16:\"EPT Slick Slider\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:40:\"Extra Paragraph Type (EPT): Slick Slider\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slick_slider_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"41cd1373-cca3-46dc-87a0-714c7a1489bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JzEHRSTeS_5k9aQaMIQiZssckNv0akkT0UHkl8qu8TE\";}s:2:\"id\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:21:\"EPT Slick Slider Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:0:\"\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slideshow',_binary 'a:11:{s:4:\"uuid\";s:36:\"b702ec4e-c33c-4331-beff-6b5b7107cc9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KeaY7LvgW90UqWSbJG60DfX1q0Up4566bgG8p85U12U\";}s:2:\"id\";s:13:\"ept_slideshow\";s:5:\"label\";s:13:\"EPT Slideshow\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:37:\"Extra Paragraph Type (EPT): Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slideshow_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"9953b7d8-252b-4d78-9b63-08418e206990\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yz4xVMckzLbuIuqcq5CLDr2LZyc6GPHhiCkw_ygR1cM\";}s:2:\"id\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:18:\"EPT Slideshow Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:35:\"Slideshow section for EPT Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_stats',_binary 'a:11:{s:4:\"uuid\";s:36:\"6838ec7f-c8a4-4325-97a7-1021f1dfe5d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KAQ05Ri6j17FmntgY7SCHOgGFRtUqdJWrNKlBxVsBsI\";}s:2:\"id\";s:9:\"ept_stats\";s:5:\"label\";s:9:\"EPT Stats\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Stats\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_stats_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"1f202608-b028-44b4-99c0-312ebcadcb47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Be2-EmGyo2-KDBpxotaDl8GmJCgv5EKdsZNMXdWrM10\";}s:2:\"id\";s:14:\"ept_stats_item\";s:5:\"label\";s:14:\"EPT Stats Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:34:\"Stats Item for EPT Stats paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tabs',_binary 'a:11:{s:4:\"uuid\";s:36:\"d64be736-43ad-47c5-a174-0a5e19f4b24a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zt6Y01DpCpOfI3LIolOc9xk6SptdAkHJlZkEp2KhkRQ\";}s:2:\"id\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"EPT Tabs\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:32:\"Extra Paragraph Type (EPT): Tabs\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tabs_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"9e15e91a-5c5e-4c79-9e75-1386629a7208\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VixuGFI2mBIwt085I9X7vz9dq9H8dh0Bb20u-pT90X8\";}s:2:\"id\";s:13:\"ept_tabs_item\";s:5:\"label\";s:13:\"EPT Tabs Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:31:\"Tab item for EPT Tabs paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_text',_binary 'a:11:{s:4:\"uuid\";s:36:\"c76a9833-ec98-4fe9-9268-c55ecc6606f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fSKAEY0p1DQvC6AE_TEi0RWHmjahL13tHQTb3WVaVik\";}s:2:\"id\";s:8:\"ept_text\";s:5:\"label\";s:8:\"EPT Text\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:31:\"Extra Paragraph Type (EPT) Text\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tiles',_binary 'a:11:{s:4:\"uuid\";s:36:\"e1accd8b-a614-4659-8cf0-f0563effdfeb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AHyDurvHt3xm3keCp8kZSod4iM7Y1JlF1O0xivGQ7As\";}s:2:\"id\";s:9:\"ept_tiles\";s:5:\"label\";s:9:\"EPT Tiles\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tiles_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"ae747fa8-05f4-441a-92bd-76441012dd9b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q4wQLWgQpxsrvWKawlFVZnqSn8qCCPj4IOKPpn7O8Po\";}s:2:\"id\";s:14:\"ept_tiles_item\";s:5:\"label\";s:14:\"EPT Tiles Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:21:\"Section for EPT Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video',_binary 'a:11:{s:4:\"uuid\";s:36:\"e50ad18b-eff8-48a4-9102-1709c8e0bb40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FU0WTLBDpLuC53lMEuAJGnwlX6sqt0SutW7q0c-btWQ\";}s:2:\"id\";s:9:\"ept_video\";s:5:\"label\";s:9:\"EPT Video\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Video\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video_and_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"dee3b2de-c5f8-4d3f-8564-0f6f24943f59\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z1YuWpAuPdJe7k9v-67rALbAapgyfzwTi2cQLvreLbo\";}s:2:\"id\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:27:\"EPT Video and Image Gallery\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:51:\"Extra Paragraph Type (EPT): Video and Image Gallery\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"1a4319ac-f841-4112-85c5-2a1ab06cb4d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OrMDgoP5KHK7xLNhKOohBVVuqmo2J4D3YWH3a3Od1Dw\";}s:2:\"id\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EPT Video and Image gallery item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:62:\"Video and Image item for EPT Video and Image Gallery paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_views',_binary 'a:11:{s:4:\"uuid\";s:36:\"7ac88ec9-7da9-488c-ac70-492b5bcfde08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JfY6zZuA9cpemb4U-YVMX2rzmT1pm_Pr1YpT7xaSxeA\";}s:2:\"id\";s:9:\"ept_views\";s:5:\"label\";s:9:\"EPT Views\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Views\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_webform',_binary 'a:11:{s:4:\"uuid\";s:36:\"95226011-0193-4ef6-9af2-4f1df3457cea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kSie3I1RcWKYzZSDRYkUpzG0jh8nhFlbo3wJd18lKVc\";}s:2:\"id\";s:11:\"ept_webform\";s:5:\"label\";s:11:\"EPT Webform\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:35:\"Extra Paragraph Type (EPT): Webform\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_webform_popup',_binary 'a:11:{s:4:\"uuid\";s:36:\"3e07ff02-27c6-4d10-98ae-318109a50f36\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Nfgfk4KcPZeTvLQf2BL053XNap0XyXoq1BIWTixbwrg\";}s:2:\"id\";s:17:\"ept_webform_popup\";s:5:\"label\";s:17:\"EPT Webform Popup\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:41:\"Extra Paragraph Type (EPT): Webform Popup\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7eR0sk71Eol86r_A7BMqn5_46wzenh5J1O5vZRCGKv8\";}s:16:\"show_unpublished\";b:1;}'),('','search.page.help_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"98a9a1a8-dfbe-4b36-a295-131fa324015e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RZ-bcSekNSsAbIPLW7Gmyd3uUjIOSrPvnb8RCCZYJm8\";}s:2:\"id\";s:11:\"help_search\";s:5:\"label\";s:4:\"Help\";s:4:\"path\";s:4:\"help\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"help_search\";s:13:\"configuration\";a:0:{}}'),('','search.page.node_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"be4dce05-236d-43ce-aa4d-b829b5c9d8a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"97tvtzGOa8_flb22CzSjgtm_YkiGMHvEBO-6q2K9V_U\";}s:2:\"id\";s:11:\"node_search\";s:5:\"label\";s:7:\"Content\";s:4:\"path\";s:4:\"node\";s:6:\"weight\";i:-10;s:6:\"plugin\";s:11:\"node_search\";s:13:\"configuration\";a:1:{s:8:\"rankings\";a:0:{}}}'),('','search.page.user_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"02f73622-4ae8-479b-bddb-6b507d943c7b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k3aUaZXGDuhkek2TZIee0PApOPTvYZLadziekdyHA5A\";}s:2:\"id\";s:11:\"user_search\";s:5:\"label\";s:5:\"Users\";s:4:\"path\";s:4:\"user\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"user_search\";s:13:\"configuration\";a:0:{}}'),('','search.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hvVxL1G-ZCxaq32IZws0YsfuhvaDiQE_np-0g35KjUk\";}s:12:\"and_or_limit\";i:7;s:12:\"default_page\";s:11:\"node_search\";s:5:\"index\";a:4:{s:10:\"cron_limit\";i:100;s:11:\"overlap_cjk\";b:1;s:17:\"minimum_word_size\";i:3;s:11:\"tag_weights\";a:12:{s:2:\"h1\";i:25;s:2:\"h2\";i:18;s:2:\"h3\";i:15;s:2:\"h4\";i:14;s:2:\"h5\";i:9;s:2:\"h6\";i:6;s:1:\"u\";i:3;s:1:\"b\";i:3;s:1:\"i\";i:3;s:6:\"strong\";i:3;s:2:\"em\";i:3;s:1:\"a\";i:10;}}s:7:\"logging\";b:0;}'),('','shortcut.set.default',_binary 'a:7:{s:4:\"uuid\";s:36:\"2b149d5c-a926-4de8-aae7-b7f45081ccab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U5VlGjd_SfV0Qm_EfnaynOfc549cNscFAx48JfYoMRI\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";}'),('','system.action.comment_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"6f753574-2b6f-4e3a-87fd-04f281182309\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpBH8OmL4sdesCdeZLsW8KOutB5gkbreWJbfjhfFKaQ\";}s:2:\"id\";s:21:\"comment_delete_action\";s:5:\"label\";s:14:\"Delete comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:28:\"entity:delete_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c8e0fba3-a9ea-40bc-9886-42d52bf69615\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C00dyL_W_5M0nFlgUB3lWUTUs96jn51Jw1MLHVEHZD0\";}s:2:\"id\";s:22:\"comment_publish_action\";s:5:\"label\";s:15:\"Publish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:29:\"entity:publish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f2a7400a-fd44-4225-906e-c04f6f5f8944\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lfyE_snmvfg_EQ3VDyhUtGAXgmqtEiqa46I3bTMg8DU\";}s:2:\"id\";s:19:\"comment_save_action\";s:5:\"label\";s:12:\"Save comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:26:\"entity:save_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"a09349ec-38d9-4ee0-b772-074a9b406491\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tWOIjSMobEWOFZddMkNqb9JySbOVwE1diC6NRqcfLTk\";}s:2:\"id\";s:24:\"comment_unpublish_action\";s:5:\"label\";s:17:\"Unpublish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:31:\"entity:unpublish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f8932ff6-cc40-43b7-9cd8-7fefb06c44cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FrZy1tmuXJcOxhXlBoI1Hsnen5TT-9OCC1iolWH84go\";}s:2:\"id\";s:19:\"media_delete_action\";s:5:\"label\";s:12:\"Delete media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:26:\"entity:delete_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"5ee77a15-afb1-4e0c-bd3b-3e462abe568d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nh83qNNrmWE-CDdHz2MdFOAk60T9mzv3R-MaKfZR2jw\";}s:2:\"id\";s:20:\"media_publish_action\";s:5:\"label\";s:13:\"Publish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:27:\"entity:publish_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"9b97ffc0-0ba9-48fc-9e78-a23777ef7ff4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VVyUA6PIaVeGtcIbgEWqJ6SYDiJdReBeojFswURFpKs\";}s:2:\"id\";s:17:\"media_save_action\";s:5:\"label\";s:10:\"Save media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:24:\"entity:save_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"59cad6a4-a038-45d4-98e9-6ace07f80050\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CsK6TseQ2DatEbZgbd30swOlZ28_HHwAESU2LvEnWq0\";}s:2:\"id\";s:22:\"media_unpublish_action\";s:5:\"label\";s:15:\"Unpublish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:29:\"entity:unpublish_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"455e72bb-d5c2-4233-8fae-fe874a5aecde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t43OqwzP3CTbcAagSsWKNy6KwMm_zShXo3c4-So6rQg\";}s:2:\"id\";s:18:\"node_delete_action\";s:5:\"label\";s:14:\"Delete content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"entity:delete_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_sticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"2003aeb9-8fd3-4006-8c7f-9129bef1a808\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sOb26JSy3fGpWkvR0WYN6_hMqj_6d1rvbvrkzp1yya0\";}s:2:\"id\";s:23:\"node_make_sticky_action\";s:5:\"label\";s:19:\"Make content sticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"node_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_unsticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"0640984c-3787-4c25-8abe-073f6ff633cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lDM9mvIGAu8Sw8rt-uCO4Sr7yX5VPrDPxYcawkbKd6k\";}s:2:\"id\";s:25:\"node_make_unsticky_action\";s:5:\"label\";s:21:\"Make content unsticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"node_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_promote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"93459360-b66a-4249-92eb-59a0d4b9e585\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N0RDBTqiK4dKoN4p4oW2j0SGWycdHyALUe9M-Ofp89U\";}s:2:\"id\";s:19:\"node_promote_action\";s:5:\"label\";s:29:\"Promote content to front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:19:\"node_promote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"6e3d2ae5-f68b-4adb-8345-78fe6e53c835\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2B9uF8NL5gutNKSdPRAhhAsDWFZZG1PJOBmx0aBGd_0\";}s:2:\"id\";s:19:\"node_publish_action\";s:5:\"label\";s:15:\"Publish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:26:\"entity:publish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7ff39d45-7ef9-4e69-a87b-aa71ae0d4343\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LhdsoZPL_pFas2fjaAWue4zvrQ_tEVofLYtcNec-JGM\";}s:2:\"id\";s:16:\"node_save_action\";s:5:\"label\";s:12:\"Save content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"entity:save_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpromote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"29499598-fb70-43f6-a160-d2522304d4e7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JBptjnfuOMtsdKygklXxoOgeOCTMtQxlkymjnnj-cC0\";}s:2:\"id\";s:21:\"node_unpromote_action\";s:5:\"label\";s:30:\"Remove content from front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"node_unpromote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"34872d09-0b48-4090-a401-75dc2bd3358d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C7X8h9FWlwkQ9y5mnU2JzgaZICAdc6HFbPVbhvjlAYE\";}s:2:\"id\";s:21:\"node_unpublish_action\";s:5:\"label\";s:17:\"Unpublish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:28:\"entity:unpublish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"8509e01a-1fe0-4d2b-80fe-6292c7281beb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DoVt_VGgVLcDD4XmVbSFzr0K17SJy9imFiYusKkJBgY\";}s:2:\"id\";s:28:\"taxonomy_term_publish_action\";s:5:\"label\";s:21:\"Publish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:35:\"entity:publish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"07d84567-f6ce-480c-94fe-71f48ce157b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z2sNRM3ECa7FPCGnSNje_9SmZJQgwhD_6fG_L4Mr8zI\";}s:2:\"id\";s:30:\"taxonomy_term_unpublish_action\";s:5:\"label\";s:23:\"Unpublish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:37:\"entity:unpublish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_add_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"080a7d5c-2fda-47ed-b9aa-be9cb07b6d2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:34:\"user_add_role_action.administrator\";s:5:\"label\";s:50:\"Add the Administrator role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_add_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"e33f0ef8-e9df-400f-b24b-60c0f3497768\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:35:\"user_add_role_action.content_editor\";s:5:\"label\";s:51:\"Add the Content editor role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_block_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ec45edef-e3ef-44f8-87d8-428346ac0579\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DyypzTfThX10FFQw-399qPfEbLLyrhXgQrKPVsmAoJ4\";}s:2:\"id\";s:22:\"user_block_user_action\";s:5:\"label\";s:26:\"Block the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:22:\"user_block_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_cancel_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7317c388-dffd-422a-b041-7ef8597810b4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nvrL9bFilzBvm2bjO9rQnFDpBA7dBBUjShSSt6NS-DU\";}s:2:\"id\";s:23:\"user_cancel_user_action\";s:5:\"label\";s:35:\"Cancel the selected user account(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_cancel_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_remove_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"a3ac7eaa-5ae2-4c20-abbb-79b198424e39\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:37:\"user_remove_role_action.administrator\";s:5:\"label\";s:55:\"Remove the Administrator role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_remove_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"daca732c-22a4-42c1-a3c8-d54dae2a458c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:38:\"user_remove_role_action.content_editor\";s:5:\"label\";s:56:\"Remove the Content editor role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_unblock_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"879c5dbe-c854-4240-b44b-cc9946b7e95b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SPsUXsR3Rc8d1y3gewzaAKWa1ncea_ywXX3f7LTn7k0\";}s:2:\"id\";s:24:\"user_unblock_user_action\";s:5:\"label\";s:28:\"Unblock the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:24:\"user_unblock_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_archive_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ec2616be-d2d8-4d45-b01a-1ae5413b4160\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OmnschvBLb9ZJn0iVyBd2odf8U8Nt0INjRbRMixZw9U\";}s:2:\"id\";s:22:\"webform_archive_action\";s:5:\"label\";s:15:\"Archive webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:22:\"webform_archive_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_close_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"a0a0e6d5-cedc-45c4-8750-df65a9373a61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dl-1T9PDkraB7MyMUjTJAioPEx6UNvIB9gqmnB1CRkk\";}s:2:\"id\";s:20:\"webform_close_action\";s:5:\"label\";s:13:\"Close webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:20:\"webform_close_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"0619fb37-5dfd-48c9-b73d-4fce7ba4215b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e1bCTp0ryXZZtnS9nlVAbtoWz3-8fmbNlqKY3GHzbsM\";}s:2:\"id\";s:21:\"webform_delete_action\";s:5:\"label\";s:14:\"Delete webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:21:\"webform_delete_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_open_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"70329b07-23bf-43c7-837b-913d499e1542\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AK83C-dOZEPruvi6GbkuhihWLnO4VtrbesqSC6izf4o\";}s:2:\"id\";s:19:\"webform_open_action\";s:5:\"label\";s:12:\"Open webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:19:\"webform_open_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"3d61837a-a6e2-456c-856f-a7adae28d2bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBnl4vapW7sy5bRi7TcF-ueJnvz7aZNLif95ifvhfTQ\";}s:2:\"id\";s:32:\"webform_submission_delete_action\";s:5:\"label\";s:17:\"Delete submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:32:\"webform_submission_delete_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_lock_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"a37fdd16-b916-42c7-a79a-e453486aa560\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MKmZlPRk3OJKNcYdYxSeZGQUh7LMah6MRShfkzch4bk\";}s:2:\"id\";s:35:\"webform_submission_make_lock_action\";s:5:\"label\";s:15:\"Lock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:35:\"webform_submission_make_lock_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_sticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"d787e419-708a-4026-aecb-296369189495\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mPWBT52fKHyINRl9S3cCWFxY3rKbwkIRxaK6sIA26oo\";}s:2:\"id\";s:37:\"webform_submission_make_sticky_action\";s:5:\"label\";s:20:\"Star/flag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_unlock_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c5c70bbf-efd5-4883-84bc-42f7d15ffaff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"begZ0-RmTzO_zDAwEKA2lKvtGYw1vbFOzbQOJzUbZX0\";}s:2:\"id\";s:37:\"webform_submission_make_unlock_action\";s:5:\"label\";s:17:\"Unlock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_unlock_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_unsticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"d1026225-bc14-481f-8e03-d69eb659f34d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4gTFiUsdp7gw6yWUlDbKFEasZLCgXWWCmm7eJejay0\";}s:2:\"id\";s:39:\"webform_submission_make_unsticky_action\";s:5:\"label\";s:24:\"Unstar/unflag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:39:\"webform_submission_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_unarchive_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f1bc7d4d-af95-4d2e-86fe-74ba836349ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aqi5Ftlnhe9KyOowpK7CanEvJMBBo8xAR1dA99bKOuc\";}s:2:\"id\";s:24:\"webform_unarchive_action\";s:5:\"label\";s:15:\"Restore webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:24:\"webform_unarchive_action\";s:13:\"configuration\";a:0:{}}'),('','system.advisories',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x0FuQ_7Cg81mSDQwG028_Z0CjH3R9ib5IDlHeV2BbAo\";}s:7:\"enabled\";b:1;s:14:\"interval_hours\";i:6;}'),('','system.cron',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f3yToH8v8EaBZU0NFFw2qR8ogSCuWVmQaN0hpYR1BD8\";}s:9:\"threshold\";a:2:{s:20:\"requirements_warning\";i:172800;s:18:\"requirements_error\";i:1209600;}s:7:\"logging\";b:1;}'),('','system.date',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IVsFTD1mvR2NGBP_1myt9kFIFmGepH4PyaN5aQBYpno\";}s:9:\"first_day\";i:0;s:7:\"country\";a:1:{s:7:\"default\";N;}s:8:\"timezone\";a:2:{s:7:\"default\";s:15:\"Europe/Belgrade\";s:4:\"user\";a:3:{s:12:\"configurable\";b:1;s:7:\"default\";i:0;s:4:\"warn\";b:0;}}}'),('','system.diff',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1WanmaEhxW_vM8_5Ktsdntj8MaO9UBHXg0lN603PsWM\";}s:7:\"context\";a:2:{s:13:\"lines_leading\";i:2;s:14:\"lines_trailing\";i:2;}}'),('','system.feature_flags',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYyVj1FtPGV40Cf65YDVTUIc7YgLH6trXlotuevfs2I\";}s:16:\"linkset_endpoint\";b:0;}'),('','system.file',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mguGHCYb9Dw5EcpfjwoShGV1Vjkbz3QuPRCLfxiye-g\";}s:22:\"allow_insecure_uploads\";b:0;s:14:\"default_scheme\";s:6:\"public\";s:21:\"temporary_maximum_age\";i:21600;}'),('','system.image',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"durWHaKeBaq4d9Wpi4RqwADj1OufDepcnJuhVLmKN24\";}s:7:\"toolkit\";s:2:\"gd\";}'),('','system.image.gd',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNXaHfkJJUThHeF0nvkoXyPLRrKYGxgHRjORvT4F5rQ\";}s:12:\"jpeg_quality\";i:75;}'),('','system.logging',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u3-njszl92FaxjrCMiq0yDcjAfcdx72w1zT1O9dx6aA\";}s:11:\"error_level\";s:4:\"hide\";}'),('','system.mail',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5PvD9swkqWUeHkabdvbJ2SQqdhrzjkCT21wtD4BLfk4\";}s:9:\"interface\";a:2:{s:7:\"default\";s:8:\"php_mail\";s:7:\"webform\";s:16:\"webform_php_mail\";}s:10:\"mailer_dsn\";a:6:{s:6:\"scheme\";s:8:\"sendmail\";s:4:\"host\";s:7:\"default\";s:4:\"user\";N;s:8:\"password\";N;s:4:\"port\";N;s:7:\"options\";a:0:{}}}'),('','system.maintenance',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1SNdA25INsV5YjlgAJtfC-6AM8VcWe_00xneMLb2yFg\";}s:8:\"langcode\";s:2:\"en\";s:7:\"message\";s:93:\"@site is currently under maintenance. We should be back shortly. Thank you for your patience.\";}'),('','system.menu.account',_binary 'a:9:{s:4:\"uuid\";s:36:\"37d50e8a-b786-4ff3-a41f-5e41d67f88b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Bh81osDyUQ4wV0GgU_NdBNqkzM87sLxjaCdFj9mnw\";}s:2:\"id\";s:7:\"account\";s:5:\"label\";s:17:\"User account menu\";s:11:\"description\";s:40:\"Links related to the active user account\";s:6:\"locked\";b:1;}'),('','system.menu.admin',_binary 'a:9:{s:4:\"uuid\";s:36:\"cf474897-e948-4315-a183-5878deecdaf0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sapEi2YDGoI9yQIT_WgIV2vUdQ6DScH0V3fAyTadAL0\";}s:2:\"id\";s:5:\"admin\";s:5:\"label\";s:14:\"Administration\";s:11:\"description\";s:25:\"Administrative task links\";s:6:\"locked\";b:1;}'),('','system.menu.footer',_binary 'a:9:{s:4:\"uuid\";s:36:\"d761cbba-9ebe-4d52-96fc-79063bff0783\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7yrlW5z9zdg2eBucB2GPqXKSMQfH9lSRSO4DbWF7AFc\";}s:2:\"id\";s:6:\"footer\";s:5:\"label\";s:6:\"Footer\";s:11:\"description\";s:22:\"Site information links\";s:6:\"locked\";b:1;}'),('','system.menu.main',_binary 'a:9:{s:4:\"uuid\";s:36:\"4108c568-d39d-4283-8af4-4ce0601c49ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q2Ra3jfoIVk0f3SjxJX61byRQFVBAbpzYDQOiY-kno8\";}s:2:\"id\";s:4:\"main\";s:5:\"label\";s:15:\"Main navigation\";s:11:\"description\";s:18:\"Site section links\";s:6:\"locked\";b:1;}'),('','system.menu.tools',_binary 'a:9:{s:4:\"uuid\";s:36:\"6e91308b-4a52-440d-824d-e3b9fb3941e2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCM-vV1zzRaLHN18dqAR_CuGOj8AFJvTx7BKl_8Gcxc\";}s:2:\"id\";s:5:\"tools\";s:5:\"label\";s:5:\"Tools\";s:11:\"description\";s:39:\"User tool links, often added by modules\";s:6:\"locked\";b:1;}'),('','system.performance',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jtno5biznHZbrIgKwzq-ze-7XaQxLCGe6PeUOR7bRiQ\";}s:5:\"cache\";a:1:{s:4:\"page\";a:1:{s:7:\"max_age\";i:0;}}s:3:\"css\";a:2:{s:10:\"preprocess\";b:0;s:4:\"gzip\";b:1;}s:8:\"fast_404\";a:4:{s:7:\"enabled\";b:1;s:5:\"paths\";s:69:\"/\\.(?:txt|png|gif|jpe?g|css|js|ico|swf|flv|cgi|bat|pl|dll|exe|asp)$/i\";s:13:\"exclude_paths\";s:27:\"/\\/(?:styles|imagecache)\\//\";s:4:\"html\";s:162:\"<!DOCTYPE html><html><head><title>404 Not Found</title></head><body><h1>Not Found</h1><p>The requested URL \"@path\" was not found on this server.</p></body></html>\";}s:2:\"js\";a:2:{s:10:\"preprocess\";b:0;s:4:\"gzip\";b:1;}}'),('','system.rss',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MIpNzlG4gPunfS7vTCwUPum6QH3GUsEBMj-qS631Jw0\";}s:5:\"items\";a:1:{s:9:\"view_mode\";s:3:\"rss\";}}'),('','system.site',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ijfbzDTN4CbE7Sr-6ubWzy_t1vH4OtU1doNCLssVz-4\";}s:8:\"langcode\";s:2:\"en\";s:4:\"uuid\";s:36:\"78d4512f-043a-4ffe-b38d-c79b75c64b27\";s:4:\"name\";s:23:\"EPT Page Builder - Demo\";s:4:\"mail\";s:17:\"admin@example.com\";s:6:\"slogan\";s:0:\"\";s:4:\"page\";a:3:{i:403;s:0:\"\";i:404;s:0:\"\";s:5:\"front\";s:7:\"/node/1\";}s:18:\"admin_compact_mode\";b:0;s:17:\"weight_select_max\";i:100;s:16:\"default_langcode\";s:2:\"en\";s:17:\"mail_notification\";N;}'),('','system.theme',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJ529VM1gSIA_vgTy2PdiDvJuG0xhSxfQjCyl5WKlv4\";}s:5:\"admin\";s:3:\"gin\";s:7:\"default\";s:9:\"ept_light\";}'),('','system.theme.global',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KZiV2LB312xgJBphfq5BTjmp16xiR5KM8InBJ-pff7Y\";}s:7:\"favicon\";a:4:{s:8:\"mimetype\";s:24:\"image/vnd.microsoft.icon\";s:4:\"path\";s:0:\"\";s:3:\"url\";s:0:\"\";s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:3:{s:4:\"path\";s:0:\"\";s:3:\"url\";N;s:11:\"use_default\";b:1;}}'),('','taxonomy.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zKpaWT6cJc1tVQQaTqatGELaCqU_oyRym6zTl27Yias\";}s:20:\"maintain_index_table\";b:1;s:17:\"override_selector\";b:0;s:20:\"terms_per_page_admin\";i:100;}'),('','taxonomy.vocabulary.tags',_binary 'a:10:{s:4:\"uuid\";s:36:\"368fd9b7-ee40-4b51-8ac1-60f818b9f9f6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iTEzwrEQ_4JIb-OYGiqzyF2TmMgWyWayresXcWgwGWM\";}s:4:\"name\";s:4:\"Tags\";s:3:\"vid\";s:4:\"tags\";s:11:\"description\";s:61:\"Use tags to group articles on similar topics into categories.\";s:6:\"weight\";i:0;s:12:\"new_revision\";b:0;}'),('','tb_megamenu.menu_config.main__ept_light',_binary 'a:9:{s:4:\"uuid\";s:36:\"9a71f48f-4fa9-44ad-996b-21fe7ea77565\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}s:4:\"menu\";a:1:{i:0;s:4:\"main\";}}s:2:\"id\";s:15:\"main__ept_light\";s:4:\"menu\";s:4:\"main\";s:5:\"theme\";s:9:\"ept_light\";s:12:\"block_config\";s:120:\"{\"animation\":\"none\",\"duration\":400,\"delay\":200,\"style\":\"\",\"auto-arrow\":\"1\",\"always-show-submenu\":\"0\",\"number-columns\":1}\";s:11:\"menu_config\";s:707:\"{\"standard.front_page\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}},\"menu_link_content:d5043c53-9961-4a60-bb2a-a37bbaaa3961\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}},\"menu_link_content:addff990-0222-4099-9e61-5f98566f7f94\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}}}\";}'),('','text.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Bkewb77RBOK3_aXMPsp8p87gbc03NvmC5gBLzPl7hVA\";}s:22:\"default_summary_length\";i:600;}'),('','update.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xbYr66-g0FjNgVBkGypCuN46vBI2XHntXN1URawq1s4\";}s:5:\"check\";a:2:{s:19:\"disabled_extensions\";b:0;s:13:\"interval_days\";i:1;}s:5:\"fetch\";a:3:{s:3:\"url\";N;s:12:\"max_attempts\";i:2;s:7:\"timeout\";i:30;}s:12:\"notification\";a:2:{s:6:\"emails\";a:1:{i:0;s:17:\"admin@example.com\";}s:9:\"threshold\";s:3:\"all\";}}'),('','user.flood',_binary 'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UYfMzeP1S8jKm9PSvxf7nQNe8DsNS-3bc2WSNNXBQWs\";}s:8:\"uid_only\";b:0;s:8:\"ip_limit\";i:50;s:9:\"ip_window\";i:3600;s:10:\"user_limit\";i:5;s:11:\"user_window\";i:21600;}'),('','user.mail',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6CZIzFifRq3qbdq3n3nDpEOO4hWIQtKOAQNPvGNGKeM\";}s:8:\"langcode\";s:2:\"en\";s:14:\"cancel_confirm\";a:2:{s:7:\"subject\";s:67:\"Account cancellation request for [user:display-name] at [site:name]\";s:4:\"body\";s:376:\"[user:display-name]\n\nA request to cancel your account has been made at [site:name].\n\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\n\n[user:cancel-url]\n\nNOTE: The cancellation of your account is not reversible.\n\nThis link expires in one day and nothing will happen if it is not used.\n\n--  [site:name] team\";}s:14:\"password_reset\";a:2:{s:7:\"subject\";s:68:\"Replacement login information for [user:display-name] at [site:name]\";s:4:\"body\";s:407:\"[user:display-name],\n\nA request to reset the password for your account has been made at [site:name].\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it\'s not used.\n\n--  [site:name] team\";}s:22:\"register_admin_created\";a:2:{s:7:\"subject\";s:58:\"An administrator created an account for you at [site:name]\";s:4:\"body\";s:473:\"[user:display-name],\n\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:29:\"register_no_approval_required\";a:2:{s:7:\"subject\";s:54:\"Account details for [user:display-name] at [site:name]\";s:4:\"body\";s:447:\"[user:display-name],\n\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:25:\"register_pending_approval\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:288:\"[user:display-name],\n\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another email containing information about how to log in, set your password, and other details.\n\n--  [site:name] team\";}s:31:\"register_pending_approval_admin\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:64:\"[user:display-name] has applied for an account.\n\n[user:edit-url]\";}s:16:\"status_activated\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (approved)\";s:4:\"body\";s:462:\"[user:display-name],\n\nYour account at [site:name] has been activated.\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:account-name]\npassword: Your password\n\n--  [site:name] team\";}s:14:\"status_blocked\";a:2:{s:7:\"subject\";s:64:\"Account details for [user:display-name] at [site:name] (blocked)\";s:4:\"body\";s:89:\"[user:display-name],\n\nYour account on [site:name] has been blocked.\n\n--  [site:name] team\";}s:15:\"status_canceled\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (canceled)\";s:4:\"body\";s:90:\"[user:display-name],\n\nYour account on [site:name] has been canceled.\n\n--  [site:name] team\";}}'),('','user.role.administrator',_binary 'a:10:{s:4:\"uuid\";s:36:\"5f4748db-4b8a-4105-a888-23753782d022\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OeKGIkmZA_c-t6QLH81WNQx8gDCc1MRmxaTuQgxBByU\";}s:2:\"id\";s:13:\"administrator\";s:5:\"label\";s:13:\"Administrator\";s:6:\"weight\";i:3;s:8:\"is_admin\";b:1;s:11:\"permissions\";a:0:{}}'),('','user.role.anonymous',_binary 'a:10:{s:4:\"uuid\";s:36:\"eda565bf-dc62-4fa8-b48c-329d2d6fc492\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.restricted_html\";}s:6:\"module\";a:6:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:6:\"filter\";i:3;s:5:\"media\";i:4;s:6:\"search\";i:5;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6WavjUYXIegP9AAg2zXGx54MWIVoomC3SZhNiqe-Dyk\";}s:2:\"id\";s:9:\"anonymous\";s:5:\"label\";s:14:\"Anonymous user\";s:6:\"weight\";i:0;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:6:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:29:\"access site-wide contact form\";i:3;s:14:\"search content\";i:4;s:31:\"use text format restricted_html\";i:5;s:10:\"view media\";}}'),('','user.role.authenticated',_binary 'a:10:{s:4:\"uuid\";s:36:\"369ad726-b0da-4331-8cb0-56ab9af109d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"filter.format.basic_html\";i:1;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:8:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:4:\"file\";i:3;s:6:\"filter\";i:4;s:5:\"media\";i:5;s:6:\"search\";i:6;s:8:\"shortcut\";i:7;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFrlqjtkTfvY3RGccjJkPf1SGIfJ942IrxTLWAO4mgA\";}s:2:\"id\";s:13:\"authenticated\";s:5:\"label\";s:18:\"Authenticated user\";s:6:\"weight\";i:1;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:11:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:16:\"access shortcuts\";i:3;s:29:\"access site-wide contact form\";i:4;s:16:\"delete own files\";i:5;s:13:\"post comments\";i:6;s:14:\"search content\";i:7;s:21:\"skip comment approval\";i:8;s:26:\"use text format basic_html\";i:9;s:31:\"use text format webform_default\";i:10;s:10:\"view media\";}}'),('','user.role.content_editor',_binary 'a:10:{s:4:\"uuid\";s:36:\"e916801a-5024-47c1-b402-bb0bb1592d19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:17:\"node.type.article\";i:1;s:14:\"node.type.page\";i:2;s:24:\"taxonomy.vocabulary.tags\";}s:6:\"module\";a:9:{i:0;s:7:\"comment\";i:1;s:10:\"contextual\";i:2;s:4:\"file\";i:3;s:4:\"node\";i:4;s:4:\"path\";i:5;s:6:\"system\";i:6;s:8:\"taxonomy\";i:7;s:11:\"tb_megamenu\";i:8;s:7:\"toolbar\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e_wG1u7SrGaJbY2-Szgbgl-c8T3kdirU3uTNq2c_QJQ\";}s:2:\"id\";s:14:\"content_editor\";s:5:\"label\";s:14:\"Content editor\";s:6:\"weight\";i:2;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:24:{i:0;s:27:\"access administration pages\";i:1;s:23:\"access content overview\";i:2;s:23:\"access contextual links\";i:3;s:21:\"access files overview\";i:4;s:14:\"access toolbar\";i:5;s:22:\"administer tb_megamenu\";i:6;s:22:\"administer url aliases\";i:7;s:22:\"create article content\";i:8;s:19:\"create page content\";i:9;s:20:\"create terms in tags\";i:10;s:18:\"create url aliases\";i:11;s:24:\"delete article revisions\";i:12;s:26:\"delete own article content\";i:13;s:16:\"delete own files\";i:14;s:23:\"delete own page content\";i:15;s:21:\"delete page revisions\";i:16;s:24:\"edit own article content\";i:17;s:17:\"edit own comments\";i:18;s:21:\"edit own page content\";i:19;s:18:\"edit terms in tags\";i:20;s:20:\"revert all revisions\";i:21;s:18:\"view all revisions\";i:22;s:28:\"view own unpublished content\";i:23;s:29:\"view the administration theme\";}}'),('','user.settings',_binary 'a:9:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-htDFWUv1S4OlJMzta2nhFl4QbhJvu0D9xsJ-clxo-M\";}s:8:\"langcode\";s:2:\"en\";s:9:\"anonymous\";s:9:\"Anonymous\";s:11:\"verify_mail\";b:1;s:6:\"notify\";a:8:{s:14:\"cancel_confirm\";b:1;s:14:\"password_reset\";b:1;s:16:\"status_activated\";b:1;s:14:\"status_blocked\";b:0;s:15:\"status_canceled\";b:0;s:22:\"register_admin_created\";b:1;s:29:\"register_no_approval_required\";b:1;s:25:\"register_pending_approval\";b:1;}s:8:\"register\";s:23:\"visitors_admin_approval\";s:13:\"cancel_method\";s:17:\"user_cancel_block\";s:22:\"password_reset_timeout\";i:86400;s:17:\"password_strength\";b:1;}'),('','views.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8oDr9oPVb_ostrNnVV6V7VdphwoH_u-NqTS0u7SE7qc\";}s:17:\"display_extenders\";a:0:{}s:13:\"sql_signature\";b:0;s:2:\"ui\";a:3:{s:4:\"show\";a:7:{s:18:\"additional_queries\";b:0;s:15:\"advanced_column\";b:0;s:15:\"default_display\";b:0;s:22:\"performance_statistics\";b:0;s:19:\"preview_information\";b:1;s:9:\"sql_query\";a:2:{s:7:\"enabled\";b:0;s:5:\"where\";s:5:\"above\";}s:13:\"display_embed\";b:0;}s:19:\"always_live_preview\";b:1;s:24:\"exposed_filter_any_label\";s:7:\"old_any\";}s:22:\"field_rewrite_elements\";a:29:{s:3:\"div\";s:3:\"DIV\";s:4:\"span\";s:4:\"SPAN\";s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";s:2:\"h6\";s:2:\"H6\";s:1:\"p\";s:1:\"P\";s:6:\"header\";s:6:\"HEADER\";s:6:\"footer\";s:6:\"FOOTER\";s:7:\"article\";s:7:\"ARTICLE\";s:7:\"section\";s:7:\"SECTION\";s:5:\"aside\";s:5:\"ASIDE\";s:7:\"details\";s:7:\"DETAILS\";s:10:\"blockquote\";s:10:\"BLOCKQUOTE\";s:6:\"figure\";s:6:\"FIGURE\";s:7:\"address\";s:7:\"ADDRESS\";s:4:\"code\";s:4:\"CODE\";s:3:\"pre\";s:3:\"PRE\";s:3:\"var\";s:3:\"VAR\";s:4:\"samp\";s:4:\"SAMP\";s:3:\"kbd\";s:3:\"KBD\";s:6:\"strong\";s:6:\"STRONG\";s:2:\"em\";s:2:\"EM\";s:3:\"del\";s:3:\"DEL\";s:3:\"ins\";s:3:\"INS\";s:1:\"q\";s:1:\"Q\";s:1:\"s\";s:1:\"S\";}}'),('','views.view.archive',_binary 'a:13:{s:4:\"uuid\";s:36:\"f33400de-a3e8-4128-b4b9-8f10fc897a3f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"exIF08PTvYSK6tJCsAzBqMEKUBKIptPorMn74SVhevc\";}s:2:\"id\";s:7:\"archive\";s:5:\"label\";s:7:\"Archive\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:22:\"All content, by month.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:15:\"Monthly archive\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:2:{s:8:\"override\";b:1;s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:2:{s:10:\"sort_order\";s:4:\"desc\";s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:0;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:1:{s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"archive\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.block_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"f0a4d615-99cd-438c-a7fe-c2d84a594ee3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HfvTcWhiVuvxchoh4DjIkXhKkj9ow2TGgHkLHSvRLq8\";}s:2:\"id\";s:13:\"block_content\";s:5:\"label\";s:14:\"Content blocks\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:31:\"Find and manage content blocks.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:24:\"block_content_field_data\";s:10:\"base_field\";s:2:\"id\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:14:\"Content blocks\";s:6:\"fields\";a:4:{s:4:\"info\";a:37:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";N;s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:17:\"Block description\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Block type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access block library\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:2:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:38:\"There are no content blocks available.\";s:8:\"tokenize\";b:0;}s:27:\"block_content_listing_empty\";a:10:{s:2:\"id\";s:27:\"block_content_listing_empty\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:27:\"block_content_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:27:\"block_content_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:4:\"info\";a:16:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"info_op\";s:5:\"label\";s:17:\"Block description\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"info_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"info\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:10:\"Block type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"reusable\";a:16:{s:2:\"id\";s:8:\"reusable\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:8:\"reusable\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:8:\"reusable\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:4:\"info\";s:4:\"info\";s:4:\"type\";s:4:\"type\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:4:{s:4:\"info\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/block\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:6:\"Blocks\";s:11:\"description\";s:31:\"Create and edit content blocks.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:20:\"system.admin_content\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.comment',_binary 'a:13:{s:4:\"uuid\";s:36:\"e6cd565b-768b-47a9-b906-fe031ec4047e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"H6JHGXl97yOKmVaV62SoY1ki1tWVdyD44fgOkdmVyRM\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:8:\"Comments\";s:6:\"module\";s:7:\"comment\";s:11:\"description\";s:25:\"Find and manage comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:26:{s:5:\"title\";s:8:\"Comments\";s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:24:\"comment_unpublish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"next ›\";s:8:\"previous\";s:12:\"‹ previous\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"administer comments\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:17:\"comment_bulk_form\";s:17:\"comment_bulk_form\";s:7:\"subject\";s:7:\"subject\";s:3:\"uid\";s:3:\"uid\";s:9:\"entity_id\";s:9:\"entity_id\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:17:\"comment_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"subject\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"entity_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:1;s:13:\"use_more_text\";s:4:\"more\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:14:\"page_published\";a:6:{s:2:\"id\";s:14:\"page_published\";s:13:\"display_title\";s:18:\"Published comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:19:\"display_description\";s:30:\"The approved comments listing.\";s:15:\"display_comment\";s:0:\"\";s:13:\"exposed_block\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:21:\"admin/content/comment\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:8:\"Comments\";s:11:\"description\";s:18:\"Comments published\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:15:\"page_unapproved\";a:6:{s:2:\"id\";s:15:\"page_unapproved\";s:13:\"display_title\";s:19:\"Unapproved comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:8:{s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:22:\"comment_publish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:3:{s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:19:\"display_description\";s:32:\"The unapproved comments listing.\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:30:\"admin/content/comment/approval\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:19:\"Unapproved comments\";s:11:\"description\";s:19:\"Comments unapproved\";s:6:\"weight\";i:1;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}}}'),('','views.view.comments_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"b85b83ea-7ca6-4445-91d4-33ba3dff6403\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:7:\"comment\";i:1;s:4:\"node\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFOucxH8PAXDQ2kViCcAHgK-JMCcxVkpIMzD56EfpZo\";}s:2:\"id\";s:15:\"comments_recent\";s:5:\"label\";s:15:\"Recent comments\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:16:\"Recent comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:14:{s:5:\"title\";s:15:\"Recent comments\";s:6:\"fields\";a:2:{s:7:\"subject\";a:26:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:1:{s:4:\"type\";s:5:\"basic\";}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:15:\"access comments\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:2:{s:7:\"created\";a:12:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;}s:3:\"cid\";a:12:{s:2:\"id\";s:3:\"cid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"cid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"cid\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"cid\";}s:7:\"exposed\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:11:\"status_node\";a:10:{s:2:\"id\";s:11:\"status_node\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"node\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:2:{s:22:\"default_field_elements\";b:1;s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:4:\"node\";a:5:{s:2:\"id\";s:4:\"node\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"node\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:15:\"Recent comments\";s:14:\"block_category\";s:13:\"Lists (Views)\";s:5:\"allow\";a:1:{s:14:\"items_per_page\";b:1;}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content',_binary 'a:13:{s:4:\"uuid\";s:36:\"db9f543b-a00c-4765-a8dd-36dc8ebd091c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d7p-wwJZ_Wmz1gnvla9jDtRsjOaWAhPoIoW9w3vo4R4\";}s:2:\"id\";s:7:\"content\";s:5:\"label\";s:7:\"Content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:24:\"Find and manage content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:7:\"Content\";s:6:\"fields\";a:8:{s:14:\"node_bulk_form\";a:14:{s:2:\"id\";s:14:\"node_bulk_form\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:14:\"node_bulk_form\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:14:\"node_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"title\";a:17:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Content type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:17:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:17:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}}s:7:\"changed\";a:17:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:8:\"langcode\";a:37:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:14:\"field_language\";s:5:\"label\";s:8:\"Language\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:8:\"language\";s:8:\"settings\";a:2:{s:14:\"link_to_entity\";b:0;s:15:\"native_language\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:23:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:3:{s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:23:\"access content overview\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:5:\"title\";a:16:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:8:\"title_op\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:8:\"title_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:5:\"title\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:12:\"Content type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:12:\"status_extra\";a:9:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:6:\"expose\";a:2:{s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:10:{s:14:\"node_bulk_form\";s:14:\"node_bulk_form\";s:5:\"title\";s:5:\"title\";s:4:\"type\";s:4:\"type\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:7:\"changed\";s:7:\"changed\";s:9:\"edit_node\";s:9:\"edit_node\";s:11:\"delete_node\";s:11:\"delete_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";s:9:\"timestamp\";s:5:\"title\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:10:{s:14:\"node_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"title\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"delete_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:18:\"admin/content/node\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:23:\"Find and manage content\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"9dd1c55e-db52-4c19-aa0d-4c122baa71f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YqZN5rc7XDQcFcInc8wkzuaHJmC5YvirhTmDcrarT6M\";}s:2:\"id\";s:14:\"content_recent\";s:5:\"label\";s:14:\"Recent content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:15:\"Recent content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:22:{s:5:\"title\";s:14:\"Recent content\";s:6:\"fields\";a:2:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"More\";s:12:\"link_display\";s:1:\"0\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:1:{s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.files',_binary 'a:13:{s:4:\"uuid\";s:36:\"36db1296-d05c-4dd7-bda9-64d0981e2f85\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"blP1XdpU4RqVoA_8po7qnIokIbHB6DJt0lpilgY5ovM\";}s:2:\"id\";s:5:\"files\";s:5:\"label\";s:5:\"Files\";s:6:\"module\";s:4:\"file\";s:11:\"description\";s:22:\"Find and manage files.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:12:\"file_managed\";s:10:\"base_field\";s:3:\"fid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:5:\"Files\";s:6:\"fields\";a:9:{s:3:\"fid\";a:24:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:3:\"Fid\";s:7:\"exclude\";b:1;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"filename\";a:36:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"file_link\";s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:8:\"filemime\";a:25:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"MIME type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"file_filemime\";}s:8:\"filesize\";a:25:{s:2:\"id\";s:8:\"filesize\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filesize\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filesize\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Size\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"file_size\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:9:\"Temporary\";s:18:\"format_custom_true\";s:9:\"Permanent\";}}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Upload date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Changed date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:3:\"fid\";s:10:\"group_type\";s:3:\"sum\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:7:\"Used in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/content/files/usage/{{ fid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:1;s:20:\"format_plural_string\";s:21:\"1 place@count places\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access files overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No files available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:8:\"filename\";a:16:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:8:\"Filename\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filename_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filename\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"filemime\";a:16:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:9:\"MIME type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filemime_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filemime\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:11:\"file_status\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"status_op\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:3:\"fid\";s:3:\"fid\";s:8:\"filename\";s:8:\"filename\";s:8:\"filemime\";s:8:\"filemime\";s:8:\"filesize\";s:8:\"filesize\";s:6:\"status\";s:6:\"status\";s:7:\"created\";s:7:\"created\";s:7:\"changed\";s:7:\"changed\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:8:{s:3:\"fid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filename\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filemime\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:8:\"filesize\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:1;s:16:\"show_admin_links\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:14:\"Files overview\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:2:{s:5:\"pager\";b:1;s:13:\"relationships\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:0;}}s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/files\";s:4:\"menu\";a:6:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Files\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_2\";a:6:{s:2:\"id\";s:6:\"page_2\";s:13:\"display_title\";s:10:\"File usage\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:15:{s:5:\"title\";s:10:\"File usage\";s:6:\"fields\";a:4:{s:12:\"entity_label\";a:23:{s:2:\"id\";s:12:\"entity_label\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:12:\"entity_label\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"entity_label\";s:5:\"label\";s:6:\"Entity\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:14:\"link_to_entity\";b:1;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:11:\"Entity type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:6:\"module\";a:22:{s:2:\"id\";s:6:\"module\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:6:\"module\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:18:\"Registering module\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:9:\"Use count\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:0;s:20:\"format_plural_string\";s:8:\"1@count\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:5:\"empty\";a:0:{}s:9:\"arguments\";a:1:{s:3:\"fid\";a:22:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:8:\"file_fid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:46:\"File usage information for {{ arguments.fid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;}}s:7:\"filters\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:12:\"entity_label\";s:12:\"entity_label\";s:4:\"type\";s:4:\"type\";s:6:\"module\";s:6:\"module\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:12:\"entity_label\";s:4:\"info\";a:4:{s:12:\"entity_label\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:6:\"module\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:11:{s:5:\"empty\";b:0;s:5:\"title\";b:0;s:5:\"pager\";b:0;s:8:\"group_by\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:13:\"relationships\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:0;s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:27:\"admin/content/files/usage/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.frontpage',_binary 'a:13:{s:4:\"uuid\";s:36:\"899f634a-224d-4abf-ae01-81a9b3031896\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OEEnRQIjfIaCFRsz8U3VqDrE82ltQKlo8wNbQJRZXu0\";}s:2:\"id\";s:9:\"frontpage\";s:5:\"label\";s:9:\"Frontpage\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:39:\"All content promoted to the front page.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:0:\"\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:3:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:181:\"No front page content has been created yet.<br/>Follow the <a target=\"_blank\" href=\"https://www.drupal.org/docs/user_guide/en/index.html\">User Guide</a> to start building your site.\";s:8:\"tokenize\";b:0;}s:18:\"node_listing_empty\";a:10:{s:2:\"id\";s:18:\"node_listing_empty\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:18:\"node_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:18:\"node_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}s:5:\"title\";a:10:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"title\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:5:\"title\";s:8:\"Welcome!\";}}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:12:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:7:\"promote\";a:16:{s:2:\"id\";s:7:\"promote\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"promote\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"promote\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:3:\"rss\";}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"rss.xml\";s:14:\"sitename_title\";b:1;s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:28:\"languages:language_interface\";i:1;s:21:\"user.node_grants:view\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:4:\"node\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.glossary',_binary 'a:13:{s:4:\"uuid\";s:36:\"9a843b37-02d2-45c5-84e0-2cd85511ce42\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r-klgGeO4haVHqAwxW1HXZLzdzLSMUVC08OuTBrRh58\";}s:2:\"id\";s:8:\"glossary\";s:5:\"label\";s:8:\"Glossary\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:23:\"All content, by letter.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:6:\"fields\";a:3:{s:5:\"title\";a:24:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:36;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"default\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:0:{}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;s:7:\"columns\";a:3:{s:5:\"title\";s:5:\"title\";s:4:\"name\";s:4:\"name\";s:7:\"changed\";s:7:\"changed\";}s:7:\"default\";s:5:\"title\";s:4:\"info\";a:3:{s:5:\"title\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:4:\"name\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:7:\"changed\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:5:\"order\";s:3:\"asc\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"attachment_1\";a:6:{s:2:\"id\";s:12:\"attachment_1\";s:13:\"display_title\";s:10:\"Attachment\";s:14:\"display_plugin\";s:10:\"attachment\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:0;}}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:3:{s:14:\"items_per_page\";i:25;s:6:\"inline\";b:1;s:9:\"separator\";s:3:\" | \";}s:7:\"summary\";a:1:{s:6:\"format\";s:19:\"unformatted_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}s:8:\"displays\";a:2:{s:7:\"default\";s:7:\"default\";s:6:\"page_1\";s:6:\"page_1\";}s:17:\"inherit_arguments\";b:0;}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:8:\"glossary\";s:4:\"menu\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:8:\"Glossary\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.media',_binary 'a:13:{s:4:\"uuid\";s:36:\"7c06b5e5-ebff-4822-8688-54ce69b5a404\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kOTUk5XWeupgBOJuRRarCiDcFKVZcvaW-FT5MTzrML8\";}s:2:\"id\";s:5:\"media\";s:5:\"label\";s:5:\"Media\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:8:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:20:\"thumbnail__target_id\";a:37:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:5:\"media\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Media name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"bundle\";a:37:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"status\";a:37:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:10:\"Media name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:4:\"True\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:4:\"name\";s:4:\"name\";s:6:\"bundle\";s:6:\"bundle\";s:7:\"changed\";s:7:\"changed\";s:3:\"uid\";s:3:\"uid\";s:6:\"status\";s:6:\"status\";s:20:\"thumbnail__target_id\";s:20:\"thumbnail__target_id\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"bundle\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:15:\"media_page_list\";a:6:{s:2:\"id\";s:15:\"media_page_list\";s:13:\"display_title\";s:5:\"Media\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/media\";s:4:\"menu\";a:8:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Media\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.media_library',_binary 'a:13:{s:4:\"uuid\";s:36:\"74d36492-489a-4ac8-ab15-1c22af9e302b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:25:\"image.style.media_library\";}s:6:\"module\";a:4:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:13:\"media_library\";i:3;s:4:\"user\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9u9hwW-Q0-uQJz1vgenJTQhZGYN0FBZoOogwPD6kgkQ\";}s:2:\"id\";s:13:\"media_library\";s:5:\"label\";s:13:\"Media library\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:4:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:2:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:24;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"6, 12, 24, 48\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:13:\"Apply filters\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:3:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:12:\"Newest first\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:1;s:11:\"granularity\";s:6:\"second\";}s:4:\"name\";a:12:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:3:\"ASC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (A-Z)\";s:16:\"field_identifier\";s:4:\"name\";}s:7:\"exposed\";b:1;}s:6:\"name_1\";a:12:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (Z-A)\";s:16:\"field_identifier\";s:6:\"name_1\";}s:7:\"exposed\";b:1;}}s:7:\"filters\";a:5:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:17:\"Publishing status\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:9:\"Published\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:10:\"Media type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:10:\"Media type\";s:11:\"description\";N;s:10:\"identifier\";s:6:\"bundle\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:0:{}i:2;a:0:{}i:3;a:0:{}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:6:\"fields\";a:5:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"edit_media\";a:26:{s:2:\"id\";s:10:\"edit_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"edit_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:15:\"Edit {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:15:\"Edit {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"Edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:12:\"delete_media\";a:26:{s:2:\"id\";s:12:\"delete_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:12:\"delete_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:18:\"entity_link_delete\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:17:\"Delete {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:17:\"Delete {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:6:\"Delete\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:8:\"defaults\";a:1:{s:6:\"fields\";b:0;}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:24:\"admin/content/media-grid\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:22:\"url.query_args:sort_by\";i:5;s:4:\"user\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"widget\";a:6:{s:2:\"id\";s:6:\"widget\";s:13:\"display_title\";s:6:\"Widget\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:12:{s:6:\"fields\";a:2:{s:25:\"media_library_select_form\";a:23:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:7:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:19:\"display_description\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:26:\"admin/content/media-widget\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"widget_table\";a:6:{s:2:\"id\";s:12:\"widget_table\";s:13:\"display_title\";s:14:\"Widget (table)\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:3;s:15:\"display_options\";a:13:{s:6:\"fields\";a:5:{s:25:\"media_library_select_form\";a:9:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:10:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:13:\"media_library\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}}s:4:\"name\";a:10:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}}s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:20:\"media_field_revision\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}}s:7:\"changed\";a:10:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:2:{s:9:\"row_class\";s:85:\"media-library-item media-library-item--table js-media-library-item js-click-to-select\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:8:\"defaults\";a:9:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:32:\"admin/content/media-widget-table\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.taxonomy_term',_binary 'a:13:{s:4:\"uuid\";s:36:\"56651306-efed-4808-bbdc-d9cf02cff348\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:3:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KejdxDJQmx8SaO-t83OVekLw6ar4ldjmsJMGcotGxnQ\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:6:\"module\";s:8:\"taxonomy\";s:11:\"description\";s:45:\"Content belonging to a certain taxonomy term.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:10:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:11:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:3:\"tid\";a:22:{s:2:\"id\";s:3:\"tid\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:3:\"tid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:18:\"taxonomy_index_tid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:0:\"\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:19:\"{{ arguments.tid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:4:{s:7:\"bundles\";a:0:{}s:6:\"access\";b:1;s:9:\"operation\";s:4:\"view\";s:8:\"multiple\";i:0;}s:12:\"break_phrase\";b:0;s:9:\"add_table\";b:0;s:13:\"require_value\";b:0;s:17:\"reduce_duplicates\";b:0;}}s:7:\"filters\";a:2:{s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:14:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:1:{s:20:\"entity_taxonomy_term\";a:12:{s:2:\"id\";s:20:\"entity_taxonomy_term\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:20:\"entity_taxonomy_term\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"entity\";s:5:\"empty\";b:1;s:6:\"target\";s:23:\"{{ raw_arguments.tid }}\";s:9:\"view_mode\";s:4:\"full\";s:8:\"tokenize\";b:1;s:13:\"bypass_access\";b:0;}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:7:\"default\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:20:\"taxonomy/term/%/feed\";s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:15:\"taxonomy/term/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.user_admin_people',_binary 'a:13:{s:4:\"uuid\";s:36:\"66ac1092-d560-4cf9-a5d3-b1941a3311d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FFLg74mnzRE10lgg5fspPCZWLnIEcvCnJMlNzj8OEtw\";}s:2:\"id\";s:17:\"user_admin_people\";s:5:\"label\";s:6:\"People\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:25:{s:5:\"title\";s:6:\"People\";s:6:\"fields\";a:8:{s:14:\"user_bulk_form\";a:23:{s:2:\"id\";s:14:\"user_bulk_form\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:14:\"user_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:14:\"user_bulk_form\";s:5:\"label\";s:11:\"Bulk update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Username\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:7:\"Blocked\";s:18:\"format_custom_true\";s:6:\"Active\";}}s:15:\"roles_target_id\";a:24:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:5:\"label\";s:5:\"Roles\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:2:\"ul\";s:9:\"separator\";s:2:\", \";}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Member for\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:9:\"@interval\";s:11:\"past_format\";s:9:\"@interval\";s:11:\"granularity\";i:2;}}s:6:\"access\";a:26:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last access\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:4:\"mail\";a:37:{s:2:\"id\";s:4:\"mail\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"mail\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"mail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"basic_string\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:16:\"administer users\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:20:\"No people available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:7:\"filters\";a:6:{s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:22:\"Name or email contains\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"user\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:4:\"mail\";s:4:\"mail\";}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:6:\"Active\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:7:\"Blocked\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:15:\"roles_target_id\";a:15:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:18:\"roles_target_id_op\";s:5:\"label\";s:4:\"Role\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:18:\"roles_target_id_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"role\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:10:\"permission\";a:15:{s:2:\"id\";s:10:\"permission\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:10:\"permission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"user_permissions\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:13:\"permission_op\";s:5:\"label\";s:10:\"Permission\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:13:\"permission_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:10:\"permission\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"uid_raw\";a:15:{s:2:\"id\";s:7:\"uid_raw\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"uid_raw\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:7:\"numeric\";s:8:\"operator\";s:2:\"!=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:1:\"0\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:10:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:14:\"user_bulk_form\";s:14:\"user_bulk_form\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:3:\"rid\";s:3:\"rid\";s:7:\"created\";s:7:\"created\";s:6:\"access\";s:6:\"access\";s:9:\"edit_node\";s:9:\"edit_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";}s:7:\"default\";s:7:\"created\";s:4:\"info\";a:8:{s:14:\"user_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:3:\"rid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"access\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"more\";s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:15:\"display_comment\";s:0:\"\";s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:1:{s:16:\"show_admin_links\";b:0;}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:17:\"admin/people/list\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:4:\"List\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:6:\"People\";s:11:\"description\";s:45:\"Manage user accounts, roles, and permissions.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.watchdog',_binary 'a:13:{s:4:\"uuid\";s:36:\"25587939-259b-48aa-8c6c-dbd04aa5d800\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"dblog\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SR5P89f0vUTPC7WY2YpLAffkDx8-Ar8LKFfowVXeqNU\";}s:2:\"id\";s:8:\"watchdog\";s:5:\"label\";s:8:\"Watchdog\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:19:\"Recent log messages\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"watchdog\";s:10:\"base_field\";s:3:\"wid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:19:\"Recent log messages\";s:6:\"fields\";a:8:{s:7:\"nothing\";a:22:{s:2:\"id\";s:7:\"nothing\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"nothing\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"Icon\";s:9:\"plugin_id\";s:6:\"custom\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:4:\"icon\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:0;}s:3:\"wid\";a:22:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:3:\"WID\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"severity\";a:23:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"machine_name\";s:5:\"label\";s:8:\"Severity\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"machine_name\";b:0;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:9:\"timestamp\";a:25:{s:2:\"id\";s:9:\"timestamp\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:9:\"timestamp\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"label\";s:4:\"Date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:7:\"message\";a:23:{s:2:\"id\";s:7:\"message\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:7:\"message\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:13:\"dblog_message\";s:5:\"label\";s:7:\"Message\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/reports/dblog/event/{{ wid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:13:\"{{ message }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:56;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:1;s:4:\"trim\";b:1;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:1;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"replace_variables\";b:1;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"User\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"link\";a:22:{s:2:\"id\";s:4:\"link\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"link\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"dblog_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"access site reports\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:4:\"area\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:26:\"No log messages available.\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:26:\"No log messages available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:3:\"wid\";a:10:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"wid\";}s:7:\"exposed\";b:0;}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:4:\"type\";a:14:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"dblog_types\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"severity\";a:14:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"in_operator\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"severity_op\";s:5:\"label\";s:8:\"Severity\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"severity_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"severity\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:25:\"{{ type }} {{ severity }}\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:7:\"nothing\";s:7:\"nothing\";s:3:\"wid\";s:3:\"wid\";s:8:\"severity\";s:8:\"severity\";s:4:\"type\";s:4:\"type\";s:9:\"timestamp\";s:9:\"timestamp\";s:7:\"message\";s:7:\"message\";s:4:\"name\";s:4:\"name\";s:4:\"link\";s:4:\"link\";}s:7:\"default\";s:3:\"wid\";s:4:\"info\";a:8:{s:7:\"nothing\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:3:\"wid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:8:\"severity\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"message\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:4:\"link\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:0;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"User\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:11:\"admin-dblog\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/reports/dblog\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.webform_submissions',_binary 'a:13:{s:4:\"uuid\";s:36:\"38120747-e809-460c-aea2-fd8cea0574d7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"user\";i:1;s:7:\"webform\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uIuCYXi8Y6GTe4pKUxK2t9OjQEcrwvFJZFeitfnQ8Ys\";}s:2:\"id\";s:19:\"webform_submissions\";s:5:\"label\";s:19:\"Webform submissions\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:34:\"Default webform submissions views.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:18:\"webform_submission\";s:10:\"base_field\";s:3:\"sid\";s:7:\"display\";a:5:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:7:{s:14:\"items_per_page\";i:25;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:6:\"‹‹\";s:4:\"next\";s:6:\"››\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:23:\"5, 10, 25, 50, 100, 200\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"fields\";a:5:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:7:\"filters\";a:0:{}s:5:\"sorts\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:0;s:7:\"content\";s:34:\"Displaying @start - @end of @total\";s:9:\"plugin_id\";s:6:\"result\";}}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"No submissions available.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:5:{s:10:\"webform_id\";a:6:{s:2:\"id\";s:10:\"webform_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"webform_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:10:\"webform_id\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"entity_type\";a:6:{s:2:\"id\";s:11:\"entity_type\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"entity_type\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"entity_type\";s:9:\"plugin_id\";s:6:\"string\";}s:9:\"entity_id\";a:6:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"entity_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:6:\"string\";}s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"uid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:16:\"entity_target_id\";}s:8:\"in_draft\";a:22:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:14:\"items_per_page\";i:25;s:8:\"override\";b:0;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"numeric\";}}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"title\";s:19:\"Webform submissions\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:16:\"embed_administer\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:16:\"embed_administer\";s:13:\"display_title\";s:17:\"Embed: Administer\";s:8:\"position\";i:2;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:23:\"Administer submissions.\";s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:8:\"defaults\";a:6:{s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:29:\"administer webform submission\";}}s:6:\"fields\";a:9:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:10:\"operations\";a:25:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;s:11:\"entity_type\";N;s:12:\"entity_field\";N;s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:13:\"embed_default\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:13:\"embed_default\";s:13:\"display_title\";s:14:\"Embed: Default\";s:8:\"position\";i:1;s:15:\"display_options\";a:5:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:20:\"Display submissions.\";s:8:\"defaults\";a:5:{s:6:\"fields\";b:1;s:5:\"style\";b:0;s:3:\"row\";b:0;s:7:\"filters\";b:1;s:13:\"filter_groups\";b:1;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:5:{s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:7:\"created\";s:7:\"created\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:5:{s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_manage\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_manage\";s:13:\"display_title\";s:13:\"Embed: Manage\";s:8:\"position\";i:3;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Manage submissions.\";s:6:\"fields\";a:10:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:4:{i:0;s:35:\"webform_submission_make_lock_action\";i:1;s:37:\"webform_submission_make_sticky_action\";i:2;s:37:\"webform_submission_make_unlock_action\";i:3;s:39:\"webform_submission_make_unsticky_action\";}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}s:23:\"edit_webform_submission\";a:26:{s:2:\"id\";s:23:\"edit_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"edit_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"edit any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_review\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_review\";s:13:\"display_title\";s:13:\"Embed: Review\";s:8:\"position\";i:4;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Review submissions.\";s:6:\"fields\";a:8:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"view any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.what_s_new',_binary 'a:12:{s:4:\"uuid\";s:36:\"e1df6ee8-b831-49f1-9777-12d640e99636\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:22:\"better_exposed_filters\";i:1;s:4:\"node\";i:2;s:4:\"text\";i:3;s:4:\"user\";}}s:2:\"id\";s:10:\"what_s_new\";s:5:\"label\";s:10:\"What\'s New\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:0:\"\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:10:\"What\'s New\";s:6:\"fields\";a:2:{s:5:\"title\";a:35:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:20:\"<h3>{{ title }}</h3>\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"body\";a:35:{s:2:\"id\";s:4:\"body\";s:5:\"table\";s:10:\"node__body\";s:5:\"field\";s:4:\"body\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"text_default\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:3:\"bef\";s:7:\"options\";a:10:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";s:19:\"text_input_required\";s:51:\"Select any filter and click on Apply to see results\";s:26:\"text_input_required_format\";s:9:\"full_html\";s:3:\"bef\";a:2:{s:7:\"general\";a:10:{s:10:\"autosubmit\";b:1;s:28:\"autosubmit_exclude_textfield\";b:0;s:26:\"autosubmit_textfield_delay\";i:500;s:35:\"autosubmit_textfield_minimum_length\";i:3;s:15:\"autosubmit_hide\";b:0;s:14:\"input_required\";b:0;s:15:\"allow_secondary\";b:0;s:15:\"secondary_label\";s:16:\"Advanced options\";s:14:\"secondary_open\";b:0;s:24:\"reset_button_always_show\";b:0;}s:6:\"filter\";a:1:{s:7:\"created\";a:2:{s:9:\"plugin_id\";s:7:\"default\";s:8:\"advanced\";a:6:{s:16:\"placeholder_text\";s:0:\"\";s:7:\"rewrite\";a:2:{s:21:\"filter_rewrite_values\";s:0:\"\";s:25:\"filter_rewrite_values_key\";b:0;}s:11:\"collapsible\";b:0;s:34:\"collapsible_disable_automatic_open\";b:0;s:12:\"is_secondary\";b:0;s:10:\"hide_label\";b:0;}}}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:0:\"\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:1:{s:8:\"operator\";s:0:\"\";}}s:4:\"type\";a:7:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:5:\"value\";a:1:{s:7:\"article\";s:7:\"article\";}}s:7:\"created\";a:16:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:0:\"\";s:4:\"type\";s:9:\"date_year\";}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:15:{s:11:\"operator_id\";s:10:\"created_op\";s:5:\"label\";s:11:\"Authored on\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"created_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"created\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:14:\"content_editor\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:15:\"min_placeholder\";s:0:\"\";s:15:\"max_placeholder\";s:0:\"\";s:11:\"placeholder\";s:0:\"\";}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:5:\"Year \";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:7:\"created\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:3:{s:5:\"title\";s:4:\"2024\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2024\";s:4:\"type\";s:9:\"date_year\";}}i:2;a:3:{s:5:\"title\";s:4:\"2023\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2023\";s:4:\"type\";s:9:\"date_year\";}}i:3;a:3:{s:5:\"title\";s:4:\"2022\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2022\";s:4:\"type\";s:9:\"date_year\";}}}}}}s:5:\"style\";a:1:{s:4:\"type\";s:7:\"default\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:1:{i:0;s:30:\"config:field.storage.node.body\";}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:13:\"exposed_block\";b:1;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:1:{i:0;s:30:\"config:field.storage.node.body\";}}}}}'),('','views.view.who_s_new',_binary 'a:13:{s:4:\"uuid\";s:36:\"d9b64673-64f0-48bb-8588-e15e4bdacdbf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zji0_13MyVGK7Bn1lUMDeZyyOIZedWvqpYUeM_SioPI\";}s:2:\"id\";s:9:\"who_s_new\";s:5:\"label\";s:9:\"Who\'s new\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:53:\"Shows a list of the newest user accounts on the site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:9:\"Who\'s new\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:5;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\">\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:10:\"1970-01-01\";s:4:\"type\";s:4:\"date\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:1:{s:4:\"type\";s:9:\"html_list\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:9:\"Who\'s new\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:19:\"A list of new users\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:9:\"Who\'s new\";s:14:\"block_category\";s:4:\"User\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.who_s_online',_binary 'a:13:{s:4:\"uuid\";s:36:\"267c96ad-120e-49d6-9273-b49f1a603f01\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"suDsVMgawXoQt4rfmdfpr05EVX3z3KyfDDTYgeSM898\";}s:2:\"id\";s:12:\"who_s_online\";s:5:\"label\";s:18:\"Who\'s online block\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:93:\"Shows the user names of the most recently active users, and the total number of active users.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:12:\"Who\'s online\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access user profiles\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:35:\"There are currently 0 users online.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:6:\"access\";a:13:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"access\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:2:\">=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:11:\"-15 minutes\";s:4:\"type\";s:6:\"offset\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:9:\"access_op\";s:5:\"label\";s:11:\"Last access\";s:11:\"description\";s:77:\"A user is considered online for this long after they have last viewed a page.\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"access_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"access\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"result\";s:5:\"empty\";b:0;s:7:\"content\";s:40:\"There are currently @total users online.\";}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:18:\"who_s_online_block\";a:6:{s:2:\"id\";s:18:\"who_s_online_block\";s:13:\"display_title\";s:12:\"Who\'s online\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:19:\"display_description\";s:45:\"A list of users that are currently logged in.\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:12:\"Who\'s online\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','webform.settings',_binary 'a:20:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eZgcriT-utjDI1pjl-24jYFW2DmCxMXaFSnJd0XoU-0\";}s:8:\"settings\";a:73:{s:14:\"default_status\";s:4:\"open\";s:18:\"default_categories\";a:0:{}s:12:\"default_page\";b:1;s:22:\"default_page_base_path\";s:5:\"/form\";s:12:\"default_ajax\";b:0;s:19:\"default_ajax_effect\";s:4:\"fade\";s:18:\"default_ajax_speed\";i:500;s:26:\"default_ajax_progress_type\";s:8:\"throbber\";s:25:\"default_form_open_message\";s:49:\"This form has not yet been opened to submissions.\";s:26:\"default_form_close_message\";s:48:\"Sorry… This form is closed to new submissions.\";s:30:\"default_form_exception_message\";s:70:\"Unable to display this webform. Please contact the site administrator.\";s:27:\"default_submit_button_label\";s:6:\"Submit\";s:26:\"default_reset_button_label\";s:5:\"Reset\";s:27:\"default_delete_button_label\";s:6:\"Delete\";s:24:\"default_form_submit_once\";b:0;s:33:\"default_form_confidential_message\";s:135:\"This form is confidential. You must <a href=\"[site:login-url]/logout?destination=[current-page:url:relative]\">Log out</a> to submit it.\";s:34:\"default_form_access_denied_message\";s:34:\"Please log in to access this form.\";s:25:\"default_form_disable_back\";b:0;s:24:\"default_form_submit_back\";b:0;s:20:\"default_form_unsaved\";b:0;s:32:\"default_form_disable_remote_addr\";b:0;s:23:\"default_form_novalidate\";b:0;s:34:\"default_form_disable_inline_errors\";b:0;s:21:\"default_form_required\";b:0;s:27:\"default_form_required_label\";s:24:\"Indicates required field\";s:27:\"default_form_details_toggle\";b:1;s:23:\"default_form_file_limit\";s:0:\"\";s:12:\"form_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:14:\"button_classes\";s:0:\"\";s:32:\"default_wizard_prev_button_label\";s:10:\"< Previous\";s:32:\"default_wizard_next_button_label\";s:6:\"Next >\";s:26:\"default_wizard_start_label\";s:5:\"Start\";s:33:\"default_wizard_confirmation_label\";s:8:\"Complete\";s:32:\"default_wizard_toggle_show_label\";s:8:\"Show all\";s:32:\"default_wizard_toggle_hide_label\";s:8:\"Hide all\";s:33:\"default_preview_next_button_label\";s:7:\"Preview\";s:33:\"default_preview_prev_button_label\";s:10:\"< Previous\";s:21:\"default_preview_label\";s:7:\"Preview\";s:21:\"default_preview_title\";s:24:\"[webform:title]: Preview\";s:23:\"default_preview_message\";s:99:\"Please review your submission. Your submission is not complete until you press the \"Submit\" button!\";s:26:\"default_draft_button_label\";s:10:\"Save Draft\";s:27:\"default_draft_saved_message\";s:91:\"Submission saved. You may return to this form later and it will restore the current values.\";s:28:\"default_draft_loaded_message\";s:77:\"A partially-completed form was found. Please complete the remaining portions.\";s:36:\"default_draft_pending_single_message\";s:83:\"You have a pending draft for this webform. <a href=\"#\">Load your pending draft</a>.\";s:38:\"default_draft_pending_multiple_message\";s:83:\"You have pending drafts for this webform. <a href=\"#\">View your pending drafts</a>.\";s:28:\"default_confirmation_message\";s:40:\"New submission added to [webform:title].\";s:31:\"default_confirmation_back_label\";s:12:\"Back to form\";s:28:\"default_confirmation_noindex\";b:1;s:24:\"default_submission_label\";s:74:\"[webform_submission:submitted-to]: Submission #[webform_submission:serial]\";s:40:\"default_submission_access_denied_message\";s:40:\"Please log in to access this submission.\";s:36:\"default_submission_exception_message\";s:73:\"Unable to process this submission. Please contact the site administrator.\";s:33:\"default_submission_locked_message\";s:32:\"This submission has been locked.\";s:22:\"default_submission_log\";b:0;s:24:\"default_submission_views\";a:0:{}s:32:\"default_submission_views_replace\";a:3:{s:13:\"global_routes\";a:2:{i:0;s:36:\"entity.webform_submission.collection\";i:1;s:30:\"entity.webform_submission.user\";}s:14:\"webform_routes\";a:3:{i:0;s:34:\"entity.webform.results_submissions\";i:1;s:26:\"entity.webform.user.drafts\";i:2;s:31:\"entity.webform.user.submissions\";}s:11:\"node_routes\";a:3:{i:0;s:39:\"entity.node.webform.results_submissions\";i:1;s:31:\"entity.node.webform.user.drafts\";i:2;s:36:\"entity.node.webform.user.submissions\";}}s:25:\"default_results_customize\";b:0;s:35:\"default_previous_submission_message\";s:87:\"You have already submitted this webform. <a href=\"#\">View your previous submission</a>.\";s:36:\"default_previous_submissions_message\";s:88:\"You have already submitted this webform. <a href=\"#\">View your previous submissions</a>.\";s:24:\"default_autofill_message\";s:66:\"This submission has been autofilled with your previous submission.\";s:15:\"preview_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:20:\"confirmation_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:25:\"confirmation_back_classes\";s:7:\"button\n\";s:27:\"default_limit_total_message\";s:34:\"No more submissions are permitted.\";s:26:\"default_limit_user_message\";s:34:\"No more submissions are permitted.\";s:13:\"default_share\";b:0;s:18:\"default_share_node\";b:0;s:24:\"default_share_theme_name\";s:0:\"\";s:6:\"dialog\";b:0;s:14:\"dialog_options\";a:3:{s:6:\"narrow\";a:2:{s:5:\"title\";s:6:\"Narrow\";s:5:\"width\";i:600;}s:6:\"normal\";a:2:{s:5:\"title\";s:6:\"Normal\";s:5:\"width\";i:800;}s:4:\"wide\";a:2:{s:5:\"title\";s:4:\"Wide\";s:5:\"width\";i:1000;}}s:17:\"webform_bulk_form\";b:1;s:25:\"webform_bulk_form_actions\";a:5:{i:0;s:19:\"webform_open_action\";i:1;s:20:\"webform_close_action\";i:2;s:22:\"webform_archive_action\";i:3;s:24:\"webform_unarchive_action\";i:4;s:21:\"webform_delete_action\";}s:28:\"webform_submission_bulk_form\";b:1;s:36:\"webform_submission_bulk_form_actions\";a:5:{i:0;s:37:\"webform_submission_make_sticky_action\";i:1;s:39:\"webform_submission_make_unsticky_action\";i:2;s:35:\"webform_submission_make_lock_action\";i:3;s:37:\"webform_submission_make_unlock_action\";i:4;s:32:\"webform_submission_delete_action\";}}s:6:\"assets\";a:2:{s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";}s:7:\"handler\";a:1:{s:17:\"excluded_handlers\";a:0:{}}s:7:\"variant\";a:1:{s:17:\"excluded_variants\";a:0:{}}s:6:\"export\";a:18:{s:14:\"temp_directory\";s:0:\"\";s:8:\"exporter\";s:9:\"delimited\";s:18:\"multiple_delimiter\";s:1:\";\";s:13:\"header_format\";s:5:\"label\";s:13:\"header_prefix\";b:1;s:29:\"header_prefix_label_delimiter\";s:2:\": \";s:27:\"header_prefix_key_delimiter\";s:2:\"__\";s:29:\"composite_element_item_format\";s:5:\"label\";s:21:\"options_single_format\";s:7:\"compact\";s:23:\"options_multiple_format\";s:7:\"compact\";s:19:\"options_item_format\";s:5:\"label\";s:22:\"entity_reference_items\";a:3:{i:0;s:2:\"id\";i:1;s:5:\"title\";i:2;s:3:\"url\";}s:21:\"likert_answers_format\";s:5:\"label\";s:16:\"signature_format\";s:6:\"status\";s:9:\"delimiter\";s:1:\",\";s:5:\"excel\";b:0;s:12:\"archive_type\";s:3:\"tar\";s:18:\"excluded_exporters\";a:0:{}}s:5:\"batch\";a:5:{s:25:\"default_batch_export_size\";i:500;s:25:\"default_batch_import_size\";i:100;s:25:\"default_batch_update_size\";i:500;s:25:\"default_batch_delete_size\";i:500;s:24:\"default_batch_email_size\";i:500;}s:5:\"purge\";a:1:{s:9:\"cron_size\";i:100;}s:4:\"form\";a:3:{s:5:\"limit\";i:50;s:15:\"filter_category\";s:0:\"\";s:12:\"filter_state\";s:0:\"\";}s:7:\"element\";a:13:{s:20:\"machine_name_pattern\";s:7:\"a-z0-9_\";s:13:\"empty_message\";s:7:\"{Empty}\";s:12:\"allowed_tags\";s:5:\"admin\";s:15:\"wrapper_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:7:\"classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:23:\"horizontal_rule_classes\";s:286:\"webform-horizontal-rule--solid\nwebform-horizontal-rule--dashed\nwebform-horizontal-rule--dotted\nwebform-horizontal-rule--gradient\nwebform-horizontal-rule--thin\nwebform-horizontal-rule--medium\nwebform-horizontal-rule--thick\nwebform-horizontal-rule--flaired\nwebform-horizontal-rule--glyph\n\";s:27:\"default_description_display\";s:0:\"\";s:18:\"default_more_title\";s:4:\"More\";s:25:\"default_section_title_tag\";s:2:\"h2\";s:20:\"default_empty_option\";b:1;s:29:\"default_empty_option_required\";s:0:\"\";s:29:\"default_empty_option_optional\";s:0:\"\";s:17:\"excluded_elements\";a:2:{s:8:\"password\";s:8:\"password\";s:16:\"password_confirm\";s:16:\"password_confirm\";}}s:11:\"html_editor\";a:5:{s:8:\"disabled\";b:0;s:14:\"element_format\";s:15:\"webform_default\";s:11:\"mail_format\";s:15:\"webform_default\";s:4:\"tidy\";b:1;s:35:\"make_unused_managed_files_temporary\";b:1;}s:4:\"file\";a:11:{s:11:\"file_public\";b:0;s:21:\"file_private_redirect\";b:1;s:29:\"file_private_redirect_message\";s:42:\"Please log in to access the uploaded file.\";s:20:\"default_max_filesize\";s:0:\"\";s:31:\"default_managed_file_extensions\";s:148:\"gif jpg jpeg png bmp eps tif pict psd txt rtf html odf pdf doc docx ppt pptx xls xlsx xml avi mov mp3 mp4 ogg wav bz2 dmg gz jar rar sit svg tar zip\";s:29:\"default_audio_file_extensions\";s:11:\"mp3 ogg wav\";s:32:\"default_document_file_extensions\";s:50:\"txt rtf pdf doc docx odt ppt pptx odp xls xlsx ods\";s:29:\"default_image_file_extensions\";s:16:\"gif jpg jpeg png\";s:29:\"default_video_file_extensions\";s:24:\"avi mov mp4 ogg wav webm\";s:35:\"make_unused_managed_files_temporary\";b:1;s:30:\"delete_temporary_managed_files\";b:1;}s:6:\"format\";a:0:{}s:4:\"mail\";a:11:{s:15:\"default_to_mail\";s:11:\"[site:mail]\";s:17:\"default_from_mail\";s:11:\"[site:mail]\";s:17:\"default_from_name\";s:11:\"[site:name]\";s:16:\"default_reply_to\";s:0:\"\";s:19:\"default_return_path\";s:0:\"\";s:19:\"default_sender_mail\";s:0:\"\";s:19:\"default_sender_name\";s:0:\"\";s:15:\"default_subject\";s:58:\"Webform submission from: [webform_submission:source-title]\";s:17:\"default_body_text\";s:133:\"Submitted on [webform_submission:created]\nSubmitted by: [webform_submission:user]\n\nSubmitted values are:\n[webform_submission:values]\n\";s:17:\"default_body_html\";s:153:\"<p>Submitted on [webform_submission:created]</p>\n<p>Submitted by: [webform_submission:user]</p>\n<p>Submitted values are:</p>\n[webform_submission:values]\n\";s:5:\"roles\";a:0:{}}s:4:\"test\";a:2:{s:5:\"types\";s:3347:\"checkbox:\n  - true\ncolor:\n  - \'#ffffcc\'\n  - \'#ffffcc\'\n  - \'#ccffff\'\nemail:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nlanguage_select:\n  - en\nmachine_name:\n  - \'loremipsum\'\n  - \'oratione\'\n  - \'dixisset\'\ntel:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ntextarea:\n  - \'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.\'\n  - \'Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;\'\n  - \'Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.\'\ntext_format:\n  - value: \'<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.</p>\'\n  - value: \'<p>Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;</p>\'\n  - value: \'<p>Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.</p>\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\nwebform_email_confirm:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nwebform_email_multiple:\n  - \'example@example.com, test@test.com, random@random.com\'\nwebform_time:\n  - \'09:00\'\n  - \'17:00\'\n\";s:5:\"names\";s:547:\"first_name:\n  - \'John\'\n  - \'Paul\'\n  - \'Ringo\'\n  - \'George\'\nlast_name:\n  - \'Lennon\'\n  - \'McCartney\'\n  - \'Starr\'\n  - \'Harrison\'\naddress:\n  - \'10 Main Street\'\n  - \'11 Brook Alley Road. APT 1\'\nzip:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\npostal_code:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\nphone:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\nfax:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ncity:\n  - \'Springfield\'\n  - \'Pleasantville\'\n  - \'Hill Valley\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\ndefault:\n  - \'Loremipsum\'\n  - \'Oratione\'\n  - \'Dixisset\'\n\";}s:2:\"ui\";a:9:{s:13:\"video_display\";s:6:\"dialog\";s:12:\"details_save\";b:1;s:13:\"help_disabled\";b:0;s:15:\"dialog_disabled\";b:0;s:18:\"offcanvas_disabled\";b:0;s:19:\"promotions_disabled\";b:0;s:16:\"support_disabled\";b:0;s:16:\"description_help\";b:1;s:12:\"toolbar_item\";b:0;}s:9:\"libraries\";a:1:{s:18:\"excluded_libraries\";a:2:{i:0;s:7:\"choices\";i:1;s:13:\"jquery.chosen\";}}s:12:\"requirements\";a:4:{s:3:\"cdn\";b:1;s:9:\"bootstrap\";b:1;s:21:\"clientside_validation\";b:1;s:4:\"spam\";b:1;}s:8:\"langcode\";s:2:\"en\";s:20:\"third_party_settings\";a:1:{s:7:\"captcha\";a:1:{s:27:\"replace_administration_mode\";b:1;}}}'),('','webform.webform.contact',_binary 'a:22:{s:4:\"uuid\";s:36:\"8b8a523d-2f23-4a57-82e5-54fb22889c9f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";s:4:\"open\";s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_je-MWeeJB6gfm6iECiqjcyNetfMFbn-YIInYwZ1gIk\";}s:4:\"open\";N;s:5:\"close\";N;s:6:\"weight\";i:0;s:3:\"uid\";N;s:8:\"template\";b:0;s:7:\"archive\";b:0;s:2:\"id\";s:7:\"contact\";s:5:\"title\";s:7:\"Contact\";s:11:\"description\";s:28:\"Basic email contact webform.\";s:10:\"categories\";a:0:{}s:8:\"elements\";s:566:\"name:\n  \'#title\': \'Your Name\'\n  \'#type\': textfield\n  \'#required\': true\n  \'#default_value\': \'[current-user:display-name]\'\nemail:\n  \'#title\': \'Your Email\'\n  \'#type\': email\n  \'#required\': true\n  \'#default_value\': \'[current-user:mail]\'\nsubject:\n  \'#title\': Subject\n  \'#type\': textfield\n  \'#required\': true\n  \'#test\': \'Testing contact webform from [site:name]\'\nmessage:\n  \'#title\': Message\n  \'#type\': textarea\n  \'#required\': true\n  \'#test\': \'Please ignore this email.\'\nactions:\n  \'#type\': webform_actions\n  \'#title\': \'Submit button(s)\'\n  \'#submit__label\': \'Send message\'\n\";s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";s:8:\"settings\";a:133:{s:4:\"ajax\";b:0;s:15:\"ajax_scroll_top\";s:4:\"form\";s:18:\"ajax_progress_type\";s:0:\"\";s:11:\"ajax_effect\";s:0:\"\";s:10:\"ajax_speed\";N;s:4:\"page\";b:1;s:16:\"page_submit_path\";s:0:\"\";s:17:\"page_confirm_path\";s:0:\"\";s:15:\"page_theme_name\";s:0:\"\";s:10:\"form_title\";s:21:\"source_entity_webform\";s:16:\"form_submit_once\";b:0;s:22:\"form_exception_message\";s:0:\"\";s:17:\"form_open_message\";s:0:\"\";s:18:\"form_close_message\";s:0:\"\";s:25:\"form_previous_submissions\";b:1;s:17:\"form_confidential\";b:0;s:25:\"form_confidential_message\";s:0:\"\";s:24:\"form_disable_remote_addr\";b:0;s:22:\"form_convert_anonymous\";b:0;s:16:\"form_prepopulate\";b:0;s:30:\"form_prepopulate_source_entity\";b:0;s:39:\"form_prepopulate_source_entity_required\";b:0;s:35:\"form_prepopulate_source_entity_type\";s:0:\"\";s:10:\"form_reset\";b:0;s:25:\"form_disable_autocomplete\";b:0;s:15:\"form_novalidate\";b:0;s:26:\"form_disable_inline_errors\";b:0;s:13:\"form_required\";b:0;s:12:\"form_unsaved\";b:0;s:17:\"form_disable_back\";b:0;s:16:\"form_submit_back\";b:0;s:14:\"form_autofocus\";b:0;s:19:\"form_details_toggle\";b:0;s:18:\"form_access_denied\";s:7:\"default\";s:24:\"form_access_denied_title\";s:0:\"\";s:26:\"form_access_denied_message\";s:0:\"\";s:29:\"form_access_denied_attributes\";a:0:{}s:15:\"form_file_limit\";s:0:\"\";s:11:\"form_method\";s:0:\"\";s:11:\"form_action\";s:0:\"\";s:15:\"form_attributes\";a:0:{}s:5:\"share\";b:0;s:10:\"share_node\";b:0;s:16:\"share_theme_name\";s:0:\"\";s:11:\"share_title\";b:1;s:26:\"share_page_body_attributes\";a:0:{}s:16:\"submission_label\";s:0:\"\";s:14:\"submission_log\";b:0;s:16:\"submission_views\";a:0:{}s:24:\"submission_views_replace\";a:0:{}s:23:\"submission_user_columns\";a:0:{}s:25:\"submission_user_duplicate\";b:0;s:24:\"submission_access_denied\";s:7:\"default\";s:30:\"submission_access_denied_title\";s:0:\"\";s:32:\"submission_access_denied_message\";s:0:\"\";s:35:\"submission_access_denied_attributes\";a:0:{}s:28:\"submission_exception_message\";s:0:\"\";s:25:\"submission_locked_message\";s:0:\"\";s:28:\"submission_excluded_elements\";a:0:{}s:24:\"submission_exclude_empty\";b:0;s:33:\"submission_exclude_empty_checkbox\";b:0;s:27:\"previous_submission_message\";s:0:\"\";s:28:\"previous_submissions_message\";s:0:\"\";s:8:\"autofill\";b:0;s:16:\"autofill_message\";s:0:\"\";s:26:\"autofill_excluded_elements\";a:0:{}s:19:\"wizard_progress_bar\";b:1;s:21:\"wizard_progress_pages\";b:0;s:26:\"wizard_progress_percentage\";b:0;s:20:\"wizard_progress_link\";b:0;s:22:\"wizard_progress_states\";b:0;s:19:\"wizard_auto_forward\";b:1;s:36:\"wizard_auto_forward_hide_next_button\";b:0;s:15:\"wizard_keyboard\";b:1;s:18:\"wizard_start_label\";s:0:\"\";s:19:\"wizard_preview_link\";b:0;s:19:\"wizard_confirmation\";b:1;s:25:\"wizard_confirmation_label\";s:0:\"\";s:12:\"wizard_track\";s:0:\"\";s:24:\"wizard_prev_button_label\";s:0:\"\";s:24:\"wizard_next_button_label\";s:0:\"\";s:13:\"wizard_toggle\";b:0;s:24:\"wizard_toggle_show_label\";s:0:\"\";s:24:\"wizard_toggle_hide_label\";s:0:\"\";s:16:\"wizard_page_type\";s:9:\"container\";s:21:\"wizard_page_title_tag\";s:2:\"h2\";s:7:\"preview\";i:0;s:13:\"preview_label\";s:0:\"\";s:13:\"preview_title\";s:0:\"\";s:15:\"preview_message\";s:0:\"\";s:18:\"preview_attributes\";a:0:{}s:25:\"preview_excluded_elements\";a:0:{}s:21:\"preview_exclude_empty\";b:1;s:30:\"preview_exclude_empty_checkbox\";b:0;s:5:\"draft\";s:4:\"none\";s:14:\"draft_multiple\";b:0;s:15:\"draft_auto_save\";b:0;s:19:\"draft_saved_message\";s:0:\"\";s:20:\"draft_loaded_message\";s:0:\"\";s:28:\"draft_pending_single_message\";s:0:\"\";s:30:\"draft_pending_multiple_message\";s:0:\"\";s:17:\"confirmation_type\";s:11:\"url_message\";s:18:\"confirmation_title\";s:0:\"\";s:20:\"confirmation_message\";s:27:\"Your message has been sent.\";s:16:\"confirmation_url\";s:7:\"<front>\";s:23:\"confirmation_attributes\";a:0:{}s:17:\"confirmation_back\";b:1;s:23:\"confirmation_back_label\";s:0:\"\";s:28:\"confirmation_back_attributes\";a:0:{}s:26:\"confirmation_exclude_query\";b:0;s:26:\"confirmation_exclude_token\";b:0;s:19:\"confirmation_update\";b:0;s:11:\"limit_total\";N;s:20:\"limit_total_interval\";N;s:19:\"limit_total_message\";s:0:\"\";s:18:\"limit_total_unique\";b:0;s:10:\"limit_user\";N;s:19:\"limit_user_interval\";N;s:18:\"limit_user_message\";s:0:\"\";s:17:\"limit_user_unique\";b:0;s:18:\"entity_limit_total\";N;s:27:\"entity_limit_total_interval\";N;s:17:\"entity_limit_user\";N;s:26:\"entity_limit_user_interval\";N;s:5:\"purge\";s:4:\"none\";s:10:\"purge_days\";N;s:16:\"results_disabled\";b:0;s:23:\"results_disabled_ignore\";b:0;s:17:\"results_customize\";b:0;s:10:\"token_view\";b:0;s:12:\"token_update\";b:0;s:12:\"token_delete\";b:0;s:15:\"serial_disabled\";b:0;}s:6:\"access\";a:11:{s:6:\"create\";a:3:{s:5:\"roles\";a:2:{i:0;s:9:\"anonymous\";i:1;s:13:\"authenticated\";}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:9:\"purge_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"administer\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:4:\"test\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:13:\"configuration\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}}s:8:\"handlers\";a:2:{s:18:\"email_confirmation\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email confirmation\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_confirmation\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:1;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:19:\"[current-user:mail]\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:8:\"_default\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:8:\"_default\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}s:18:\"email_notification\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email notification\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_notification\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:2;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:8:\"_default\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:37:\"[webform_submission:values:email:raw]\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:36:\"[webform_submission:values:name:raw]\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}}s:8:\"variants\";a:0:{}}'),('','webform.webform_options.country_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"fcbe2856-cef2-499f-8ba0-fbc8ffac8fdd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"adQ16YGDPk7QfUKrfrC35o2sKdHEozdNtdpiH7CftQQ\";}s:2:\"id\";s:13:\"country_codes\";s:5:\"label\";s:13:\"Country codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.country_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"9354d04a-fde3-4871-958b-953be0d0a8c8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zsfFP124dAM-sJkuEfnwaA7DN6o3-IsaXLgdNmObbYg\";}s:2:\"id\";s:13:\"country_names\";s:5:\"label\";s:13:\"Country names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.days',_binary 'a:10:{s:4:\"uuid\";s:36:\"6408d5ed-d58e-4d75-a41e-8c2526f7d3ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNrKbYrWWjeubUUM8AsQ19KnX7cU1elACR14CZJHmdg\";}s:2:\"id\";s:4:\"days\";s:5:\"label\";s:4:\"Days\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:121:\"Sunday: Sunday\nMonday: Monday\nTuesday: Tuesday\nWednesday: Wednesday\nThursday: Thursday\nFriday: Friday\nSaturday: Saturday\n\";}'),('','webform.webform_options.education',_binary 'a:10:{s:4:\"uuid\";s:36:\"4639bce4-22a5-4e03-9cad-186c79584f07\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mII4acOv33s-j8PINywrCag4OITbeJGxdPO373dnHHw\";}s:2:\"id\";s:9:\"education\";s:5:\"label\";s:9:\"Education\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:152:\"High School: High School\nAssociate Degree: Associate Degree\nGraduate or Professional Degree: Graduate or Professional Degree\nSome College: Some College\n\";}'),('','webform.webform_options.employment_status',_binary 'a:10:{s:4:\"uuid\";s:36:\"329c38fd-eb24-471e-aa3d-b63a51b3a1d6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8MCmsz_csdJkVItxI8g_s4zp2PM285YqCy_gWTzOLPw\";}s:2:\"id\";s:17:\"employment_status\";s:5:\"label\";s:17:\"Employment status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:113:\"\'Full Time\': \'Full Time\'\n\'Part Time\': \'Part Time\'\n\'Military\': \'Military\'\nUnemployed: Unemployed\nRetired: Retired\n\";}'),('','webform.webform_options.ethnicity',_binary 'a:10:{s:4:\"uuid\";s:36:\"0df45fa9-e8c8-4d2f-ae91-771c2df5499d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIPgrAC82wE2GAk1mOv2UvMYv71YQe4VT8667QIYdvI\";}s:2:\"id\";s:9:\"ethnicity\";s:5:\"label\";s:9:\"Ethnicity\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:200:\"Caucasian: Caucasian\n\'Latino/Hispanic\': \'Latino/Hispanic\'\n\'Middle Eastern\': \'Middle Eastern\'\nAfrican: African\nCaribbean: Caribbean\n\'South Asian\': \'South Asian\'\n\'East Asian\': \'East Asian\'\nMixed: Mixed\n\";}'),('','webform.webform_options.gender',_binary 'a:10:{s:4:\"uuid\";s:36:\"1fcf461d-9e42-4571-b6cf-28abee7d1f9b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yxhG0JmQs2HT-Ro6ZeDQboDc9ZWR4GglflTtyoqxK4A\";}s:2:\"id\";s:6:\"gender\";s:5:\"label\";s:6:\"Gender\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:756:\"Man: Man\nWoman: Woman\nNon-binary: Non-binary\nAgender/Genderless: Agender/Genderless\nAndrogyne/Androgynous: Androgyne/Androgynous\nAporagender: Aporagender\nBigender: Bigender\nDemi-agender: Demi-agender\nDemi-boy: Demi-boy\nDemi-fluid: Demi-fluid\nDemi-girl: Demi-girl\nDemi-gender: Demi-gender\nDemi-non-binary: Demi-non-binary\nGenderqueer: Genderqueer\nGenderflux: Genderflux\nGenderfluid: Genderfluid\nGender-indifferent: Gender-indifferent\nGender-neutral: Gender-neutral\nGraygender: Graygender\nIntergender: Intergender\nMaverique: Maverique\nMaxigender: Maxigender\nMultigender/Polygender: Multigender/Polygender\nNeutrois: Neutrois\nPangender/Omnigender: Pangender/Omnigender\nTrigender: Trigender\nTwo-spirit: Two-spirit\n\'Prefer Not to Answer\': \'Prefer Not to Answer\'\n\";}'),('','webform.webform_options.industry',_binary 'a:10:{s:4:\"uuid\";s:36:\"93091529-37e9-4c06-afeb-b349faa470ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"s_SXZn2HbRGvTex-TLOCxz2oOnMYqtEZh8HD4_318QI\";}s:2:\"id\";s:8:\"industry\";s:5:\"label\";s:8:\"Industry\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1425:\"Accounting/Finance: Accounting/Finance\nAdvertising/Public Relations: Advertising/Public Relations\nAerospace/Aviation: Aerospace/Aviation\nArts/Entertainment/Publishing: Arts/Entertainment/Publishing\nAutomotive: Automotive\nBanking/Mortgage: Banking/Mortgage\nBusiness Development: Business Development\nBusiness Opportunity: Business Opportunity\nClerical/Administrative: Clerical/Administrative\nConstruction/Facilities: Construction/Facilities\nConsumer Goods: Consumer Goods\nCustomer Service: Customer Service\nEducation/Training: Education/Training\nEnergy/Utilities: Energy/Utilities\nEngineering: Engineering\nGovernment/Military: Government/Military\nHealthcare: Healthcare\nHospitality/Travel: Hospitality/Travel\nHuman Resources: Human Resources\nInstallation/Maintenance: Installation/Maintenance\nInsurance: Insurance\nInternet: Internet\nLaw Enforcement/Security: Law Enforcement/Security\nLegal: Legal\nManagement/Executive: Management/Executive\nManufacturing/Operations: Manufacturing/Operations\nMarketing: Marketing\nNon-Profit/Volunteer: Non-Profit/Volunteer\nPharmaceutical/Biotech: Pharmaceutical/Biotech\nProfessional Services: Professional Services\nReal Estate: Real Estate\nRestaurant/Food Service: Restaurant/Food Service\nRetail: Retail\nSales: Sales\nScience/Research: Science/Research\nSkilled Labor: Skilled Labor\nTechnology: Technology\nTelecommunications: Telecommunications\nTransportation/Logistics: Transportation/Logistics\n\";}'),('','webform.webform_options.languages',_binary 'a:10:{s:4:\"uuid\";s:36:\"b5b13230-e38a-46a3-950e-7fb23a36c978\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mYH14Vi65Ixj10c_GFa7CipxU3D0Bt9wgo8zE8zjOfE\";}s:2:\"id\";s:9:\"languages\";s:5:\"label\";s:9:\"Languages\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.likert_agreement',_binary 'a:10:{s:4:\"uuid\";s:36:\"85e67cce-5058-4806-85e0-7af5f9b85ac0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nPp-CfMKrP0yDMtyO0wQRwawEqaJVAPzQapinXmDgyU\";}s:2:\"id\";s:16:\"likert_agreement\";s:5:\"label\";s:17:\"Likert: Agreement\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:71:\"1: Strongly Disagree\n2: Disagree\n3: Neutral\n4: Agree\n5: Strongly Agree\n\";}'),('','webform.webform_options.likert_comparison',_binary 'a:10:{s:4:\"uuid\";s:36:\"b7c1b8ab-fa1a-40b6-99de-c764482a5e3d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DMG4TKTHEXtHN8ho_sG_GiZHgweZ6nrRm6BAjk0LZ_Y\";}s:2:\"id\";s:17:\"likert_comparison\";s:5:\"label\";s:18:\"Likert: Comparison\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:84:\"1: Much Worse\n2: Somewhat Worse\n3: About the Same\n4: Somewhat Better\n5: Much Better\n\";}'),('','webform.webform_options.likert_importance',_binary 'a:10:{s:4:\"uuid\";s:36:\"a7ba4359-4c6f-4830-8d8a-1b39544c95d7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hbc8n5HtVZVs5fSBSpSbuY07CVvqkKP76csvRHN9pK8\";}s:2:\"id\";s:17:\"likert_importance\";s:5:\"label\";s:18:\"Likert: Importance\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:88:\"1: Not at all Important\n2: Somewhat Important\n3: Neutral\n4: Important\n5: Very Important\n\";}'),('','webform.webform_options.likert_quality',_binary 'a:10:{s:4:\"uuid\";s:36:\"431a023e-67ab-48e5-8bac-a1572c14c19f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swmYtBVUbwq7aHJWWDN7ODByuvur9vMkexDC9h64NZ8\";}s:2:\"id\";s:14:\"likert_quality\";s:5:\"label\";s:15:\"Likert: Quality\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:50:\"1: Poor\n2: Fair\n3: Good\n4: Very good\n5: Excellent\n\";}'),('','webform.webform_options.likert_satisfaction',_binary 'a:10:{s:4:\"uuid\";s:36:\"f3e69acd-d88d-48a1-ae55-9997d56e4d8a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AKE2SNwCpl6Mu_cmbq9ZM2_cXxCikCVj1vcPE9oHWTs\";}s:2:\"id\";s:19:\"likert_satisfaction\";s:5:\"label\";s:20:\"Likert: Satisfaction\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:77:\"1: Very Unsatisfied\n2: Unsatisfied\n3: Neutral\n4: Satisfied\n5: Very Satisfied\n\";}'),('','webform.webform_options.likert_ten_scale',_binary 'a:10:{s:4:\"uuid\";s:36:\"d39bd682-6e68-4cbd-8ace-ae4db6b7d13f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zEZX8JSVqznnFtqFfpuC593h3t1JDAZhF0Q3pvA229o\";}s:2:\"id\";s:16:\"likert_ten_scale\";s:5:\"label\";s:17:\"Likert: Ten Scale\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:52:\"1: 1\n2: 2\n3: 3\n4: 4\n5: 5\n6: 6\n7: 7\n8: 8\n9: 9\n10: 10\n\";}'),('','webform.webform_options.likert_would_you',_binary 'a:10:{s:4:\"uuid\";s:36:\"da40135e-38ac-464f-8ee9-0a9085b6b37b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qBS2TmfAJB37Qn3TnrNM8x4AWimmDapcizzRllgo0fo\";}s:2:\"id\";s:16:\"likert_would_you\";s:5:\"label\";s:17:\"Likert: Would You\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:72:\"1: Definitely Not\n2: Probably Not\n3: Not Sure\n4: Probably\n5: Definitely\n\";}'),('','webform.webform_options.marital_status',_binary 'a:10:{s:4:\"uuid\";s:36:\"caf25914-1f32-4cc2-8565-20b048649e59\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cjVDbAE5BlopGrY-tfxsxMoyEibwBBNgdQwDdxOSkow\";}s:2:\"id\";s:14:\"marital_status\";s:5:\"label\";s:14:\"Marital status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:68:\"Single: Single\nMarried: Married\nDivorced: Divorced\nWidowed: Widowed\n\";}'),('','webform.webform_options.months',_binary 'a:10:{s:4:\"uuid\";s:36:\"b28be784-d785-41d2-b9a2-5b26173eb305\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pZJnuQkh9afNML5IcMuKTUC__vmHMFn66Qr5IWtedZ4\";}s:2:\"id\";s:6:\"months\";s:5:\"label\";s:6:\"Months\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:184:\"January: January\nFebruary: February\nMarch: March\nApril: April\nMay: May\nJune: June\nJuly: July\nAugust: August\nSeptember: September\nOctober: October\nNovember: November\nDecember: December\n\";}'),('','webform.webform_options.phone_types',_binary 'a:10:{s:4:\"uuid\";s:36:\"9fc50b5c-88f4-4154-ae56-ddbe476c4e3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LkO63Zl2cP_l9YdjzWI8dWoD9uD0pytkPiUiUM2bo9A\";}s:2:\"id\";s:11:\"phone_types\";s:5:\"label\";s:10:\"Phone type\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:37:\"Home: Home\nOffice: Office\nCell: Cell\n\";}'),('','webform.webform_options.province_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"7817e355-803d-4cdf-88a9-a3ab29e94c21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cR3A6XXinVGC9g5vLS-vVvTC2ppZXRNXLPWA8xBUMew\";}s:2:\"id\";s:14:\"province_codes\";s:5:\"label\";s:14:\"Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:237:\"AB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}');
INSERT INTO `config_export` VALUES ('','webform.webform_options.province_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"be00197d-93d4-42c6-8d82-abc6357218e4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aaEeYBWoWETLKX2ivmZBpUAd3uPe2iPNydaxBuLPXKc\";}s:2:\"id\";s:14:\"province_names\";s:5:\"label\";s:14:\"Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:379:\"Alberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),('','webform.webform_options.relationship',_binary 'a:10:{s:4:\"uuid\";s:36:\"e7f91e1a-5e99-4f06-bd68-f4a6d8a72ad9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4J2RPG4JmsD4Fm1NlIQY0JHkrJ08UUl0qTF0_EjUxvw\";}s:2:\"id\";s:12:\"relationship\";s:5:\"label\";s:12:\"Relationship\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:101:\"Parent: Parent\n\'Significant Other\': \'Significant Other\'\nSibling: Sibling\nChild: Child\nFriend: Friend\n\";}'),('','webform.webform_options.sex',_binary 'a:10:{s:4:\"uuid\";s:36:\"554341f6-de3f-4da4-8d70-e2302b2d1a3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WRpxpwYpfcO_i0so7BV4QXxXlbPiSVppYmAV6DAz4c0\";}s:2:\"id\";s:3:\"sex\";s:5:\"label\";s:3:\"Sex\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:26:\"Male: Male\nFemale: Female\n\";}'),('','webform.webform_options.sex_icao',_binary 'a:10:{s:4:\"uuid\";s:36:\"fec065d0-b801-4d27-9b36-c4c20d17c22f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9mxo86dMII5OxkHl4mbe2l4AgQloOXuErOte57BU9IY\";}s:2:\"id\";s:8:\"sex_icao\";s:5:\"label\";s:54:\"Sex - International Civil Aviation Organization (ICAO)\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:33:\"M: Male\nF: Female\nX: Unspecified\n\";}'),('','webform.webform_options.size',_binary 'a:10:{s:4:\"uuid\";s:36:\"dcb23767-92c9-44f0-af6f-82142d05d7f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RKkc6tf1VudvYiOtwPCf3Tp_EoA6fov6BFC34D7gMoQ\";}s:2:\"id\";s:4:\"size\";s:5:\"label\";s:4:\"Size\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:91:\"Extra Small: Extra Small\nSmall: Small\nMedium: Medium\nLarge: Large\nExtra Large: Extra Large\n\";}'),('','webform.webform_options.state_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"d3af1e77-6eac-4403-a5fb-758c5365a402\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8mYO8ewsZX3LVfNga69jXa0RNO0LNN8-EGkXLhSAMBU\";}s:2:\"id\";s:11:\"state_codes\";s:5:\"label\";s:11:\"State codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:728:\"AL: Alabama\nAK: Alaska\nAZ: Arizona\nAR: Arkansas\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPA: Pennsylvania\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\n\";}'),('','webform.webform_options.state_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"294b5fc1-0d98-46dc-b941-253bcd531719\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KfYqMSrFJ5iGtDzvy_rGUeRUJ4KyM7Xt-tWtYx9WjiM\";}s:2:\"id\";s:11:\"state_names\";s:5:\"label\";s:11:\"State names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1081:\"Alabama: Alabama\nAlaska: Alaska\nArizona: Arizona\nArkansas: Arkansas\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\nFlorida: Florida\nGeorgia: Georgia\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPennsylvania: Pennsylvania\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\n\";}'),('','webform.webform_options.state_province_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"6973c62d-f428-4205-934b-9559ce7d133c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ziWv9xVss1UBnP_R38EqduZOprwOAifpxjXhyOPzmys\";}s:2:\"id\";s:20:\"state_province_codes\";s:5:\"label\";s:20:\"State/Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1241:\"AL: Alabama\nAK: Alaska\nAS: \'American Samoa\'\nAZ: Arizona\nAR: Arkansas\nAE: \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\nAA: \'Armed Forces Americas\'\nAP: \'Armed Forces Pacific\'\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFM: \'Federated States of Micronesia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMH: \'Marshall Islands\'\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nMP: \'Northern Mariana Islands\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPW: Palau\nPA: Pennsylvania\nPR: \'Puerto Rico\'\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVI: \'Virgin Islands\'\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\nAB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),('','webform.webform_options.state_province_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"041d2cb0-73c1-4dd6-8388-5b44d924fd3f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d4mxS_CxdzHZK4WaGQf1H3m-Uubm5HPbu9U4ydzscuo\";}s:2:\"id\";s:20:\"state_province_names\";s:5:\"label\";s:20:\"State/Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1953:\"Alabama: Alabama\nAlaska: Alaska\n\'American Samoa\': \'American Samoa\'\nArizona: Arizona\nArkansas: Arkansas\n\'Armed Forces (Canada, Europe, Africa, or Middle East)\': \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\n\'Armed Forces Americas\': \'Armed Forces Americas\'\n\'Armed Forces Pacific\': \'Armed Forces Pacific\'\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\n\'Federated States of Micronesia\': \'Federated States of Micronesia\'\nFlorida: Florida\nGeorgia: Georgia\nGuam: Guam\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\n\'Marshall Islands\': \'Marshall Islands\'\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\n\'Northern Mariana Islands\': \'Northern Mariana Islands\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPalau: Palau\nPennsylvania: Pennsylvania\n\'Puerto Rico\': \'Puerto Rico\'\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\n\'Virgin Islands\': \'Virgin Islands\'\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\nAlberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),('','webform.webform_options.time_zones',_binary 'a:10:{s:4:\"uuid\";s:36:\"a170e99b-fa17-41e0-a271-10a7c2bb61f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8rVcRXLnTAEoWs7zl8du-7RIUnayqUcGYnvb3JT21-o\";}s:2:\"id\";s:10:\"time_zones\";s:5:\"label\";s:10:\"Time zones\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.titles',_binary 'a:10:{s:4:\"uuid\";s:36:\"428cbf5b-9239-4908-8e3c-1b29a9657d92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PEUoedWrfYEX7oZ8CcOukfBTVxar1cPSROX8534esuU\";}s:2:\"id\";s:6:\"titles\";s:5:\"label\";s:6:\"Titles\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:41:\"Miss: Miss\nMs: Ms\nMr: Mr\nMrs: Mrs\nDr: Dr\n\";}'),('','webform.webform_options.translations',_binary 'a:10:{s:4:\"uuid\";s:36:\"8c38f0bb-4da2-49a0-b196-c2d5c1ba66cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mb_L3vE-0IBZH5s2rjpk2LNn0QHClQP9AARQdCmVLt4\";}s:2:\"id\";s:12:\"translations\";s:5:\"label\";s:12:\"Translations\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.yes_no',_binary 'a:10:{s:4:\"uuid\";s:36:\"9d57dfd8-f21c-40ec-bbaa-57fe26b6397c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W88NYg31DbaVNQx1Uir_dwwXHVtF09QOq4VBGsH1Snk\";}s:2:\"id\";s:6:\"yes_no\";s:5:\"label\";s:6:\"Yes/No\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:16:\"Yes: Yes\nNo: No\n\";}');
/*!40000 ALTER TABLE `config_export` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `file_managed`
--

DROP TABLE IF EXISTS `file_managed`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `file_managed` (
  `fid` int unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `filename` varchar(255) DEFAULT NULL,
  `uri` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  `filemime` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `filesize` bigint unsigned DEFAULT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `changed` int NOT NULL,
  PRIMARY KEY (`fid`),
  UNIQUE KEY `file_field__uuid__value` (`uuid`),
  KEY `file_field__uid__target_id` (`uid`),
  KEY `file_field__uri` (`uri`(191)),
  KEY `file_field__status` (`status`),
  KEY `file_field__changed` (`changed`)
) ENGINE=InnoDB AUTO_INCREMENT=25 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for file entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `file_managed`
--

LOCK TABLES `file_managed` WRITE;
/*!40000 ALTER TABLE `file_managed` DISABLE KEYS */;
INSERT INTO `file_managed` VALUES (2,'60d8a89d-c0e4-4f6f-a02b-be56df95423e','en',1,'loU-RC_IfFJoRkm1ymCgvLwNgQN140h4McUa96sP_NM.jpg','public://oembed_thumbnails/2024-10/loU-RC_IfFJoRkm1ymCgvLwNgQN140h4McUa96sP_NM.jpg','image/jpeg',20824,1,1728242881,1728242881),(3,'1ef80ac2-157b-43e3-88d2-d1aa83385bbe','en',1,'333b8c43-dbee-469a-8766-c302f74bb595.jpg','public://2024-10/333b8c43-dbee-469a-8766-c302f74bb595.jpg','image/jpeg',92112,1,1728819558,1728819575),(4,'83ea2354-5924-4631-b0b9-c8235dcda17d','en',1,'bg-image1.webp','public://2024-10/bg-image1.webp','image/webp',73324,1,1728883281,1728883296),(5,'27a2e1c3-c1c1-406d-ac9f-ce46469004fc','en',1,'fluid_grid_1.webp','public://2024-10/fluid_grid_1.webp','image/webp',48672,1,1728884475,1728884491),(6,'a5734f68-39c4-447e-9b19-aa91c80aef37','en',1,'faq example.webp','public://2024-10/faq example.webp','image/webp',14826,1,1728884651,1728884661),(7,'a1b2e5be-a598-4a93-adad-be739d909ff1','en',1,'2 columns CTA.webp','public://2024-10/2 columns CTA.webp','image/webp',27076,1,1728884846,1728884856),(8,'210fbf6a-6326-4844-8ed3-bd55cf195244','en',1,'EBT Tabs.webp','public://2024-10/EBT Tabs.webp','image/webp',8288,1,1728885156,1728885164),(9,'03ea38ce-6683-4459-9011-0cbabcf143f9','en',1,'8af0c440-2152-4678-86c7-95ee5c055211.jpg','public://2024-10/8af0c440-2152-4678-86c7-95ee5c055211.jpg','image/jpeg',72125,1,1728885422,1728885435),(10,'f06ef861-cfbe-457e-9ee4-059ff7de69c0','en',1,'ept-slick-slider.webp','public://2024-10/ept-slick-slider.webp','image/webp',34012,1,1728885872,1728885878),(11,'b0d51bae-d787-4260-9ce3-c354cac9e303','en',1,'ebt carousel.webp','public://2024-10/ebt carousel.webp','image/webp',43104,1,1728887601,1728887611),(12,'eacb6931-12a4-462a-89ed-e8a0300dfbae','en',1,'Home-Drupal-9_0.webp','public://2024-10/Home-Drupal-9_0.webp','image/webp',44306,1,1728887677,1728887683),(13,'d2235e60-83f3-4650-b2b0-6e8a5fe0fb61','en',1,'with_square_img_0.webp','public://2024-10/with_square_img_0.webp','image/webp',36710,1,1728887791,1728887798),(14,'1db9b011-c7f0-4abc-9e6b-0d06e3e2a4fb','en',1,'ept tiles.webp','public://2024-10/ept tiles.webp','image/webp',56258,1,1728887900,1728887910),(15,'c5becdcc-54b2-48cd-acda-9e048f3d2ab1','en',1,'EPT text.webp','public://2024-10/EPT text.webp','image/webp',39042,1,1728888003,1728888015),(16,'c46c3254-d755-417b-ab28-21b8747e6918','en',1,'ept counter.webp','public://2024-10/ept counter.webp','image/webp',65676,1,1728888321,1728888367),(17,'8f411a08-cf69-4725-8f5b-ffb6f1982478','en',1,'glightbox.webp','public://2024-10/glightbox.webp','image/webp',22398,1,1728888670,1728888706),(18,'9728eed8-3c60-44e0-9972-fab3de265240','en',1,'dark drop.webp','public://2024-10/dark drop.webp','image/webp',67540,1,1728889183,1728889191),(19,'528ff0c5-d513-4850-a4c9-616c71d6255b','en',1,'ept case.webp','public://2024-10/ept case.webp','image/webp',142334,1,1728933322,1728933335),(20,'cca69110-3961-414d-9a95-75e39a356ca2','en',1,'4950565d-af48-45ef-be68-c27550a02da9.jpg','public://2024-10/4950565d-af48-45ef-be68-c27550a02da9.jpg','image/jpeg',111698,1,1728934033,1728934044),(21,'57499a89-5124-4b71-bcbf-14a53e8bae01','en',1,'4950565d-af48-45ef-be68-c27550a02da9.webp','public://2024-10/4950565d-af48-45ef-be68-c27550a02da9.webp','image/webp',102772,1,1728935124,1728935148),(22,'ba718488-03e3-44c6-9608-b7012b00a3a8','en',1,'DOM Box.webp','public://2024-10/DOM Box.webp','image/webp',74164,1,1728936151,1728936159),(23,'aceb3a02-bf1e-4e25-8bfc-dec82bce67ea','en',1,'background image or video.webp','public://2024-10/background image or video.webp','image/webp',28554,1,1728936355,1728936372),(24,'abcaf6ea-2236-4ac6-a648-a7c7c0111dd8','en',1,'javascript plugins.webp','public://2024-10/javascript plugins.webp','image/webp',32980,1,1728936556,1728936566);
/*!40000 ALTER TABLE `file_managed` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `file_usage`
--

DROP TABLE IF EXISTS `file_usage`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `file_usage` (
  `fid` int unsigned NOT NULL COMMENT 'File ID.',
  `module` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the module that is using the file.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the object type in which the file is used.',
  `id` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '0' COMMENT 'The primary key of the object using the file.',
  `count` int unsigned NOT NULL DEFAULT '0' COMMENT 'The number of times this file is used by this object.',
  PRIMARY KEY (`fid`,`type`,`id`,`module`),
  KEY `type_id` (`type`,`id`),
  KEY `fid_count` (`fid`,`count`),
  KEY `fid_module` (`fid`,`module`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Track where a file is used.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `file_usage`
--

LOCK TABLES `file_usage` WRITE;
/*!40000 ALTER TABLE `file_usage` DISABLE KEYS */;
INSERT INTO `file_usage` VALUES (2,'file','media','1',1),(3,'file','media','2',2),(4,'file','media','3',2),(5,'file','media','4',6),(6,'file','media','5',4),(7,'file','media','6',4),(8,'file','media','7',4),(9,'file','media','8',2),(10,'file','media','9',2),(11,'file','media','10',2),(12,'file','media','11',2),(13,'file','media','12',2),(14,'file','media','13',2),(15,'file','media','14',2),(16,'file','media','15',2),(17,'file','media','16',2),(18,'file','media','17',2),(19,'file','media','18',2),(20,'file','media','19',2),(21,'file','media','19',2),(22,'file','media','20',2),(23,'file','media','21',2),(24,'file','media','22',2);
/*!40000 ALTER TABLE `file_usage` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `flood`
--

DROP TABLE IF EXISTS `flood`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `flood` (
  `fid` int NOT NULL AUTO_INCREMENT COMMENT 'Unique flood event ID.',
  `event` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Name of event (e.g. contact).',
  `identifier` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Identifier of the visitor, such as an IP address or hostname.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp of the event.',
  `expiration` bigint NOT NULL DEFAULT '0' COMMENT 'Expiration timestamp. Expired events are purged on cron run.',
  PRIMARY KEY (`fid`),
  KEY `allow` (`event`,`identifier`,`timestamp`),
  KEY `purge` (`expiration`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Flood controls the threshold of events, such as the number…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `flood`
--

LOCK TABLES `flood` WRITE;
/*!40000 ALTER TABLE `flood` DISABLE KEYS */;
/*!40000 ALTER TABLE `flood` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `help_search_items`
--

DROP TABLE IF EXISTS `help_search_items`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `help_search_items` (
  `sid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Numeric index of this item in the search index',
  `section_plugin_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The help section the item comes from',
  `permission` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The permission needed to view this item',
  `topic_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The topic ID of the item',
  PRIMARY KEY (`sid`),
  KEY `section_plugin_id` (`section_plugin_id`),
  KEY `topic_id` (`topic_id`)
) ENGINE=InnoDB AUTO_INCREMENT=87 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores information about indexed help search items';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `help_search_items`
--

LOCK TABLES `help_search_items` WRITE;
/*!40000 ALTER TABLE `help_search_items` DISABLE KEYS */;
INSERT INTO `help_search_items` VALUES (1,'help_topics','','config.export_full'),(2,'help_topics','','config.export_single'),(3,'help_topics','','config.import_full'),(4,'help_topics','','config.import_single'),(5,'help_topics','','contact.adding_fields'),(6,'help_topics','','contact.configuring_personal'),(7,'help_topics','','contact.creating'),(8,'help_topics','','contact.overview'),(9,'help_topics','','contact.setting_default'),(10,'help_topics','','core.appearance'),(11,'help_topics','','core.config_overview'),(12,'help_topics','','core.content_structure'),(13,'help_topics','','core.cron'),(14,'help_topics','','core.extending'),(15,'help_topics','','core.maintenance'),(16,'help_topics','','core.media'),(17,'help_topics','','core.menus'),(18,'help_topics','','core.performance'),(19,'help_topics','','core.security'),(20,'help_topics','','core.settings_tray'),(21,'help_topics','','core.tracking_content'),(22,'help_topics','','core.translations'),(23,'help_topics','','core.ui_accessibility'),(24,'help_topics','','core.ui_components'),(25,'help_topics','','core.web_services'),(26,'help_topics','','help.help_topic_search'),(27,'help_topics','','help.overview'),(28,'help_topics','','search.configuring'),(29,'help_topics','','search.index'),(30,'help_topics','','search.overview'),(31,'help_topics','','system.cache'),(32,'help_topics','','system.config_basic'),(33,'help_topics','','system.config_error'),(34,'help_topics','','system.maintenance_mode'),(35,'help_topics','','system.module_install'),(36,'help_topics','','system.module_uninstall'),(37,'help_topics','','system.reports'),(38,'help_topics','','system.theme_install'),(39,'help_topics','','system.theme_uninstall'),(40,'help_topics','','user.create'),(41,'help_topics','','user.new_role'),(42,'help_topics','','user.overview'),(43,'help_topics','','user.permissions'),(44,'help_topics','','user.security_account_settings'),(45,'help_topics','','user.update'),(46,'help_topics','','announcements_feed.overview'),(47,'help_topics','','block.configure'),(48,'help_topics','','block.overview'),(49,'help_topics','','block.place'),(50,'help_topics','','filter.overview'),(51,'help_topics','','block_content.add'),(52,'help_topics','','block_content.type'),(53,'help_topics','','breakpoint.overview'),(54,'help_topics','','editor.overview'),(55,'help_topics','','comment.configuring'),(56,'help_topics','','comment.creating_type'),(57,'help_topics','','comment.disabling'),(58,'help_topics','','comment.moderating'),(59,'help_topics','','comment.overview'),(60,'help_topics','','contextual.overview'),(61,'help_topics','','field_ui.add_field'),(62,'help_topics','','field_ui.manage_display'),(63,'help_topics','','field_ui.manage_form'),(64,'help_topics','','field_ui.reference_field'),(65,'help_topics','','node.creating_content'),(66,'help_topics','','node.creating_type'),(67,'help_topics','','node.editing'),(68,'help_topics','','node.overview'),(69,'help_topics','','history.tracking_user_content'),(70,'help_topics','','image.style'),(71,'help_topics','','views.overview'),(72,'help_topics','','menu_ui.content_type_configuration'),(73,'help_topics','','menu_ui.menu_item_add'),(74,'help_topics','','menu_ui.menu_operations'),(75,'help_topics','','menu_ui.overriding'),(76,'help_topics','','path.creating_alias'),(77,'help_topics','','path.editing_alias'),(78,'help_topics','','path.overview'),(79,'help_topics','','shortcut.overview'),(80,'help_topics','','taxonomy.configuring'),(81,'help_topics','','taxonomy.overview'),(82,'help_topics','','views_ui.add_display'),(83,'help_topics','','views_ui.bulk_operations'),(84,'help_topics','','views_ui.create'),(85,'help_topics','','views_ui.edit'),(86,'help_topics','','media.media_type');
/*!40000 ALTER TABLE `help_search_items` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `history`
--

DROP TABLE IF EXISTS `history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `history` (
  `uid` int NOT NULL DEFAULT '0' COMMENT 'The "users".uid that read the "node" nid.',
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid that was read.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp at which the read occurred.',
  PRIMARY KEY (`uid`,`nid`),
  KEY `nid` (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='A record of which "users" have read which "node"s.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `history`
--

LOCK TABLES `history` WRITE;
/*!40000 ALTER TABLE `history` DISABLE KEYS */;
INSERT INTO `history` VALUES (1,1,1735498895);
/*!40000 ALTER TABLE `history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `key_value`
--

DROP TABLE IF EXISTS `key_value`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `key_value` (
  `collection` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A named collection of key and value pairs.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The key of the key-value pair. As KEY is a SQL reserved keyword, name was chosen instead.',
  `value` longblob NOT NULL COMMENT 'The value.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Generic key-value storage table. See the state system for…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `key_value`
--

LOCK TABLES `key_value` WRITE;
/*!40000 ALTER TABLE `key_value` DISABLE KEYS */;
INSERT INTO `key_value` VALUES ('config.entity.key_store.action','uuid:0619fb37-5dfd-48c9-b73d-4fce7ba4215b',_binary 'a:1:{i:0;s:35:\"system.action.webform_delete_action\";}'),('config.entity.key_store.action','uuid:0640984c-3787-4c25-8abe-073f6ff633cc',_binary 'a:1:{i:0;s:39:\"system.action.node_make_unsticky_action\";}'),('config.entity.key_store.action','uuid:07d84567-f6ce-480c-94fe-71f48ce157b7',_binary 'a:1:{i:0;s:44:\"system.action.taxonomy_term_unpublish_action\";}'),('config.entity.key_store.action','uuid:080a7d5c-2fda-47ed-b9aa-be9cb07b6d2e',_binary 'a:1:{i:0;s:48:\"system.action.user_add_role_action.administrator\";}'),('config.entity.key_store.action','uuid:2003aeb9-8fd3-4006-8c7f-9129bef1a808',_binary 'a:1:{i:0;s:37:\"system.action.node_make_sticky_action\";}'),('config.entity.key_store.action','uuid:29499598-fb70-43f6-a160-d2522304d4e7',_binary 'a:1:{i:0;s:35:\"system.action.node_unpromote_action\";}'),('config.entity.key_store.action','uuid:34872d09-0b48-4090-a401-75dc2bd3358d',_binary 'a:1:{i:0;s:35:\"system.action.node_unpublish_action\";}'),('config.entity.key_store.action','uuid:3d61837a-a6e2-456c-856f-a7adae28d2bb',_binary 'a:1:{i:0;s:46:\"system.action.webform_submission_delete_action\";}'),('config.entity.key_store.action','uuid:455e72bb-d5c2-4233-8fae-fe874a5aecde',_binary 'a:1:{i:0;s:32:\"system.action.node_delete_action\";}'),('config.entity.key_store.action','uuid:59cad6a4-a038-45d4-98e9-6ace07f80050',_binary 'a:1:{i:0;s:36:\"system.action.media_unpublish_action\";}'),('config.entity.key_store.action','uuid:5ee77a15-afb1-4e0c-bd3b-3e462abe568d',_binary 'a:1:{i:0;s:34:\"system.action.media_publish_action\";}'),('config.entity.key_store.action','uuid:6e3d2ae5-f68b-4adb-8345-78fe6e53c835',_binary 'a:1:{i:0;s:33:\"system.action.node_publish_action\";}'),('config.entity.key_store.action','uuid:6f753574-2b6f-4e3a-87fd-04f281182309',_binary 'a:1:{i:0;s:35:\"system.action.comment_delete_action\";}'),('config.entity.key_store.action','uuid:70329b07-23bf-43c7-837b-913d499e1542',_binary 'a:1:{i:0;s:33:\"system.action.webform_open_action\";}'),('config.entity.key_store.action','uuid:7317c388-dffd-422a-b041-7ef8597810b4',_binary 'a:1:{i:0;s:37:\"system.action.user_cancel_user_action\";}'),('config.entity.key_store.action','uuid:7ff39d45-7ef9-4e69-a87b-aa71ae0d4343',_binary 'a:1:{i:0;s:30:\"system.action.node_save_action\";}'),('config.entity.key_store.action','uuid:8509e01a-1fe0-4d2b-80fe-6292c7281beb',_binary 'a:1:{i:0;s:42:\"system.action.taxonomy_term_publish_action\";}'),('config.entity.key_store.action','uuid:879c5dbe-c854-4240-b44b-cc9946b7e95b',_binary 'a:1:{i:0;s:38:\"system.action.user_unblock_user_action\";}'),('config.entity.key_store.action','uuid:93459360-b66a-4249-92eb-59a0d4b9e585',_binary 'a:1:{i:0;s:33:\"system.action.node_promote_action\";}'),('config.entity.key_store.action','uuid:9b97ffc0-0ba9-48fc-9e78-a23777ef7ff4',_binary 'a:1:{i:0;s:31:\"system.action.media_save_action\";}'),('config.entity.key_store.action','uuid:a09349ec-38d9-4ee0-b772-074a9b406491',_binary 'a:1:{i:0;s:38:\"system.action.comment_unpublish_action\";}'),('config.entity.key_store.action','uuid:a0a0e6d5-cedc-45c4-8750-df65a9373a61',_binary 'a:1:{i:0;s:34:\"system.action.webform_close_action\";}'),('config.entity.key_store.action','uuid:a37fdd16-b916-42c7-a79a-e453486aa560',_binary 'a:1:{i:0;s:49:\"system.action.webform_submission_make_lock_action\";}'),('config.entity.key_store.action','uuid:a3ac7eaa-5ae2-4c20-abbb-79b198424e39',_binary 'a:1:{i:0;s:51:\"system.action.user_remove_role_action.administrator\";}'),('config.entity.key_store.action','uuid:c5c70bbf-efd5-4883-84bc-42f7d15ffaff',_binary 'a:1:{i:0;s:51:\"system.action.webform_submission_make_unlock_action\";}'),('config.entity.key_store.action','uuid:c8e0fba3-a9ea-40bc-9886-42d52bf69615',_binary 'a:1:{i:0;s:36:\"system.action.comment_publish_action\";}'),('config.entity.key_store.action','uuid:d1026225-bc14-481f-8e03-d69eb659f34d',_binary 'a:1:{i:0;s:53:\"system.action.webform_submission_make_unsticky_action\";}'),('config.entity.key_store.action','uuid:d787e419-708a-4026-aecb-296369189495',_binary 'a:1:{i:0;s:51:\"system.action.webform_submission_make_sticky_action\";}'),('config.entity.key_store.action','uuid:daca732c-22a4-42c1-a3c8-d54dae2a458c',_binary 'a:1:{i:0;s:52:\"system.action.user_remove_role_action.content_editor\";}'),('config.entity.key_store.action','uuid:e33f0ef8-e9df-400f-b24b-60c0f3497768',_binary 'a:1:{i:0;s:49:\"system.action.user_add_role_action.content_editor\";}'),('config.entity.key_store.action','uuid:ec2616be-d2d8-4d45-b01a-1ae5413b4160',_binary 'a:1:{i:0;s:36:\"system.action.webform_archive_action\";}'),('config.entity.key_store.action','uuid:ec45edef-e3ef-44f8-87d8-428346ac0579',_binary 'a:1:{i:0;s:36:\"system.action.user_block_user_action\";}'),('config.entity.key_store.action','uuid:f1bc7d4d-af95-4d2e-86fe-74ba836349ef',_binary 'a:1:{i:0;s:38:\"system.action.webform_unarchive_action\";}'),('config.entity.key_store.action','uuid:f2a7400a-fd44-4225-906e-c04f6f5f8944',_binary 'a:1:{i:0;s:33:\"system.action.comment_save_action\";}'),('config.entity.key_store.action','uuid:f8932ff6-cc40-43b7-9cd8-7fefb06c44cf',_binary 'a:1:{i:0;s:33:\"system.action.media_delete_action\";}'),('config.entity.key_store.base_field_override','uuid:3818335f-a764-468f-ba14-8dbe325fa7f3',_binary 'a:1:{i:0;s:42:\"core.base_field_override.node.page.promote\";}'),('config.entity.key_store.block','theme:claro',_binary 'a:8:{i:0;s:31:\"block.block.claro_local_actions\";i:1;s:28:\"block.block.claro_page_title\";i:2;s:37:\"block.block.claro_primary_local_tasks\";i:3;s:39:\"block.block.claro_secondary_local_tasks\";i:4;s:22:\"block.block.claro_help\";i:6;s:29:\"block.block.claro_breadcrumbs\";i:7;s:25:\"block.block.claro_content\";i:8;s:26:\"block.block.claro_messages\";}'),('config.entity.key_store.block','theme:ept_light',_binary 'a:12:{i:0;s:34:\"block.block.ept_light_account_menu\";i:1;s:33:\"block.block.ept_light_breadcrumbs\";i:2;s:29:\"block.block.ept_light_content\";i:3;s:26:\"block.block.ept_light_help\";i:4;s:31:\"block.block.ept_light_main_menu\";i:5;s:30:\"block.block.ept_light_messages\";i:6;s:32:\"block.block.ept_light_page_title\";i:8;s:43:\"block.block.ept_light_primary_admin_actions\";i:9;s:41:\"block.block.ept_light_primary_local_tasks\";i:12;s:43:\"block.block.ept_light_secondary_local_tasks\";i:13;s:35:\"block.block.ept_light_site_branding\";i:14;s:28:\"block.block.ept_light_footer\";}'),('config.entity.key_store.block','theme:gin',_binary 'a:8:{i:0;s:29:\"block.block.gin_local_actions\";i:1;s:26:\"block.block.gin_page_title\";i:2;s:35:\"block.block.gin_primary_local_tasks\";i:3;s:37:\"block.block.gin_secondary_local_tasks\";i:4;s:20:\"block.block.gin_help\";i:5;s:27:\"block.block.gin_breadcrumbs\";i:6;s:23:\"block.block.gin_content\";i:7;s:24:\"block.block.gin_messages\";}'),('config.entity.key_store.block','theme:olivero',_binary 'a:13:{i:0;s:24:\"block.block.olivero_help\";i:1;s:30:\"block.block.olivero_page_title\";i:2;s:41:\"block.block.olivero_primary_admin_actions\";i:3;s:39:\"block.block.olivero_primary_local_tasks\";i:4;s:41:\"block.block.olivero_secondary_local_tasks\";i:5;s:29:\"block.block.olivero_syndicate\";i:8;s:31:\"block.block.olivero_breadcrumbs\";i:9;s:27:\"block.block.olivero_content\";i:10;s:28:\"block.block.olivero_messages\";i:11;s:27:\"block.block.olivero_powered\";i:12;s:33:\"block.block.olivero_site_branding\";i:13;s:32:\"block.block.olivero_account_menu\";i:14;s:29:\"block.block.olivero_main_menu\";}'),('config.entity.key_store.block','uuid:07cc9530-0745-41b8-a927-b15f94d11bfb',_binary 'a:1:{i:0;s:28:\"block.block.olivero_messages\";}'),('config.entity.key_store.block','uuid:11d088e1-eb0e-4d66-ac1d-c629d4c31759',_binary 'a:1:{i:0;s:37:\"block.block.gin_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:19cc65dc-0021-4f62-9692-28154e28e6d6',_binary 'a:1:{i:0;s:31:\"block.block.olivero_breadcrumbs\";}'),('config.entity.key_store.block','uuid:1f0cb4e0-55ff-4097-a00c-015a0892bae5',_binary 'a:1:{i:0;s:24:\"block.block.olivero_help\";}'),('config.entity.key_store.block','uuid:2889853d-c6c8-46fb-8345-4f1161d60b42',_binary 'a:1:{i:0;s:41:\"block.block.olivero_primary_admin_actions\";}'),('config.entity.key_store.block','uuid:302175a6-2514-4728-9834-feade3c1cb23',_binary 'a:1:{i:0;s:24:\"block.block.gin_messages\";}'),('config.entity.key_store.block','uuid:360ce22f-fdb1-4a74-baf4-b253df6d8b6d',_binary 'a:1:{i:0;s:32:\"block.block.olivero_account_menu\";}'),('config.entity.key_store.block','uuid:37f8f7d2-81b3-4c42-a9a4-84cb29380e2c',_binary 'a:1:{i:0;s:26:\"block.block.gin_page_title\";}'),('config.entity.key_store.block','uuid:38507368-0a7f-4498-a629-376fb4821455',_binary 'a:1:{i:0;s:23:\"block.block.gin_content\";}'),('config.entity.key_store.block','uuid:3b00e68f-1ed0-4482-b8b1-e496f1da9936',_binary 'a:1:{i:0;s:26:\"block.block.claro_messages\";}'),('config.entity.key_store.block','uuid:447aab50-0670-4a09-ad2b-204da3cad682',_binary 'a:1:{i:0;s:29:\"block.block.olivero_main_menu\";}'),('config.entity.key_store.block','uuid:45129ab9-c3af-46c1-b266-7caf3e552d05',_binary 'a:1:{i:0;s:27:\"block.block.olivero_content\";}'),('config.entity.key_store.block','uuid:4a702f15-1477-4e9c-a8bf-5c98f5bff5f5',_binary 'a:1:{i:0;s:39:\"block.block.olivero_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:4e19c95d-851d-48dd-8e91-3df3501787a3',_binary 'a:1:{i:0;s:27:\"block.block.olivero_powered\";}'),('config.entity.key_store.block','uuid:56ef6a64-122b-4123-89be-e28c850c9ab5',_binary 'a:1:{i:0;s:41:\"block.block.ept_light_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:5e004719-546a-4a9e-8ed6-bce3b1438316',_binary 'a:1:{i:0;s:33:\"block.block.olivero_site_branding\";}'),('config.entity.key_store.block','uuid:7010f57e-634e-4b97-8a69-97b80a011cb4',_binary 'a:1:{i:0;s:33:\"block.block.ept_light_breadcrumbs\";}'),('config.entity.key_store.block','uuid:736d4519-e22a-419a-87cd-009a768a73b7',_binary 'a:1:{i:0;s:31:\"block.block.ept_light_main_menu\";}'),('config.entity.key_store.block','uuid:7b17ab28-0376-4ee3-91ee-5bd02432291e',_binary 'a:1:{i:0;s:29:\"block.block.ept_light_content\";}'),('config.entity.key_store.block','uuid:877e883f-c61a-49fd-bf14-7370c20fec8c',_binary 'a:1:{i:0;s:35:\"block.block.gin_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:8ed1a440-61c0-42d9-af64-c0573a386802',_binary 'a:1:{i:0;s:30:\"block.block.olivero_page_title\";}'),('config.entity.key_store.block','uuid:8edfdbdd-cd33-4ebe-b1d4-74fb38d1039e',_binary 'a:1:{i:0;s:26:\"block.block.ept_light_help\";}'),('config.entity.key_store.block','uuid:901eabdd-054d-4bcb-9773-45c7fd010fdf',_binary 'a:1:{i:0;s:43:\"block.block.ept_light_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:906009a1-78bd-4b80-9f60-5260448561b2',_binary 'a:1:{i:0;s:27:\"block.block.gin_breadcrumbs\";}'),('config.entity.key_store.block','uuid:916365b2-7723-493b-8918-5f3ff7d57c7d',_binary 'a:1:{i:0;s:31:\"block.block.claro_local_actions\";}'),('config.entity.key_store.block','uuid:91c1ee17-a1ad-4235-992c-274ff1022382',_binary 'a:1:{i:0;s:35:\"block.block.ept_light_site_branding\";}'),('config.entity.key_store.block','uuid:a78731d9-6557-4805-9b50-71d93a910730',_binary 'a:1:{i:0;s:28:\"block.block.ept_light_footer\";}'),('config.entity.key_store.block','uuid:a8c9d41b-02e1-478d-85b3-fb3a1f815f49',_binary 'a:1:{i:0;s:37:\"block.block.claro_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:b7350fce-d849-4243-936a-283b164fea04',_binary 'a:1:{i:0;s:41:\"block.block.olivero_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:b76f1641-4f78-438e-a0fe-ce65bd7f9006',_binary 'a:1:{i:0;s:28:\"block.block.claro_page_title\";}'),('config.entity.key_store.block','uuid:b7ad69dc-b6ab-4ee3-ab50-2994b490c801',_binary 'a:1:{i:0;s:29:\"block.block.olivero_syndicate\";}'),('config.entity.key_store.block','uuid:bb1e9b33-93c2-4829-9613-e4ccc525f30b',_binary 'a:1:{i:0;s:39:\"block.block.claro_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:be976f48-8227-4e04-b46e-05849e446c76',_binary 'a:1:{i:0;s:29:\"block.block.claro_breadcrumbs\";}'),('config.entity.key_store.block','uuid:c8fc509e-9767-4eae-81f5-6cdbe64aa2b3',_binary 'a:1:{i:0;s:30:\"block.block.ept_light_messages\";}'),('config.entity.key_store.block','uuid:ce83be5e-1fd7-4a0f-9b06-0a0d8710cb26',_binary 'a:1:{i:0;s:25:\"block.block.claro_content\";}'),('config.entity.key_store.block','uuid:d66baf8e-252f-4c79-acb6-b8b6d6b0a27a',_binary 'a:1:{i:0;s:22:\"block.block.claro_help\";}'),('config.entity.key_store.block','uuid:e3753ad7-7b76-4f93-add9-02296fe5a072',_binary 'a:1:{i:0;s:20:\"block.block.gin_help\";}'),('config.entity.key_store.block','uuid:f127d369-8154-4de3-9366-638b32c1d495',_binary 'a:1:{i:0;s:29:\"block.block.gin_local_actions\";}'),('config.entity.key_store.block','uuid:f35c55e3-3d40-497f-9b7f-2896cbc2e345',_binary 'a:1:{i:0;s:34:\"block.block.ept_light_account_menu\";}'),('config.entity.key_store.block','uuid:f45a0a49-c001-47cb-b97e-767aac0f24f2',_binary 'a:1:{i:0;s:32:\"block.block.ept_light_page_title\";}'),('config.entity.key_store.block','uuid:feb5ed42-838e-41fe-bce3-ac32e38425f9',_binary 'a:1:{i:0;s:43:\"block.block.ept_light_primary_admin_actions\";}'),('config.entity.key_store.block_content_type','uuid:682f8d4b-7fbf-4b68-aeeb-78ff6ffa44c8',_binary 'a:1:{i:0;s:24:\"block_content.type.basic\";}'),('config.entity.key_store.comment_type','uuid:33c6c326-f5e0-4ece-8508-28b245963a92',_binary 'a:1:{i:0;s:20:\"comment.type.comment\";}'),('config.entity.key_store.contact_form','uuid:3d45f5dc-8385-44e2-add9-10e58ad548b8',_binary 'a:1:{i:0;s:21:\"contact.form.personal\";}'),('config.entity.key_store.contact_form','uuid:d9d62dfa-bada-46f4-869f-64b74f835a2f',_binary 'a:1:{i:0;s:21:\"contact.form.feedback\";}'),('config.entity.key_store.date_format','uuid:045e5b96-3ec2-48a7-ba8c-c6cd6c3e6478',_binary 'a:1:{i:0;s:26:\"core.date_format.html_year\";}'),('config.entity.key_store.date_format','uuid:1db472d5-aa8d-43d1-99f1-0718ae5620bf',_binary 'a:1:{i:0;s:27:\"core.date_format.html_month\";}'),('config.entity.key_store.date_format','uuid:1e7ea1cc-62aa-4605-b6b6-e50e8e13c716',_binary 'a:1:{i:0;s:26:\"core.date_format.html_date\";}'),('config.entity.key_store.date_format','uuid:26c2a255-dd57-40de-9edb-d3ecd4eafa69',_binary 'a:1:{i:0;s:21:\"core.date_format.long\";}'),('config.entity.key_store.date_format','uuid:3d36a601-a518-4117-b489-72f027a4d007',_binary 'a:1:{i:0;s:25:\"core.date_format.fallback\";}'),('config.entity.key_store.date_format','uuid:504c65d8-2f56-4376-8b9b-e7ca5b007ba8',_binary 'a:1:{i:0;s:26:\"core.date_format.html_time\";}'),('config.entity.key_store.date_format','uuid:9c97ee83-74c2-4456-80d2-eb94e9ca333e',_binary 'a:1:{i:0;s:26:\"core.date_format.html_week\";}'),('config.entity.key_store.date_format','uuid:b3b94f80-dd74-4a2f-b128-51de30c5e289',_binary 'a:1:{i:0;s:23:\"core.date_format.medium\";}'),('config.entity.key_store.date_format','uuid:c34d2a68-a9e5-40c6-8224-8940032e30eb',_binary 'a:1:{i:0;s:30:\"core.date_format.html_datetime\";}'),('config.entity.key_store.date_format','uuid:c5c2ce9a-1442-4bf1-a654-b45e23c4b6e3',_binary 'a:1:{i:0;s:22:\"core.date_format.short\";}'),('config.entity.key_store.date_format','uuid:ebd666ec-7725-4d54-8907-f69b8c4e48ec',_binary 'a:1:{i:0;s:35:\"core.date_format.html_yearless_date\";}'),('config.entity.key_store.date_format','uuid:f5992887-d80e-47c5-bcb3-28c304448abb',_binary 'a:1:{i:0;s:31:\"core.date_format.olivero_medium\";}'),('config.entity.key_store.editor','uuid:5b65cbab-6e9a-450e-a54e-4c334c4ca75d',_binary 'a:1:{i:0;s:23:\"editor.editor.full_html\";}'),('config.entity.key_store.editor','uuid:a5122dd4-68d5-4282-a77b-0ad04cf12b8a',_binary 'a:1:{i:0;s:29:\"editor.editor.webform_default\";}'),('config.entity.key_store.editor','uuid:de26b70d-0b5e-4129-a929-f1de8a455f1b',_binary 'a:1:{i:0;s:24:\"editor.editor.basic_html\";}'),('config.entity.key_store.entity_form_display','uuid:063fafbf-a44a-44d9-b44e-e6b7f1c968f2',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_block.default\";}'),('config.entity.key_store.entity_form_display','uuid:0a168361-abfe-403a-8922-8305dbbef7af',_binary 'a:1:{i:0;s:51:\"core.entity_form_display.paragraph.ept_text.default\";}'),('config.entity.key_store.entity_form_display','uuid:0e9a2579-f110-4139-81b2-dc1025db5053',_binary 'a:1:{i:0;s:64:\"core.entity_form_display.paragraph.ept_slick_slider_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:1003a694-14ea-404d-bf58-34d4ad51a83c',_binary 'a:1:{i:0;s:56:\"core.entity_form_display.paragraph.ept_slideshow.default\";}'),('config.entity.key_store.entity_form_display','uuid:11f77720-51d3-4dc6-b653-b86d5771046b',_binary 'a:1:{i:0;s:57:\"core.entity_form_display.paragraph.ept_stats_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:1912a858-abb3-4ca8-aa94-e9265ace4567',_binary 'a:1:{i:0;s:44:\"core.entity_form_display.media.audio.default\";}'),('config.entity.key_store.entity_form_display','uuid:209743da-7b46-410c-8256-e9acf9b4200b',_binary 'a:1:{i:0;s:60:\"core.entity_form_display.paragraph.ept_carousel_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:21a9c7b6-423a-4c02-931a-6bb7c808ca5e',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.block_content.basic.default\";}'),('config.entity.key_store.entity_form_display','uuid:2a6ec3c5-051d-451f-bfa5-ae16ca4d9cc1',_binary 'a:1:{i:0;s:70:\"core.entity_form_display.paragraph.ept_video_and_image_gallery.default\";}'),('config.entity.key_store.entity_form_display','uuid:2ba6d267-9074-4e3c-a4c5-e392e2e1b8ec',_binary 'a:1:{i:0;s:56:\"core.entity_form_display.paragraph.ept_tabs_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:343bdaca-8837-45f9-9879-bc37b630068f',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_cards.default\";}'),('config.entity.key_store.entity_form_display','uuid:39e1a15a-eab7-4dcc-af37-af10f81e96dd',_binary 'a:1:{i:0;s:63:\"core.entity_form_display.paragraph.ept_bootstrap_button.default\";}'),('config.entity.key_store.entity_form_display','uuid:3b42b32b-b440-4ab8-9a73-96284648f0b9',_binary 'a:1:{i:0;s:55:\"core.entity_form_display.paragraph.ept_carousel.default\";}'),('config.entity.key_store.entity_form_display','uuid:3bbc19b5-b8d1-4737-93da-814614ad0da5',_binary 'a:1:{i:0;s:59:\"core.entity_form_display.paragraph.ept_basic_button.default\";}'),('config.entity.key_store.entity_form_display','uuid:3d683f4e-cbb1-4a0e-b1df-f9f9c87e4284',_binary 'a:1:{i:0;s:50:\"core.entity_form_display.media.video.media_library\";}'),('config.entity.key_store.entity_form_display','uuid:45b2e5a1-2031-4177-b3c2-580549849e46',_binary 'a:1:{i:0;s:57:\"core.entity_form_display.paragraph.ept_tiles_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:46bc1cc1-610e-4909-9538-f9f08a6a24c0',_binary 'a:1:{i:0;s:48:\"core.entity_form_display.comment.comment.default\";}'),('config.entity.key_store.entity_form_display','uuid:47cd5408-95d9-4b89-a9c5-7d8aedd625f0',_binary 'a:1:{i:0;s:57:\"core.entity_form_display.media.remote_video.media_library\";}'),('config.entity.key_store.entity_form_display','uuid:483f7e15-2bcb-4ed9-952b-548c4960e622',_binary 'a:1:{i:0;s:61:\"core.entity_form_display.paragraph.ept_slideshow_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:4c160f87-d7c6-4dde-a9d2-878ce2336387',_binary 'a:1:{i:0;s:50:\"core.entity_form_display.media.audio.media_library\";}'),('config.entity.key_store.entity_form_display','uuid:4fadf498-bcbb-44d6-b829-6d1abdabf326',_binary 'a:1:{i:0;s:54:\"core.entity_form_display.paragraph.ept_columns.default\";}'),('config.entity.key_store.entity_form_display','uuid:5a1fd1b5-9098-41dc-99e7-65246d6fe6da',_binary 'a:1:{i:0;s:75:\"core.entity_form_display.paragraph.ept_video_and_image_gallery_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:5f9fd1ed-53a9-4349-8202-c90230a11f12',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_views.default\";}'),('config.entity.key_store.entity_form_display','uuid:62a89609-5a89-4eb4-a5a2-c3c58c93480d',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_quote.default\";}'),('config.entity.key_store.entity_form_display','uuid:6b2455af-c7c1-4faf-ae2f-5faf8b33c82d',_binary 'a:1:{i:0;s:59:\"core.entity_form_display.paragraph.ept_slick_slider.default\";}'),('config.entity.key_store.entity_form_display','uuid:6e0ad4c3-90f1-4e63-9ad2-e7c012a124d2',_binary 'a:1:{i:0;s:54:\"core.entity_form_display.paragraph.ept_counter.default\";}'),('config.entity.key_store.entity_form_display','uuid:71680c26-8af6-49c5-94f2-7276e46d9545',_binary 'a:1:{i:0;s:60:\"core.entity_form_display.paragraph.ept_webform_popup.default\";}'),('config.entity.key_store.entity_form_display','uuid:7c5e18c3-3d08-4151-8d31-a9d9a597a5ee',_binary 'a:1:{i:0;s:44:\"core.entity_form_display.media.video.default\";}'),('config.entity.key_store.entity_form_display','uuid:8323a260-ffc2-4476-8123-c40c72552a6e',_binary 'a:1:{i:0;s:53:\"core.entity_form_display.media.document.media_library\";}'),('config.entity.key_store.entity_form_display','uuid:8a29f047-88c0-4af9-8cd2-705177201f7a',_binary 'a:1:{i:0;s:50:\"core.entity_form_display.paragraph.ept_cta.default\";}'),('config.entity.key_store.entity_form_display','uuid:8c95a60e-1c70-45a6-b8a2-c4d53b93ce5d',_binary 'a:1:{i:0;s:59:\"core.entity_form_display.paragraph.ept_counter_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:8eb5837f-793f-476b-8d5b-8eb1ea190520',_binary 'a:1:{i:0;s:42:\"core.entity_form_display.user.user.default\";}'),('config.entity.key_store.entity_form_display','uuid:91fbcfb7-0a83-434f-99ac-c23c349657be',_binary 'a:1:{i:0;s:50:\"core.entity_form_display.media.image.media_library\";}'),('config.entity.key_store.entity_form_display','uuid:97a32351-c013-445a-af13-08939389c3b1',_binary 'a:1:{i:0;s:51:\"core.entity_form_display.media.remote_video.default\";}'),('config.entity.key_store.entity_form_display','uuid:a18df3e8-1c60-449a-81fb-3d8f4dc347dc',_binary 'a:1:{i:0;s:64:\"core.entity_form_display.paragraph.ept_accordion_section.default\";}'),('config.entity.key_store.entity_form_display','uuid:a5784c00-a16b-4f3b-91dd-568be1356d3a',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_tiles.default\";}'),('config.entity.key_store.entity_form_display','uuid:a60ae7a6-353d-412e-81ca-b8eff5eb6f78',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_image.default\";}'),('config.entity.key_store.entity_form_display','uuid:a9e1d9c8-64cb-4c33-ae6e-7c4617fa82d4',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_stats.default\";}'),('config.entity.key_store.entity_form_display','uuid:bcf372a8-c025-4ef1-bc1e-7467ead740ff',_binary 'a:1:{i:0;s:56:\"core.entity_form_display.paragraph.ept_accordion.default\";}'),('config.entity.key_store.entity_form_display','uuid:bd32a1a0-f63c-4e6b-b14f-7dfa6323a07a',_binary 'a:1:{i:0;s:60:\"core.entity_form_display.paragraph.ept_image_gallery.default\";}'),('config.entity.key_store.entity_form_display','uuid:be53fd67-518c-4b3c-ac43-3b2c15a8d954',_binary 'a:1:{i:0;s:51:\"core.entity_form_display.paragraph.ept_hero.default\";}'),('config.entity.key_store.entity_form_display','uuid:c0e1ca3f-d656-43c4-a362-86c7cb0ac490',_binary 'a:1:{i:0;s:57:\"core.entity_form_display.paragraph.ept_micromodal.default\";}'),('config.entity.key_store.entity_form_display','uuid:c24b87ec-64f6-4fa0-aed7-1c3d86160e5e',_binary 'a:1:{i:0;s:47:\"core.entity_form_display.media.document.default\";}'),('config.entity.key_store.entity_form_display','uuid:c6ec1d38-d434-4a7d-be65-080873fd0aff',_binary 'a:1:{i:0;s:42:\"core.entity_form_display.node.page.default\";}'),('config.entity.key_store.entity_form_display','uuid:d798701f-5b10-44f6-b850-ac38718396b6',_binary 'a:1:{i:0;s:54:\"core.entity_form_display.paragraph.ept_webform.default\";}'),('config.entity.key_store.entity_form_display','uuid:de67467e-664b-4fd4-b096-f4f20912ea91',_binary 'a:1:{i:0;s:45:\"core.entity_form_display.node.article.default\";}'),('config.entity.key_store.entity_form_display','uuid:e1a6c8e5-95b1-4c04-8b08-798a42e3f990',_binary 'a:1:{i:0;s:51:\"core.entity_form_display.paragraph.ept_tabs.default\";}'),('config.entity.key_store.entity_form_display','uuid:ed55009f-a01e-42ae-987d-b5ccc04e073b',_binary 'a:1:{i:0;s:56:\"core.entity_form_display.paragraph.ept_countdown.default\";}'),('config.entity.key_store.entity_form_display','uuid:f08ad847-8b1c-4396-9081-ca9a56f6b01a',_binary 'a:1:{i:0;s:44:\"core.entity_form_display.media.image.default\";}'),('config.entity.key_store.entity_form_display','uuid:fe1a956f-1eb5-49f4-8ccd-d852faeeea9d',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_video.default\";}'),('config.entity.key_store.entity_form_mode','uuid:94fd7791-9806-4755-a50f-91d35400a4cb',_binary 'a:1:{i:0;s:41:\"core.entity_form_mode.media.media_library\";}'),('config.entity.key_store.entity_form_mode','uuid:ef62034d-b624-4a32-9e4a-54a2baf7fa78',_binary 'a:1:{i:0;s:35:\"core.entity_form_mode.user.register\";}'),('config.entity.key_store.entity_view_display','uuid:077ee820-2041-4778-8135-0fc65cd20cb5',_binary 'a:1:{i:0;s:59:\"core.entity_view_display.paragraph.ept_counter_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:08b2118c-18b9-4669-b9e4-0786d49af6ef',_binary 'a:1:{i:0;s:56:\"core.entity_view_display.paragraph.ept_countdown.default\";}'),('config.entity.key_store.entity_view_display','uuid:0f767bd2-1919-4166-8346-62c5fc895c81',_binary 'a:1:{i:0;s:45:\"core.entity_view_display.node.article.default\";}'),('config.entity.key_store.entity_view_display','uuid:1053ac57-9af0-4e5b-ba2f-c5695c62ef08',_binary 'a:1:{i:0;s:50:\"core.entity_view_display.media.image.media_library\";}'),('config.entity.key_store.entity_view_display','uuid:113fc4a1-1a78-4da6-b222-3a4cd08a0def',_binary 'a:1:{i:0;s:56:\"core.entity_view_display.paragraph.ept_slideshow.default\";}'),('config.entity.key_store.entity_view_display','uuid:153a53c8-5121-4586-9a2d-42dbb61c9965',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_tiles.default\";}'),('config.entity.key_store.entity_view_display','uuid:19dfadc9-d9a4-4d4c-9953-240f406fe79c',_binary 'a:1:{i:0;s:44:\"core.entity_view_display.media.image.default\";}'),('config.entity.key_store.entity_view_display','uuid:1e04e293-6847-44fd-816b-d0cafeb9bfb1',_binary 'a:1:{i:0;s:57:\"core.entity_view_display.paragraph.ept_tiles_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:2727e08a-658f-4ab5-b47b-287082974eca',_binary 'a:1:{i:0;s:51:\"core.entity_view_display.paragraph.ept_hero.default\";}'),('config.entity.key_store.entity_view_display','uuid:273d4d81-bc41-43e6-bbfd-346c986e0c86',_binary 'a:1:{i:0;s:75:\"core.entity_view_display.paragraph.ept_video_and_image_gallery_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:2b90284a-5b66-4a1f-8feb-f7da7fba402f',_binary 'a:1:{i:0;s:57:\"core.entity_view_display.paragraph.ept_micromodal.default\";}'),('config.entity.key_store.entity_view_display','uuid:2c82ecbc-46e1-498d-9678-2831bf2e17b6',_binary 'a:1:{i:0;s:60:\"core.entity_view_display.paragraph.ept_webform_popup.default\";}'),('config.entity.key_store.entity_view_display','uuid:3027dd27-1f17-44e8-84f5-7366b5d87788',_binary 'a:1:{i:0;s:53:\"core.entity_view_display.media.document.media_library\";}'),('config.entity.key_store.entity_view_display','uuid:3c020353-d472-46d4-83e7-cc933ac7aa20',_binary 'a:1:{i:0;s:54:\"core.entity_view_display.paragraph.ept_webform.default\";}'),('config.entity.key_store.entity_view_display','uuid:49052cac-09f9-471f-8cc0-d9c144baf2ff',_binary 'a:1:{i:0;s:60:\"core.entity_view_display.paragraph.ept_image_gallery.default\";}'),('config.entity.key_store.entity_view_display','uuid:4bf53171-20df-4e38-bb87-a451cfc4aa6c',_binary 'a:1:{i:0;s:50:\"core.entity_view_display.paragraph.ept_cta.default\";}'),('config.entity.key_store.entity_view_display','uuid:4c097cad-2585-405b-86e6-5effe6d6f443',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_video.default\";}'),('config.entity.key_store.entity_view_display','uuid:4f8ec3e2-1797-492f-8b2d-8ce7545d59bc',_binary 'a:1:{i:0;s:54:\"core.entity_view_display.media.image.ept_image_gallery\";}'),('config.entity.key_store.entity_view_display','uuid:51e43f2e-4f69-45a1-95c7-5ecf07778894',_binary 'a:1:{i:0;s:53:\"core.entity_view_display.media.remote_video.ept_video\";}'),('config.entity.key_store.entity_view_display','uuid:53a48e63-4272-4544-9051-7617915e3d41',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.block_content.basic.default\";}'),('config.entity.key_store.entity_view_display','uuid:5672ce5e-9fb4-4800-8c9d-3b15ca3f7fde',_binary 'a:1:{i:0;s:50:\"core.entity_view_display.media.video.media_library\";}'),('config.entity.key_store.entity_view_display','uuid:63fe648a-c5c1-42b9-8b04-7bb9db119166',_binary 'a:1:{i:0;s:44:\"core.entity_view_display.media.video.default\";}'),('config.entity.key_store.entity_view_display','uuid:72019611-98d6-4f86-81ec-768c71520e64',_binary 'a:1:{i:0;s:76:\"core.entity_view_display.media.remote_video.ept_video_and_image_gallery_item\";}'),('config.entity.key_store.entity_view_display','uuid:772993d5-eed2-4b18-a6f6-28eb39e116b4',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_quote.default\";}'),('config.entity.key_store.entity_view_display','uuid:7da9a817-79f8-4bec-add7-e39bb0ba78c4',_binary 'a:1:{i:0;s:51:\"core.entity_view_display.paragraph.ept_tabs.default\";}'),('config.entity.key_store.entity_view_display','uuid:83448cb5-91c5-4a34-a576-3ea914fa7d6b',_binary 'a:1:{i:0;s:54:\"core.entity_view_display.paragraph.ept_columns.default\";}'),('config.entity.key_store.entity_view_display','uuid:87bcc8b2-7f6c-4c74-800a-a87d1b94f5f4',_binary 'a:1:{i:0;s:44:\"core.entity_view_display.media.audio.default\";}'),('config.entity.key_store.entity_view_display','uuid:8e1a5df7-4ec6-40ba-b5be-4d5d2b6f489f',_binary 'a:1:{i:0;s:57:\"core.entity_view_display.paragraph.ept_stats_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:8ee3416a-ed7c-41d9-a9fd-2b0aca7d452b',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_cards.default\";}'),('config.entity.key_store.entity_view_display','uuid:95f5dba7-e075-42d7-bb71-a987d5625124',_binary 'a:1:{i:0;s:60:\"core.entity_view_display.paragraph.ept_carousel_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:9ecc7509-3522-45c5-bda4-7ed77885a161',_binary 'a:1:{i:0;s:51:\"core.entity_view_display.media.remote_video.default\";}'),('config.entity.key_store.entity_view_display','uuid:a34b4adb-f67d-4569-90a5-e74b6a28bcdb',_binary 'a:1:{i:0;s:55:\"core.entity_view_display.paragraph.ept_carousel.default\";}'),('config.entity.key_store.entity_view_display','uuid:a5054ddd-1cf1-49bf-bb8f-790f40e08130',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_image.default\";}'),('config.entity.key_store.entity_view_display','uuid:a806c6af-6b6a-4398-a270-06147cb09d21',_binary 'a:1:{i:0;s:63:\"core.entity_view_display.paragraph.ept_bootstrap_button.default\";}'),('config.entity.key_store.entity_view_display','uuid:ad408e08-db1a-47df-8098-0b2a61f16481',_binary 'a:1:{i:0;s:54:\"core.entity_view_display.paragraph.ept_counter.default\";}'),('config.entity.key_store.entity_view_display','uuid:af3b0da5-5654-474f-b056-1b7fe53c1991',_binary 'a:1:{i:0;s:47:\"core.entity_view_display.media.document.default\";}'),('config.entity.key_store.entity_view_display','uuid:afa0542b-6646-4a58-8063-b778fe6b3423',_binary 'a:1:{i:0;s:42:\"core.entity_view_display.user.user.default\";}'),('config.entity.key_store.entity_view_display','uuid:b0bc3306-d88a-4581-af6c-2a1f29aac6ce',_binary 'a:1:{i:0;s:57:\"core.entity_view_display.media.remote_video.media_library\";}'),('config.entity.key_store.entity_view_display','uuid:b64bcaef-5bd0-446f-a6d5-7096df12851d',_binary 'a:1:{i:0;s:41:\"core.entity_view_display.node.page.teaser\";}'),('config.entity.key_store.entity_view_display','uuid:b696c09e-d916-4b49-a1c2-566c781bf923',_binary 'a:1:{i:0;s:44:\"core.entity_view_display.node.article.teaser\";}'),('config.entity.key_store.entity_view_display','uuid:b90a3de2-2933-49e5-8726-03f0e73085fa',_binary 'a:1:{i:0;s:56:\"core.entity_view_display.paragraph.ept_tabs_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:bad692de-34e5-483c-9717-c610a77e5be5',_binary 'a:1:{i:0;s:41:\"core.entity_view_display.node.article.rss\";}'),('config.entity.key_store.entity_view_display','uuid:bc183acd-cdee-4366-86c4-4db46beceef3',_binary 'a:1:{i:0;s:42:\"core.entity_view_display.node.page.default\";}'),('config.entity.key_store.entity_view_display','uuid:c452f408-f85b-4944-a31e-1bbef7fcda71',_binary 'a:1:{i:0;s:61:\"core.entity_view_display.paragraph.ept_slideshow_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:c47a77e8-55b1-49a2-adeb-dc69b79b24e0',_binary 'a:1:{i:0;s:69:\"core.entity_view_display.media.image.ept_video_and_image_gallery_item\";}'),('config.entity.key_store.entity_view_display','uuid:d0875a9d-cb50-4731-ac2a-fb25c1858dae',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_views.default\";}'),('config.entity.key_store.entity_view_display','uuid:d4e6aedc-c8f3-451b-94d6-cd44fc4b6c11',_binary 'a:1:{i:0;s:64:\"core.entity_view_display.paragraph.ept_accordion_section.default\";}'),('config.entity.key_store.entity_view_display','uuid:da002566-b092-4563-9d08-c4b5c52593e5',_binary 'a:1:{i:0;s:48:\"core.entity_view_display.comment.comment.default\";}'),('config.entity.key_store.entity_view_display','uuid:dfadbabc-626b-46a2-a063-3f65ad0c2b45',_binary 'a:1:{i:0;s:70:\"core.entity_view_display.paragraph.ept_video_and_image_gallery.default\";}'),('config.entity.key_store.entity_view_display','uuid:e06c8535-7973-44b5-8144-18baa167f488',_binary 'a:1:{i:0;s:51:\"core.entity_view_display.paragraph.ept_text.default\";}'),('config.entity.key_store.entity_view_display','uuid:e7417c73-82e0-49a6-b66c-942b3596d612',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_block.default\";}'),('config.entity.key_store.entity_view_display','uuid:e906e660-3e2c-436c-9fb5-1dc3aaa2d1a9',_binary 'a:1:{i:0;s:64:\"core.entity_view_display.paragraph.ept_slick_slider_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:ec282fce-d81d-4383-9a77-3fb87be08553',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_stats.default\";}'),('config.entity.key_store.entity_view_display','uuid:f4454fef-a659-4b88-9579-11ba22f32177',_binary 'a:1:{i:0;s:59:\"core.entity_view_display.paragraph.ept_basic_button.default\";}'),('config.entity.key_store.entity_view_display','uuid:f60b271e-f09b-45a9-8e92-1ae341b267f5',_binary 'a:1:{i:0;s:56:\"core.entity_view_display.paragraph.ept_accordion.default\";}'),('config.entity.key_store.entity_view_display','uuid:fa961609-f5ef-403a-8089-73f33b1e73f0',_binary 'a:1:{i:0;s:59:\"core.entity_view_display.paragraph.ept_carousel_item.slider\";}'),('config.entity.key_store.entity_view_display','uuid:fd378f17-2b7e-4025-89fa-c56cabc7bab2',_binary 'a:1:{i:0;s:42:\"core.entity_view_display.user.user.compact\";}'),('config.entity.key_store.entity_view_display','uuid:fd3c8ee0-7347-4825-a6ac-e712dc98946b',_binary 'a:1:{i:0;s:50:\"core.entity_view_display.media.audio.media_library\";}'),('config.entity.key_store.entity_view_display','uuid:febc7649-4ada-4466-aea7-1872bc394145',_binary 'a:1:{i:0;s:59:\"core.entity_view_display.paragraph.ept_slick_slider.default\";}'),('config.entity.key_store.entity_view_mode','uuid:18890f85-c8b4-4c37-a805-81e116c96c33',_binary 'a:1:{i:0;s:31:\"core.entity_view_mode.user.full\";}'),('config.entity.key_store.entity_view_mode','uuid:298a8e9e-ea9f-462a-9e62-03ff202ebda4',_binary 'a:1:{i:0;s:39:\"core.entity_view_mode.paragraph.preview\";}'),('config.entity.key_store.entity_view_mode','uuid:3096aebe-dabe-4849-b718-4be67ed1e0a2',_binary 'a:1:{i:0;s:31:\"core.entity_view_mode.node.full\";}'),('config.entity.key_store.entity_view_mode','uuid:3267d362-0cde-4190-8a4e-f368fdab39d5',_binary 'a:1:{i:0;s:34:\"core.entity_view_mode.user.compact\";}'),('config.entity.key_store.entity_view_mode','uuid:3e515c12-bfb7-4a38-9360-e1bebd522e14',_binary 'a:1:{i:0;s:40:\"core.entity_view_mode.block_content.full\";}'),('config.entity.key_store.entity_view_mode','uuid:4578cd26-ab79-41fc-b999-3224d7b96b78',_binary 'a:1:{i:0;s:41:\"core.entity_view_mode.media.media_library\";}'),('config.entity.key_store.entity_view_mode','uuid:562fdf9e-431f-4436-87cc-5edcb21506bf',_binary 'a:1:{i:0;s:30:\"core.entity_view_mode.node.rss\";}'),('config.entity.key_store.entity_view_mode','uuid:56447995-bbf0-4a46-b361-7337f6962da6',_binary 'a:1:{i:0;s:60:\"core.entity_view_mode.media.ept_video_and_image_gallery_item\";}'),('config.entity.key_store.entity_view_mode','uuid:5eb23a5d-001b-4f18-b772-c45ec412d4a1',_binary 'a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}'),('config.entity.key_store.entity_view_mode','uuid:8ae8b19f-547b-42bd-9d8f-a88c05759d47',_binary 'a:1:{i:0;s:37:\"core.entity_view_mode.media.ept_video\";}'),('config.entity.key_store.entity_view_mode','uuid:976815c3-f2f0-4a48-82b3-fb4ee2924c88',_binary 'a:1:{i:0;s:32:\"core.entity_view_mode.media.full\";}'),('config.entity.key_store.entity_view_mode','uuid:aaef918d-7b8e-4ea0-822a-44703c28e61c',_binary 'a:1:{i:0;s:34:\"core.entity_view_mode.comment.full\";}'),('config.entity.key_store.entity_view_mode','uuid:ac6b99d6-0ed0-46ea-97e8-2b17a00adab0',_binary 'a:1:{i:0;s:40:\"core.entity_view_mode.node.search_result\";}'),('config.entity.key_store.entity_view_mode','uuid:c1d7c975-f7cc-4e65-a0b5-d7a0b84e6fed',_binary 'a:1:{i:0;s:40:\"core.entity_view_mode.taxonomy_term.full\";}'),('config.entity.key_store.entity_view_mode','uuid:c2742453-7e21-4da9-b647-07ef5aca9cf3',_binary 'a:1:{i:0;s:45:\"core.entity_view_mode.media.ept_image_gallery\";}'),('config.entity.key_store.entity_view_mode','uuid:edab19fa-a328-4f2e-a4a2-bce49808300d',_binary 'a:1:{i:0;s:39:\"core.entity_view_mode.node.search_index\";}'),('config.entity.key_store.entity_view_mode','uuid:f0967983-7199-4bf7-8047-72fb6a840ca0',_binary 'a:1:{i:0;s:38:\"core.entity_view_mode.paragraph.slider\";}'),('config.entity.key_store.field_config','uuid:00840cc4-7392-4663-a414-47758f14db31',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";}'),('config.entity.key_store.field_config','uuid:0369fd76-8a03-4f51-98c8-2662289d77b1',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_basic_button.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:04f2459a-8250-49b8-9c26-a1bc5f23b1ce',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_slideshow.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:0570de2b-d581-4073-a8b0-0729eacf75eb',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_slick_slider.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:0a76e0e6-37a2-4e5e-a2ca-41101da17e1e',_binary 'a:1:{i:0;s:51:\"field.field.paragraph.ept_slideshow.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:0b1a6314-b982-4d68-89cc-0362ac441239',_binary 'a:1:{i:0;s:46:\"field.field.media.video.field_media_video_file\";}'),('config.entity.key_store.field_config','uuid:0c7eb82c-6093-4901-bd0b-fd48f6eedcb2',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_title\";}'),('config.entity.key_store.field_config','uuid:0cd4c4a7-feca-4fb7-9e8b-02984559941b',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:0d3eae73-ae6d-4601-b1d4-4df1d7d62c53',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_views.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:0f3cce54-16b4-433a-a3d8-f66dceadfb5e',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_carousel.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:1003b7da-189c-4687-89e9-fe627bd2f746',_binary 'a:1:{i:0;s:63:\"field.field.paragraph.ept_micromodal.field_ept_micromodal_title\";}'),('config.entity.key_store.field_config','uuid:123bb9be-f4f0-4e79-9c1f-5a74d1adc56a',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_image\";}'),('config.entity.key_store.field_config','uuid:15235fd9-9fad-4092-b19c-8e011debebfb',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_page\";}'),('config.entity.key_store.field_config','uuid:153fe814-ed15-45dd-ac36-e3166140cf03',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_counter.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:1b1a1524-2e19-47c4-af5c-c693044a59e0',_binary 'a:1:{i:0;s:72:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";}'),('config.entity.key_store.field_config','uuid:1c882037-c7e3-42e4-9707-af10c5015ef2',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_stats.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:254d23bc-cd9a-4186-b124-2f3fa923fc05',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_tiles.field_ept_tiles\";}'),('config.entity.key_store.field_config','uuid:27323f57-acfd-4aff-a508-544c6c8bdf3d',_binary 'a:1:{i:0;s:34:\"field.field.user.user.user_picture\";}'),('config.entity.key_store.field_config','uuid:28952958-350e-4fa8-b1bf-0526c52b982e',_binary 'a:1:{i:0;s:74:\"field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";}'),('config.entity.key_store.field_config','uuid:29c56f04-456b-4f6f-87b5-6352ddaa6a51',_binary 'a:1:{i:0;s:61:\"field.field.paragraph.ept_tiles_item.field_ept_clickable_tile\";}'),('config.entity.key_store.field_config','uuid:2bdd8485-4125-400d-b6ef-feffe57ca0b6',_binary 'a:1:{i:0;s:65:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:2d995ad8-7b72-4241-8c5b-bfb64c7a936a',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:2ea8eb6b-de2b-4de9-ac7c-5703ce8bc44f',_binary 'a:1:{i:0;s:40:\"field.field.comment.comment.comment_body\";}'),('config.entity.key_store.field_config','uuid:2eb61b2c-ee83-43b2-beb6-334f5562bc8c',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_cta.field_ept_cta_second_link\";}'),('config.entity.key_store.field_config','uuid:36557cf2-e64e-4835-ad8e-b5bbc8150e8e',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_countdown.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:38a67ca0-85d7-4dee-8871-eef6909b89f3',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_accordion.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:3988d015-d4a9-4560-9665-3defb0bfead9',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_columns.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:3b694b0c-21b1-40f1-aab1-5f8f6b508006',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_tabs.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:3d160c57-3e25-403d-8a51-0a0b3397f5eb',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_image_gallery.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:3f86759a-0926-49a9-a1b3-ebe22666f4d8',_binary 'a:1:{i:0;s:68:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_text\";}'),('config.entity.key_store.field_config','uuid:40656cb2-323c-4502-b916-5613d935c06a',_binary 'a:1:{i:0;s:56:\"field.field.paragraph.ept_cta.field_ept_cta_column_image\";}'),('config.entity.key_store.field_config','uuid:406dd338-600c-4eb2-841a-df635188cfb3',_binary 'a:1:{i:0;s:45:\"field.field.paragraph.ept_text.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:410f42b6-e143-4eb8-9c88-c13fd9c4c17f',_binary 'a:1:{i:0;s:41:\"field.field.media.image.field_media_image\";}'),('config.entity.key_store.field_config','uuid:440982f1-1d49-45ce-856f-cb3b95954c65',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_block.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:44deba9e-6935-4553-9ef0-ecc889381ae8',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_counter.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:484e5ed3-f463-4d7b-b27a-25b553c3a82b',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_basic_button.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:48e0dea0-fc4d-4a86-8ed4-203f0efe3a52',_binary 'a:1:{i:0;s:63:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_image\";}'),('config.entity.key_store.field_config','uuid:49f52820-ba38-497e-b59f-d89788210ff0',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_cards.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:4bad9ad2-5f7d-40ee-92a6-547badbee525',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_slick_slider.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:4be87c8b-a691-4546-9b46-8104a7920252',_binary 'a:1:{i:0;s:64:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_number\";}'),('config.entity.key_store.field_config','uuid:4ed02114-671f-4880-bd68-143fe1b70c33',_binary 'a:1:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";}'),('config.entity.key_store.field_config','uuid:51db6984-7e76-4d6a-be3b-8f052f3bae29',_binary 'a:1:{i:0;s:60:\"field.field.paragraph.ept_countdown.field_ept_countdown_date\";}'),('config.entity.key_store.field_config','uuid:532449b1-8d51-4c87-ad35-6a4555565967',_binary 'a:1:{i:0;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";}'),('config.entity.key_store.field_config','uuid:53805c44-6771-4268-b091-a3f4f1269139',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_counter.field_ept_counter_items\";}'),('config.entity.key_store.field_config','uuid:5c1e6fab-0fe9-4952-a3c8-991a0f293a80',_binary 'a:1:{i:0;s:64:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:5d8d9518-713c-4c54-a1b1-e9255a1064cf',_binary 'a:1:{i:0;s:45:\"field.field.paragraph.ept_tabs.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:5dcc6a7e-0a0a-4b27-8ec1-fc41c3bb654a',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";}'),('config.entity.key_store.field_config','uuid:5fbf0b1d-881b-44e3-9225-31e307913827',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_video.field_ept_video\";}'),('config.entity.key_store.field_config','uuid:5fd2a01d-4924-4824-af89-5638dcb01e07',_binary 'a:1:{i:0;s:69:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_title\";}'),('config.entity.key_store.field_config','uuid:60166fc5-cd70-42a2-ab4a-021bef6afcf3',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_title\";}'),('config.entity.key_store.field_config','uuid:64183760-d4b4-4088-905f-cc5481b32e41',_binary 'a:1:{i:0;s:38:\"field.field.node.page.field_components\";}'),('config.entity.key_store.field_config','uuid:6483f62f-11d2-44ea-bf5b-d0db486d3689',_binary 'a:1:{i:0;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide\";}'),('config.entity.key_store.field_config','uuid:64aa7603-d2f0-4050-a82f-35b5ef3b978f',_binary 'a:1:{i:0;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_link\";}'),('config.entity.key_store.field_config','uuid:65e27c50-82c3-46dd-ad6d-c95805dd83bf',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_video.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:6671231f-f98f-4ea0-a6ab-9bfe42290292',_binary 'a:1:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link\";}'),('config.entity.key_store.field_config','uuid:67b226bf-e2f6-418d-9999-d41f6b3d3825',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_webform_popup.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:68fe7948-f81f-4f36-8ce6-3a736d2696be',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_video.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:6902be14-683f-4f5a-8d50-8543bbf0aca5',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_text.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:6c45f2f3-d271-4c13-b678-675fb9cbc261',_binary 'a:1:{i:0;s:36:\"field.field.node.article.field_image\";}'),('config.entity.key_store.field_config','uuid:6d566515-d2a4-4ce3-96e1-678ae2feea9c',_binary 'a:1:{i:0;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";}'),('config.entity.key_store.field_config','uuid:70a56a53-e5dd-4fcf-99b5-29d8b6d4619b',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_webform.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:71eb6510-d311-4704-9d7a-147c6ba1fca0',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_accordion.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:720ab2af-faa7-4459-84ec-84810093337c',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_image.field_ept_image_caption\";}'),('config.entity.key_store.field_config','uuid:77455be2-5b47-46b9-a671-60e6534bb5da',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_webform_popup.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:77a71623-7050-467d-bbb6-f7e2b8e10f9d',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_link\";}'),('config.entity.key_store.field_config','uuid:77e74bf9-008e-4d96-9381-dc809ff7b841',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_columns.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:7a06dca5-73c0-4c47-a217-2f9d7f3b9d43',_binary 'a:1:{i:0;s:48:\"field.field.paragraph.ept_cta.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:7ab22f13-220c-400f-9f56-3043d91300ed',_binary 'a:1:{i:0;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_text\";}'),('config.entity.key_store.field_config','uuid:7c6589db-fb84-410a-a79c-846a25ff7d97',_binary 'a:1:{i:0;s:48:\"field.field.paragraph.ept_webform.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:7f39ca00-ae38-46ac-a2f2-ce0b4f545f9f',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_tiles.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:819b216b-97f6-4f18-82b6-2074094a280f',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_quote.field_ept_quote_author\";}'),('config.entity.key_store.field_config','uuid:81f724c9-9e84-4627-825c-4d7ea016d18e',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_webform_popup.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:84658343-fa44-4fe9-acaa-5c0c2ff5f1d0',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_image_gallery.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:84bea7b4-b9e4-4cf4-8ec9-389dd6b02c10',_binary 'a:1:{i:0;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title\";}'),('config.entity.key_store.field_config','uuid:8a07cecc-6fab-4d81-8cda-096df1dc73ab',_binary 'a:1:{i:0;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";}'),('config.entity.key_store.field_config','uuid:8b147c97-e78e-4773-a7dd-fbdd3db585a6',_binary 'a:1:{i:0;s:68:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:8bd0ca98-8e9c-4dba-b1cf-ae98a043504f',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_tabs_item.field_ept_tab_content\";}'),('config.entity.key_store.field_config','uuid:8c000a0e-d859-4bdb-9ddc-1c1c48e64c4b',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_cards.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:8e45972c-1dc7-444f-9475-a98aa5a83a12',_binary 'a:1:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";}'),('config.entity.key_store.field_config','uuid:8fecb003-ae49-44e1-ac0e-aeaebabeca06',_binary 'a:1:{i:0;s:36:\"field.field.block_content.basic.body\";}'),('config.entity.key_store.field_config','uuid:90b23d65-43c8-4f09-8924-c0be432e4510',_binary 'a:1:{i:0;s:47:\"field.field.media.document.field_media_document\";}'),('config.entity.key_store.field_config','uuid:929dd04a-655a-436e-b9ec-8b400a26f596',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_slideshow.field_ept_slideshow\";}'),('config.entity.key_store.field_config','uuid:9302769a-011f-4ea8-8a1a-82c6399fc628',_binary 'a:1:{i:0;s:82:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";}'),('config.entity.key_store.field_config','uuid:93b358ac-f703-4792-a4cb-65cb87eb34aa',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";}'),('config.entity.key_store.field_config','uuid:94fe1479-276a-47c8-a255-ba6fdb6b874f',_binary 'a:1:{i:0;s:61:\"field.field.paragraph.ept_counter_item.field_ept_counter_icon\";}'),('config.entity.key_store.field_config','uuid:9610a78c-d4d5-4d29-9221-2b862f3b5c9d',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:97adadda-941e-43f5-8c16-c2a84adbb6a6',_binary 'a:1:{i:0;s:61:\"field.field.paragraph.ept_bootstrap_button.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:9857343f-763e-4b29-8143-ec3fb9d9963d',_binary 'a:1:{i:0;s:63:\"field.field.paragraph.ept_counter_item.field_ept_counter_number\";}'),('config.entity.key_store.field_config','uuid:9905b685-324b-4f6a-8423-5973b3364a40',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:991df58b-c253-4036-a94c-16bf928672f2',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_countdown.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:99ba3548-2963-43fc-9439-5c4981283ee3',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_image.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:9bf7105c-9c7f-493b-b93c-2ee846a91521',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_slick_slider.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:9cd49d18-67b3-4776-ba0b-dda42289ac3c',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:9d669ec1-badd-49d6-82c8-4a8eba8ca7da',_binary 'a:1:{i:0;s:62:\"field.field.paragraph.ept_counter_item.field_ept_counter_title\";}'),('config.entity.key_store.field_config','uuid:9d80d485-b1e2-4fbf-ad86-60acbbdd3d92',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_bootstrap_button.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:9e49c287-a8e3-4673-b781-6db3e163c7f1',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";}'),('config.entity.key_store.field_config','uuid:9e4cb219-cde1-47ad-8d3d-ff3a8093595a',_binary 'a:1:{i:0;s:56:\"field.field.paragraph.ept_webform.field_ept_webform_form\";}'),('config.entity.key_store.field_config','uuid:a054c663-7358-4e24-99c7-7caa63091265',_binary 'a:1:{i:0;s:44:\"field.field.paragraph.ept_cta.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:a059a1dc-b8c7-41a3-a0ba-57ef2b7c3ef2',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_text\";}'),('config.entity.key_store.field_config','uuid:a08772a7-ac82-466b-918c-b39c7f16c309',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_quote.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:a49781a9-d084-428f-b05d-d1b72c5a9c45',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_cards.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:a4f2e656-d59b-4df7-833b-709b38ab9360',_binary 'a:1:{i:0;s:48:\"field.field.paragraph.ept_cta.field_ept_cta_link\";}'),('config.entity.key_store.field_config','uuid:a6969ae3-e3c4-4adf-b115-07a5a0172b95',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_accordion.field_ept_accordion\";}'),('config.entity.key_store.field_config','uuid:a8fb2e31-9a7a-45bb-84f7-84bce2a8e256',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_stats.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:a96f802e-f6f6-415b-a00b-47d8e483f3c2',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_text\";}'),('config.entity.key_store.field_config','uuid:a98491aa-0091-4a36-af08-7e4f9e2a3554',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_slideshow.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:ac698185-3f8a-4519-a9b7-29609da24892',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_tiles.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:ac9343a5-d157-4641-93f9-1b5bd7d0980f',_binary 'a:1:{i:0;s:29:\"field.field.node.article.body\";}'),('config.entity.key_store.field_config','uuid:ad867234-0316-48d0-bba3-4dcafd6d6091',_binary 'a:1:{i:0;s:68:\"field.field.paragraph.ept_counter_item.field_ept_counter_description\";}'),('config.entity.key_store.field_config','uuid:ad96e4c6-579a-4465-ba2d-117890a7bff3',_binary 'a:1:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text\";}'),('config.entity.key_store.field_config','uuid:ae2f7f13-51c7-4ea2-99c7-c5b6b22f7360',_binary 'a:1:{i:0;s:51:\"field.field.paragraph.ept_countdown.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:af24502d-ca80-4229-bc11-8b9d175d53f2',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_image\";}'),('config.entity.key_store.field_config','uuid:b25f97c8-ef2e-408c-b977-6254d1414afe',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:b40d62dd-ee5a-44cf-9983-6bbbd7667b68',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_block.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:b46ea217-84f7-4321-912a-7446b534bb92',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";}'),('config.entity.key_store.field_config','uuid:b4f633fb-12be-4793-b294-21badb491880',_binary 'a:1:{i:0;s:48:\"field.field.paragraph.ept_counter.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:b6314b7b-d04b-4c21-b388-edad4a320f8e',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_micromodal.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:bbd8f0a6-7c0d-47e5-a62d-a2c5aed60232',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_image_gallery.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:bcee11b6-9de3-4ea7-ab28-783aaf52a980',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_tabs.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:c3236ac3-dc6f-4f78-9199-3450f0c1f3b9',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_micromodal.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:c3f52d5a-54bd-4606-8b04-4a6c1e456a0b',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_block\";}'),('config.entity.key_store.field_config','uuid:c440db95-46b7-4316-8502-e20c900704c5',_binary 'a:1:{i:0;s:61:\"field.field.paragraph.ept_slick_slider.field_ept_slick_slider\";}'),('config.entity.key_store.field_config','uuid:c4e09c22-0835-4bec-a402-756220f2e9f7',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_quote.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:c7106e91-0b1d-44f0-82fc-584be35a29c2',_binary 'a:1:{i:0;s:26:\"field.field.node.page.body\";}'),('config.entity.key_store.field_config','uuid:c9626d4b-c719-4c6c-bc96-f92de310cf2e',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_bootstrap_button.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:c9a94fcc-b813-47ed-9b68-5780ad0e270c',_binary 'a:1:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";}'),('config.entity.key_store.field_config','uuid:cccc3ad2-8bd3-4a0b-8777-2510ebee041b',_binary 'a:1:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";}'),('config.entity.key_store.field_config','uuid:cfaf7cc4-f386-4397-8876-cdcee33b93b6',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_stats.field_ept_stats\";}'),('config.entity.key_store.field_config','uuid:d157a78a-d59b-4666-8f4f-2c3fb507bb31',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_webform.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:d3dcae7f-9494-4866-b051-d4817b208fd5',_binary 'a:1:{i:0;s:35:\"field.field.node.article.field_tags\";}'),('config.entity.key_store.field_config','uuid:d5f47d43-c851-4f4d-a9bf-282937a2eb88',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_basic_button.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:d7d805e1-ee4a-4aeb-87d9-e74edbe4f1e7',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_carousel\";}'),('config.entity.key_store.field_config','uuid:d95cc73b-b5b3-45bb-ab62-c70e8411b8e9',_binary 'a:1:{i:0;s:66:\"field.field.paragraph.ept_basic_button.field_ept_basic_button_link\";}'),('config.entity.key_store.field_config','uuid:dd24c6a8-a5d2-434a-90d0-3a97c829c794',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_text.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:de00022b-0652-4a4f-a13f-6d001b19f4c0',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_video.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:dfb637af-23af-4aa3-8753-1c3c1b41f2a4',_binary 'a:1:{i:0;s:63:\"field.field.paragraph.ept_image_gallery.field_ept_image_gallery\";}'),('config.entity.key_store.field_config','uuid:e3f4b834-b3d2-43cf-8914-8378ae9e9f82',_binary 'a:1:{i:0;s:51:\"field.field.paragraph.ept_columns.field_ept_columns\";}'),('config.entity.key_store.field_config','uuid:e46eefbb-e77e-4dbb-b856-37283bfcbcf6',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_image.field_ept_image_link\";}'),('config.entity.key_store.field_config','uuid:e61c2ef3-bfa8-4a34-aa69-9a530904c063',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_carousel.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:e6f7cd85-741e-4d86-ae78-2eabee82b952',_binary 'a:1:{i:0;s:45:\"field.field.paragraph.ept_cta.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:eda0ee86-a9c6-40a3-90a6-52025f859080',_binary 'a:1:{i:0;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:ee4ec7f5-67b4-42d7-baf2-7aaee393847f',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_image.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:ef74c15e-0e9f-4f8c-82b1-f7cec4763c50',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";}'),('config.entity.key_store.field_config','uuid:efadba67-9ef3-474a-8246-0e5a51d74660',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_tiles.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:efd74810-b803-4db6-b891-9ea3905eb31d',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_views\";}'),('config.entity.key_store.field_config','uuid:f00824ef-dc9b-4ba7-81ad-8e7910f662a6',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_stats.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:f14e46f4-90c2-43c0-b2de-b00cf7ff030e',_binary 'a:1:{i:0;s:68:\"field.field.paragraph.ept_webform_popup.field_ept_webform_popup_form\";}'),('config.entity.key_store.field_config','uuid:f1e8eab0-49cf-40c1-a0c3-1c7c52bbcf18',_binary 'a:1:{i:0;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";}'),('config.entity.key_store.field_config','uuid:f3ed6271-02a1-49ae-87a5-dcbb0788200c',_binary 'a:1:{i:0;s:45:\"field.field.paragraph.ept_tabs.field_ept_tabs\";}'),('config.entity.key_store.field_config','uuid:f701ef4d-7de9-46b4-88f4-6995981e11ce',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_quote.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:f9453349-a4b8-4f21-ad48-735cb6bb9eca',_binary 'a:1:{i:0;s:51:\"field.field.paragraph.ept_micromodal.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:f9935753-c052-4b7b-b23a-a14f2748a834',_binary 'a:1:{i:0;s:48:\"field.field.paragraph.ept_columns.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:f9ef68e5-ed23-45fb-a5d1-bac433eeb379',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_views.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:fa75defe-e7d5-4782-bedf-3d3107b3a40f',_binary 'a:1:{i:0;s:51:\"field.field.paragraph.ept_accordion.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:fe2fb5d1-bcf8-4e29-9e00-d600aab8954a',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_quote.field_ept_quote_image\";}'),('config.entity.key_store.field_storage_config','uuid:012f2184-9082-4983-9239-7dac48864d9c',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_accordion_title\";}'),('config.entity.key_store.field_storage_config','uuid:0210aa9b-f809-485d-9dc9-01d5b19a7a97',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_views\";}'),('config.entity.key_store.field_storage_config','uuid:05e5fd5b-7ad6-434e-99a8-8635a8fa97cc',_binary 'a:1:{i:0;s:32:\"field.storage.block_content.body\";}'),('config.entity.key_store.field_storage_config','uuid:072a57f4-9c76-4a9a-a3f4-f13ef03b81be',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_counter_number\";}'),('config.entity.key_store.field_storage_config','uuid:08a96db8-eb88-4875-8250-d218a934e839',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_link\";}'),('config.entity.key_store.field_storage_config','uuid:095f6e1d-c38c-4e36-824d-929e502f2c16',_binary 'a:1:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_text\";}'),('config.entity.key_store.field_storage_config','uuid:0bd5b0b1-4d3b-472e-ac51-086416f9360a',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_column_image\";}'),('config.entity.key_store.field_storage_config','uuid:1295648c-a917-438e-a846-fd85d14ae8a0',_binary 'a:1:{i:0;s:42:\"field.storage.media.field_media_audio_file\";}'),('config.entity.key_store.field_storage_config','uuid:14901660-c7de-459b-8e6b-6065e1894829',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_block\";}'),('config.entity.key_store.field_storage_config','uuid:1567fe07-a329-492a-bc5f-d82e3865bd57',_binary 'a:1:{i:0;s:42:\"field.storage.media.field_media_video_file\";}'),('config.entity.key_store.field_storage_config','uuid:177e4cd0-bbd1-44cd-9d3f-5b5dd4378ed4',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_accordion_text\";}'),('config.entity.key_store.field_storage_config','uuid:1a9f268a-efba-464e-854e-f46e7e1341e9',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_slideshow\";}'),('config.entity.key_store.field_storage_config','uuid:1da3ad04-a3d6-45a2-8a2e-100f0d629948',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_carousel_image\";}'),('config.entity.key_store.field_storage_config','uuid:233edf85-6a6a-473c-933a-1a6a9015993a',_binary 'a:1:{i:0;s:31:\"field.storage.user.user_picture\";}'),('config.entity.key_store.field_storage_config','uuid:2545ccb9-b7f9-49f1-a002-1aa70a099849',_binary 'a:1:{i:0;s:50:\"field.storage.paragraph.field_ept_cta_column_image\";}'),('config.entity.key_store.field_storage_config','uuid:26a81385-82de-46f0-8582-8c93b0fbcb01',_binary 'a:1:{i:0;s:23:\"field.storage.node.body\";}'),('config.entity.key_store.field_storage_config','uuid:30383ff9-015d-4872-a3cb-3c814a4683f6',_binary 'a:1:{i:0;s:39:\"field.storage.paragraph.field_ept_video\";}'),('config.entity.key_store.field_storage_config','uuid:32ff7444-1fb2-4c29-97a3-9e9f53ec491a',_binary 'a:1:{i:0;s:50:\"field.storage.paragraph.field_ept_stats_item_image\";}'),('config.entity.key_store.field_storage_config','uuid:360bef36-b4f7-492b-9677-6170eebdf2bb',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_basic_button_link\";}'),('config.entity.key_store.field_storage_config','uuid:385056ad-483b-468c-8fc7-fa477f32138c',_binary 'a:1:{i:0;s:53:\"field.storage.paragraph.field_ept_counter_description\";}'),('config.entity.key_store.field_storage_config','uuid:389f5e03-e7e9-4fb0-bdb5-618f4ada2579',_binary 'a:1:{i:0;s:44:\"field.storage.paragraph.field_ept_image_link\";}'),('config.entity.key_store.field_storage_config','uuid:39b9627d-fdb9-4ed9-afc4-0c4d133a92c6',_binary 'a:1:{i:0;s:45:\"field.storage.paragraph.field_ept_quote_image\";}'),('config.entity.key_store.field_storage_config','uuid:3adc57b0-490d-4760-8c68-b19c339fedb5',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_link\";}'),('config.entity.key_store.field_storage_config','uuid:467150cb-7feb-412a-9426-4b2a3f4a1caa',_binary 'a:1:{i:0;s:46:\"field.storage.paragraph.field_ept_slick_slider\";}'),('config.entity.key_store.field_storage_config','uuid:48fc10e7-9c7a-4b33-8f60-3ce608c713c5',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_link\";}'),('config.entity.key_store.field_storage_config','uuid:4a613783-5795-48bc-bd8e-e3fe3a00ea51',_binary 'a:1:{i:0;s:34:\"field.storage.comment.comment_body\";}'),('config.entity.key_store.field_storage_config','uuid:4bdff313-152c-4ea9-ba49-6f433c48203a',_binary 'a:1:{i:0;s:50:\"field.storage.paragraph.field_ept_carousel_caption\";}'),('config.entity.key_store.field_storage_config','uuid:54f29aab-0b38-45f1-bef4-33ea7848198c',_binary 'a:1:{i:0;s:39:\"field.storage.paragraph.field_ept_stats\";}'),('config.entity.key_store.field_storage_config','uuid:5741fa83-8e57-4e60-99ce-6e8bd5bf8b78',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_countdown_date\";}'),('config.entity.key_store.field_storage_config','uuid:58a0c8d3-2aaa-43a3-af29-df451a7410e3',_binary 'a:1:{i:0;s:50:\"field.storage.paragraph.field_ept_micromodal_title\";}'),('config.entity.key_store.field_storage_config','uuid:58c5cc3e-9949-4686-882a-a56b59c60ea8',_binary 'a:1:{i:0;s:45:\"field.storage.paragraph.field_ept_block_block\";}'),('config.entity.key_store.field_storage_config','uuid:5c2ba04c-75d7-42c4-b482-67caddfd5348',_binary 'a:1:{i:0;s:52:\"field.storage.paragraph.field_ept_webform_popup_form\";}'),('config.entity.key_store.field_storage_config','uuid:62135f80-efc0-4ec3-883a-ce4ccfe66aaa',_binary 'a:1:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_link\";}'),('config.entity.key_store.field_storage_config','uuid:6b41e063-a182-4108-9b56-c0f4bb265180',_binary 'a:1:{i:0;s:40:\"field.storage.media.field_media_document\";}'),('config.entity.key_store.field_storage_config','uuid:7518ddce-1000-4e47-8c93-f8230ca40081',_binary 'a:1:{i:0;s:41:\"field.storage.paragraph.field_ept_columns\";}'),('config.entity.key_store.field_storage_config','uuid:75781815-4f60-47eb-bdc4-255e273d1add',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_title\";}'),('config.entity.key_store.field_storage_config','uuid:776f5eb1-0740-473f-b278-4678ab1e0a4e',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_clickable_tile\";}'),('config.entity.key_store.field_storage_config','uuid:79fcf2b8-c7f0-45ad-b0c1-f2032eef3896',_binary 'a:1:{i:0;s:38:\"field.storage.paragraph.field_ept_tabs\";}'),('config.entity.key_store.field_storage_config','uuid:7baebb7a-a11d-4ca3-803c-81356e567dc2',_binary 'a:1:{i:0;s:35:\"field.storage.node.field_components\";}'),('config.entity.key_store.field_storage_config','uuid:81f6ea79-133f-4e53-bb0a-4169a69c4472',_binary 'a:1:{i:0;s:29:\"field.storage.node.field_tags\";}'),('config.entity.key_store.field_storage_config','uuid:843571d5-1f13-41be-91d6-4a2cdc24036d',_binary 'a:1:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_text\";}'),('config.entity.key_store.field_storage_config','uuid:8622c9ec-6687-4349-af19-885f22d99285',_binary 'a:1:{i:0;s:44:\"field.storage.paragraph.field_ept_views_view\";}'),('config.entity.key_store.field_storage_config','uuid:87c56ad4-62d6-4644-86c1-680e4755ff8b',_binary 'a:1:{i:0;s:45:\"field.storage.paragraph.field_ept_tab_content\";}'),('config.entity.key_store.field_storage_config','uuid:89e38776-3ba0-4f79-9023-af5e40b20171',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_hero_link\";}'),('config.entity.key_store.field_storage_config','uuid:8f6db9bb-d214-4b8e-a41e-8e68af02013e',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_text\";}'),('config.entity.key_store.field_storage_config','uuid:9bab1d24-d574-48e2-8d0e-4ab68fb47d98',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_text\";}'),('config.entity.key_store.field_storage_config','uuid:a1361495-0a6d-4f18-8570-b713e198ddf3',_binary 'a:1:{i:0;s:46:\"field.storage.paragraph.field_ept_gallery_item\";}'),('config.entity.key_store.field_storage_config','uuid:a21fa265-c368-46f8-b0bf-ccd4251290bf',_binary 'a:1:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_title\";}'),('config.entity.key_store.field_storage_config','uuid:a25a51c6-fb73-441d-bfe4-baf60db380f2',_binary 'a:1:{i:0;s:47:\"field.storage.paragraph.field_ept_image_gallery\";}'),('config.entity.key_store.field_storage_config','uuid:a3a4414c-7488-42d9-ad4e-706dbb16b1da',_binary 'a:1:{i:0;s:39:\"field.storage.paragraph.field_ept_image\";}'),('config.entity.key_store.field_storage_config','uuid:a51e7805-3dcf-415a-b08c-6e41b660115d',_binary 'a:1:{i:0;s:50:\"field.storage.paragraph.field_ept_hero_second_link\";}'),('config.entity.key_store.field_storage_config','uuid:a62c9e27-ad8b-430d-85ce-9db276ada8eb',_binary 'a:1:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_title\";}'),('config.entity.key_store.field_storage_config','uuid:a88d5b44-1516-4b8b-96a9-776c192940bc',_binary 'a:1:{i:0;s:46:\"field.storage.paragraph.field_ept_webform_form\";}'),('config.entity.key_store.field_storage_config','uuid:ad3c2c1b-78c7-400a-a114-8f5a64daf409',_binary 'a:1:{i:0;s:39:\"field.storage.paragraph.field_ept_tiles\";}'),('config.entity.key_store.field_storage_config','uuid:ae1f0138-a2f5-4881-bf90-0ade773b59b5',_binary 'a:1:{i:0;s:37:\"field.storage.media.field_media_image\";}'),('config.entity.key_store.field_storage_config','uuid:aed153c8-a66a-428a-be76-0d9ff9c57e30',_binary 'a:1:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";}'),('config.entity.key_store.field_storage_config','uuid:b471db54-e924-4e9f-b6d7-c7e32f497206',_binary 'a:1:{i:0;s:44:\"field.storage.media.field_media_oembed_video\";}'),('config.entity.key_store.field_storage_config','uuid:bceb6f2f-b114-41f5-8b07-0ce990d0087a',_binary 'a:1:{i:0;s:55:\"field.storage.paragraph.field_ept_bootstrap_button_link\";}'),('config.entity.key_store.field_storage_config','uuid:bd174355-0ad0-4843-9909-9069e6e2eac2',_binary 'a:1:{i:0;s:46:\"field.storage.paragraph.field_ept_counter_icon\";}'),('config.entity.key_store.field_storage_config','uuid:be93c2a2-2803-47c8-8cbb-88ab3561ae6c',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_title_prefix\";}'),('config.entity.key_store.field_storage_config','uuid:c605bbbd-911f-4bca-9f1d-7575ba23063c',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_title\";}'),('config.entity.key_store.field_storage_config','uuid:c84089e9-ca27-4ede-81db-501ab243fe10',_binary 'a:1:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_image\";}'),('config.entity.key_store.field_storage_config','uuid:c9282b5e-9cbb-4d37-84d7-b405cf59a041',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_accordion\";}'),('config.entity.key_store.field_storage_config','uuid:ceb57be4-05e2-49c4-afad-48cb1341e682',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_gallery_item_text\";}'),('config.entity.key_store.field_storage_config','uuid:d142f67c-eb14-402b-8d63-83e817038f33',_binary 'a:1:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";}'),('config.entity.key_store.field_storage_config','uuid:d704c8d4-b783-49b6-af10-1f4524374151',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_slide\";}'),('config.entity.key_store.field_storage_config','uuid:d8e5d125-f4f7-4c1d-ac26-f7468f91d3b9',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_text\";}'),('config.entity.key_store.field_storage_config','uuid:d90ba792-7242-4c28-a755-2203bfbd33dc',_binary 'a:1:{i:0;s:47:\"field.storage.paragraph.field_ept_image_caption\";}'),('config.entity.key_store.field_storage_config','uuid:d985b37a-8f1d-4d3c-8d92-09cb8326cf66',_binary 'a:1:{i:0;s:52:\"field.storage.paragraph.field_ept_slick_slider_image\";}'),('config.entity.key_store.field_storage_config','uuid:d9aff85c-3ad9-418b-b47e-58f08b64180e',_binary 'a:1:{i:0;s:30:\"field.storage.node.field_image\";}'),('config.entity.key_store.field_storage_config','uuid:dd8a6a77-dce1-4167-81fc-78b560cda129',_binary 'a:1:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_page\";}'),('config.entity.key_store.field_storage_config','uuid:e0b4af62-c275-4029-b2a7-59ffabd9c786',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_stats_item_number\";}'),('config.entity.key_store.field_storage_config','uuid:e5ac8a81-1f96-4b7d-b8e0-6d9b2c08fcbd',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_cta_second_link\";}'),('config.entity.key_store.field_storage_config','uuid:e76f4c36-a02a-4c1e-b34f-cecbd30657dd',_binary 'a:1:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";}'),('config.entity.key_store.field_storage_config','uuid:ef4b1edf-7e44-4fd4-9484-139b43615d23',_binary 'a:1:{i:0;s:42:\"field.storage.paragraph.field_ept_cta_link\";}'),('config.entity.key_store.field_storage_config','uuid:f68b8da9-803f-4c9b-8f4c-4fc24f899205',_binary 'a:1:{i:0;s:46:\"field.storage.paragraph.field_ept_quote_author\";}'),('config.entity.key_store.field_storage_config','uuid:fa2205d7-3b05-4d76-a029-30510c45d952',_binary 'a:1:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_items\";}'),('config.entity.key_store.field_storage_config','uuid:fb3b02a6-684b-4508-8b49-e87fa4e916c1',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_videos_and_images\";}'),('config.entity.key_store.field_storage_config','uuid:fbb51140-67d8-4112-868c-19dd46c31b98',_binary 'a:1:{i:0;s:42:\"field.storage.paragraph.field_ept_carousel\";}'),('config.entity.key_store.filter_format','uuid:3692adcd-2f32-40f4-8ab0-3369f24cb8e0',_binary 'a:1:{i:0;s:29:\"filter.format.webform_default\";}'),('config.entity.key_store.filter_format','uuid:5837f230-16d1-4857-8f42-39560aa7f6bb',_binary 'a:1:{i:0;s:23:\"filter.format.full_html\";}'),('config.entity.key_store.filter_format','uuid:9ffd8de5-5d95-4675-941e-b6205d96c828',_binary 'a:1:{i:0;s:24:\"filter.format.basic_html\";}'),('config.entity.key_store.filter_format','uuid:b26630f8-bc66-410b-9271-2fd35673a39c',_binary 'a:1:{i:0;s:29:\"filter.format.restricted_html\";}'),('config.entity.key_store.filter_format','uuid:e7b49ea5-e3d9-43a7-9355-811016606856',_binary 'a:1:{i:0;s:24:\"filter.format.plain_text\";}'),('config.entity.key_store.image_style','uuid:1d081002-40ce-4508-b331-45087f55f851',_binary 'a:1:{i:0;s:17:\"image.style.large\";}'),('config.entity.key_store.image_style','uuid:45c23df0-c353-4723-86c7-ddfc29333553',_binary 'a:1:{i:0;s:21:\"image.style.thumbnail\";}'),('config.entity.key_store.image_style','uuid:7407b366-d102-42ad-8d9b-28fc84ce386e',_binary 'a:1:{i:0;s:16:\"image.style.wide\";}'),('config.entity.key_store.image_style','uuid:8ad0f8e1-bf91-4861-b98d-bd4757ce19fe',_binary 'a:1:{i:0;s:27:\"image.style.ept_quote_image\";}'),('config.entity.key_store.image_style','uuid:96327273-04cd-4db7-9889-976db88ae72b',_binary 'a:1:{i:0;s:29:\"image.style.ept_gallery_image\";}'),('config.entity.key_store.image_style','uuid:c7167138-d49d-4235-8671-ee7f0d2d2b21',_binary 'a:1:{i:0;s:39:\"image.style.ept_video_and_image_gallery\";}'),('config.entity.key_store.image_style','uuid:cc99d86c-9cb9-4913-9000-8ea5ef978940',_binary 'a:1:{i:0;s:18:\"image.style.medium\";}'),('config.entity.key_store.image_style','uuid:d5e3c8ee-d135-4d9b-87f8-3983d8804dd0',_binary 'a:1:{i:0;s:33:\"image.style.ept_slick_slider_card\";}'),('config.entity.key_store.image_style','uuid:dce163df-e6d0-4a19-be9f-835d8fb9ad19',_binary 'a:1:{i:0;s:25:\"image.style.media_library\";}'),('config.entity.key_store.media_type','uuid:0bf0a6ff-42d0-4443-95d9-32bb21b3d878',_binary 'a:1:{i:0;s:16:\"media.type.image\";}'),('config.entity.key_store.media_type','uuid:6a011382-b41c-428b-bec3-c2acb1a0b347',_binary 'a:1:{i:0;s:16:\"media.type.audio\";}'),('config.entity.key_store.media_type','uuid:d833ee62-0e66-41f9-bc64-0ee184be48b7',_binary 'a:1:{i:0;s:23:\"media.type.remote_video\";}'),('config.entity.key_store.media_type','uuid:f37b6fcf-a1f5-41c8-ad6b-ab36d7822130',_binary 'a:1:{i:0;s:16:\"media.type.video\";}'),('config.entity.key_store.media_type','uuid:f7d4d4ed-07f1-4c0e-add0-5205dca6bb2d',_binary 'a:1:{i:0;s:19:\"media.type.document\";}'),('config.entity.key_store.menu','uuid:37d50e8a-b786-4ff3-a41f-5e41d67f88b1',_binary 'a:1:{i:0;s:19:\"system.menu.account\";}'),('config.entity.key_store.menu','uuid:4108c568-d39d-4283-8af4-4ce0601c49ec',_binary 'a:1:{i:0;s:16:\"system.menu.main\";}'),('config.entity.key_store.menu','uuid:6e91308b-4a52-440d-824d-e3b9fb3941e2',_binary 'a:1:{i:0;s:17:\"system.menu.tools\";}'),('config.entity.key_store.menu','uuid:cf474897-e948-4315-a183-5878deecdaf0',_binary 'a:1:{i:0;s:17:\"system.menu.admin\";}'),('config.entity.key_store.menu','uuid:d761cbba-9ebe-4d52-96fc-79063bff0783',_binary 'a:1:{i:0;s:18:\"system.menu.footer\";}'),('config.entity.key_store.node_type','uuid:9597cbd8-ec71-47b6-98f5-c2eeebffff0e',_binary 'a:1:{i:0;s:17:\"node.type.article\";}'),('config.entity.key_store.node_type','uuid:e24a8178-cabf-4c12-8439-99829f4ce10e',_binary 'a:1:{i:0;s:14:\"node.type.page\";}'),('config.entity.key_store.paragraphs_type','uuid:07a0dbc7-10e5-4ae6-897e-e0a112e89e81',_binary 'a:1:{i:0;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}'),('config.entity.key_store.paragraphs_type','uuid:09477678-6921-49a1-a83f-aa21d8c811e4',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_cards\";}'),('config.entity.key_store.paragraphs_type','uuid:0f8caf80-346b-4e13-bb09-4c47aafab045',_binary 'a:1:{i:0;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}'),('config.entity.key_store.paragraphs_type','uuid:1a4319ac-f841-4112-85c5-2a1ab06cb4d1',_binary 'a:1:{i:0;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}'),('config.entity.key_store.paragraphs_type','uuid:1f202608-b028-44b4-99c0-312ebcadcb47',_binary 'a:1:{i:0;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}'),('config.entity.key_store.paragraphs_type','uuid:29db5768-3c25-444b-84f5-1a0ab0ba6377',_binary 'a:1:{i:0;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}'),('config.entity.key_store.paragraphs_type','uuid:3188911c-48a1-42f6-8342-f2b8eb94edff',_binary 'a:1:{i:0;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}'),('config.entity.key_store.paragraphs_type','uuid:3252260c-9d6c-4095-8836-d9e0aaa25dc6',_binary 'a:1:{i:0;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}'),('config.entity.key_store.paragraphs_type','uuid:3e07ff02-27c6-4d10-98ae-318109a50f36',_binary 'a:1:{i:0;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}'),('config.entity.key_store.paragraphs_type','uuid:41cd1373-cca3-46dc-87a0-714c7a1489bb',_binary 'a:1:{i:0;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}'),('config.entity.key_store.paragraphs_type','uuid:4290efa9-ba8f-4d75-8ae5-02743a3c35f1',_binary 'a:1:{i:0;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}'),('config.entity.key_store.paragraphs_type','uuid:5a3625a2-f528-429b-8415-b0b1eface1d4',_binary 'a:1:{i:0;s:34:\"paragraphs.paragraphs_type.ept_cta\";}'),('config.entity.key_store.paragraphs_type','uuid:6838ec7f-c8a4-4325-97a7-1021f1dfe5d5',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_stats\";}'),('config.entity.key_store.paragraphs_type','uuid:698fe7c4-0789-4365-b3ce-d8bbd2d7d879',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_block\";}'),('config.entity.key_store.paragraphs_type','uuid:7ac88ec9-7da9-488c-ac70-492b5bcfde08',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_views\";}'),('config.entity.key_store.paragraphs_type','uuid:8fca0905-ad07-4e5a-b80e-a842bece8ab5',_binary 'a:1:{i:0;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}'),('config.entity.key_store.paragraphs_type','uuid:95226011-0193-4ef6-9af2-4f1df3457cea',_binary 'a:1:{i:0;s:38:\"paragraphs.paragraphs_type.ept_webform\";}'),('config.entity.key_store.paragraphs_type','uuid:9953b7d8-252b-4d78-9b63-08418e206990',_binary 'a:1:{i:0;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}'),('config.entity.key_store.paragraphs_type','uuid:9e15e91a-5c5e-4c79-9e75-1386629a7208',_binary 'a:1:{i:0;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}'),('config.entity.key_store.paragraphs_type','uuid:ae747fa8-05f4-441a-92bd-76441012dd9b',_binary 'a:1:{i:0;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}'),('config.entity.key_store.paragraphs_type','uuid:b702ec4e-c33c-4331-beff-6b5b7107cc9d',_binary 'a:1:{i:0;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}'),('config.entity.key_store.paragraphs_type','uuid:c76a9833-ec98-4fe9-9268-c55ecc6606f7',_binary 'a:1:{i:0;s:35:\"paragraphs.paragraphs_type.ept_text\";}'),('config.entity.key_store.paragraphs_type','uuid:ced6180f-b154-47b8-a7b7-61647c71db48',_binary 'a:1:{i:0;s:35:\"paragraphs.paragraphs_type.ept_hero\";}'),('config.entity.key_store.paragraphs_type','uuid:d1c90790-b1df-488f-a53e-bc8c9bbe2e9c',_binary 'a:1:{i:0;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}'),('config.entity.key_store.paragraphs_type','uuid:d468b305-ccc4-4dd1-827a-5ac37883f188',_binary 'a:1:{i:0;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}'),('config.entity.key_store.paragraphs_type','uuid:d64be736-43ad-47c5-a174-0a5e19f4b24a',_binary 'a:1:{i:0;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}'),('config.entity.key_store.paragraphs_type','uuid:dee3b2de-c5f8-4d3f-8564-0f6f24943f59',_binary 'a:1:{i:0;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}'),('config.entity.key_store.paragraphs_type','uuid:e1accd8b-a614-4659-8cf0-f0563effdfeb',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}'),('config.entity.key_store.paragraphs_type','uuid:e359103e-fb7d-4814-b51e-5b6eb0bf50cd',_binary 'a:1:{i:0;s:38:\"paragraphs.paragraphs_type.ept_columns\";}'),('config.entity.key_store.paragraphs_type','uuid:e50ad18b-eff8-48a4-9102-1709c8e0bb40',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_video\";}'),('config.entity.key_store.paragraphs_type','uuid:e7cc4707-218e-4bb9-bcbe-65d47620375d',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_quote\";}'),('config.entity.key_store.paragraphs_type','uuid:ec405efa-b146-4a07-abc8-d507909706f1',_binary 'a:1:{i:0;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}'),('config.entity.key_store.paragraphs_type','uuid:f1d6ed2b-6a40-4f21-930f-5cd318945855',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_image\";}'),('config.entity.key_store.paragraphs_type','uuid:fb9a64bf-58bb-4e29-a23f-83bc70d9958c',_binary 'a:1:{i:0;s:38:\"paragraphs.paragraphs_type.ept_counter\";}'),('config.entity.key_store.paragraphs_type','uuid:ffeadf94-a846-4eeb-af7e-504e5b867d19',_binary 'a:1:{i:0;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}'),('config.entity.key_store.shortcut_set','uuid:2b149d5c-a926-4de8-aae7-b7f45081ccab',_binary 'a:1:{i:0;s:20:\"shortcut.set.default\";}'),('config.entity.key_store.taxonomy_vocabulary','uuid:368fd9b7-ee40-4b51-8ac1-60f818b9f9f6',_binary 'a:1:{i:0;s:24:\"taxonomy.vocabulary.tags\";}'),('config.entity.key_store.tb_megamenu','uuid:9a71f48f-4fa9-44ad-996b-21fe7ea77565',_binary 'a:1:{i:0;s:39:\"tb_megamenu.menu_config.main__ept_light\";}'),('config.entity.key_store.user_role','uuid:369ad726-b0da-4331-8cb0-56ab9af109d5',_binary 'a:1:{i:0;s:23:\"user.role.authenticated\";}'),('config.entity.key_store.user_role','uuid:5f4748db-4b8a-4105-a888-23753782d022',_binary 'a:1:{i:0;s:23:\"user.role.administrator\";}'),('config.entity.key_store.user_role','uuid:e916801a-5024-47c1-b402-bb0bb1592d19',_binary 'a:1:{i:0;s:24:\"user.role.content_editor\";}'),('config.entity.key_store.user_role','uuid:eda565bf-dc62-4fa8-b48c-329d2d6fc492',_binary 'a:1:{i:0;s:19:\"user.role.anonymous\";}'),('config.entity.key_store.view','uuid:25587939-259b-48aa-8c6c-dbd04aa5d800',_binary 'a:1:{i:0;s:19:\"views.view.watchdog\";}'),('config.entity.key_store.view','uuid:267c96ad-120e-49d6-9273-b49f1a603f01',_binary 'a:1:{i:0;s:23:\"views.view.who_s_online\";}'),('config.entity.key_store.view','uuid:36db1296-d05c-4dd7-bda9-64d0981e2f85',_binary 'a:1:{i:0;s:16:\"views.view.files\";}'),('config.entity.key_store.view','uuid:38120747-e809-460c-aea2-fd8cea0574d7',_binary 'a:1:{i:0;s:30:\"views.view.webform_submissions\";}'),('config.entity.key_store.view','uuid:56651306-efed-4808-bbdc-d9cf02cff348',_binary 'a:1:{i:0;s:24:\"views.view.taxonomy_term\";}'),('config.entity.key_store.view','uuid:66ac1092-d560-4cf9-a5d3-b1941a3311d1',_binary 'a:1:{i:0;s:28:\"views.view.user_admin_people\";}'),('config.entity.key_store.view','uuid:74d36492-489a-4ac8-ab15-1c22af9e302b',_binary 'a:1:{i:0;s:24:\"views.view.media_library\";}'),('config.entity.key_store.view','uuid:7c06b5e5-ebff-4822-8688-54ce69b5a404',_binary 'a:1:{i:0;s:16:\"views.view.media\";}'),('config.entity.key_store.view','uuid:899f634a-224d-4abf-ae01-81a9b3031896',_binary 'a:1:{i:0;s:20:\"views.view.frontpage\";}'),('config.entity.key_store.view','uuid:9a843b37-02d2-45c5-84e0-2cd85511ce42',_binary 'a:1:{i:0;s:19:\"views.view.glossary\";}'),('config.entity.key_store.view','uuid:9dd1c55e-db52-4c19-aa0d-4c122baa71f4',_binary 'a:1:{i:0;s:25:\"views.view.content_recent\";}'),('config.entity.key_store.view','uuid:b85b83ea-7ca6-4445-91d4-33ba3dff6403',_binary 'a:1:{i:0;s:26:\"views.view.comments_recent\";}'),('config.entity.key_store.view','uuid:d9b64673-64f0-48bb-8588-e15e4bdacdbf',_binary 'a:1:{i:0;s:20:\"views.view.who_s_new\";}'),('config.entity.key_store.view','uuid:db9f543b-a00c-4765-a8dd-36dc8ebd091c',_binary 'a:1:{i:0;s:18:\"views.view.content\";}'),('config.entity.key_store.view','uuid:e1df6ee8-b831-49f1-9777-12d640e99636',_binary 'a:1:{i:0;s:21:\"views.view.what_s_new\";}'),('config.entity.key_store.view','uuid:e6cd565b-768b-47a9-b906-fe031ec4047e',_binary 'a:1:{i:0;s:18:\"views.view.comment\";}'),('config.entity.key_store.view','uuid:f0a4d615-99cd-438c-a7fe-c2d84a594ee3',_binary 'a:1:{i:0;s:24:\"views.view.block_content\";}'),('config.entity.key_store.view','uuid:f33400de-a3e8-4128-b4b9-8f10fc897a3f',_binary 'a:1:{i:0;s:18:\"views.view.archive\";}'),('config.entity.key_store.webform','status:open',_binary 'a:1:{i:0;s:23:\"webform.webform.contact\";}'),('config.entity.key_store.webform','template:',_binary 'a:1:{i:0;s:23:\"webform.webform.contact\";}'),('config.entity.key_store.webform','uuid:8b8a523d-2f23-4a57-82e5-54fb22889c9f',_binary 'a:1:{i:0;s:23:\"webform.webform.contact\";}'),('config.entity.key_store.webform_options','uuid:041d2cb0-73c1-4dd6-8388-5b44d924fd3f',_binary 'a:1:{i:0;s:44:\"webform.webform_options.state_province_names\";}'),('config.entity.key_store.webform_options','uuid:0df45fa9-e8c8-4d2f-ae91-771c2df5499d',_binary 'a:1:{i:0;s:33:\"webform.webform_options.ethnicity\";}'),('config.entity.key_store.webform_options','uuid:1fcf461d-9e42-4571-b6cf-28abee7d1f9b',_binary 'a:1:{i:0;s:30:\"webform.webform_options.gender\";}'),('config.entity.key_store.webform_options','uuid:294b5fc1-0d98-46dc-b941-253bcd531719',_binary 'a:1:{i:0;s:35:\"webform.webform_options.state_names\";}'),('config.entity.key_store.webform_options','uuid:329c38fd-eb24-471e-aa3d-b63a51b3a1d6',_binary 'a:1:{i:0;s:41:\"webform.webform_options.employment_status\";}'),('config.entity.key_store.webform_options','uuid:428cbf5b-9239-4908-8e3c-1b29a9657d92',_binary 'a:1:{i:0;s:30:\"webform.webform_options.titles\";}'),('config.entity.key_store.webform_options','uuid:431a023e-67ab-48e5-8bac-a1572c14c19f',_binary 'a:1:{i:0;s:38:\"webform.webform_options.likert_quality\";}'),('config.entity.key_store.webform_options','uuid:4639bce4-22a5-4e03-9cad-186c79584f07',_binary 'a:1:{i:0;s:33:\"webform.webform_options.education\";}'),('config.entity.key_store.webform_options','uuid:554341f6-de3f-4da4-8d70-e2302b2d1a3c',_binary 'a:1:{i:0;s:27:\"webform.webform_options.sex\";}'),('config.entity.key_store.webform_options','uuid:6408d5ed-d58e-4d75-a41e-8c2526f7d3ba',_binary 'a:1:{i:0;s:28:\"webform.webform_options.days\";}'),('config.entity.key_store.webform_options','uuid:6973c62d-f428-4205-934b-9559ce7d133c',_binary 'a:1:{i:0;s:44:\"webform.webform_options.state_province_codes\";}'),('config.entity.key_store.webform_options','uuid:7817e355-803d-4cdf-88a9-a3ab29e94c21',_binary 'a:1:{i:0;s:38:\"webform.webform_options.province_codes\";}'),('config.entity.key_store.webform_options','uuid:85e67cce-5058-4806-85e0-7af5f9b85ac0',_binary 'a:1:{i:0;s:40:\"webform.webform_options.likert_agreement\";}'),('config.entity.key_store.webform_options','uuid:8c38f0bb-4da2-49a0-b196-c2d5c1ba66cd',_binary 'a:1:{i:0;s:36:\"webform.webform_options.translations\";}'),('config.entity.key_store.webform_options','uuid:93091529-37e9-4c06-afeb-b349faa470ce',_binary 'a:1:{i:0;s:32:\"webform.webform_options.industry\";}'),('config.entity.key_store.webform_options','uuid:9354d04a-fde3-4871-958b-953be0d0a8c8',_binary 'a:1:{i:0;s:37:\"webform.webform_options.country_names\";}'),('config.entity.key_store.webform_options','uuid:9d57dfd8-f21c-40ec-bbaa-57fe26b6397c',_binary 'a:1:{i:0;s:30:\"webform.webform_options.yes_no\";}'),('config.entity.key_store.webform_options','uuid:9fc50b5c-88f4-4154-ae56-ddbe476c4e3c',_binary 'a:1:{i:0;s:35:\"webform.webform_options.phone_types\";}'),('config.entity.key_store.webform_options','uuid:a170e99b-fa17-41e0-a271-10a7c2bb61f1',_binary 'a:1:{i:0;s:34:\"webform.webform_options.time_zones\";}'),('config.entity.key_store.webform_options','uuid:a7ba4359-4c6f-4830-8d8a-1b39544c95d7',_binary 'a:1:{i:0;s:41:\"webform.webform_options.likert_importance\";}'),('config.entity.key_store.webform_options','uuid:b28be784-d785-41d2-b9a2-5b26173eb305',_binary 'a:1:{i:0;s:30:\"webform.webform_options.months\";}'),('config.entity.key_store.webform_options','uuid:b5b13230-e38a-46a3-950e-7fb23a36c978',_binary 'a:1:{i:0;s:33:\"webform.webform_options.languages\";}'),('config.entity.key_store.webform_options','uuid:b7c1b8ab-fa1a-40b6-99de-c764482a5e3d',_binary 'a:1:{i:0;s:41:\"webform.webform_options.likert_comparison\";}'),('config.entity.key_store.webform_options','uuid:be00197d-93d4-42c6-8d82-abc6357218e4',_binary 'a:1:{i:0;s:38:\"webform.webform_options.province_names\";}'),('config.entity.key_store.webform_options','uuid:caf25914-1f32-4cc2-8565-20b048649e59',_binary 'a:1:{i:0;s:38:\"webform.webform_options.marital_status\";}'),('config.entity.key_store.webform_options','uuid:d39bd682-6e68-4cbd-8ace-ae4db6b7d13f',_binary 'a:1:{i:0;s:40:\"webform.webform_options.likert_ten_scale\";}'),('config.entity.key_store.webform_options','uuid:d3af1e77-6eac-4403-a5fb-758c5365a402',_binary 'a:1:{i:0;s:35:\"webform.webform_options.state_codes\";}'),('config.entity.key_store.webform_options','uuid:da40135e-38ac-464f-8ee9-0a9085b6b37b',_binary 'a:1:{i:0;s:40:\"webform.webform_options.likert_would_you\";}'),('config.entity.key_store.webform_options','uuid:dcb23767-92c9-44f0-af6f-82142d05d7f2',_binary 'a:1:{i:0;s:28:\"webform.webform_options.size\";}'),('config.entity.key_store.webform_options','uuid:e7f91e1a-5e99-4f06-bd68-f4a6d8a72ad9',_binary 'a:1:{i:0;s:36:\"webform.webform_options.relationship\";}'),('config.entity.key_store.webform_options','uuid:f3e69acd-d88d-48a1-ae55-9997d56e4d8a',_binary 'a:1:{i:0;s:43:\"webform.webform_options.likert_satisfaction\";}'),('config.entity.key_store.webform_options','uuid:fcbe2856-cef2-499f-8ba0-fbc8ffac8fdd',_binary 'a:1:{i:0;s:37:\"webform.webform_options.country_codes\";}'),('config.entity.key_store.webform_options','uuid:fec065d0-b801-4d27-9b36-c4c20d17c22f',_binary 'a:1:{i:0;s:32:\"webform.webform_options.sex_icao\";}'),('entity.definitions.bundle_field_map','block_content',_binary 'a:1:{s:4:\"body\";a:2:{s:4:\"type\";s:17:\"text_with_summary\";s:7:\"bundles\";a:1:{s:5:\"basic\";s:5:\"basic\";}}}'),('entity.definitions.bundle_field_map','comment',_binary 'a:1:{s:12:\"comment_body\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:7:\"comment\";s:7:\"comment\";}}}'),('entity.definitions.bundle_field_map','media',_binary 'a:5:{s:22:\"field_media_audio_file\";a:2:{s:4:\"type\";s:4:\"file\";s:7:\"bundles\";a:1:{s:5:\"audio\";s:5:\"audio\";}}s:20:\"field_media_document\";a:2:{s:4:\"type\";s:4:\"file\";s:7:\"bundles\";a:1:{s:8:\"document\";s:8:\"document\";}}s:17:\"field_media_image\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:5:\"image\";s:5:\"image\";}}s:24:\"field_media_oembed_video\";a:2:{s:4:\"type\";s:6:\"string\";s:7:\"bundles\";a:1:{s:12:\"remote_video\";s:12:\"remote_video\";}}s:22:\"field_media_video_file\";a:2:{s:4:\"type\";s:4:\"file\";s:7:\"bundles\";a:1:{s:5:\"video\";s:5:\"video\";}}}'),('entity.definitions.bundle_field_map','node',_binary 'a:4:{s:11:\"field_image\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}s:10:\"field_tags\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}s:4:\"body\";a:2:{s:4:\"type\";s:17:\"text_with_summary\";s:7:\"bundles\";a:2:{s:4:\"page\";s:4:\"page\";s:7:\"article\";s:7:\"article\";}}s:16:\"field_components\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:4:\"page\";s:4:\"page\";}}}'),('entity.definitions.bundle_field_map','paragraph',_binary 'a:67:{s:18:\"field_ept_settings\";a:2:{s:4:\"type\";s:12:\"ept_settings\";s:7:\"bundles\";a:26:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:9:\"ept_cards\";s:9:\"ept_cards\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}}s:19:\"field_ept_accordion\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";}}s:25:\"field_ept_accordion_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:21:\"ept_accordion_section\";s:21:\"ept_accordion_section\";}}s:24:\"field_ept_accordion_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:21:\"ept_accordion_section\";s:21:\"ept_accordion_section\";}}s:15:\"field_ept_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:26:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:9:\"ept_cards\";s:9:\"ept_cards\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}}s:14:\"field_ept_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:26:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:9:\"ept_cards\";s:9:\"ept_cards\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}}s:27:\"field_ept_basic_button_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";}}s:21:\"field_ept_block_block\";a:2:{s:4:\"type\";s:11:\"block_field\";s:7:\"bundles\";a:1:{s:9:\"ept_block\";s:9:\"ept_block\";}}s:31:\"field_ept_bootstrap_button_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";}}s:24:\"field_ept_carousel_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:17:\"ept_carousel_item\";s:17:\"ept_carousel_item\";}}s:18:\"field_ept_carousel\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:12:\"ept_carousel\";s:12:\"ept_carousel\";}}s:26:\"field_ept_carousel_caption\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:17:\"ept_carousel_item\";s:17:\"ept_carousel_item\";}}s:17:\"field_ept_columns\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:11:\"ept_columns\";s:11:\"ept_columns\";}}s:24:\"field_ept_countdown_date\";a:2:{s:4:\"type\";s:8:\"datetime\";s:7:\"bundles\";a:1:{s:13:\"ept_countdown\";s:13:\"ept_countdown\";}}s:24:\"field_ept_counter_number\";a:2:{s:4:\"type\";s:7:\"integer\";s:7:\"bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}}s:22:\"field_ept_counter_icon\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}}s:23:\"field_ept_counter_items\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:11:\"ept_counter\";s:11:\"ept_counter\";}}s:23:\"field_ept_counter_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}}s:29:\"field_ept_counter_description\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}}s:25:\"field_ept_cta_second_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:7:\"ept_cta\";s:7:\"ept_cta\";}}s:18:\"field_ept_cta_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:7:\"ept_cta\";s:7:\"ept_cta\";}}s:26:\"field_ept_cta_column_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:7:\"ept_cta\";s:7:\"ept_cta\";}}s:26:\"field_ept_hero_second_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:8:\"ept_hero\";s:8:\"ept_hero\";}}s:19:\"field_ept_hero_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:8:\"ept_hero\";s:8:\"ept_hero\";}}s:27:\"field_ept_hero_column_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:8:\"ept_hero\";s:8:\"ept_hero\";}}s:27:\"field_ept_hero_title_prefix\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:8:\"ept_hero\";s:8:\"ept_hero\";}}s:20:\"field_ept_image_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:9:\"ept_image\";s:9:\"ept_image\";}}s:15:\"field_ept_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:9:\"ept_image\";s:9:\"ept_image\";}}s:23:\"field_ept_image_caption\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:9:\"ept_image\";s:9:\"ept_image\";}}s:23:\"field_ept_image_gallery\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";}}s:26:\"field_ept_micromodal_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";}}s:21:\"field_ept_quote_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:9:\"ept_quote\";s:9:\"ept_quote\";}}s:22:\"field_ept_quote_author\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:9:\"ept_quote\";s:9:\"ept_quote\";}}s:27:\"field_ept_slick_slider_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:21:\"ept_slick_slider_item\";s:21:\"ept_slick_slider_item\";}}s:28:\"field_ept_slick_slider_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:21:\"ept_slick_slider_item\";s:21:\"ept_slick_slider_item\";}}s:22:\"field_ept_slick_slider\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";}}s:27:\"field_ept_slick_slider_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:21:\"ept_slick_slider_item\";s:21:\"ept_slick_slider_item\";}}s:25:\"field_ept_slideshow_slide\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}}s:24:\"field_ept_slideshow_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}}s:19:\"field_ept_slideshow\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";}}s:25:\"field_ept_slideshow_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}}s:24:\"field_ept_slideshow_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}}s:25:\"field_ept_stats_item_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}}s:26:\"field_ept_stats_item_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}}s:15:\"field_ept_stats\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:9:\"ept_stats\";s:9:\"ept_stats\";}}s:25:\"field_ept_stats_item_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}}s:27:\"field_ept_stats_item_number\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}}s:18:\"field_ept_tab_page\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:21:\"field_ept_tab_content\";a:2:{s:4:\"type\";s:11:\"list_string\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:19:\"field_ept_tab_block\";a:2:{s:4:\"type\";s:11:\"block_field\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:14:\"field_ept_tabs\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:8:\"ept_tabs\";s:8:\"ept_tabs\";}}s:19:\"field_ept_tab_title\";a:2:{s:4:\"type\";s:4:\"text\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:18:\"field_ept_tab_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:19:\"field_ept_tab_views\";a:2:{s:4:\"type\";s:14:\"viewsreference\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:20:\"field_ept_tiles_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}}s:21:\"field_ept_tiles_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}}s:24:\"field_ept_clickable_tile\";a:2:{s:4:\"type\";s:7:\"boolean\";s:7:\"bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}}s:15:\"field_ept_tiles\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:9:\"ept_tiles\";s:9:\"ept_tiles\";}}s:21:\"field_ept_tiles_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}}s:20:\"field_ept_tiles_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}}s:15:\"field_ept_video\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:9:\"ept_video\";s:9:\"ept_video\";}}s:22:\"field_ept_gallery_item\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:32:\"ept_video_and_image_gallery_item\";s:32:\"ept_video_and_image_gallery_item\";}}s:27:\"field_ept_videos_and_images\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";}}s:27:\"field_ept_gallery_item_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:32:\"ept_video_and_image_gallery_item\";s:32:\"ept_video_and_image_gallery_item\";}}s:20:\"field_ept_views_view\";a:2:{s:4:\"type\";s:14:\"viewsreference\";s:7:\"bundles\";a:1:{s:9:\"ept_views\";s:9:\"ept_views\";}}s:22:\"field_ept_webform_form\";a:2:{s:4:\"type\";s:7:\"webform\";s:7:\"bundles\";a:1:{s:11:\"ept_webform\";s:11:\"ept_webform\";}}s:28:\"field_ept_webform_popup_form\";a:2:{s:4:\"type\";s:7:\"webform\";s:7:\"bundles\";a:1:{s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}}}'),('entity.definitions.bundle_field_map','user',_binary 'a:1:{s:12:\"user_picture\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:4:\"user\";s:4:\"user\";}}}'),('entity.definitions.installed','action.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:6:\"action\";s:8:\"\0*\0class\";s:27:\"Drupal\\system\\Entity\\Action\";s:11:\"\0*\0provider\";s:6:\"system\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\system\\Entity\\Action\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:18:\"administer actions\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Actions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"actions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:13:\"@count action\";s:6:\"plural\";s:14:\"@count actions\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"config:action_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:4:\"type\";i:3;s:6:\"plugin\";i:4;s:13:\"configuration\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','base_field_override.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"base_field_override\";s:8:\"\0*\0class\";s:42:\"Drupal\\Core\\Field\\Entity\\BaseFieldOverride\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:42:\"Drupal\\Core\\Field\\Entity\\BaseFieldOverride\";s:11:\"\0*\0handlers\";a:2:{s:7:\"storage\";s:42:\"Drupal\\Core\\Field\\BaseFieldOverrideStorage\";s:6:\"access\";s:55:\"Drupal\\Core\\Field\\BaseFieldOverrideAccessControlHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Base field override\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:base_field_override_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:5:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:6:\"bundle\";i:3;s:10:\"field_name\";i:4;s:10:\"field_type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:19:\"base_field_override\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:6:\"bundle\";i:4;s:5:\"label\";i:5;s:11:\"description\";i:6;s:8:\"required\";i:7;s:12:\"translatable\";i:8;s:13:\"default_value\";i:9;s:22:\"default_value_callback\";i:10;s:8:\"settings\";i:11;s:10:\"field_type\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','block.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:5:\"block\";s:8:\"\0*\0class\";s:25:\"Drupal\\block\\Entity\\Block\";s:11:\"\0*\0provider\";s:5:\"block\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\block\\Entity\\Block\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:38:\"Drupal\\block\\BlockAccessControlHandler\";s:12:\"view_builder\";s:29:\"Drupal\\block\\BlockViewBuilder\";s:12:\"list_builder\";s:29:\"Drupal\\block\\BlockListBuilder\";s:4:\"form\";a:2:{s:7:\"default\";s:22:\"Drupal\\block\\BlockForm\";s:6:\"delete\";s:33:\"Drupal\\block\\Form\\BlockDeleteForm\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:17:\"administer blocks\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:44:\"/admin/structure/block/manage/{block}/delete\";s:9:\"edit-form\";s:37:\"/admin/structure/block/manage/{block}\";s:6:\"enable\";s:44:\"/admin/structure/block/manage/{block}/enable\";s:7:\"disable\";s:45:\"/admin/structure/block/manage/{block}/disable\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:12:\"@count block\";s:6:\"plural\";s:13:\"@count blocks\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:17:\"config:block_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:2:{i:0;s:5:\"theme\";i:1;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"theme\";i:2;s:6:\"region\";i:3;s:6:\"weight\";i:4;s:8:\"provider\";i:5;s:6:\"plugin\";i:6;s:8:\"settings\";i:7;s:10:\"visibility\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','block_content.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:13:\"block_content\";s:8:\"\0*\0class\";s:40:\"Drupal\\block_content\\Entity\\BlockContent\";s:11:\"\0*\0provider\";s:13:\"block_content\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:0;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:6:\"bundle\";s:4:\"type\";s:5:\"label\";s:4:\"info\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\block_content\\Entity\\BlockContent\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:14:\"storage_schema\";s:46:\"Drupal\\block_content\\BlockContentStorageSchema\";s:6:\"access\";s:53:\"Drupal\\block_content\\BlockContentAccessControlHandler\";s:12:\"list_builder\";s:44:\"Drupal\\block_content\\BlockContentListBuilder\";s:12:\"view_builder\";s:44:\"Drupal\\block_content\\BlockContentViewBuilder\";s:10:\"views_data\";s:42:\"Drupal\\block_content\\BlockContentViewsData\";s:4:\"form\";a:6:{s:3:\"add\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:4:\"edit\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:6:\"delete\";s:48:\"Drupal\\block_content\\Form\\BlockContentDeleteForm\";s:7:\"default\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";}s:14:\"route_provider\";a:1:{s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}s:11:\"translation\";s:51:\"Drupal\\block_content\\BlockContentTranslationHandler\";}s:19:\"\0*\0admin_permission\";s:24:\"administer block content\";s:24:\"\0*\0collection_permission\";s:20:\"access block library\";s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:8:{s:9:\"canonical\";s:36:\"/admin/content/block/{block_content}\";s:11:\"delete-form\";s:43:\"/admin/content/block/{block_content}/delete\";s:9:\"edit-form\";s:36:\"/admin/content/block/{block_content}\";s:10:\"collection\";s:20:\"/admin/content/block\";s:6:\"create\";s:6:\"/block\";s:20:\"revision-delete-form\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/delete\";s:20:\"revision-revert-form\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/revert\";s:15:\"version-history\";s:46:\"/admin/content/block/{block_content}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:18:\"block_content_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:13:\"block_content\";s:22:\"\0*\0revision_data_table\";s:28:\"block_content_field_revision\";s:17:\"\0*\0revision_table\";s:22:\"block_content_revision\";s:13:\"\0*\0data_table\";s:24:\"block_content_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Content blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"content blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count content block\";s:6:\"plural\";s:21:\"@count content blocks\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:35:\"entity.block_content_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"block_content_list\";}s:14:\"\0*\0constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:25:\"BlockContentEntityChanged\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:12:\"revision_log\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','block_content.field_storage_definitions',_binary 'a:16:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Content block ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"The content block ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The content block UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"The revision ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"The content block language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"The block type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:18:\"block_content_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:155;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:193;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:223;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_log\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The log entry explaining the changes in this revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:12:\"revision_log\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:260;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:302;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"info\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Block description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"A brief description of your block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"info\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:341;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"The time that the content block was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:384;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"reusable\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Reusable\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"A boolean indicating whether this block is reusable.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:0;s:12:\"revisionable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:8:\"reusable\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:415;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:458;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:501;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:543;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:18:\"block_content.body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"05e5fd5b-7ad6-434e-99a8-8635a8fa97cc\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:18:\"block_content.body\";s:13:\"\0*\0field_name\";s:4:\"body\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:17:\"text_with_summary\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','block_content_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:18:\"block_content_type\";s:8:\"\0*\0class\";s:44:\"Drupal\\block_content\\Entity\\BlockContentType\";s:11:\"\0*\0provider\";s:13:\"block_content\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:44:\"Drupal\\block_content\\Entity\\BlockContentType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:50:\"Drupal\\block_content\\BlockTypeAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:3:\"add\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:4:\"edit\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:6:\"delete\";s:52:\"Drupal\\block_content\\Form\\BlockContentTypeDeleteForm\";}s:14:\"route_provider\";a:2:{s:4:\"html\";s:49:\"Drupal\\Core\\Entity\\Routing\\AdminHtmlRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:12:\"list_builder\";s:48:\"Drupal\\block_content\\BlockContentTypeListBuilder\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:22:\"administer block types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/delete\";s:9:\"edit-form\";s:58:\"/admin/structure/block-content/manage/{block_content_type}\";s:23:\"entity-permissions-form\";s:70:\"/admin/structure/block-content/manage/{block_content_type}/permissions\";s:10:\"collection\";s:30:\"/admin/structure/block-content\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:13:\"block_content\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count block type\";s:6:\"plural\";s:18:\"@count block types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:30:\"config:block_content_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:8:\"revision\";i:3;s:11:\"description\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','ckeditor5_template.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:18:\"ckeditor5_template\";s:8:\"\0*\0class\";s:63:\"Drupal\\ckeditor5_plugin_pack_templates\\Entity\\CKEditor5Template\";s:11:\"\0*\0provider\";s:31:\"ckeditor5_plugin_pack_templates\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"weight\";s:6:\"weight\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:63:\"Drupal\\ckeditor5_plugin_pack_templates\\Entity\\CKEditor5Template\";s:11:\"\0*\0handlers\";a:4:{s:12:\"list_builder\";s:67:\"Drupal\\ckeditor5_plugin_pack_templates\\CKEditor5TemplateListBuilder\";s:4:\"form\";a:4:{s:7:\"default\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:3:\"add\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:4:\"edit\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:30:\"administer ckeditor5 templates\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:10:\"collection\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:8:\"add-form\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:9:\"edit-form\";s:72:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}\";s:11:\"delete-form\";s:61:\"/admin/config/ckeditor5-templates/{ckeditor5_template}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"CKEditor5 Template\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"CKEditor5 Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"CKEditor5 Template\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"CKEditor5 Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:25:\"@count ckeditor5 template\";s:6:\"plural\";s:26:\"@count ckeditor5 templates\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:30:\"config:ckeditor5_template_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:18:\"ckeditor5_template\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"status\";i:4;s:4:\"data\";i:5;s:4:\"icon\";i:6;s:11:\"textFormats\";i:7;s:6:\"weight\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','comment.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:7:\"comment\";s:8:\"\0*\0class\";s:29:\"Drupal\\comment\\Entity\\Comment\";s:11:\"\0*\0provider\";s:7:\"comment\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:3:\"cid\";s:6:\"bundle\";s:12:\"comment_type\";s:5:\"label\";s:7:\"subject\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:5:\"owner\";s:3:\"uid\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\comment\\Entity\\Comment\";s:11:\"\0*\0handlers\";a:8:{s:7:\"storage\";s:29:\"Drupal\\comment\\CommentStorage\";s:14:\"storage_schema\";s:35:\"Drupal\\comment\\CommentStorageSchema\";s:6:\"access\";s:42:\"Drupal\\comment\\CommentAccessControlHandler\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:12:\"view_builder\";s:33:\"Drupal\\comment\\CommentViewBuilder\";s:10:\"views_data\";s:31:\"Drupal\\comment\\CommentViewsData\";s:4:\"form\";a:2:{s:7:\"default\";s:26:\"Drupal\\comment\\CommentForm\";s:6:\"delete\";s:30:\"Drupal\\comment\\Form\\DeleteForm\";}s:11:\"translation\";s:40:\"Drupal\\comment\\CommentTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:9:\"canonical\";s:18:\"/comment/{comment}\";s:11:\"delete-form\";s:25:\"/comment/{comment}/delete\";s:20:\"delete-multiple-form\";s:29:\"/admin/content/comment/delete\";s:9:\"edit-form\";s:23:\"/comment/{comment}/edit\";s:6:\"create\";s:8:\"/comment\";}s:21:\"\0*\0bundle_entity_type\";s:12:\"comment_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Comment type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:7:\"comment\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:18:\"comment_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Comment\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"comment\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"comments\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:14:\"@count comment\";s:6:\"plural\";s:15:\"@count comments\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";s:11:\"comment_uri\";s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:29:\"entity.comment_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:12:\"comment_list\";}s:14:\"\0*\0constraints\";a:3:{s:11:\"CommentName\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','comment.field_storage_definitions',_binary 'a:20:{s:3:\"cid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Comment ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"The comment ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:3:\"cid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The comment UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The comment language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"comment_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Comment Type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The comment type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:12:\"comment_type\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"comment_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:116;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:22:\"default_value_callback\";s:47:\"Drupal\\comment\\Entity\\Comment::getDefaultStatus\";s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:154;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:52:\"Drupal\\comment\\Entity\\Comment::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"The user ID of the comment author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:194;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"pid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Parent ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The parent comment ID if this is a reply to a comment.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:3:\"pid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:7:\"comment\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:232;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"entity_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Entity ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The ID of the entity of which this comment is a reply.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:9:\"entity_id\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:268;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"subject\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Subject\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:7:\"subject\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:64;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:305;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:64;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The comment author\'s name.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:60;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:342;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:60;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The comment author\'s email address.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:380;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"homepage\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Homepage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The comment author\'s home page address.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:8:\"homepage\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:14:\"field_item:uri\";s:8:\"settings\";a:2:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:411;}s:7:\"\0*\0type\";s:3:\"uri\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"hostname\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Hostname\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The comment author\'s hostname.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:49:\"Drupal\\comment\\Entity\\Comment::getDefaultHostname\";s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:8:\"hostname\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:445;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"The time that the comment was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:481;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"The time that the comment was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:511;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"thread\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Thread place\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:144:\"The alphadecimal representation of the comment\'s place in a thread, consisting of a base 36 string prefixed by an integer indicating its length.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:6:\"thread\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:541;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"entity_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Entity type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The entity type to which this comment is attached.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:11:\"entity_type\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:575;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:10:\"field_name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Comment field name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The field name through which this comment was added.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:10:\"field_name\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:610;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:645;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"comment_body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:20:\"comment.comment_body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"4a613783-5795-48bc-bd8e-e3fe3a00ea51\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:20:\"comment.comment_body\";s:13:\"\0*\0field_name\";s:12:\"comment_body\";s:14:\"\0*\0entity_type\";s:7:\"comment\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','comment_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"comment_type\";s:8:\"\0*\0class\";s:33:\"Drupal\\comment\\Entity\\CommentType\";s:11:\"\0*\0provider\";s:7:\"comment\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\comment\\Entity\\CommentType\";s:11:\"\0*\0handlers\";a:5:{s:4:\"form\";a:4:{s:7:\"default\";s:30:\"Drupal\\comment\\CommentTypeForm\";s:3:\"add\";s:30:\"Drupal\\comment\\CommentTypeForm\";s:4:\"edit\";s:30:\"Drupal\\comment\\CommentTypeForm\";s:6:\"delete\";s:41:\"Drupal\\comment\\Form\\CommentTypeDeleteForm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:58:\"Drupal\\user\\Entity\\EntityPermissionsRouteProviderWithCheck\";}s:12:\"list_builder\";s:37:\"Drupal\\comment\\CommentTypeListBuilder\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer comment types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:11:\"delete-form\";s:53:\"/admin/structure/comment/manage/{comment_type}/delete\";s:9:\"edit-form\";s:46:\"/admin/structure/comment/manage/{comment_type}\";s:8:\"add-form\";s:34:\"/admin/structure/comment/types/add\";s:23:\"entity-permissions-form\";s:58:\"/admin/structure/comment/manage/{comment_type}/permissions\";s:10:\"collection\";s:24:\"/admin/structure/comment\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:7:\"comment\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Comment type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"comment type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"comment types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count comment type\";s:6:\"plural\";s:20:\"@count comment types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:comment_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:21:\"target_entity_type_id\";i:3;s:11:\"description\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','contact_form.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"contact_form\";s:8:\"\0*\0class\";s:33:\"Drupal\\contact\\Entity\\ContactForm\";s:11:\"\0*\0provider\";s:7:\"contact\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\contact\\Entity\\ContactForm\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:46:\"Drupal\\contact\\ContactFormAccessControlHandler\";s:12:\"list_builder\";s:37:\"Drupal\\contact\\ContactFormListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:34:\"Drupal\\contact\\ContactFormEditForm\";s:4:\"edit\";s:34:\"Drupal\\contact\\ContactFormEditForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:58:\"Drupal\\user\\Entity\\EntityPermissionsRouteProviderWithCheck\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer contact forms\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:11:\"delete-form\";s:53:\"/admin/structure/contact/manage/{contact_form}/delete\";s:9:\"edit-form\";s:46:\"/admin/structure/contact/manage/{contact_form}\";s:23:\"entity-permissions-form\";s:58:\"/admin/structure/contact/manage/{contact_form}/permissions\";s:10:\"collection\";s:24:\"/admin/structure/contact\";s:9:\"canonical\";s:23:\"/contact/{contact_form}\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:15:\"contact_message\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count contact form\";s:6:\"plural\";s:20:\"@count contact forms\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:contact_form_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"form\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:7:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:10:\"recipients\";i:3;s:5:\"reply\";i:4;s:6:\"weight\";i:5;s:7:\"message\";i:6;s:8:\"redirect\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','contact_message.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:15:\"contact_message\";s:8:\"\0*\0class\";s:29:\"Drupal\\contact\\Entity\\Message\";s:11:\"\0*\0provider\";s:7:\"contact\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:6:{s:6:\"bundle\";s:12:\"contact_form\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\contact\\Entity\\Message\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:49:\"Drupal\\contact\\ContactMessageAccessControlHandler\";s:7:\"storage\";s:43:\"Drupal\\Core\\Entity\\ContentEntityNullStorage\";s:12:\"view_builder\";s:33:\"Drupal\\contact\\MessageViewBuilder\";s:4:\"form\";a:1:{s:7:\"default\";s:26:\"Drupal\\contact\\MessageForm\";}}s:19:\"\0*\0admin_permission\";s:24:\"administer contact forms\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";s:12:\"contact_form\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Contact message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Contact messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"contact message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"contact messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:22:\"@count contact message\";s:6:\"plural\";s:23:\"@count contact messages\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:29:\"entity.contact_form.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:20:\"contact_message_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','contact_message.field_storage_definitions',_binary 'a:9:{s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The message UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The message language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:28;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:12:\"contact_form\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Form ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The ID of the associated form.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:12:\"contact_form\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"contact_form\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:58;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The sender\'s name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"The name of the person that is sending the contact message.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:85;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"The sender\'s email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"The email of the person that is sending the contact message.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:110;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:7:\"subject\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Subject\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:7:\"subject\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:100;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:132;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:7:\"message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:4:\"rows\";i:12;}}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:0;s:5:\"label\";s:5:\"above\";}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:7:\"message\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:160;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"copy\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Copy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Whether to send a copy of the message to the sender.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"copy\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:194;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:9:\"recipient\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Recipient ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"The ID of the recipient user for personal contact messages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:9:\"recipient\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:224;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','date_format.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"date_format\";s:8:\"\0*\0class\";s:38:\"Drupal\\Core\\Datetime\\Entity\\DateFormat\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:38:\"Drupal\\Core\\Datetime\\Entity\\DateFormat\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:44:\"Drupal\\system\\DateFormatAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:4:\"form\";a:3:{s:3:\"add\";s:36:\"Drupal\\system\\Form\\DateFormatAddForm\";s:4:\"edit\";s:37:\"Drupal\\system\\Form\\DateFormatEditForm\";s:6:\"delete\";s:39:\"Drupal\\system\\Form\\DateFormatDeleteForm\";}s:12:\"list_builder\";s:35:\"Drupal\\system\\DateFormatListBuilder\";}s:19:\"\0*\0admin_permission\";s:29:\"administer site configuration\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"edit-form\";s:61:\"/admin/config/regional/date-time/formats/manage/{date_format}\";s:11:\"delete-form\";s:68:\"/admin/config/regional/date-time/formats/manage/{date_format}/delete\";s:10:\"collection\";s:40:\"/admin/config/regional/date-time/formats\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Date format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:8:\"rendered\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"locked\";i:3;s:7:\"pattern\";}s:21:\"\0*\0mergedConfigExport\";a:10:{s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:6:\"status\";s:6:\"status\";s:12:\"dependencies\";s:12:\"dependencies\";s:20:\"third_party_settings\";s:20:\"third_party_settings\";s:5:\"_core\";s:5:\"_core\";s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"locked\";s:6:\"locked\";s:7:\"pattern\";s:7:\"pattern\";}}'),('entity.definitions.installed','editor.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:6:\"editor\";s:8:\"\0*\0class\";s:27:\"Drupal\\editor\\Entity\\Editor\";s:11:\"\0*\0provider\";s:6:\"editor\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:6:\"format\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\editor\\Entity\\Editor\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:40:\"Drupal\\editor\\EditorAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Text editor\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Text editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"text editor\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"text editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count text editor\";s:6:\"plural\";s:19:\"@count text editors\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"config:editor_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"RequiredConfigDependencies\";a:1:{i:0;s:13:\"filter_format\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:6:\"format\";i:1;s:6:\"editor\";i:2;s:8:\"settings\";i:3;s:12:\"image_upload\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_form_display.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"entity_form_display\";s:8:\"\0*\0class\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:71:\"\\Drupal\\Core\\Entity\\Entity\\Access\\EntityFormDisplayAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Entity form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:entity_form_display_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";i:4;s:7:\"content\";i:5;s:6:\"hidden\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_form_mode.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"entity_form_mode\";s:8:\"\0*\0class\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityFormMode\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:11:\"description\";s:11:\"description\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityFormMode\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Form mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:entity_form_mode_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:16:\"targetEntityType\";i:4;s:5:\"cache\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_view_display.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"entity_view_display\";s:8:\"\0*\0class\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityViewDisplay\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityViewDisplay\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:71:\"\\Drupal\\Core\\Entity\\Entity\\Access\\EntityViewDisplayAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Entity view display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:entity_view_display_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";i:4;s:7:\"content\";i:5;s:6:\"hidden\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_view_mode.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"entity_view_mode\";s:8:\"\0*\0class\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityViewMode\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:11:\"description\";s:11:\"description\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityViewMode\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"View mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:entity_view_mode_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:16:\"targetEntityType\";i:4;s:5:\"cache\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','field_config.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"field_config\";s:8:\"\0*\0class\";s:31:\"Drupal\\field\\Entity\\FieldConfig\";s:11:\"\0*\0provider\";s:5:\"field\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\field\\Entity\\FieldConfig\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:44:\"Drupal\\field\\FieldConfigAccessControlHandler\";s:7:\"storage\";s:31:\"Drupal\\field\\FieldConfigStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:12:\"@count field\";s:6:\"plural\";s:13:\"@count fields\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:field_config_list\";}s:14:\"\0*\0constraints\";a:2:{s:26:\"RequiredConfigDependencies\";a:1:{i:0;s:20:\"field_storage_config\";}s:19:\"ImmutableProperties\";a:5:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";i:3;s:6:\"bundle\";i:4;s:10:\"field_type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:5:\"field\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:6:\"bundle\";i:4;s:5:\"label\";i:5;s:11:\"description\";i:6;s:8:\"required\";i:7;s:12:\"translatable\";i:8;s:13:\"default_value\";i:9;s:22:\"default_value_callback\";i:10;s:8:\"settings\";i:11;s:10:\"field_type\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','field_storage_config.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:20:\"field_storage_config\";s:8:\"\0*\0class\";s:38:\"Drupal\\field\\Entity\\FieldStorageConfig\";s:11:\"\0*\0provider\";s:5:\"field\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:2:\"id\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:38:\"Drupal\\field\\Entity\\FieldStorageConfig\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:51:\"Drupal\\field\\FieldStorageConfigAccessControlHandler\";s:7:\"storage\";s:38:\"Drupal\\field\\FieldStorageConfigStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Field storage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Field storages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"field storage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"field storages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count field storage\";s:6:\"plural\";s:21:\"@count field storages\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:32:\"config:field_storage_config_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";i:3;s:4:\"type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:7:\"storage\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:4:\"type\";i:4;s:8:\"settings\";i:5;s:6:\"module\";i:6;s:6:\"locked\";i:7;s:11:\"cardinality\";i:8;s:12:\"translatable\";i:9;s:7:\"indexes\";i:10;s:22:\"persist_with_no_fields\";i:11;s:14:\"custom_storage\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','file.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"file\";s:8:\"\0*\0class\";s:23:\"Drupal\\file\\Entity\\File\";s:11:\"\0*\0provider\";s:4:\"file\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"fid\";s:5:\"label\";s:8:\"filename\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:5:\"owner\";s:3:\"uid\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\file\\Entity\\File\";s:11:\"\0*\0handlers\";a:8:{s:7:\"storage\";s:23:\"Drupal\\file\\FileStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\file\\FileStorageSchema\";s:6:\"access\";s:36:\"Drupal\\file\\FileAccessControlHandler\";s:10:\"views_data\";s:25:\"Drupal\\file\\FileViewsData\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:4:\"form\";a:1:{s:6:\"delete\";s:42:\"Drupal\\Core\\Entity\\ContentEntityDeleteForm\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\file\\Entity\\FileRouteProvider\";}s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:1:{s:11:\"delete-form\";s:19:\"/file/{file}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:12:\"file_managed\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"File\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"file\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count file\";s:6:\"plural\";s:12:\"@count files\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"file_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','file.field_storage_definitions',_binary 'a:11:{s:3:\"fid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"File ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The file ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"fid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The file UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The file language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:0;s:22:\"default_value_callback\";s:46:\"Drupal\\file\\Entity\\File::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"The user ID of the file.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filename\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Filename\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"Name of the file with no path components.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filename\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:153;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uri\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The URI to access the file (either local or remote).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:1:{s:13:\"FileUriUnique\";N;}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"uri\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:file_uri\";s:8:\"settings\";a:2:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:1;}}s:18:\"\0*\0fieldDefinition\";r:187;}s:7:\"\0*\0type\";s:8:\"file_uri\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:1;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filemime\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"File MIME type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"The file\'s MIME type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filemime\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:222;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filesize\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"File size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The size of the file in bytes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filesize\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:256;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Status\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"The status of the file, temporary (FALSE) and permanent (TRUE).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:293;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The timestamp that the file was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:334;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"The timestamp that the file was last changed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:363;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','filter_format.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:13:\"filter_format\";s:8:\"\0*\0class\";s:33:\"Drupal\\filter\\Entity\\FilterFormat\";s:11:\"\0*\0provider\";s:6:\"filter\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:6:\"format\";s:5:\"label\";s:4:\"name\";s:6:\"weight\";s:6:\"weight\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\filter\\Entity\\FilterFormat\";s:11:\"\0*\0handlers\";a:4:{s:4:\"form\";a:3:{s:3:\"add\";s:33:\"Drupal\\filter\\FilterFormatAddForm\";s:4:\"edit\";s:34:\"Drupal\\filter\\FilterFormatEditForm\";s:7:\"disable\";s:36:\"Drupal\\filter\\Form\\FilterDisableForm\";}s:12:\"list_builder\";s:37:\"Drupal\\filter\\FilterFormatListBuilder\";s:6:\"access\";s:46:\"Drupal\\filter\\FilterFormatAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:18:\"administer filters\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:2:{s:9:\"edit-form\";s:52:\"/admin/config/content/formats/manage/{filter_format}\";s:7:\"disable\";s:60:\"/admin/config/content/formats/manage/{filter_format}/disable\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Text format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Text formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"text format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"text formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count text format\";s:6:\"plural\";s:19:\"@count text formats\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:25:\"config:filter_format_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:6:\"format\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:4:\"name\";i:1;s:6:\"format\";i:2;s:6:\"weight\";i:3;s:5:\"roles\";i:4;s:7:\"filters\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','image_style.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"image_style\";s:8:\"\0*\0class\";s:30:\"Drupal\\image\\Entity\\ImageStyle\";s:11:\"\0*\0provider\";s:5:\"image\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:4:\"name\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:30:\"Drupal\\image\\Entity\\ImageStyle\";s:11:\"\0*\0handlers\";a:4:{s:4:\"form\";a:4:{s:3:\"add\";s:35:\"Drupal\\image\\Form\\ImageStyleAddForm\";s:4:\"edit\";s:36:\"Drupal\\image\\Form\\ImageStyleEditForm\";s:6:\"delete\";s:38:\"Drupal\\image\\Form\\ImageStyleDeleteForm\";s:5:\"flush\";s:37:\"Drupal\\image\\Form\\ImageStyleFlushForm\";}s:12:\"list_builder\";s:34:\"Drupal\\image\\ImageStyleListBuilder\";s:7:\"storage\";s:30:\"Drupal\\image\\ImageStyleStorage\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";}s:19:\"\0*\0admin_permission\";s:23:\"administer image styles\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:10:\"flush-form\";s:59:\"/admin/config/media/image-styles/manage/{image_style}/flush\";s:9:\"edit-form\";s:53:\"/admin/config/media/image-styles/manage/{image_style}\";s:11:\"delete-form\";s:60:\"/admin/config/media/image-styles/manage/{image_style}/delete\";s:10:\"collection\";s:32:\"/admin/config/media/image-styles\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Image style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"image style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count image style\";s:6:\"plural\";s:19:\"@count image styles\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:23:\"config:image_style_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:5:\"style\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:3:{i:0;s:4:\"name\";i:1;s:5:\"label\";i:2;s:7:\"effects\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','media.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:5:\"media\";s:8:\"\0*\0class\";s:25:\"Drupal\\media\\Entity\\Media\";s:11:\"\0*\0provider\";s:5:\"media\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:3:\"mid\";s:8:\"revision\";s:3:\"vid\";s:6:\"bundle\";s:6:\"bundle\";s:5:\"label\";s:4:\"name\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:5:\"owner\";s:3:\"uid\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\media\\Entity\\Media\";s:11:\"\0*\0handlers\";a:7:{s:7:\"storage\";s:25:\"Drupal\\media\\MediaStorage\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:12:\"list_builder\";s:29:\"Drupal\\media\\MediaListBuilder\";s:6:\"access\";s:38:\"Drupal\\media\\MediaAccessControlHandler\";s:4:\"form\";a:7:{s:7:\"default\";s:22:\"Drupal\\media\\MediaForm\";s:3:\"add\";s:22:\"Drupal\\media\\MediaForm\";s:4:\"edit\";s:22:\"Drupal\\media\\MediaForm\";s:6:\"delete\";s:42:\"Drupal\\Core\\Entity\\ContentEntityDeleteForm\";s:23:\"delete-multiple-confirm\";s:42:\"Drupal\\Core\\Entity\\Form\\DeleteMultipleForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";}s:10:\"views_data\";s:27:\"Drupal\\media\\MediaViewsData\";s:14:\"route_provider\";a:2:{s:4:\"html\";s:39:\"Drupal\\media\\Routing\\MediaRouteProvider\";s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}}s:19:\"\0*\0admin_permission\";s:16:\"administer media\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:11:{s:8:\"add-page\";s:10:\"/media/add\";s:8:\"add-form\";s:23:\"/media/add/{media_type}\";s:9:\"canonical\";s:19:\"/media/{media}/edit\";s:10:\"collection\";s:20:\"/admin/content/media\";s:11:\"delete-form\";s:21:\"/media/{media}/delete\";s:20:\"delete-multiple-form\";s:13:\"/media/delete\";s:9:\"edit-form\";s:19:\"/media/{media}/edit\";s:8:\"revision\";s:46:\"/media/{media}/revisions/{media_revision}/view\";s:20:\"revision-delete-form\";s:47:\"/media/{media}/revision/{media_revision}/delete\";s:20:\"revision-revert-form\";s:47:\"/media/{media}/revision/{media_revision}/revert\";s:15:\"version-history\";s:24:\"/media/{media}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:10:\"media_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:5:\"media\";s:22:\"\0*\0revision_data_table\";s:20:\"media_field_revision\";s:17:\"\0*\0revision_table\";s:14:\"media_revision\";s:13:\"\0*\0data_table\";s:16:\"media_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"media item\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"media items\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count media item\";s:6:\"plural\";s:18:\"@count media items\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:27:\"entity.media_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:10:\"media_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','media.field_storage_definitions',_binary 'a:22:{s:3:\"mid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:3:\"mid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"bundle\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";s:10:\"Media type\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:6:\"bundle\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:10:\"media_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:139;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:170;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:200;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:237;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:100;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:279;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:48:\"Drupal\\media\\Entity\\Media::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The user ID of the author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:4:\"size\";s:2:\"60\";s:17:\"autocomplete_type\";s:4:\"tags\";s:11:\"placeholder\";s:0:\"\";}}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"author\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:326;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:382;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"thumbnail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Thumbnail\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"The thumbnail of the media item.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"view\";a:2:{s:7:\"options\";a:4:{s:4:\"type\";s:5:\"image\";s:6:\"weight\";i:5;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"image_style\";s:9:\"thumbnail\";}}s:12:\"configurable\";b:1;}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:9:\"thumbnail\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:image\";s:8:\"settings\";a:16:{s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:9:\"alt_field\";i:1;s:18:\"alt_field_required\";i:1;s:11:\"title_field\";i:0;s:20:\"title_field_required\";i:0;s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:12:\"max_filesize\";s:0:\"\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:428;}s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:5:{s:9:\"target_id\";a:3:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}s:3:\"alt\";a:3:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;}s:5:\"title\";a:3:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;}s:5:\"width\";a:3:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}s:6:\"height\";a:3:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:12:\"foreign keys\";a:1:{s:9:\"target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:9:\"target_id\";s:3:\"fid\";}}}s:11:\"unique keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"The time the media item was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:22:\"default_value_callback\";s:41:\"Drupal\\media\\Entity\\Media::getRequestTime\";s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:9:\"timestamp\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:514;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The time the media item was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:558;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:589;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:632;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:674;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:22:\"field_media_audio_file\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"media.field_media_audio_file\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"1295648c-a917-438e-a846-fd85d14ae8a0\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JCHoh95CpUeBx9ch24Tmi6ru0nwmNz8xWVH4Qs7RnTg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"media.field_media_audio_file\";s:13:\"\0*\0field_name\";s:22:\"field_media_audio_file\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:4:\"file\";s:9:\"\0*\0module\";s:4:\"file\";s:11:\"\0*\0settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_media_document\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"media.field_media_document\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"6b41e063-a182-4108-9b56-c0f4bb265180\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BdkTx7IL59MCw5a_fOZprPTOGM_wcjz-Fm8g7HV3vFk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"media.field_media_document\";s:13:\"\0*\0field_name\";s:20:\"field_media_document\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:4:\"file\";s:9:\"\0*\0module\";s:4:\"file\";s:11:\"\0*\0settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:17:\"field_media_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:23:\"media.field_media_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ae1f0138-a2f5-4881-bf90-0ade773b59b5\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0N0KSFk57p6qsq3qM4lYVGSuROvzXK-tSsdwByqUh3g\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:23:\"media.field_media_image\";s:13:\"\0*\0field_name\";s:17:\"field_media_image\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_media_oembed_video\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"media.field_media_oembed_video\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"b471db54-e924-4e9f-b6d7-c7e32f497206\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cNf_852Dq-fNnSaMI4LxL-J6N7bLkHuDbD9EUqOn4_U\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"media.field_media_oembed_video\";s:13:\"\0*\0field_name\";s:24:\"field_media_oembed_video\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:3:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;s:8:\"is_ascii\";b:0;}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_media_video_file\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"media.field_media_video_file\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"1567fe07-a329-492a-bc5f-d82e3865bd57\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z5mgbn1PIVZ5TNMByBmivqo_u3Rdk58UIzpyN4ypTeM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"media.field_media_video_file\";s:13:\"\0*\0field_name\";s:22:\"field_media_video_file\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:4:\"file\";s:9:\"\0*\0module\";s:4:\"file\";s:11:\"\0*\0settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','media_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:10:\"media_type\";s:8:\"\0*\0class\";s:29:\"Drupal\\media\\Entity\\MediaType\";s:11:\"\0*\0provider\";s:5:\"media\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\media\\Entity\\MediaType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:42:\"Drupal\\media\\MediaTypeAccessControlHandler\";s:4:\"form\";a:3:{s:3:\"add\";s:26:\"Drupal\\media\\MediaTypeForm\";s:4:\"edit\";s:26:\"Drupal\\media\\MediaTypeForm\";s:6:\"delete\";s:44:\"Drupal\\media\\Form\\MediaTypeDeleteConfirmForm\";}s:12:\"list_builder\";s:33:\"Drupal\\media\\MediaTypeListBuilder\";s:14:\"route_provider\";a:2:{s:4:\"html\";s:51:\"Drupal\\Core\\Entity\\Routing\\DefaultHtmlRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:22:\"administer media types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:8:\"add-form\";s:26:\"/admin/structure/media/add\";s:9:\"edit-form\";s:42:\"/admin/structure/media/manage/{media_type}\";s:11:\"delete-form\";s:49:\"/admin/structure/media/manage/{media_type}/delete\";s:23:\"entity-permissions-form\";s:54:\"/admin/structure/media/manage/{media_type}/permissions\";s:10:\"collection\";s:22:\"/admin/structure/media\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:5:\"media\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Media types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"media types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count media type\";s:6:\"plural\";s:18:\"@count media types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:22:\"config:media_type_list\";}s:14:\"\0*\0constraints\";a:2:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:6:\"source\";}s:23:\"MediaMappingsConstraint\";a:0:{}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:9:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"source\";i:4;s:25:\"queue_thumbnail_downloads\";i:5;s:12:\"new_revision\";i:6;s:20:\"source_configuration\";i:7;s:9:\"field_map\";i:8;s:6:\"status\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','menu.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:4:\"menu\";s:8:\"\0*\0class\";s:25:\"Drupal\\system\\Entity\\Menu\";s:11:\"\0*\0provider\";s:6:\"system\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\system\\Entity\\Menu\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:38:\"Drupal\\system\\MenuAccessControlHandler\";s:7:\"storage\";s:25:\"Drupal\\system\\MenuStorage\";}s:19:\"\0*\0admin_permission\";s:15:\"administer menu\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count menu\";s:6:\"plural\";s:12:\"@count menus\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:16:\"config:menu_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"locked\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','menu_link_content.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":40:{s:5:\"\0*\0id\";s:17:\"menu_link_content\";s:8:\"\0*\0class\";s:47:\"Drupal\\menu_link_content\\Entity\\MenuLinkContent\";s:11:\"\0*\0provider\";s:17:\"menu_link_content\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:6:\"bundle\";s:9:\"published\";s:7:\"enabled\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:47:\"Drupal\\menu_link_content\\Entity\\MenuLinkContent\";s:11:\"\0*\0handlers\";a:7:{s:7:\"storage\";s:48:\"\\Drupal\\menu_link_content\\MenuLinkContentStorage\";s:14:\"storage_schema\";s:53:\"Drupal\\menu_link_content\\MenuLinkContentStorageSchema\";s:6:\"access\";s:60:\"Drupal\\menu_link_content\\MenuLinkContentAccessControlHandler\";s:4:\"form\";a:2:{s:7:\"default\";s:49:\"Drupal\\menu_link_content\\Form\\MenuLinkContentForm\";s:6:\"delete\";s:55:\"Drupal\\menu_link_content\\Form\\MenuLinkContentDeleteForm\";}s:12:\"list_builder\";s:44:\"Drupal\\menu_link_content\\MenuLinkListBuilder\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:10:\"moderation\";s:0:\"\";}s:19:\"\0*\0admin_permission\";s:15:\"administer menu\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"canonical\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:9:\"edit-form\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:11:\"delete-form\";s:53:\"/admin/structure/menu/item/{menu_link_content}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:17:\"menu_link_content\";s:22:\"\0*\0revision_data_table\";s:32:\"menu_link_content_field_revision\";s:17:\"\0*\0revision_table\";s:26:\"menu_link_content_revision\";s:13:\"\0*\0data_table\";s:22:\"menu_link_content_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Custom menu link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Custom menu links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"custom menu link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"custom menu links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:23:\"@count custom menu link\";s:6:\"plural\";s:24:\"@count custom menu links\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:22:\"menu_link_content_list\";}s:14:\"\0*\0constraints\";a:3:{s:17:\"MenuTreeHierarchy\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:1:{s:17:\"stringTranslation\";s:18:\"string_translation\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','menu_link_content.field_storage_definitions',_binary 'a:22:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Entity ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"The entity ID for this menu link content entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"The content menu link UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"The menu link language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:111;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"bundle\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";s:23:\"Custom menu link bundle\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"The content menu link bundle.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"bundle\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:151;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:184;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:214;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:251;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"enabled\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Enabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"A flag for whether the link should be enabled in menus or hidden.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:7:\"boolean\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:-1;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:7:\"enabled\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:290;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Menu link title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"The text to be used for this link in the menu.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:344;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"description\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Shown when hovering over the menu link.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:11:\"description\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:392;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"menu_name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Menu name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:93:\"The menu name. All links with the same menu name (such as \"tools\") are part of the same menu.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:5:\"tools\";}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:9:\"menu_name\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:438;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"link\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"The location this menu link points to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:-2;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:4:\"link\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:link\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}}s:18:\"\0*\0fieldDefinition\";r:475;}s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:3:{s:3:\"uri\";a:3:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"title\";a:3:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;}s:7:\"options\";a:4:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:3:\"uri\";a:1:{i:0;a:2:{i:0;s:3:\"uri\";i:1;i:30;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"external\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"External\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:120:\"A flag to indicate if the link points to a full URL starting with a protocol, like http:// (1 = external, 0 = internal).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"external\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:528;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:10:\"rediscover\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"Indicates whether the menu link should be rediscovered\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:10:\"rediscover\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:570;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:172:\"Link weight among links in the same menu at the same depth. In the menu, the links with high weight will sink and links with a low weight will be positioned nearer the top.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:14:\"number_integer\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:20;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:607;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"expanded\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Show as expanded\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:164:\"If selected and this menu link has children, the menu will always appear expanded. This option may be overridden for the entire menu tree when placing a menu block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:7:\"boolean\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:0;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"expanded\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:657;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"parent\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Parent plugin ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:94:\"The ID of the parent menu link plugin, or empty string when at the top level of the hierarchy.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"parent\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:709;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"The time that the menu link was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:743;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:774;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:817;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:859;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','node.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"node\";s:8:\"\0*\0class\";s:23:\"Drupal\\node\\Entity\\Node\";s:11:\"\0*\0provider\";s:4:\"node\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:12:{s:2:\"id\";s:3:\"nid\";s:8:\"revision\";s:3:\"vid\";s:6:\"bundle\";s:4:\"type\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"status\";s:6:\"status\";s:9:\"published\";s:6:\"status\";s:3:\"uid\";s:3:\"uid\";s:5:\"owner\";s:3:\"uid\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\node\\Entity\\Node\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:23:\"Drupal\\node\\NodeStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\node\\NodeStorageSchema\";s:12:\"view_builder\";s:27:\"Drupal\\node\\NodeViewBuilder\";s:6:\"access\";s:36:\"Drupal\\node\\NodeAccessControlHandler\";s:10:\"views_data\";s:25:\"Drupal\\node\\NodeViewsData\";s:4:\"form\";a:4:{s:7:\"default\";s:20:\"Drupal\\node\\NodeForm\";s:6:\"delete\";s:31:\"Drupal\\node\\Form\\NodeDeleteForm\";s:4:\"edit\";s:20:\"Drupal\\node\\NodeForm\";s:23:\"delete-multiple-confirm\";s:31:\"Drupal\\node\\Form\\DeleteMultiple\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\node\\Entity\\NodeRouteProvider\";}s:12:\"list_builder\";s:27:\"Drupal\\node\\NodeListBuilder\";s:11:\"translation\";s:34:\"Drupal\\node\\NodeTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";s:23:\"access content overview\";s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:7:{s:9:\"canonical\";s:12:\"/node/{node}\";s:11:\"delete-form\";s:19:\"/node/{node}/delete\";s:20:\"delete-multiple-form\";s:26:\"/admin/content/node/delete\";s:9:\"edit-form\";s:17:\"/node/{node}/edit\";s:15:\"version-history\";s:22:\"/node/{node}/revisions\";s:8:\"revision\";s:43:\"/node/{node}/revisions/{node_revision}/view\";s:6:\"create\";s:5:\"/node\";}s:21:\"\0*\0bundle_entity_type\";s:9:\"node_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:4:\"node\";s:22:\"\0*\0revision_data_table\";s:19:\"node_field_revision\";s:17:\"\0*\0revision_table\";s:13:\"node_revision\";s:13:\"\0*\0data_table\";s:15:\"node_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"content item\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content items\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count content item\";s:6:\"plural\";s:20:\"@count content items\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:26:\"entity.node_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:1:{i:0;s:21:\"user.node_grants:view\";}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"node_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:12:\"revision_uid\";s:16:\"revision_created\";s:18:\"revision_timestamp\";s:20:\"revision_log_message\";s:12:\"revision_log\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','node.field_storage_definitions',_binary 'a:22:{s:3:\"nid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"nid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";s:12:\"Content type\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:9:\"node_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:139;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:18:\"revision_timestamp\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:18:\"revision_timestamp\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:170;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:12:\"revision_uid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:200;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_log\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:12:\"revision_log\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:237;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:120;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:279;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:46:\"Drupal\\node\\Entity\\Node::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The username of the content author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"author\";s:6:\"weight\";i:0;}}s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:8:\"settings\";a:3:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:4:\"size\";s:2:\"60\";s:11:\"placeholder\";s:0:\"\";}}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:326;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:380;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The date and time that the content was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:9:\"timestamp\";s:6:\"weight\";i:0;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:424;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the node was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:466;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"promote\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Promoted to front page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:15;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:497;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"sticky\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Sticky at top of lists\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:16;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:6:\"sticky\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:544;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:591;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:634;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:676;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:9:\"node.body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"26a81385-82de-46f0-8582-8c93b0fbcb01\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:9:\"node.body\";s:13:\"\0*\0field_name\";s:4:\"body\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:17:\"text_with_summary\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:11:\"field_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:16:\"node.field_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d9aff85c-3ad9-418b-b47e-58f08b64180e\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:16:\"node.field_image\";s:13:\"\0*\0field_name\";s:11:\"field_image\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:10:\"\0*\0deleted\";b:0;}s:10:\"field_tags\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:15:\"node.field_tags\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"81f6ea79-133f-4e53-bb0a-4169a69c4472\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:15:\"node.field_tags\";s:13:\"\0*\0field_name\";s:10:\"field_tags\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:16:\"field_components\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":32:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";s:2:\"-1\";s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;s:20:\"field_storage_submit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Update settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:18:\"cardinality_number\";s:1:\"1\";}}'),('entity.definitions.installed','node_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:9:\"node_type\";s:8:\"\0*\0class\";s:27:\"Drupal\\node\\Entity\\NodeType\";s:11:\"\0*\0provider\";s:4:\"node\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:4:\"type\";s:5:\"label\";s:4:\"name\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\node\\Entity\\NodeType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:40:\"Drupal\\node\\NodeTypeAccessControlHandler\";s:4:\"form\";a:3:{s:3:\"add\";s:24:\"Drupal\\node\\NodeTypeForm\";s:4:\"edit\";s:24:\"Drupal\\node\\NodeTypeForm\";s:6:\"delete\";s:38:\"Drupal\\node\\Form\\NodeTypeDeleteConfirm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:12:\"list_builder\";s:31:\"Drupal\\node\\NodeTypeListBuilder\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer content types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:9:\"edit-form\";s:41:\"/admin/structure/types/manage/{node_type}\";s:11:\"delete-form\";s:48:\"/admin/structure/types/manage/{node_type}/delete\";s:23:\"entity-permissions-form\";s:53:\"/admin/structure/types/manage/{node_type}/permissions\";s:10:\"collection\";s:22:\"/admin/structure/types\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:4:\"node\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count content type\";s:6:\"plural\";s:20:\"@count content types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:21:\"config:node_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:7:{i:0;s:4:\"name\";i:1;s:4:\"type\";i:2;s:11:\"description\";i:3;s:4:\"help\";i:4;s:12:\"new_revision\";i:5;s:12:\"preview_mode\";i:6;s:17:\"display_submitted\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','paragraph.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:9:\"paragraph\";s:8:\"\0*\0class\";s:34:\"Drupal\\paragraphs\\Entity\\Paragraph\";s:11:\"\0*\0provider\";s:10:\"paragraphs\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:0;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:4:\"type\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:11:\"revision_id\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\paragraphs\\Entity\\Paragraph\";s:11:\"\0*\0handlers\";a:7:{s:12:\"view_builder\";s:38:\"Drupal\\paragraphs\\ParagraphViewBuilder\";s:6:\"access\";s:47:\"Drupal\\paragraphs\\ParagraphAccessControlHandler\";s:14:\"storage_schema\";s:40:\"Drupal\\paragraphs\\ParagraphStorageSchema\";s:4:\"form\";a:3:{s:7:\"default\";s:36:\"Drupal\\Core\\Entity\\ContentEntityForm\";s:6:\"delete\";s:42:\"Drupal\\Core\\Entity\\ContentEntityDeleteForm\";s:4:\"edit\";s:36:\"Drupal\\Core\\Entity\\ContentEntityForm\";}s:10:\"views_data\";s:28:\"Drupal\\views\\EntityViewsData\";s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:10:\"moderation\";s:0:\"\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";s:15:\"paragraphs_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Paragraph type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:15:\"paragraphs_item\";s:22:\"\0*\0revision_data_table\";s:35:\"paragraphs_item_revision_field_data\";s:17:\"\0*\0revision_table\";s:24:\"paragraphs_item_revision\";s:13:\"\0*\0data_table\";s:26:\"paragraphs_item_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Paragraphs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Paragraphs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:16:\"@count Paragraph\";s:6:\"plural\";s:17:\"@count Paragraphs\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:32:\"entity.paragraphs_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:14:\"paragraph_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:7:{s:33:\"entity_revision_parent_type_field\";s:11:\"parent_type\";s:31:\"entity_revision_parent_id_field\";s:9:\"parent_id\";s:39:\"entity_revision_parent_field_name_field\";s:17:\"parent_field_name\";s:33:\"common_reference_revisions_target\";b:1;s:27:\"content_translation_ui_skip\";b:1;s:35:\"default_reference_revision_settings\";a:4:{s:20:\"field_storage_config\";a:2:{s:11:\"cardinality\";i:-1;s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}}s:12:\"field_config\";a:1:{s:8:\"settings\";a:1:{s:7:\"handler\";s:17:\"default:paragraph\";}}s:19:\"entity_form_display\";a:1:{s:4:\"type\";s:10:\"paragraphs\";}s:19:\"entity_view_display\";a:1:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";}}s:31:\"serialized_field_property_names\";a:1:{s:17:\"behavior_settings\";a:1:{i:0;s:5:\"value\";}}}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','paragraph.field_storage_definitions',_binary 'a:81:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"The paragraphs entity language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";s:14:\"Paragraph type\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:15:\"paragraphs_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:135;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:166;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The time that the Paragraph was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:6:\"region\";s:6:\"hidden\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:210;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"parent_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Parent ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"The ID of the parent entity of which this entity is referenced.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:9:\"parent_id\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:247;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"parent_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Parent type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"The entity parent type to which this entity is referenced.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:11:\"parent_type\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:282;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:17:\"parent_field_name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Parent field name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:64:\"The entity parent field name to which this entity is referenced.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:17:\"parent_field_name\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:317;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:17:\"behavior_settings\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Behavior settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"The behavior plugin settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:17:\"behavior_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:352;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:387;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:430;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:472;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:18:\"field_ept_settings\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"aed153c8-a66a-428a-be76-0d9ff9c57e30\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HvKMBmRf1ancerUpnNjtwfTeY-R4_vPBnsqEe9j-ovs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:8:\"ept_core\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ept_settings\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:12:\"ept_settings\";s:9:\"\0*\0module\";s:8:\"ept_core\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ept_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:25:\"paragraph.field_ept_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d142f67c-eb14-402b-8d63-83e817038f33\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjnRL-vwDWFKmoYTCU9jkwjIlui_gNnOJnIwnLo9m2k\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:25:\"paragraph.field_ept_title\";s:13:\"\0*\0field_name\";s:15:\"field_ept_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"field_ept_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:24:\"paragraph.field_ept_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"e76f4c36-a02a-4c1e-b34f-cecbd30657dd\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7r3ygKhgvLH2hBQgQ6uizJgLea8q4TUMhKv9AysHhVw\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:24:\"paragraph.field_ept_text\";s:13:\"\0*\0field_name\";s:14:\"field_ept_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_accordion\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_accordion\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"c9282b5e-9cbb-4d37-84d7-b405cf59a041\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"99EX18edsQlLBda3J37pHASAxF4OUjSVJ4_nSq1pW94\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_accordion\";s:13:\"\0*\0field_name\";s:19:\"field_ept_accordion\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_accordion_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_accordion_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"012f2184-9082-4983-9239-7dac48864d9c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6S4PB05UjgSgHEDSalqgqkJHWyCcYsdkgPKTvGC2c8s\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_accordion_title\";s:13:\"\0*\0field_name\";s:25:\"field_ept_accordion_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_accordion_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_accordion_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"177e4cd0-bbd1-44cd-9d3f-5b5dd4378ed4\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l5c0DoOjgcErJEjFGkUqN_upYgubdHpE_MiwbMK2YRI\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_accordion_text\";s:13:\"\0*\0field_name\";s:24:\"field_ept_accordion_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_basic_button_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_basic_button_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"360bef36-b4f7-492b-9677-6170eebdf2bb\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Tj1qQArNpaPeg2XmPed8WY2JiAk8p21-R1HVn28zVoY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_basic_button_link\";s:13:\"\0*\0field_name\";s:27:\"field_ept_basic_button_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ept_block_block\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":32:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_block_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"58c5cc3e-9949-4686-882a-a56b59c60ea8\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hAESsXJ5KZsWYKr-KB5wJoHNBdcOTlIFJUomBW8VxoU\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_block_block\";s:13:\"\0*\0field_name\";s:21:\"field_ept_block_block\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:11:\"block_field\";s:9:\"\0*\0module\";s:11:\"block_field\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;s:20:\"field_storage_submit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Update settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:18:\"cardinality_number\";s:1:\"1\";}s:31:\"field_ept_bootstrap_button_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:41:\"paragraph.field_ept_bootstrap_button_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"bceb6f2f-b114-41f5-8b07-0ce990d0087a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BweaoyqqEqOIBPWV2qKw_2N4R6oBSudk91cCNPtz_iY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:41:\"paragraph.field_ept_bootstrap_button_link\";s:13:\"\0*\0field_name\";s:31:\"field_ept_bootstrap_button_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_carousel_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_carousel_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"1da3ad04-a3d6-45a2-8a2e-100f0d629948\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ViB2NrYfe_RWvrvvb9X_U6kuX0eI47m5Wpa6hCFqZWE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_carousel_image\";s:13:\"\0*\0field_name\";s:24:\"field_ept_carousel_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ept_carousel\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_carousel\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fbb51140-67d8-4112-868c-19dd46c31b98\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RbALd0Xz78o-CtP2iD8j7s8h1scHn1lSdm-_EQqZyrY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_carousel\";s:13:\"\0*\0field_name\";s:18:\"field_ept_carousel\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ept_carousel_caption\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ept_carousel_caption\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"4bdff313-152c-4ea9-ba49-6f433c48203a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HeWBlq69mptI0nGWU0dliRAS9rVOa2HzuJbUbzsJg4M\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ept_carousel_caption\";s:13:\"\0*\0field_name\";s:26:\"field_ept_carousel_caption\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:17:\"field_ept_columns\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":32:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:27:\"paragraph.field_ept_columns\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7518ddce-1000-4e47-8c93-f8230ca40081\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lIenGVJ8vS3WAEr1xteI9sDUdCoc-UNgbf7xDipU4_s\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:27:\"paragraph.field_ept_columns\";s:13:\"\0*\0field_name\";s:17:\"field_ept_columns\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";s:2:\"-1\";s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;s:20:\"field_storage_submit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Update settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:18:\"cardinality_number\";s:1:\"1\";}s:24:\"field_ept_countdown_date\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_countdown_date\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"5741fa83-8e57-4e60-99ce-6e8bd5bf8b78\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SWGbKy8XYRkCxbrmDvY2UYyxzAKxcSL7ouH4CljiXbY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"datetime\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_countdown_date\";s:13:\"\0*\0field_name\";s:24:\"field_ept_countdown_date\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:8:\"datetime\";s:9:\"\0*\0module\";s:8:\"datetime\";s:11:\"\0*\0settings\";a:1:{s:13:\"datetime_type\";s:8:\"datetime\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_counter_number\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_counter_number\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"072a57f4-9c76-4a9a-a3f4-f13ef03b81be\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MzVJsn5k9Si1YXppdAIDnZzJ1W16U44-V2RnkeyaeyI\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_counter_number\";s:13:\"\0*\0field_name\";s:24:\"field_ept_counter_number\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ept_counter_items\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ept_counter_items\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fa2205d7-3b05-4d76-a029-30510c45d952\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vFwfw4KEUwjCwBs2-7ay4ctFQ2ObvCZYU16zxuQC5HM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ept_counter_items\";s:13:\"\0*\0field_name\";s:23:\"field_ept_counter_items\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ept_counter_icon\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_ept_counter_icon\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"bd174355-0ad0-4843-9909-9069e6e2eac2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0JA4V_sLzmSUMXzEuZ7m6J_MFEw5Nrb7bG9XU34Ucc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_ept_counter_icon\";s:13:\"\0*\0field_name\";s:22:\"field_ept_counter_icon\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ept_counter_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ept_counter_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a62c9e27-ad8b-430d-85ce-9db276ada8eb\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CTuSHda2RHGJciX7ZF12J7Y9A3TK_RrRj7CRxyKyNGA\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ept_counter_title\";s:13:\"\0*\0field_name\";s:23:\"field_ept_counter_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:29:\"field_ept_counter_description\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:39:\"paragraph.field_ept_counter_description\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"385056ad-483b-468c-8fc7-fa477f32138c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Vb_uSodiEH1YHgcoZFitK_cSCdO65_4U1fUOrl-0G-0\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:39:\"paragraph.field_ept_counter_description\";s:13:\"\0*\0field_name\";s:29:\"field_ept_counter_description\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_cta_second_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_cta_second_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"e5ac8a81-1f96-4b7d-b8e0-6d9b2c08fcbd\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DHvUvJxjsMX4y4-L8sAyVpFvA0pptpqcHZ8p_EMBBdU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_cta_second_link\";s:13:\"\0*\0field_name\";s:25:\"field_ept_cta_second_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ept_cta_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_cta_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ef4b1edf-7e44-4fd4-9484-139b43615d23\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LvryVrIdU5CC3UNEhpU7Vej6X8Y4RKKDsOdhseGGUVg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_cta_link\";s:13:\"\0*\0field_name\";s:18:\"field_ept_cta_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ept_cta_column_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ept_cta_column_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"2545ccb9-b7f9-49f1-a002-1aa70a099849\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BVZIBdZwlh9CG5xDwjnekBIIuVdEEtKvFPci5rwGdA0\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ept_cta_column_image\";s:13:\"\0*\0field_name\";s:26:\"field_ept_cta_column_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ept_hero_second_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ept_hero_second_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a51e7805-3dcf-415a-b08c-6e41b660115d\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_LEdcxkwVZPMeBjAfFM_DTcqJxHu-SXmfvkzYA16OTE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ept_hero_second_link\";s:13:\"\0*\0field_name\";s:26:\"field_ept_hero_second_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_hero_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_hero_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"89e38776-3ba0-4f79-9023-af5e40b20171\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XgZuheOtVwvMdFAli6FX9XwC6jCtmfQsa4Y--V6AWLk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_hero_link\";s:13:\"\0*\0field_name\";s:19:\"field_ept_hero_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_hero_column_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_hero_column_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0bd5b0b1-4d3b-472e-ac51-086416f9360a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"knr6QfLVidPHSzwjlRdOZ6PqAiVNnXT73--qFC4pZqo\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_hero_column_image\";s:13:\"\0*\0field_name\";s:27:\"field_ept_hero_column_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_hero_title_prefix\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_hero_title_prefix\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"be93c2a2-2803-47c8-8cbb-88ab3561ae6c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HgeEpS7HHbPsoLeKHrpRrax2ttxvlJADvMU3R-HwVf4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_hero_title_prefix\";s:13:\"\0*\0field_name\";s:27:\"field_ept_hero_title_prefix\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ept_image_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ept_image_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"389f5e03-e7e9-4fb0-bdb5-618f4ada2579\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VKNAP2cuu9mjHYh_BiZTS3nC4gx2nPLjvdAFIHAhJs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ept_image_link\";s:13:\"\0*\0field_name\";s:20:\"field_ept_image_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ept_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:25:\"paragraph.field_ept_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a3a4414c-7488-42d9-ad4e-706dbb16b1da\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t2q8Lh-nuJZ2Ozh8PR1_zVbozcHAD18kLOnsz0e4oxY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:25:\"paragraph.field_ept_image\";s:13:\"\0*\0field_name\";s:15:\"field_ept_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ept_image_caption\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ept_image_caption\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d90ba792-7242-4c28-a755-2203bfbd33dc\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-2PNM_k1cGXc-Q0fAWwWKl0WSoTksX8UcJ3-t0wUn1s\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ept_image_caption\";s:13:\"\0*\0field_name\";s:23:\"field_ept_image_caption\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ept_image_gallery\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ept_image_gallery\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a25a51c6-fb73-441d-bfe4-baf60db380f2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"42vUEff48hmnJOtdaZMLlF0wtf_QYb_mBJO5EVMCKBk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ept_image_gallery\";s:13:\"\0*\0field_name\";s:23:\"field_ept_image_gallery\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ept_micromodal_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ept_micromodal_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"58a0c8d3-2aaa-43a3-af29-df451a7410e3\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9wlDgbRXeLI7j3BoH97N3phJfeK2l1E2osqZh_FRkh4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ept_micromodal_title\";s:13:\"\0*\0field_name\";s:26:\"field_ept_micromodal_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ept_quote_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_quote_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"39b9627d-fdb9-4ed9-afc4-0c4d133a92c6\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tQ8LcsYTu_fXhMAvx5We58I0EB2mrFc9tC42tO2YpQ4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_quote_image\";s:13:\"\0*\0field_name\";s:21:\"field_ept_quote_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ept_quote_author\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_ept_quote_author\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"f68b8da9-803f-4c9b-8f4c-4fc24f899205\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yN0vOPqU28gSDN6dC5uNd2vwbTDVhm0njE_mJ2k_rCk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_ept_quote_author\";s:13:\"\0*\0field_name\";s:22:\"field_ept_quote_author\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_slick_slider_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_slick_slider_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"3adc57b0-490d-4760-8c68-b19c339fedb5\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"urQvYyrbemmSrIdbqn5B3hiHO3OGBgCpwmTx0L9ipCM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_slick_slider_link\";s:13:\"\0*\0field_name\";s:27:\"field_ept_slick_slider_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:28:\"field_ept_slick_slider_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:38:\"paragraph.field_ept_slick_slider_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d985b37a-8f1d-4d3c-8d92-09cb8326cf66\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LzVCCy3JB_QNYYe-TIA7NOSStFsPdMhJRj2kRx6xp48\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:38:\"paragraph.field_ept_slick_slider_image\";s:13:\"\0*\0field_name\";s:28:\"field_ept_slick_slider_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ept_slick_slider\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_ept_slick_slider\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"467150cb-7feb-412a-9426-4b2a3f4a1caa\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"p4cFkBoz3tkJW1Ep5zM4g_f4mQ-XFHh3pShn7qHErpU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_ept_slick_slider\";s:13:\"\0*\0field_name\";s:22:\"field_ept_slick_slider\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_slick_slider_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_slick_slider_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d8e5d125-f4f7-4c1d-ac26-f7468f91d3b9\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9lgsbO7ntDggj0S64_Kj04ysNSAJqsLLVWCg1sASI7o\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_slick_slider_text\";s:13:\"\0*\0field_name\";s:27:\"field_ept_slick_slider_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_slideshow_slide\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_slideshow_slide\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d704c8d4-b783-49b6-af10-1f4524374151\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qxeflsuOm7AVY0acEDYWC8RbV1WUHCbVdEWrV-i8xCU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_slideshow_slide\";s:13:\"\0*\0field_name\";s:25:\"field_ept_slideshow_slide\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_slideshow_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_slideshow_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"08a96db8-eb88-4875-8250-d218a934e839\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j3IfmwQ3lYIJp87Put31sIn-_9bc3uFqZWFLa_w_9hk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_slideshow_link\";s:13:\"\0*\0field_name\";s:24:\"field_ept_slideshow_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_slideshow\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_slideshow\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"1a9f268a-efba-464e-854e-f46e7e1341e9\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNz95cfhiI0VPQ9jlgmyexwx_snf3hcYXB3N76R6FEg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_slideshow\";s:13:\"\0*\0field_name\";s:19:\"field_ept_slideshow\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_slideshow_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_slideshow_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"c605bbbd-911f-4bca-9f1d-7575ba23063c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tyAlxAEOc2ScLxGA0DPp-lg0u4x8VXHrFuotd44B_SE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_slideshow_title\";s:13:\"\0*\0field_name\";s:25:\"field_ept_slideshow_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_slideshow_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_slideshow_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"8f6db9bb-d214-4b8e-a41e-8e68af02013e\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hf7ieZizeOOo0vAYdXIuWovA7ihSiu5RQ6PQD9LV27c\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_slideshow_text\";s:13:\"\0*\0field_name\";s:24:\"field_ept_slideshow_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_stats_item_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_stats_item_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"48fc10e7-9c7a-4b33-8f60-3ce608c713c5\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r9tIHirJngA0lU8nZzF4zo3Sk3sZoNMDm7tn4Q8f6nU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_stats_item_link\";s:13:\"\0*\0field_name\";s:25:\"field_ept_stats_item_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ept_stats_item_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ept_stats_item_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"32ff7444-1fb2-4c29-97a3-9e9f53ec491a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UoI74uzcaxvNAutge4YEMTgWFuRMeasXrgpq3PK1sVs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ept_stats_item_image\";s:13:\"\0*\0field_name\";s:26:\"field_ept_stats_item_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ept_stats\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:25:\"paragraph.field_ept_stats\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"54f29aab-0b38-45f1-bef4-33ea7848198c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A2WIvrY8Lq2oUgdXcZ6AeYNUvyM4mmPAuE7W3ZK_2Wc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:25:\"paragraph.field_ept_stats\";s:13:\"\0*\0field_name\";s:15:\"field_ept_stats\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_stats_item_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_stats_item_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"9bab1d24-d574-48e2-8d0e-4ab68fb47d98\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IMNMgfxAACwo5FdbEzobs2cmUZRx-IryVkWAVFd6jPc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_stats_item_text\";s:13:\"\0*\0field_name\";s:25:\"field_ept_stats_item_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_stats_item_number\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_stats_item_number\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"e0b4af62-c275-4029-b2a7-59ffabd9c786\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HhOT5HnntE62swJxbAxEUWcqiYJnPIfz8wawWbRbXDs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_stats_item_number\";s:13:\"\0*\0field_name\";s:27:\"field_ept_stats_item_number\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"field_ept_tabs\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:24:\"paragraph.field_ept_tabs\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"79fcf2b8-c7f0-45ad-b0c1-f2032eef3896\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NMqcA7Fqw60GbpdVeUtmztxo2zdXkrGvZx8twbTDDeU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:24:\"paragraph.field_ept_tabs\";s:13:\"\0*\0field_name\";s:14:\"field_ept_tabs\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ept_tab_page\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_tab_page\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"dd8a6a77-dce1-4167-81fc-78b560cda129\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HG0HGpRQXhX56PVuj3x5C5jDc-vtEneALavRoeN1CvM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_tab_page\";s:13:\"\0*\0field_name\";s:18:\"field_ept_tab_page\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:4:\"node\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ept_tab_content\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_tab_content\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"87c56ad4-62d6-4644-86c1-680e4755ff8b\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fKb1I7aWTTDXPpSXxFasd3Do_zu03KEABHYH6l26zZU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"options\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_tab_content\";s:13:\"\0*\0field_name\";s:21:\"field_ept_tab_content\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:11:\"list_string\";s:9:\"\0*\0module\";s:7:\"options\";s:11:\"\0*\0settings\";a:2:{s:14:\"allowed_values\";a:4:{s:4:\"text\";s:4:\"Text\";s:4:\"page\";s:4:\"Page\";s:5:\"block\";s:5:\"Block\";s:5:\"views\";s:5:\"Views\";}s:23:\"allowed_values_function\";s:0:\"\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_tab_block\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_tab_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"14901660-c7de-459b-8e6b-6065e1894829\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mkRqIh2Wq5dPyqwbNdS4O7366xpiXfnEqoCKO_Dxil8\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_tab_block\";s:13:\"\0*\0field_name\";s:19:\"field_ept_tab_block\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:11:\"block_field\";s:9:\"\0*\0module\";s:11:\"block_field\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_tab_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_tab_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"75781815-4f60-47eb-bdc4-255e273d1add\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jmZoEFoCrYRXWTQoBNH-lk2Jtzlrk1QgYJW-ZwiojjU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_tab_title\";s:13:\"\0*\0field_name\";s:19:\"field_ept_tab_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"text\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:1:{s:10:\"max_length\";i:255;}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ept_tab_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_tab_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"843571d5-1f13-41be-91d6-4a2cdc24036d\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-LqQ-u0-ZIOFFNbSXCCLceO2nHJcofY3jorF2Bo_oOs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_tab_text\";s:13:\"\0*\0field_name\";s:18:\"field_ept_tab_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_tab_views\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_tab_views\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0210aa9b-f809-485d-9dc9-01d5b19a7a97\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yuhCLkHFy1lOVHdkbi-9gSbiwW6Cz9cKfJdJaYwK_Pk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_tab_views\";s:13:\"\0*\0field_name\";s:19:\"field_ept_tab_views\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:14:\"viewsreference\";s:9:\"\0*\0module\";s:14:\"viewsreference\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ept_tiles_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ept_tiles_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"62135f80-efc0-4ec3-883a-ce4ccfe66aaa\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ca5c5aWMZPNjvFUQqM813ltjPOGiBvCBP1o5N8IrcOM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ept_tiles_link\";s:13:\"\0*\0field_name\";s:20:\"field_ept_tiles_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ept_tiles_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_tiles_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"c84089e9-ca27-4ede-81db-501ab243fe10\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LTIRUfdCjzSopVuoQqk229l5haSvo7JDJ2W9r1MheDo\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_tiles_image\";s:13:\"\0*\0field_name\";s:21:\"field_ept_tiles_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ept_tiles\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:25:\"paragraph.field_ept_tiles\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ad3c2c1b-78c7-400a-a114-8f5a64daf409\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XenLJeS9-3QAxnei6iPwJsGOprgjG7bUCwDd60onVWw\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:25:\"paragraph.field_ept_tiles\";s:13:\"\0*\0field_name\";s:15:\"field_ept_tiles\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_clickable_tile\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_clickable_tile\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"776f5eb1-0740-473f-b278-4678ab1e0a4e\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKnQMenIUygu6qoP8n4_EzChFXMkjnwf78bFFBWCN0w\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_clickable_tile\";s:13:\"\0*\0field_name\";s:24:\"field_ept_clickable_tile\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ept_tiles_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_tiles_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a21fa265-c368-46f8-b0bf-ccd4251290bf\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fWLTZKbXw0jB-UFCqh6l4jRNvxOPFhGWVUKUjcIHfEg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_tiles_title\";s:13:\"\0*\0field_name\";s:21:\"field_ept_tiles_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ept_tiles_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ept_tiles_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"095f6e1d-c38c-4e36-824d-929e502f2c16\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K1TV7SR5GOPQTJv3GF_zAIsJciKLKB5xd_eo3WUc5HA\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ept_tiles_text\";s:13:\"\0*\0field_name\";s:20:\"field_ept_tiles_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ept_video\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:25:\"paragraph.field_ept_video\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"30383ff9-015d-4872-a3cb-3c814a4683f6\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WUq7ljAeKbQ5WQGxUm1FFT157H56wcSHSihAGR-RPhc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:25:\"paragraph.field_ept_video\";s:13:\"\0*\0field_name\";s:15:\"field_ept_video\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_videos_and_images\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_videos_and_images\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fb3b02a6-684b-4508-8b49-e87fa4e916c1\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P8bQebl9F2OCnDtVw7LFuwUlmGfUGA7HLJaYolmUgpU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_videos_and_images\";s:13:\"\0*\0field_name\";s:27:\"field_ept_videos_and_images\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ept_gallery_item\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_ept_gallery_item\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a1361495-0a6d-4f18-8570-b713e198ddf3\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8JLKZdRZR-OD6hbmGc3VHufx5PLi683tbf4QM_K4ZAU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_ept_gallery_item\";s:13:\"\0*\0field_name\";s:22:\"field_ept_gallery_item\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_gallery_item_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_gallery_item_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ceb57be4-05e2-49c4-afad-48cb1341e682\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cWuIwOJOPOwoJ4OA0TCSko2wR73oMOOVlyC7clefebo\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_gallery_item_text\";s:13:\"\0*\0field_name\";s:27:\"field_ept_gallery_item_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ept_views_view\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ept_views_view\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"8622c9ec-6687-4349-af19-885f22d99285\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GjkDxormsrh0OTX-iAPBLiJLIDg3h8b7yPlpgyt-kM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ept_views_view\";s:13:\"\0*\0field_name\";s:20:\"field_ept_views_view\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:14:\"viewsreference\";s:9:\"\0*\0module\";s:14:\"viewsreference\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ept_webform_form\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_ept_webform_form\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a88d5b44-1516-4b8b-96a9-776c192940bc\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PpYNq6QObTDp2wWrcCdc7DcYdgeYKcySPhoxN3JbQ0c\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:7:\"webform\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_ept_webform_form\";s:13:\"\0*\0field_name\";s:22:\"field_ept_webform_form\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:7:\"webform\";s:9:\"\0*\0module\";s:7:\"webform\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:28:\"field_ept_webform_popup_form\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:38:\"paragraph.field_ept_webform_popup_form\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"5c2ba04c-75d7-42c4-b482-67caddfd5348\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0JLSwQyxgVansS3j_MWcmzVVNlzTh7AvepEBcn10Cyk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:7:\"webform\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:38:\"paragraph.field_ept_webform_popup_form\";s:13:\"\0*\0field_name\";s:28:\"field_ept_webform_popup_form\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:7:\"webform\";s:9:\"\0*\0module\";s:7:\"webform\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','paragraphs_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:15:\"paragraphs_type\";s:8:\"\0*\0class\";s:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\";s:11:\"\0*\0provider\";s:10:\"paragraphs\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:52:\"Drupal\\paragraphs\\ParagraphsTypeAccessControlHandler\";s:12:\"list_builder\";s:54:\"Drupal\\paragraphs\\Controller\\ParagraphsTypeListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:41:\"Drupal\\paragraphs\\Form\\ParagraphsTypeForm\";s:4:\"edit\";s:41:\"Drupal\\paragraphs\\Form\\ParagraphsTypeForm\";s:6:\"delete\";s:50:\"Drupal\\paragraphs\\Form\\ParagraphsTypeDeleteConfirm\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:27:\"administer paragraphs types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"edit-form\";s:50:\"/admin/structure/paragraphs_type/{paragraphs_type}\";s:11:\"delete-form\";s:57:\"/admin/structure/paragraphs_type/{paragraphs_type}/delete\";s:10:\"collection\";s:32:\"/admin/structure/paragraphs_type\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:9:\"paragraph\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Paragraphs type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Paragraphs types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Paragraphs type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Paragraphs types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:22:\"@count Paragraphs type\";s:6:\"plural\";s:23:\"@count Paragraphs types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:27:\"config:paragraphs_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:15:\"paragraphs_type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:9:\"icon_uuid\";i:3;s:12:\"icon_default\";i:4;s:11:\"description\";i:5;s:16:\"behavior_plugins\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','path_alias.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:10:\"path_alias\";s:8:\"\0*\0class\";s:34:\"Drupal\\path_alias\\Entity\\PathAlias\";s:11:\"\0*\0provider\";s:10:\"path_alias\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\path_alias\\Entity\\PathAlias\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:34:\"Drupal\\path_alias\\PathAliasStorage\";s:14:\"storage_schema\";s:40:\"Drupal\\path_alias\\PathAliasStorageSchema\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";s:22:\"administer url aliases\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:10:\"path_alias\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";s:19:\"path_alias_revision\";s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:16:\"@count URL alias\";s:6:\"plural\";s:18:\"@count URL aliases\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:11:\"route_match\";}s:14:\"\0*\0constraints\";a:2:{s:15:\"UniquePathAlias\";a:0:{}s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','path_alias.field_storage_definitions',_binary 'a:8:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"und\";}}s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"path\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"System path\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"The path that this alias belongs to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:4:\"path\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:9:\"ValidPath\";a:0:{}s:5:\"Regex\";a:2:{s:7:\"pattern\";s:6:\"/^\\//i\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"The source path has to start with a slash.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:18:\"\0*\0fieldDefinition\";r:141;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"alias\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"An alias used with this path.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:5:\"alias\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:5:\"Regex\";a:2:{s:7:\"pattern\";s:6:\"/^\\//i\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"The alias path has to start with a slash.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:18:\"\0*\0fieldDefinition\";r:187;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:232;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:271;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','shortcut.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:8:\"shortcut\";s:8:\"\0*\0class\";s:31:\"Drupal\\shortcut\\Entity\\Shortcut\";s:11:\"\0*\0provider\";s:8:\"shortcut\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:12:\"shortcut_set\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\shortcut\\Entity\\Shortcut\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:44:\"Drupal\\shortcut\\ShortcutAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:3:\"add\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:4:\"edit\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:6:\"delete\";s:39:\"Drupal\\shortcut\\Form\\ShortcutDeleteForm\";}s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"canonical\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:11:\"delete-form\";s:60:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete\";s:9:\"edit-form\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";}s:21:\"\0*\0bundle_entity_type\";s:12:\"shortcut_set\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:8:\"shortcut\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:19:\"shortcut_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Shortcut link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Shortcut links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"shortcut link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"shortcut links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count shortcut link\";s:6:\"plural\";s:21:\"@count shortcut links\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:shortcut_set_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','shortcut.field_storage_definitions',_binary 'a:8:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The ID of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The UUID of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"The language code of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"shortcut_set\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"The bundle of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:12:\"shortcut_set\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"shortcut_set\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:116;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The name of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-10;s:8:\"settings\";a:1:{s:4:\"size\";i:40;}}}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:154;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Weight among shortcuts in the same shortcut set.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:197;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"link\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Path\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"The location this shortcut points to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:4:\"link\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:link\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:1;}}s:18:\"\0*\0fieldDefinition\";r:234;}s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:3:{s:3:\"uri\";a:3:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"title\";a:3:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;}s:7:\"options\";a:4:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:3:\"uri\";a:1:{i:0;a:2:{i:0;s:3:\"uri\";i:1;i:30;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:287;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','shortcut_set.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"shortcut_set\";s:8:\"\0*\0class\";s:34:\"Drupal\\shortcut\\Entity\\ShortcutSet\";s:11:\"\0*\0provider\";s:8:\"shortcut\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\shortcut\\Entity\\ShortcutSet\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:34:\"Drupal\\shortcut\\ShortcutSetStorage\";s:6:\"access\";s:47:\"Drupal\\shortcut\\ShortcutSetAccessControlHandler\";s:12:\"list_builder\";s:38:\"Drupal\\shortcut\\ShortcutSetListBuilder\";s:4:\"form\";a:5:{s:7:\"default\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:3:\"add\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:4:\"edit\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:9:\"customize\";s:33:\"Drupal\\shortcut\\Form\\SetCustomize\";s:6:\"delete\";s:42:\"Drupal\\shortcut\\Form\\ShortcutSetDeleteForm\";}}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:14:\"customize-form\";s:69:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize\";s:11:\"delete-form\";s:66:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete\";s:9:\"edit-form\";s:59:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}\";s:10:\"collection\";s:37:\"/admin/config/user-interface/shortcut\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:8:\"shortcut\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Shortcut sets\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"shortcut sets\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count shortcut set\";s:6:\"plural\";s:20:\"@count shortcut sets\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:shortcut_set_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:3:\"set\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:2:{i:0;s:2:\"id\";i:1;s:5:\"label\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','taxonomy_term.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:13:\"taxonomy_term\";s:8:\"\0*\0class\";s:27:\"Drupal\\taxonomy\\Entity\\Term\";s:11:\"\0*\0provider\";s:8:\"taxonomy\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"tid\";s:8:\"revision\";s:11:\"revision_id\";s:6:\"bundle\";s:3:\"vid\";s:5:\"label\";s:4:\"name\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\taxonomy\\Entity\\Term\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:27:\"Drupal\\taxonomy\\TermStorage\";s:14:\"storage_schema\";s:33:\"Drupal\\taxonomy\\TermStorageSchema\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:6:\"access\";s:40:\"Drupal\\taxonomy\\TermAccessControlHandler\";s:10:\"views_data\";s:29:\"Drupal\\taxonomy\\TermViewsData\";s:4:\"form\";a:4:{s:7:\"default\";s:24:\"Drupal\\taxonomy\\TermForm\";s:6:\"delete\";s:35:\"Drupal\\taxonomy\\Form\\TermDeleteForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";}s:14:\"route_provider\";a:1:{s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}s:11:\"translation\";s:38:\"Drupal\\taxonomy\\TermTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";s:24:\"access taxonomy overview\";s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:8:{s:9:\"canonical\";s:30:\"/taxonomy/term/{taxonomy_term}\";s:11:\"delete-form\";s:37:\"/taxonomy/term/{taxonomy_term}/delete\";s:9:\"edit-form\";s:35:\"/taxonomy/term/{taxonomy_term}/edit\";s:6:\"create\";s:14:\"/taxonomy/term\";s:8:\"revision\";s:69:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view\";s:20:\"revision-delete-form\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete\";s:20:\"revision-revert-form\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert\";s:15:\"version-history\";s:40:\"/taxonomy/term/{taxonomy_term}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:19:\"taxonomy_vocabulary\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:18:\"taxonomy_term_data\";s:22:\"\0*\0revision_data_table\";s:28:\"taxonomy_term_field_revision\";s:17:\"\0*\0revision_table\";s:22:\"taxonomy_term_revision\";s:13:\"\0*\0data_table\";s:24:\"taxonomy_term_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Taxonomy term\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Taxonomy terms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"taxonomy term\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"taxonomy terms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count taxonomy term\";s:6:\"plural\";s:21:\"@count taxonomy terms\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:40:\"entity.taxonomy_vocabulary.overview_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"taxonomy_term_list\";}s:14:\"\0*\0constraints\";a:3:{s:17:\"TaxonomyHierarchy\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','taxonomy_term.field_storage_definitions',_binary 'a:17:{s:3:\"tid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Term ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The term ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:3:\"tid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The term UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The term language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:111;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"The vocabulary to which the term is assigned.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:19:\"taxonomy_vocabulary\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:151;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:189;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:219;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:256;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:100;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:5:\"class\";s:22:\"Drupal\\user\\StatusItem\";}s:18:\"\0*\0fieldDefinition\";r:298;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:346;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"description\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:14:\"text_textfield\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:11:\"description\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:text_long\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:390;}s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:2:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}s:6:\"format\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;}}s:7:\"indexes\";a:1:{s:6:\"format\";a:1:{i:0;s:6:\"format\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"The weight of this term in relation to other terms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:436;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"parent\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Term Parents\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The parents of this term.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"cardinality\";i:-1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"parent\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:13:\"taxonomy_term\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:476;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the term was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:512;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:543;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:586;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:628;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','taxonomy_vocabulary.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"taxonomy_vocabulary\";s:8:\"\0*\0class\";s:33:\"Drupal\\taxonomy\\Entity\\Vocabulary\";s:11:\"\0*\0provider\";s:8:\"taxonomy\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"vid\";s:5:\"label\";s:4:\"name\";s:6:\"weight\";s:6:\"weight\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\taxonomy\\Entity\\Vocabulary\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:33:\"Drupal\\taxonomy\\VocabularyStorage\";s:12:\"list_builder\";s:37:\"Drupal\\taxonomy\\VocabularyListBuilder\";s:6:\"access\";s:46:\"Drupal\\taxonomy\\VocabularyAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:30:\"Drupal\\taxonomy\\VocabularyForm\";s:5:\"reset\";s:40:\"Drupal\\taxonomy\\Form\\VocabularyResetForm\";s:6:\"delete\";s:41:\"Drupal\\taxonomy\\Form\\VocabularyDeleteForm\";s:8:\"overview\";s:34:\"Drupal\\taxonomy\\Form\\OverviewTerms\";}s:14:\"route_provider\";a:2:{s:4:\"html\";s:54:\"Drupal\\taxonomy\\Entity\\Routing\\VocabularyRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}}s:19:\"\0*\0admin_permission\";s:19:\"administer taxonomy\";s:24:\"\0*\0collection_permission\";s:24:\"access taxonomy overview\";s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:7:{s:8:\"add-form\";s:29:\"/admin/structure/taxonomy/add\";s:11:\"delete-form\";s:61:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete\";s:10:\"reset-form\";s:60:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset\";s:13:\"overview-form\";s:63:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview\";s:9:\"edit-form\";s:54:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}\";s:23:\"entity-permissions-form\";s:75:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions\";s:10:\"collection\";s:25:\"/admin/structure/taxonomy\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:13:\"taxonomy_term\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Taxonomy vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Taxonomy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"vocabularies\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count vocabulary\";s:6:\"plural\";s:19:\"@count vocabularies\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:taxonomy_vocabulary_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:10:\"vocabulary\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:4:\"name\";i:1;s:3:\"vid\";i:2;s:11:\"description\";i:3;s:6:\"weight\";i:4;s:12:\"new_revision\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','tb_megamenu.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"tb_megamenu\";s:8:\"\0*\0class\";s:40:\"Drupal\\tb_megamenu\\Entity\\MegaMenuConfig\";s:11:\"\0*\0provider\";s:11:\"tb_megamenu\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:4:\"menu\";s:4:\"menu\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\tb_megamenu\\Entity\\MegaMenuConfig\";s:11:\"\0*\0handlers\";a:4:{s:12:\"list_builder\";s:42:\"Drupal\\tb_megamenu\\Controller\\MegaMenuList\";s:4:\"form\";a:3:{s:3:\"add\";s:35:\"Drupal\\tb_megamenu\\Form\\MegaMenuAdd\";s:4:\"edit\";s:35:\"Drupal\\tb_megamenu\\Form\\MegaMenuAdd\";s:6:\"delete\";s:38:\"Drupal\\tb_megamenu\\Form\\MegaMenuDelete\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:22:\"administer tb_megamenu\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:2:{s:9:\"edit-form\";s:42:\"/admin/structure/tb-megamenu/{tb_megamenu}\";s:11:\"delete-form\";s:49:\"/admin/structure/tb-megamenu/{tb_megamenu}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"TB Mega Menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:23:\"config:tb_megamenu_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:11:\"menu_config\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:4:\"menu\";i:2;s:5:\"theme\";i:3;s:12:\"block_config\";i:4;s:11:\"menu_config\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','user.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"user\";s:8:\"\0*\0class\";s:23:\"Drupal\\user\\Entity\\User\";s:11:\"\0*\0provider\";s:4:\"user\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:3:\"uid\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\user\\Entity\\User\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:23:\"Drupal\\user\\UserStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\user\\UserStorageSchema\";s:6:\"access\";s:36:\"Drupal\\user\\UserAccessControlHandler\";s:12:\"list_builder\";s:27:\"Drupal\\user\\UserListBuilder\";s:10:\"views_data\";s:25:\"Drupal\\user\\UserViewsData\";s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\user\\Entity\\UserRouteProvider\";}s:4:\"form\";a:3:{s:7:\"default\";s:23:\"Drupal\\user\\ProfileForm\";s:6:\"cancel\";s:31:\"Drupal\\user\\Form\\UserCancelForm\";s:8:\"register\";s:24:\"Drupal\\user\\RegisterForm\";}s:11:\"translation\";s:37:\"Drupal\\user\\ProfileTranslationHandler\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";s:16:\"administer users\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:9:\"canonical\";s:12:\"/user/{user}\";s:9:\"edit-form\";s:17:\"/user/{user}/edit\";s:11:\"cancel-form\";s:19:\"/user/{user}/cancel\";s:10:\"collection\";s:13:\"/admin/people\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:5:\"users\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:16:\"users_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"User\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Users\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"users\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count user\";s:6:\"plural\";s:12:\"@count users\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:22:\"entity.user.admin_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"user_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','user.field_storage_definitions',_binary 'a:18:{s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The user ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The user UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The user language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:18:\"preferred_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Preferred language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"The user\'s preferred language code for receiving emails and viewing the site.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:18:\"preferred_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:60:\"Drupal\\user\\Entity\\User::getAllowedConfigurableLanguageCodes\";}s:6:\"Length\";a:1:{s:3:\"max\";i:12;}}}}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:24:\"preferred_admin_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Preferred admin language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:68:\"The user\'s preferred language code for viewing administration pages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";N;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:24:\"preferred_admin_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:60:\"Drupal\\user\\Entity\\User::getAllowedConfigurableLanguageCodes\";}s:6:\"Length\";a:1:{s:3:\"max\";i:12;}}}}}s:18:\"\0*\0fieldDefinition\";r:152;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"The name of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:11:\"constraints\";a:2:{s:8:\"UserName\";a:0:{}s:14:\"UserNameUnique\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:5:\"class\";s:25:\"\\Drupal\\user\\UserNameItem\";}s:18:\"\0*\0fieldDefinition\";r:192;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"pass\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Password\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The password of this user (hashed).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:1:{s:18:\"ProtectedUserField\";N;}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"pass\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:password\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:231;}s:7:\"\0*\0type\";s:8:\"password\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The email of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:11:\"constraints\";a:3:{s:14:\"UserMailUnique\";N;s:16:\"UserMailRequired\";N;s:18:\"ProtectedUserField\";N;}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:267;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"timezone\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Timezone\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The timezone of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:8:\"timezone\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:4:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:44:\"Drupal\\user\\Entity\\User::getAllowedTimezones\";}}}}s:5:\"class\";s:24:\"Drupal\\user\\TimeZoneItem\";}s:18:\"\0*\0fieldDefinition\";r:304;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"User status\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Whether the user is active or blocked.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:5:\"class\";s:22:\"Drupal\\user\\StatusItem\";}s:18:\"\0*\0fieldDefinition\";r:344;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The time that the user was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:386;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the user was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:415;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"access\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Last access\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"The time that the user last accessed the site.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:6:\"access\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:445;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"login\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Last login\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"The time that the user last logged in.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:5:\"login\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:477;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"init\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Initial email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The email address used for initial account creation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"init\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:509;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"roles\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"cardinality\";i:-1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The roles the user has.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:5:\"roles\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:9:\"user_role\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:542;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:578;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"user_picture\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:17:\"user.user_picture\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"233edf85-6a6a-473c-933a-1a6a9015993a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:17:\"user.user_picture\";s:13:\"\0*\0field_name\";s:12:\"user_picture\";s:14:\"\0*\0entity_type\";s:4:\"user\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','user_role.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:9:\"user_role\";s:8:\"\0*\0class\";s:23:\"Drupal\\user\\Entity\\Role\";s:11:\"\0*\0provider\";s:4:\"user\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:6:\"weight\";s:6:\"weight\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\user\\Entity\\Role\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:23:\"Drupal\\user\\RoleStorage\";s:6:\"access\";s:36:\"Drupal\\user\\RoleAccessControlHandler\";s:12:\"list_builder\";s:27:\"Drupal\\user\\RoleListBuilder\";s:4:\"form\";a:2:{s:7:\"default\";s:20:\"Drupal\\user\\RoleForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}}s:19:\"\0*\0admin_permission\";s:22:\"administer permissions\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:45:\"/admin/people/roles/manage/{user_role}/delete\";s:9:\"edit-form\";s:38:\"/admin/people/roles/manage/{user_role}\";s:21:\"edit-permissions-form\";s:37:\"/admin/people/permissions/{user_role}\";s:10:\"collection\";s:19:\"/admin/people/roles\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count role\";s:6:\"plural\";s:12:\"@count roles\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:21:\"config:user_role_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"role\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"weight\";i:3;s:8:\"is_admin\";i:4;s:11:\"permissions\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','view.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:4:\"view\";s:8:\"\0*\0class\";s:24:\"Drupal\\views\\Entity\\View\";s:11:\"\0*\0provider\";s:5:\"views\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:24:\"Drupal\\views\\Entity\\View\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:16:\"administer views\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"View\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"view\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count view\";s:6:\"plural\";s:12:\"@count views\";s:7:\"context\";s:16:\"View entity type\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:16:\"config:view_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"module\";i:3;s:11:\"description\";i:4;s:3:\"tag\";i:5;s:10:\"base_table\";i:6;s:10:\"base_field\";i:7;s:7:\"display\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','webform.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:7:\"webform\";s:8:\"\0*\0class\";s:29:\"Drupal\\webform\\Entity\\Webform\";s:11:\"\0*\0provider\";s:7:\"webform\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"title\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\webform\\Entity\\Webform\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:36:\"\\Drupal\\webform\\WebformEntityStorage\";s:12:\"view_builder\";s:39:\"Drupal\\webform\\WebformEntityViewBuilder\";s:12:\"list_builder\";s:39:\"Drupal\\webform\\WebformEntityListBuilder\";s:6:\"access\";s:48:\"Drupal\\webform\\WebformEntityAccessControlHandler\";s:4:\"form\";a:14:{s:3:\"add\";s:35:\"Drupal\\webform\\WebformEntityAddForm\";s:9:\"duplicate\";s:35:\"Drupal\\webform\\WebformEntityAddForm\";s:6:\"delete\";s:38:\"Drupal\\webform\\WebformEntityDeleteForm\";s:23:\"delete-multiple-confirm\";s:51:\"Drupal\\webform\\Form\\WebformEntityDeleteMultipleForm\";s:4:\"edit\";s:40:\"Drupal\\webform\\WebformEntityElementsForm\";s:6:\"export\";s:38:\"Drupal\\webform\\WebformEntityExportForm\";s:8:\"settings\";s:62:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsGeneralForm\";s:13:\"settings_form\";s:59:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsFormForm\";s:20:\"settings_submissions\";s:66:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsSubmissionsForm\";s:21:\"settings_confirmation\";s:67:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsConfirmationForm\";s:15:\"settings_assets\";s:61:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsAssetsForm\";s:15:\"settings_access\";s:61:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsAccessForm\";s:8:\"handlers\";s:40:\"Drupal\\webform\\WebformEntityHandlersForm\";s:8:\"variants\";s:40:\"Drupal\\webform\\WebformEntityVariantsForm\";}}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:23:{s:9:\"canonical\";s:18:\"/webform/{webform}\";s:13:\"access-denied\";s:32:\"/webform/{webform}/access-denied\";s:11:\"submissions\";s:30:\"/webform/{webform}/submissions\";s:8:\"add-form\";s:18:\"/webform/{webform}\";s:9:\"edit-form\";s:50:\"/admin/structure/webform/manage/{webform}/elements\";s:9:\"test-form\";s:23:\"/webform/{webform}/test\";s:14:\"duplicate-form\";s:51:\"/admin/structure/webform/manage/{webform}/duplicate\";s:11:\"delete-form\";s:48:\"/admin/structure/webform/manage/{webform}/delete\";s:20:\"delete-multiple-form\";s:31:\"/admin/structure/webform/delete\";s:11:\"export-form\";s:48:\"/admin/structure/webform/manage/{webform}/export\";s:8:\"settings\";s:50:\"/admin/structure/webform/manage/{webform}/settings\";s:13:\"settings-form\";s:55:\"/admin/structure/webform/manage/{webform}/settings/form\";s:20:\"settings-submissions\";s:62:\"/admin/structure/webform/manage/{webform}/settings/submissions\";s:21:\"settings-confirmation\";s:63:\"/admin/structure/webform/manage/{webform}/settings/confirmation\";s:15:\"settings-assets\";s:57:\"/admin/structure/webform/manage/{webform}/settings/assets\";s:15:\"settings-access\";s:57:\"/admin/structure/webform/manage/{webform}/settings/access\";s:8:\"handlers\";s:50:\"/admin/structure/webform/manage/{webform}/handlers\";s:8:\"variants\";s:50:\"/admin/structure/webform/manage/{webform}/variants\";s:19:\"results-submissions\";s:61:\"/admin/structure/webform/manage/{webform}/results/submissions\";s:14:\"results-export\";s:58:\"/admin/structure/webform/manage/{webform}/results/download\";s:11:\"results-log\";s:53:\"/admin/structure/webform/manage/{webform}/results/log\";s:13:\"results-clear\";s:55:\"/admin/structure/webform/manage/{webform}/results/clear\";s:10:\"collection\";s:24:\"/admin/structure/webform\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:18:\"webform_submission\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Webforms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"webforms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:14:\"@count webform\";s:6:\"plural\";s:15:\"@count webforms\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:19:\"config:webform_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:3:{i:0;s:6:\"status\";i:1;s:8:\"template\";i:2;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:20:{i:0;s:6:\"status\";i:1;s:4:\"open\";i:2;s:5:\"close\";i:3;s:6:\"weight\";i:4;s:3:\"uid\";i:5;s:8:\"template\";i:6;s:7:\"archive\";i:7;s:2:\"id\";i:8;s:4:\"uuid\";i:9;s:5:\"title\";i:10;s:11:\"description\";i:11;s:10:\"categories\";i:12;s:8:\"elements\";i:13;s:3:\"css\";i:14;s:10:\"javascript\";i:15;s:8:\"settings\";i:16;s:6:\"access\";i:17;s:8:\"handlers\";i:18;s:8:\"variants\";i:19;s:20:\"third_party_settings\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','webform_options.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:15:\"webform_options\";s:8:\"\0*\0class\";s:36:\"Drupal\\webform\\Entity\\WebformOptions\";s:11:\"\0*\0provider\";s:7:\"webform\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:36:\"Drupal\\webform\\Entity\\WebformOptions\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:37:\"\\Drupal\\webform\\WebformOptionsStorage\";s:6:\"access\";s:49:\"Drupal\\webform\\WebformOptionsAccessControlHandler\";s:12:\"list_builder\";s:40:\"Drupal\\webform\\WebformOptionsListBuilder\";s:4:\"form\";a:4:{s:3:\"add\";s:33:\"Drupal\\webform\\WebformOptionsForm\";s:4:\"edit\";s:33:\"Drupal\\webform\\WebformOptionsForm\";s:9:\"duplicate\";s:33:\"Drupal\\webform\\WebformOptionsForm\";s:6:\"delete\";s:39:\"Drupal\\webform\\WebformOptionsDeleteForm\";}}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:8:\"add-form\";s:43:\"/admin/structure/webform/options/manage/add\";s:9:\"edit-form\";s:62:\"/admin/structure/webform/options/manage/{webform_options}/edit\";s:14:\"duplicate-form\";s:67:\"/admin/structure/webform/options/manage/{webform_options}/duplicate\";s:11:\"delete-form\";s:64:\"/admin/structure/webform/options/manage/{webform_options}/delete\";s:10:\"collection\";s:39:\"/admin/structure/webform/options/manage\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:22:\"@count webform options\";s:6:\"plural\";s:22:\"@count webform options\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:27:\"config:webform_options_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:4:\"uuid\";i:2;s:5:\"label\";i:3;s:8:\"category\";i:4;s:6:\"likert\";i:5;s:7:\"options\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','webform_submission.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:18:\"webform_submission\";s:8:\"\0*\0class\";s:39:\"Drupal\\webform\\Entity\\WebformSubmission\";s:11:\"\0*\0provider\";s:7:\"webform\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:3:\"sid\";s:6:\"bundle\";s:10:\"webform_id\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:39:\"Drupal\\webform\\Entity\\WebformSubmission\";s:11:\"\0*\0handlers\";a:7:{s:7:\"storage\";s:39:\"Drupal\\webform\\WebformSubmissionStorage\";s:14:\"storage_schema\";s:45:\"Drupal\\webform\\WebformSubmissionStorageSchema\";s:10:\"views_data\";s:41:\"Drupal\\webform\\WebformSubmissionViewsData\";s:12:\"view_builder\";s:43:\"Drupal\\webform\\WebformSubmissionViewBuilder\";s:12:\"list_builder\";s:43:\"Drupal\\webform\\WebformSubmissionListBuilder\";s:6:\"access\";s:52:\"Drupal\\webform\\WebformSubmissionAccessControlHandler\";s:4:\"form\";a:8:{s:3:\"add\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:4:\"edit\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:8:\"edit_all\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:3:\"api\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:4:\"test\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:5:\"notes\";s:41:\"Drupal\\webform\\WebformSubmissionNotesForm\";s:9:\"duplicate\";s:45:\"Drupal\\webform\\WebformSubmissionDuplicateForm\";s:6:\"delete\";s:47:\"Drupal\\webform\\Form\\WebformSubmissionDeleteForm\";}}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:11:{s:9:\"canonical\";s:73:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}\";s:13:\"access-denied\";s:87:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/access-denied\";s:5:\"table\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/table\";s:4:\"text\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/text\";s:4:\"yaml\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/yaml\";s:9:\"edit-form\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit\";s:10:\"notes-form\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/notes\";s:11:\"resend-form\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/resend\";s:14:\"duplicate-form\";s:83:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/duplicate\";s:11:\"delete-form\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/delete\";s:10:\"collection\";s:48:\"/admin/structure/webform/submissions/manage/list\";}s:21:\"\0*\0bundle_entity_type\";s:7:\"webform\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:18:\"webform_submission\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Webform submission\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Submissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"submission\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"submissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count submission\";s:6:\"plural\";s:18:\"@count submissions\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:1:{i:0;s:4:\"user\";}s:18:\"\0*\0list_cache_tags\";a:2:{i:0;s:19:\"config:webform_list\";i:1;s:23:\"webform_submission_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','webform_submission.field_storage_definitions',_binary 'a:19:{s:6:\"serial\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Serial number\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"The serial number of the webform submission entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:6:\"serial\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"sid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Submission ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The ID of the webform submission entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:3:\"sid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Submission UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"The UUID of the webform submission entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:78;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"token\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Token\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"A secure token used to look up a submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:5:\"token\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uri\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Submission URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The URI the user submitted the webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:3:\"uri\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:2000;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:150;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2000;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:75:\"The time that the webform submission was first saved as draft or submitted.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:185;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"completed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Completed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:75:\"The time that the webform submission was submitted as complete (not draft).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:9:\"completed\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:214;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"The time that the webform submission was last saved (complete or draft).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:243;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"in_draft\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Is draft\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Is this a draft of the submission?\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:8:\"in_draft\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:272;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"current_page\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Current page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"The current wizard page.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:12:\"current_page\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:313;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"remote_addr\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Remote IP address\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The IP address of the user that submitted the webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:11:\"remote_addr\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:347;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Submitted by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The username of the user that submitted the webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:22:\"default_value_callback\";s:57:\"Drupal\\webform\\Entity\\WebformSubmission::getCurrentUserId\";s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:381;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"The submission language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:418;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:10:\"webform_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The associated webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:10:\"webform_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:7:\"webform\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:448;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"entity_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Submitted to: Entity type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"The entity type to which this submission was submitted from.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:11:\"entity_type\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:484;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"entity_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Submitted to: Entity ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:73:\"The ID of the entity of which this webform submission was submitted from.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:9:\"entity_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:518;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"locked\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Locked\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"A flag that indicates a locked webform submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:6:\"locked\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:552;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"sticky\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Sticky\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag that indicate the status of the webform submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:6:\"sticky\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:593;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"notes\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Notes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"Administrative notes about the webform submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:5:\"notes\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:634;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.storage_schema.sql','block_content.entity_schema_data',_binary 'a:4:{s:13:\"block_content\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:26:\"block_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:22:\"block_content_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:17:\"block_content__id\";a:1:{i:0;s:2:\"id\";}}}s:24:\"block_content_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:45:\"block_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:26:\"block_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"block_content__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:2:\"id\";}}}s:28:\"block_content_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:45:\"block_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.body',_binary 'a:2:{s:19:\"block_content__body\";a:4:{s:11:\"description\";s:42:\"Data storage for block_content field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}s:28:\"block_content_revision__body\";a:4:{s:11:\"description\";s:54:\"Revision archive storage for block_content field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.changed',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.default_langcode',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.id',_binary 'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.info',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"info\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"info\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.langcode',_binary 'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.reusable',_binary 'a:1:{s:24:\"block_content_field_data\";a:2:{s:6:\"fields\";a:1:{s:8:\"reusable\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:29:\"block_content_field__reusable\";a:1:{i:0;s:8:\"reusable\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_created',_binary 'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_default',_binary 'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_id',_binary 'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_log',_binary 'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:12:\"revision_log\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_translation_affected',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_user',_binary 'a:1:{s:22:\"block_content_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:45:\"block_content_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.status',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.type',_binary 'a:2:{s:13:\"block_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:36:\"block_content_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:24:\"block_content_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:36:\"block_content_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.uuid',_binary 'a:1:{s:13:\"block_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:32:\"block_content_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','comment.entity_schema_data',_binary 'a:2:{s:7:\"comment\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"cid\";}}s:18:\"comment_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"cid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:39:\"comment__id__default_langcode__langcode\";a:3:{i:0;s:3:\"cid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:28:\"comment__status_comment_type\";a:3:{i:0;s:6:\"status\";i:1;s:12:\"comment_type\";i:2;s:3:\"cid\";}s:19:\"comment__status_pid\";a:2:{i:0;s:3:\"pid\";i:1;s:6:\"status\";}s:16:\"comment__num_new\";a:7:{i:0;s:9:\"entity_id\";i:1;s:11:\"entity_type\";i:2;s:12:\"comment_type\";i:3;s:6:\"status\";i:4;s:7:\"created\";i:5;s:3:\"cid\";i:6;s:6:\"thread\";}s:24:\"comment__entity_langcode\";a:4:{i:0;s:9:\"entity_id\";i:1;s:11:\"entity_type\";i:2;s:12:\"comment_type\";i:3;s:16:\"default_langcode\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.changed',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.cid',_binary 'a:2:{s:7:\"comment\";a:1:{s:6:\"fields\";a:1:{s:3:\"cid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"cid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.comment_body',_binary 'a:1:{s:21:\"comment__comment_body\";a:4:{s:11:\"description\";s:44:\"Data storage for comment field comment_body.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:18:\"comment_body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:19:\"comment_body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:19:\"comment_body_format\";a:1:{i:0;s:19:\"comment_body_format\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.comment_type',_binary 'a:2:{s:7:\"comment\";a:2:{s:6:\"fields\";a:1:{s:12:\"comment_type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:38:\"comment_field__comment_type__target_id\";a:1:{i:0;s:12:\"comment_type\";}}}s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:12:\"comment_type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:38:\"comment_field__comment_type__target_id\";a:1:{i:0;s:12:\"comment_type\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.created',_binary 'a:1:{s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:22:\"comment_field__created\";a:1:{i:0;s:7:\"created\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.default_langcode',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.entity_id',_binary 'a:1:{s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:9:\"entity_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:0:{}}}'),('entity.storage_schema.sql','comment.field_schema_data.entity_type',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"entity_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.field_name',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:10:\"field_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.homepage',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"homepage\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.hostname',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"hostname\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.langcode',_binary 'a:2:{s:7:\"comment\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.mail',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"mail\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.name',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:60;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.pid',_binary 'a:1:{s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"pid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:0:{}}}'),('entity.storage_schema.sql','comment.field_schema_data.status',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.subject',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"subject\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:64;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.thread',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"thread\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.uid',_binary 'a:1:{s:18:\"comment_field_data\";a:3:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:29:\"comment_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}s:12:\"foreign keys\";a:1:{s:18:\"comment_field__uid\";a:2:{s:5:\"table\";s:5:\"users\";s:7:\"columns\";a:1:{s:3:\"uid\";s:3:\"uid\";}}}}}'),('entity.storage_schema.sql','comment.field_schema_data.uuid',_binary 'a:1:{s:7:\"comment\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:26:\"comment_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','file.entity_schema_data',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"fid\";}}}'),('entity.storage_schema.sql','file.field_schema_data.changed',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"file_field__changed\";a:1:{i:0;s:7:\"changed\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.created',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.fid',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:3:\"fid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','file.field_schema_data.filemime',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filemime\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.filename',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filename\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.filesize',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filesize\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.langcode',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','file.field_schema_data.status',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:18:\"file_field__status\";a:1:{i:0;s:6:\"status\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.uid',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:26:\"file_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.uri',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:3:\"uri\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:15:\"file_field__uri\";a:1:{i:0;s:3:\"uri\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.uuid',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"file_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','media.entity_schema_data',_binary 'a:4:{s:5:\"media\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"mid\";}s:11:\"unique keys\";a:1:{s:10:\"media__vid\";a:1:{i:0;s:3:\"vid\";}}}s:14:\"media_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"vid\";}s:7:\"indexes\";a:1:{s:10:\"media__mid\";a:1:{i:0;s:3:\"mid\";}}}s:16:\"media_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"mid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:37:\"media__id__default_langcode__langcode\";a:3:{i:0;s:3:\"mid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:10:\"media__vid\";a:1:{i:0;s:3:\"vid\";}s:20:\"media__status_bundle\";a:3:{i:0;s:6:\"status\";i:1;s:6:\"bundle\";i:2;s:3:\"mid\";}}}s:20:\"media_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"vid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:37:\"media__id__default_langcode__langcode\";a:3:{i:0;s:3:\"mid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.bundle',_binary 'a:2:{s:5:\"media\";a:2:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:30:\"media_field__bundle__target_id\";a:1:{i:0;s:6:\"bundle\";}}}s:16:\"media_field_data\";a:2:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:30:\"media_field__bundle__target_id\";a:1:{i:0;s:6:\"bundle\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.changed',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.created',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.default_langcode',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','media.field_schema_data.field_media_audio_file',_binary 'a:2:{s:29:\"media__field_media_audio_file\";a:5:{s:11:\"description\";s:52:\"Data storage for media field field_media_audio_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_audio_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_audio_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_audio_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_audio_file_target_id\";a:1:{i:0;s:32:\"field_media_audio_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_audio_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_audio_file_target_id\";s:3:\"fid\";}}}}s:38:\"media_revision__field_media_audio_file\";a:5:{s:11:\"description\";s:64:\"Revision archive storage for media field field_media_audio_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_audio_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_audio_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_audio_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_audio_file_target_id\";a:1:{i:0;s:32:\"field_media_audio_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_audio_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_audio_file_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','media.field_schema_data.field_media_document',_binary 'a:2:{s:27:\"media__field_media_document\";a:5:{s:11:\"description\";s:50:\"Data storage for media field field_media_document.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_document_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:28:\"field_media_document_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:32:\"field_media_document_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_media_document_target_id\";a:1:{i:0;s:30:\"field_media_document_target_id\";}}s:12:\"foreign keys\";a:1:{s:30:\"field_media_document_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:30:\"field_media_document_target_id\";s:3:\"fid\";}}}}s:36:\"media_revision__field_media_document\";a:5:{s:11:\"description\";s:62:\"Revision archive storage for media field field_media_document.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_document_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:28:\"field_media_document_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:32:\"field_media_document_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_media_document_target_id\";a:1:{i:0;s:30:\"field_media_document_target_id\";}}s:12:\"foreign keys\";a:1:{s:30:\"field_media_document_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:30:\"field_media_document_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','media.field_schema_data.field_media_image',_binary 'a:2:{s:24:\"media__field_media_image\";a:5:{s:11:\"description\";s:47:\"Data storage for media field field_media_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_media_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:21:\"field_media_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:23:\"field_media_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:23:\"field_media_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:24:\"field_media_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_media_image_target_id\";a:1:{i:0;s:27:\"field_media_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:27:\"field_media_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:27:\"field_media_image_target_id\";s:3:\"fid\";}}}}s:33:\"media_revision__field_media_image\";a:5:{s:11:\"description\";s:59:\"Revision archive storage for media field field_media_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_media_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:21:\"field_media_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:23:\"field_media_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:23:\"field_media_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:24:\"field_media_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_media_image_target_id\";a:1:{i:0;s:27:\"field_media_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:27:\"field_media_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:27:\"field_media_image_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','media.field_schema_data.field_media_oembed_video',_binary 'a:2:{s:31:\"media__field_media_oembed_video\";a:4:{s:11:\"description\";s:54:\"Data storage for media field field_media_oembed_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_oembed_video_value\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:40:\"media_revision__field_media_oembed_video\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for media field field_media_oembed_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_oembed_video_value\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.field_media_video_file',_binary 'a:2:{s:29:\"media__field_media_video_file\";a:5:{s:11:\"description\";s:52:\"Data storage for media field field_media_video_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_video_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_video_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_video_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_video_file_target_id\";a:1:{i:0;s:32:\"field_media_video_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_video_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_video_file_target_id\";s:3:\"fid\";}}}}s:38:\"media_revision__field_media_video_file\";a:5:{s:11:\"description\";s:64:\"Revision archive storage for media field field_media_video_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_video_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_video_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_video_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_video_file_target_id\";a:1:{i:0;s:32:\"field_media_video_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_video_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_video_file_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','media.field_schema_data.langcode',_binary 'a:4:{s:5:\"media\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','media.field_schema_data.mid',_binary 'a:4:{s:5:\"media\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','media.field_schema_data.name',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.revision_created',_binary 'a:1:{s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.revision_default',_binary 'a:1:{s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.revision_log_message',_binary 'a:1:{s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.revision_translation_affected',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.revision_user',_binary 'a:1:{s:14:\"media_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:37:\"media_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.status',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','media.field_schema_data.thumbnail',_binary 'a:2:{s:16:\"media_field_data\";a:3:{s:6:\"fields\";a:5:{s:20:\"thumbnail__target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:14:\"thumbnail__alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:16:\"thumbnail__title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:16:\"thumbnail__width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:17:\"thumbnail__height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:1:{i:0;s:20:\"thumbnail__target_id\";}}s:12:\"foreign keys\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:20:\"thumbnail__target_id\";s:3:\"fid\";}}}}s:20:\"media_field_revision\";a:3:{s:6:\"fields\";a:5:{s:20:\"thumbnail__target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:14:\"thumbnail__alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:16:\"thumbnail__title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:16:\"thumbnail__width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:17:\"thumbnail__height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:1:{i:0;s:20:\"thumbnail__target_id\";}}s:12:\"foreign keys\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:20:\"thumbnail__target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','media.field_schema_data.uid',_binary 'a:2:{s:16:\"media_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"media_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}s:20:\"media_field_revision\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"media_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.uuid',_binary 'a:1:{s:5:\"media\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:24:\"media_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.vid',_binary 'a:4:{s:5:\"media\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.entity_schema_data',_binary 'a:4:{s:17:\"menu_link_content\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:30:\"menu_link_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:26:\"menu_link_content_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:21:\"menu_link_content__id\";a:1:{i:0;s:2:\"id\";}}}s:22:\"menu_link_content_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:49:\"menu_link_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:30:\"menu_link_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"menu_link_content__enabled_bundle\";a:3:{i:0;s:7:\"enabled\";i:1;s:6:\"bundle\";i:2;s:2:\"id\";}}}s:32:\"menu_link_content_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:49:\"menu_link_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.bundle',_binary 'a:2:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.changed',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.default_langcode',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.description',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"description\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"description\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.enabled',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"enabled\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"enabled\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.expanded',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"expanded\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.external',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"external\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"external\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.id',_binary 'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.langcode',_binary 'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.link',_binary 'a:2:{s:22:\"menu_link_content_data\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:34:\"menu_link_content_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}s:32:\"menu_link_content_field_revision\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:34:\"menu_link_content_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.menu_name',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"menu_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.parent',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"parent\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.rediscover',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:10:\"rediscover\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_created',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_default',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_id',_binary 'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_log_message',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_translation_affected',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_user',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:29:\"menu_link_content__ef029a1897\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.title',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.uuid',_binary 'a:1:{s:17:\"menu_link_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:36:\"menu_link_content_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.weight',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.entity_schema_data',_binary 'a:4:{s:4:\"node\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"nid\";}s:11:\"unique keys\";a:1:{s:9:\"node__vid\";a:1:{i:0;s:3:\"vid\";}}}s:13:\"node_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"vid\";}s:7:\"indexes\";a:1:{s:9:\"node__nid\";a:1:{i:0;s:3:\"nid\";}}}s:15:\"node_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"nid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:36:\"node__id__default_langcode__langcode\";a:3:{i:0;s:3:\"nid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:9:\"node__vid\";a:1:{i:0;s:3:\"vid\";}s:17:\"node__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:3:\"nid\";}s:15:\"node__frontpage\";a:4:{i:0;s:7:\"promote\";i:1;s:6:\"status\";i:2;s:6:\"sticky\";i:3;s:7:\"created\";}s:16:\"node__title_type\";a:2:{i:0;s:5:\"title\";i:1;a:2:{i:0;s:4:\"type\";i:1;i:4;}}}}s:19:\"node_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"vid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:36:\"node__id__default_langcode__langcode\";a:3:{i:0;s:3:\"nid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.body',_binary 'a:2:{s:10:\"node__body\";a:4:{s:11:\"description\";s:33:\"Data storage for node field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}s:19:\"node_revision__body\";a:4:{s:11:\"description\";s:45:\"Revision archive storage for node field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.changed',_binary 'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"node_field__changed\";a:1:{i:0;s:7:\"changed\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.created',_binary 'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"node_field__created\";a:1:{i:0;s:7:\"created\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.default_langcode',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.field_components',_binary 'a:2:{s:22:\"node__field_components\";a:4:{s:11:\"description\";s:45:\"Data storage for node field field_components.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_components_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:35:\"field_components_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_components_target_id\";a:1:{i:0;s:26:\"field_components_target_id\";}s:35:\"field_components_target_revision_id\";a:1:{i:0;s:35:\"field_components_target_revision_id\";}}}s:31:\"node_revision__field_components\";a:4:{s:11:\"description\";s:57:\"Revision archive storage for node field field_components.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_components_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:35:\"field_components_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_components_target_id\";a:1:{i:0;s:26:\"field_components_target_id\";}s:35:\"field_components_target_revision_id\";a:1:{i:0;s:35:\"field_components_target_revision_id\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.field_image',_binary 'a:2:{s:17:\"node__field_image\";a:5:{s:11:\"description\";s:40:\"Data storage for node field field_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:15:\"field_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:17:\"field_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:17:\"field_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:18:\"field_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_image_target_id\";a:1:{i:0;s:21:\"field_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:21:\"field_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:21:\"field_image_target_id\";s:3:\"fid\";}}}}s:26:\"node_revision__field_image\";a:5:{s:11:\"description\";s:52:\"Revision archive storage for node field field_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:15:\"field_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:17:\"field_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:17:\"field_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:18:\"field_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_image_target_id\";a:1:{i:0;s:21:\"field_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:21:\"field_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:21:\"field_image_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','node.field_schema_data.field_tags',_binary 'a:2:{s:16:\"node__field_tags\";a:4:{s:11:\"description\";s:39:\"Data storage for node field field_tags.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_tags_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:20:\"field_tags_target_id\";a:1:{i:0;s:20:\"field_tags_target_id\";}}}s:25:\"node_revision__field_tags\";a:4:{s:11:\"description\";s:51:\"Revision archive storage for node field field_tags.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_tags_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:20:\"field_tags_target_id\";a:1:{i:0;s:20:\"field_tags_target_id\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.langcode',_binary 'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:2:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:20:\"node_field__langcode\";a:1:{i:0;s:8:\"langcode\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.nid',_binary 'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.promote',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"promote\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"promote\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_default',_binary 'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_log',_binary 'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:12:\"revision_log\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_timestamp',_binary 'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:18:\"revision_timestamp\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_translation_affected',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_uid',_binary 'a:1:{s:13:\"node_revision\";a:3:{s:6:\"fields\";a:1:{s:12:\"revision_uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:35:\"node_field__revision_uid__target_id\";a:1:{i:0;s:12:\"revision_uid\";}}s:12:\"foreign keys\";a:1:{s:24:\"node_field__revision_uid\";a:2:{s:5:\"table\";s:5:\"users\";s:7:\"columns\";a:1:{s:12:\"revision_uid\";s:3:\"uid\";}}}}}'),('entity.storage_schema.sql','node.field_schema_data.status',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.sticky',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.title',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.type',_binary 'a:2:{s:4:\"node\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"node_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"node_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.uid',_binary 'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:26:\"node_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}s:19:\"node_field_revision\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:26:\"node_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.uuid',_binary 'a:1:{s:4:\"node\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"node_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.vid',_binary 'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.entity_schema_data',_binary 'a:4:{s:15:\"paragraphs_item\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:22:\"paragraph__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:24:\"paragraphs_item_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:13:\"paragraph__id\";a:1:{i:0;s:2:\"id\";}}}s:26:\"paragraphs_item_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:41:\"paragraph__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:22:\"paragraph__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"paragraph__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:2:\"id\";}s:25:\"paragraphs__parent_fields\";a:3:{i:0;s:11:\"parent_type\";i:1;s:9:\"parent_id\";i:2;s:17:\"parent_field_name\";}}}s:35:\"paragraphs_item_revision_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:41:\"paragraph__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:25:\"paragraphs__parent_fields\";a:3:{i:0;s:11:\"parent_type\";i:1;s:9:\"parent_id\";i:2;s:17:\"parent_field_name\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.behavior_settings',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"behavior_settings\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"behavior_settings\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.created',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.default_langcode',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_accordion',_binary 'a:2:{s:30:\"paragraph__field_ept_accordion\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_accordion.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_accordion_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ept_accordion_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_accordion_target_id\";a:1:{i:0;s:29:\"field_ept_accordion_target_id\";}s:38:\"field_ept_accordion_target_revision_id\";a:1:{i:0;s:38:\"field_ept_accordion_target_revision_id\";}}}s:39:\"paragraph_revision__field_ept_accordion\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_accordion.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_accordion_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ept_accordion_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_accordion_target_id\";a:1:{i:0;s:29:\"field_ept_accordion_target_id\";}s:38:\"field_ept_accordion_target_revision_id\";a:1:{i:0;s:38:\"field_ept_accordion_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_accordion_text',_binary 'a:2:{s:35:\"paragraph__field_ept_accordion_text\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_accordion_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_accordion_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ept_accordion_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_accordion_text_format\";a:1:{i:0;s:31:\"field_ept_accordion_text_format\";}}}s:44:\"paragraph_revision__field_ept_accordion_text\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_accordion_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_accordion_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ept_accordion_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_accordion_text_format\";a:1:{i:0;s:31:\"field_ept_accordion_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_accordion_title',_binary 'a:2:{s:36:\"paragraph__field_ept_accordion_title\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_accordion_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_accordion_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_accordion_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_accordion_title_format\";a:1:{i:0;s:32:\"field_ept_accordion_title_format\";}}}s:45:\"paragraph_revision__field_ept_accordion_title\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_accordion_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_accordion_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_accordion_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_accordion_title_format\";a:1:{i:0;s:32:\"field_ept_accordion_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_basic_button_link',_binary 'a:2:{s:38:\"paragraph__field_ept_basic_button_link\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_basic_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_basic_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ept_basic_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ept_basic_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_basic_button_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ept_basic_button_link_uri\";i:1;i:30;}}}}s:47:\"paragraph_revision__field_ept_basic_button_link\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_basic_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_basic_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ept_basic_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ept_basic_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_basic_button_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ept_basic_button_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_block_block',_binary 'a:2:{s:32:\"paragraph__field_ept_block_block\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ept_block_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_block_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ept_block_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_block_block_plugin_id\";a:1:{i:0;s:31:\"field_ept_block_block_plugin_id\";}}}s:41:\"paragraph_revision__field_ept_block_block\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ept_block_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_block_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ept_block_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_block_block_plugin_id\";a:1:{i:0;s:31:\"field_ept_block_block_plugin_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_bootstrap_button_link',_binary 'a:2:{s:42:\"paragraph__field_ept_bootstrap_button_link\";a:4:{s:11:\"description\";s:65:\"Data storage for paragraph field field_ept_bootstrap_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_bootstrap_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:37:\"field_ept_bootstrap_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:39:\"field_ept_bootstrap_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ept_bootstrap_button_link_uri\";a:1:{i:0;a:2:{i:0;s:35:\"field_ept_bootstrap_button_link_uri\";i:1;i:30;}}}}s:23:\"paragraph_r__32204566b2\";a:4:{s:11:\"description\";s:77:\"Revision archive storage for paragraph field field_ept_bootstrap_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_bootstrap_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:37:\"field_ept_bootstrap_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:39:\"field_ept_bootstrap_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ept_bootstrap_button_link_uri\";a:1:{i:0;a:2:{i:0;s:35:\"field_ept_bootstrap_button_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_carousel',_binary 'a:2:{s:29:\"paragraph__field_ept_carousel\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ept_carousel.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_carousel_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:37:\"field_ept_carousel_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_carousel_target_id\";a:1:{i:0;s:28:\"field_ept_carousel_target_id\";}s:37:\"field_ept_carousel_target_revision_id\";a:1:{i:0;s:37:\"field_ept_carousel_target_revision_id\";}}}s:38:\"paragraph_revision__field_ept_carousel\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ept_carousel.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_carousel_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:37:\"field_ept_carousel_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_carousel_target_id\";a:1:{i:0;s:28:\"field_ept_carousel_target_id\";}s:37:\"field_ept_carousel_target_revision_id\";a:1:{i:0;s:37:\"field_ept_carousel_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_carousel_caption',_binary 'a:2:{s:37:\"paragraph__field_ept_carousel_caption\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ept_carousel_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_carousel_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ept_carousel_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_carousel_caption_format\";a:1:{i:0;s:33:\"field_ept_carousel_caption_format\";}}}s:46:\"paragraph_revision__field_ept_carousel_caption\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ept_carousel_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_carousel_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ept_carousel_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_carousel_caption_format\";a:1:{i:0;s:33:\"field_ept_carousel_caption_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_carousel_image',_binary 'a:2:{s:35:\"paragraph__field_ept_carousel_image\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_carousel_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:34:\"field_ept_carousel_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_carousel_image_target_id\";a:1:{i:0;s:34:\"field_ept_carousel_image_target_id\";}}}s:44:\"paragraph_revision__field_ept_carousel_image\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_carousel_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:34:\"field_ept_carousel_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_carousel_image_target_id\";a:1:{i:0;s:34:\"field_ept_carousel_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_clickable_tile',_binary 'a:2:{s:35:\"paragraph__field_ept_clickable_tile\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_clickable_tile.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_clickable_tile_value\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:44:\"paragraph_revision__field_ept_clickable_tile\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_clickable_tile.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_clickable_tile_value\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_columns',_binary 'a:2:{s:28:\"paragraph__field_ept_columns\";a:4:{s:11:\"description\";s:51:\"Data storage for paragraph field field_ept_columns.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_columns_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:36:\"field_ept_columns_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_columns_target_id\";a:1:{i:0;s:27:\"field_ept_columns_target_id\";}s:36:\"field_ept_columns_target_revision_id\";a:1:{i:0;s:36:\"field_ept_columns_target_revision_id\";}}}s:37:\"paragraph_revision__field_ept_columns\";a:4:{s:11:\"description\";s:63:\"Revision archive storage for paragraph field field_ept_columns.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_columns_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:36:\"field_ept_columns_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_columns_target_id\";a:1:{i:0;s:27:\"field_ept_columns_target_id\";}s:36:\"field_ept_columns_target_revision_id\";a:1:{i:0;s:36:\"field_ept_columns_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_countdown_date',_binary 'a:2:{s:35:\"paragraph__field_ept_countdown_date\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_countdown_date.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_countdown_date_value\";a:4:{s:11:\"description\";s:15:\"The date value.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_countdown_date_value\";a:1:{i:0;s:30:\"field_ept_countdown_date_value\";}}}s:44:\"paragraph_revision__field_ept_countdown_date\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_countdown_date.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_countdown_date_value\";a:4:{s:11:\"description\";s:15:\"The date value.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_countdown_date_value\";a:1:{i:0;s:30:\"field_ept_countdown_date_value\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_counter_description',_binary 'a:2:{s:40:\"paragraph__field_ept_counter_description\";a:4:{s:11:\"description\";s:63:\"Data storage for paragraph field field_ept_counter_description.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_counter_description_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:36:\"field_ept_counter_description_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_counter_description_format\";a:1:{i:0;s:36:\"field_ept_counter_description_format\";}}}s:23:\"paragraph_r__f6562160d8\";a:4:{s:11:\"description\";s:75:\"Revision archive storage for paragraph field field_ept_counter_description.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_counter_description_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:36:\"field_ept_counter_description_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_counter_description_format\";a:1:{i:0;s:36:\"field_ept_counter_description_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_counter_icon',_binary 'a:2:{s:33:\"paragraph__field_ept_counter_icon\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_ept_counter_icon.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_counter_icon_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_counter_icon_target_id\";a:1:{i:0;s:32:\"field_ept_counter_icon_target_id\";}}}s:42:\"paragraph_revision__field_ept_counter_icon\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_ept_counter_icon.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_counter_icon_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_counter_icon_target_id\";a:1:{i:0;s:32:\"field_ept_counter_icon_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_counter_items',_binary 'a:2:{s:34:\"paragraph__field_ept_counter_items\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ept_counter_items.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_counter_items_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:42:\"field_ept_counter_items_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_counter_items_target_id\";a:1:{i:0;s:33:\"field_ept_counter_items_target_id\";}s:42:\"field_ept_counter_items_target_revision_id\";a:1:{i:0;s:42:\"field_ept_counter_items_target_revision_id\";}}}s:43:\"paragraph_revision__field_ept_counter_items\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ept_counter_items.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_counter_items_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:42:\"field_ept_counter_items_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_counter_items_target_id\";a:1:{i:0;s:33:\"field_ept_counter_items_target_id\";}s:42:\"field_ept_counter_items_target_revision_id\";a:1:{i:0;s:42:\"field_ept_counter_items_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_counter_number',_binary 'a:2:{s:35:\"paragraph__field_ept_counter_number\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_counter_number.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_counter_number_value\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:44:\"paragraph_revision__field_ept_counter_number\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_counter_number.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_counter_number_value\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_counter_title',_binary 'a:2:{s:34:\"paragraph__field_ept_counter_title\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ept_counter_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_counter_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ept_counter_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_counter_title_format\";a:1:{i:0;s:30:\"field_ept_counter_title_format\";}}}s:43:\"paragraph_revision__field_ept_counter_title\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ept_counter_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_counter_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ept_counter_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_counter_title_format\";a:1:{i:0;s:30:\"field_ept_counter_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_cta_column_image',_binary 'a:2:{s:37:\"paragraph__field_ept_cta_column_image\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ept_cta_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_ept_cta_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_cta_column_image_target_id\";a:1:{i:0;s:36:\"field_ept_cta_column_image_target_id\";}}}s:46:\"paragraph_revision__field_ept_cta_column_image\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ept_cta_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_ept_cta_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_cta_column_image_target_id\";a:1:{i:0;s:36:\"field_ept_cta_column_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_cta_link',_binary 'a:2:{s:29:\"paragraph__field_ept_cta_link\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ept_cta_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:22:\"field_ept_cta_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:24:\"field_ept_cta_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:26:\"field_ept_cta_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"field_ept_cta_link_uri\";a:1:{i:0;a:2:{i:0;s:22:\"field_ept_cta_link_uri\";i:1;i:30;}}}}s:38:\"paragraph_revision__field_ept_cta_link\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ept_cta_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:22:\"field_ept_cta_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:24:\"field_ept_cta_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:26:\"field_ept_cta_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"field_ept_cta_link_uri\";a:1:{i:0;a:2:{i:0;s:22:\"field_ept_cta_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_cta_second_link',_binary 'a:2:{s:36:\"paragraph__field_ept_cta_second_link\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_cta_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_cta_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:31:\"field_ept_cta_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:33:\"field_ept_cta_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_cta_second_link_uri\";a:1:{i:0;a:2:{i:0;s:29:\"field_ept_cta_second_link_uri\";i:1;i:30;}}}}s:45:\"paragraph_revision__field_ept_cta_second_link\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_cta_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_cta_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:31:\"field_ept_cta_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:33:\"field_ept_cta_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_cta_second_link_uri\";a:1:{i:0;a:2:{i:0;s:29:\"field_ept_cta_second_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_gallery_item',_binary 'a:2:{s:33:\"paragraph__field_ept_gallery_item\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_ept_gallery_item.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_gallery_item_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_gallery_item_target_id\";a:1:{i:0;s:32:\"field_ept_gallery_item_target_id\";}}}s:42:\"paragraph_revision__field_ept_gallery_item\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_ept_gallery_item.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_gallery_item_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_gallery_item_target_id\";a:1:{i:0;s:32:\"field_ept_gallery_item_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_gallery_item_text',_binary 'a:2:{s:38:\"paragraph__field_ept_gallery_item_text\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_gallery_item_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_gallery_item_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_gallery_item_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_gallery_item_text_format\";a:1:{i:0;s:34:\"field_ept_gallery_item_text_format\";}}}s:47:\"paragraph_revision__field_ept_gallery_item_text\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_gallery_item_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_gallery_item_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_gallery_item_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_gallery_item_text_format\";a:1:{i:0;s:34:\"field_ept_gallery_item_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_hero_column_image',_binary 'a:2:{s:38:\"paragraph__field_ept_hero_column_image\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_hero_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ept_hero_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ept_hero_column_image_target_id\";a:1:{i:0;s:37:\"field_ept_hero_column_image_target_id\";}}}s:47:\"paragraph_revision__field_ept_hero_column_image\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_hero_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ept_hero_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ept_hero_column_image_target_id\";a:1:{i:0;s:37:\"field_ept_hero_column_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_hero_link',_binary 'a:2:{s:30:\"paragraph__field_ept_hero_link\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_hero_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:23:\"field_ept_hero_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:25:\"field_ept_hero_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:27:\"field_ept_hero_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:23:\"field_ept_hero_link_uri\";a:1:{i:0;a:2:{i:0;s:23:\"field_ept_hero_link_uri\";i:1;i:30;}}}}s:39:\"paragraph_revision__field_ept_hero_link\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_hero_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:23:\"field_ept_hero_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:25:\"field_ept_hero_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:27:\"field_ept_hero_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:23:\"field_ept_hero_link_uri\";a:1:{i:0;a:2:{i:0;s:23:\"field_ept_hero_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_hero_second_link',_binary 'a:2:{s:37:\"paragraph__field_ept_hero_second_link\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ept_hero_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_hero_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:32:\"field_ept_hero_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:34:\"field_ept_hero_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_hero_second_link_uri\";a:1:{i:0;a:2:{i:0;s:30:\"field_ept_hero_second_link_uri\";i:1;i:30;}}}}s:46:\"paragraph_revision__field_ept_hero_second_link\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ept_hero_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_hero_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:32:\"field_ept_hero_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:34:\"field_ept_hero_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_hero_second_link_uri\";a:1:{i:0;a:2:{i:0;s:30:\"field_ept_hero_second_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_hero_title_prefix',_binary 'a:2:{s:38:\"paragraph__field_ept_hero_title_prefix\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_hero_title_prefix.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_hero_title_prefix_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_hero_title_prefix_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_hero_title_prefix_format\";a:1:{i:0;s:34:\"field_ept_hero_title_prefix_format\";}}}s:47:\"paragraph_revision__field_ept_hero_title_prefix\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_hero_title_prefix.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_hero_title_prefix_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_hero_title_prefix_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_hero_title_prefix_format\";a:1:{i:0;s:34:\"field_ept_hero_title_prefix_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_image',_binary 'a:2:{s:26:\"paragraph__field_ept_image\";a:4:{s:11:\"description\";s:49:\"Data storage for paragraph field field_ept_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_image_target_id\";a:1:{i:0;s:25:\"field_ept_image_target_id\";}}}s:35:\"paragraph_revision__field_ept_image\";a:4:{s:11:\"description\";s:61:\"Revision archive storage for paragraph field field_ept_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_image_target_id\";a:1:{i:0;s:25:\"field_ept_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_image_caption',_binary 'a:2:{s:34:\"paragraph__field_ept_image_caption\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ept_image_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_image_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ept_image_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_image_caption_format\";a:1:{i:0;s:30:\"field_ept_image_caption_format\";}}}s:43:\"paragraph_revision__field_ept_image_caption\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ept_image_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_image_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ept_image_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_image_caption_format\";a:1:{i:0;s:30:\"field_ept_image_caption_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_image_gallery',_binary 'a:2:{s:34:\"paragraph__field_ept_image_gallery\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ept_image_gallery.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_image_gallery_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_image_gallery_target_id\";a:1:{i:0;s:33:\"field_ept_image_gallery_target_id\";}}}s:43:\"paragraph_revision__field_ept_image_gallery\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ept_image_gallery.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_image_gallery_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_image_gallery_target_id\";a:1:{i:0;s:33:\"field_ept_image_gallery_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_image_link',_binary 'a:2:{s:31:\"paragraph__field_ept_image_link\";a:4:{s:11:\"description\";s:54:\"Data storage for paragraph field field_ept_image_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_image_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ept_image_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ept_image_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_image_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ept_image_link_uri\";i:1;i:30;}}}}s:40:\"paragraph_revision__field_ept_image_link\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for paragraph field field_ept_image_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_image_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ept_image_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ept_image_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_image_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ept_image_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_micromodal_title',_binary 'a:2:{s:37:\"paragraph__field_ept_micromodal_title\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ept_micromodal_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_micromodal_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ept_micromodal_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_micromodal_title_format\";a:1:{i:0;s:33:\"field_ept_micromodal_title_format\";}}}s:46:\"paragraph_revision__field_ept_micromodal_title\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ept_micromodal_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_micromodal_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ept_micromodal_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_micromodal_title_format\";a:1:{i:0;s:33:\"field_ept_micromodal_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_quote_author',_binary 'a:2:{s:33:\"paragraph__field_ept_quote_author\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_ept_quote_author.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_quote_author_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:29:\"field_ept_quote_author_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_quote_author_format\";a:1:{i:0;s:29:\"field_ept_quote_author_format\";}}}s:42:\"paragraph_revision__field_ept_quote_author\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_ept_quote_author.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_quote_author_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:29:\"field_ept_quote_author_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_quote_author_format\";a:1:{i:0;s:29:\"field_ept_quote_author_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_quote_image',_binary 'a:2:{s:32:\"paragraph__field_ept_quote_image\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ept_quote_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_quote_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_quote_image_target_id\";a:1:{i:0;s:31:\"field_ept_quote_image_target_id\";}}}s:41:\"paragraph_revision__field_ept_quote_image\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ept_quote_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_quote_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_quote_image_target_id\";a:1:{i:0;s:31:\"field_ept_quote_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_settings',_binary 'a:2:{s:29:\"paragraph__field_ept_settings\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ept_settings.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_settings_ept_settings\";a:5:{s:11:\"description\";s:34:\"Serialized paragraph settings data\";s:4:\"type\";s:4:\"blob\";s:9:\"serialize\";b:1;s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:38:\"paragraph_revision__field_ept_settings\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ept_settings.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_settings_ept_settings\";a:5:{s:11:\"description\";s:34:\"Serialized paragraph settings data\";s:4:\"type\";s:4:\"blob\";s:9:\"serialize\";b:1;s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slick_slider',_binary 'a:2:{s:33:\"paragraph__field_ept_slick_slider\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_ept_slick_slider.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_slick_slider_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:41:\"field_ept_slick_slider_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_slick_slider_target_id\";a:1:{i:0;s:32:\"field_ept_slick_slider_target_id\";}s:41:\"field_ept_slick_slider_target_revision_id\";a:1:{i:0;s:41:\"field_ept_slick_slider_target_revision_id\";}}}s:42:\"paragraph_revision__field_ept_slick_slider\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_ept_slick_slider.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_slick_slider_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:41:\"field_ept_slick_slider_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_slick_slider_target_id\";a:1:{i:0;s:32:\"field_ept_slick_slider_target_id\";}s:41:\"field_ept_slick_slider_target_revision_id\";a:1:{i:0;s:41:\"field_ept_slick_slider_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slick_slider_image',_binary 'a:2:{s:39:\"paragraph__field_ept_slick_slider_image\";a:4:{s:11:\"description\";s:62:\"Data storage for paragraph field field_ept_slick_slider_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:38:\"field_ept_slick_slider_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:38:\"field_ept_slick_slider_image_target_id\";a:1:{i:0;s:38:\"field_ept_slick_slider_image_target_id\";}}}s:48:\"paragraph_revision__field_ept_slick_slider_image\";a:4:{s:11:\"description\";s:74:\"Revision archive storage for paragraph field field_ept_slick_slider_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:38:\"field_ept_slick_slider_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:38:\"field_ept_slick_slider_image_target_id\";a:1:{i:0;s:38:\"field_ept_slick_slider_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slick_slider_link',_binary 'a:2:{s:38:\"paragraph__field_ept_slick_slider_link\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_slick_slider_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_slick_slider_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ept_slick_slider_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ept_slick_slider_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_slick_slider_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ept_slick_slider_link_uri\";i:1;i:30;}}}}s:47:\"paragraph_revision__field_ept_slick_slider_link\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_slick_slider_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_slick_slider_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ept_slick_slider_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ept_slick_slider_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_slick_slider_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ept_slick_slider_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slick_slider_text',_binary 'a:2:{s:38:\"paragraph__field_ept_slick_slider_text\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_slick_slider_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_slick_slider_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_slick_slider_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_slick_slider_text_format\";a:1:{i:0;s:34:\"field_ept_slick_slider_text_format\";}}}s:47:\"paragraph_revision__field_ept_slick_slider_text\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_slick_slider_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_slick_slider_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_slick_slider_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_slick_slider_text_format\";a:1:{i:0;s:34:\"field_ept_slick_slider_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slideshow',_binary 'a:2:{s:30:\"paragraph__field_ept_slideshow\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_slideshow.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_slideshow_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ept_slideshow_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_slideshow_target_id\";a:1:{i:0;s:29:\"field_ept_slideshow_target_id\";}s:38:\"field_ept_slideshow_target_revision_id\";a:1:{i:0;s:38:\"field_ept_slideshow_target_revision_id\";}}}s:39:\"paragraph_revision__field_ept_slideshow\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_slideshow.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_slideshow_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ept_slideshow_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_slideshow_target_id\";a:1:{i:0;s:29:\"field_ept_slideshow_target_id\";}s:38:\"field_ept_slideshow_target_revision_id\";a:1:{i:0;s:38:\"field_ept_slideshow_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slideshow_link',_binary 'a:2:{s:35:\"paragraph__field_ept_slideshow_link\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_slideshow_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_slideshow_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:30:\"field_ept_slideshow_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:32:\"field_ept_slideshow_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_slideshow_link_uri\";a:1:{i:0;a:2:{i:0;s:28:\"field_ept_slideshow_link_uri\";i:1;i:30;}}}}s:44:\"paragraph_revision__field_ept_slideshow_link\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_slideshow_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_slideshow_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:30:\"field_ept_slideshow_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:32:\"field_ept_slideshow_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_slideshow_link_uri\";a:1:{i:0;a:2:{i:0;s:28:\"field_ept_slideshow_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slideshow_slide',_binary 'a:2:{s:36:\"paragraph__field_ept_slideshow_slide\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_slideshow_slide.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_slideshow_slide_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ept_slideshow_slide_target_id\";a:1:{i:0;s:35:\"field_ept_slideshow_slide_target_id\";}}}s:45:\"paragraph_revision__field_ept_slideshow_slide\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_slideshow_slide.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_slideshow_slide_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ept_slideshow_slide_target_id\";a:1:{i:0;s:35:\"field_ept_slideshow_slide_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slideshow_text',_binary 'a:2:{s:35:\"paragraph__field_ept_slideshow_text\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_slideshow_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_slideshow_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ept_slideshow_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_slideshow_text_format\";a:1:{i:0;s:31:\"field_ept_slideshow_text_format\";}}}s:44:\"paragraph_revision__field_ept_slideshow_text\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_slideshow_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_slideshow_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ept_slideshow_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_slideshow_text_format\";a:1:{i:0;s:31:\"field_ept_slideshow_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slideshow_title',_binary 'a:2:{s:36:\"paragraph__field_ept_slideshow_title\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_slideshow_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_slideshow_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_slideshow_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_slideshow_title_format\";a:1:{i:0;s:32:\"field_ept_slideshow_title_format\";}}}s:45:\"paragraph_revision__field_ept_slideshow_title\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_slideshow_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_slideshow_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_slideshow_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_slideshow_title_format\";a:1:{i:0;s:32:\"field_ept_slideshow_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_stats',_binary 'a:2:{s:26:\"paragraph__field_ept_stats\";a:4:{s:11:\"description\";s:49:\"Data storage for paragraph field field_ept_stats.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_stats_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ept_stats_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_stats_target_id\";a:1:{i:0;s:25:\"field_ept_stats_target_id\";}s:34:\"field_ept_stats_target_revision_id\";a:1:{i:0;s:34:\"field_ept_stats_target_revision_id\";}}}s:35:\"paragraph_revision__field_ept_stats\";a:4:{s:11:\"description\";s:61:\"Revision archive storage for paragraph field field_ept_stats.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_stats_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ept_stats_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_stats_target_id\";a:1:{i:0;s:25:\"field_ept_stats_target_id\";}s:34:\"field_ept_stats_target_revision_id\";a:1:{i:0;s:34:\"field_ept_stats_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_stats_item_image',_binary 'a:2:{s:37:\"paragraph__field_ept_stats_item_image\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ept_stats_item_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_ept_stats_item_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_stats_item_image_target_id\";a:1:{i:0;s:36:\"field_ept_stats_item_image_target_id\";}}}s:46:\"paragraph_revision__field_ept_stats_item_image\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ept_stats_item_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_ept_stats_item_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_stats_item_image_target_id\";a:1:{i:0;s:36:\"field_ept_stats_item_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_stats_item_link',_binary 'a:2:{s:36:\"paragraph__field_ept_stats_item_link\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_stats_item_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_stats_item_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:31:\"field_ept_stats_item_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:33:\"field_ept_stats_item_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_stats_item_link_uri\";a:1:{i:0;a:2:{i:0;s:29:\"field_ept_stats_item_link_uri\";i:1;i:30;}}}}s:45:\"paragraph_revision__field_ept_stats_item_link\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_stats_item_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_stats_item_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:31:\"field_ept_stats_item_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:33:\"field_ept_stats_item_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_stats_item_link_uri\";a:1:{i:0;a:2:{i:0;s:29:\"field_ept_stats_item_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_stats_item_number',_binary 'a:2:{s:38:\"paragraph__field_ept_stats_item_number\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_stats_item_number.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_stats_item_number_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_stats_item_number_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_stats_item_number_format\";a:1:{i:0;s:34:\"field_ept_stats_item_number_format\";}}}s:47:\"paragraph_revision__field_ept_stats_item_number\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_stats_item_number.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_stats_item_number_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_stats_item_number_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_stats_item_number_format\";a:1:{i:0;s:34:\"field_ept_stats_item_number_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_stats_item_text',_binary 'a:2:{s:36:\"paragraph__field_ept_stats_item_text\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_stats_item_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_stats_item_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_stats_item_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_stats_item_text_format\";a:1:{i:0;s:32:\"field_ept_stats_item_text_format\";}}}s:45:\"paragraph_revision__field_ept_stats_item_text\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_stats_item_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_stats_item_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_stats_item_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_stats_item_text_format\";a:1:{i:0;s:32:\"field_ept_stats_item_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tabs',_binary 'a:2:{s:25:\"paragraph__field_ept_tabs\";a:4:{s:11:\"description\";s:48:\"Data storage for paragraph field field_ept_tabs.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tabs_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:33:\"field_ept_tabs_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_tabs_target_id\";a:1:{i:0;s:24:\"field_ept_tabs_target_id\";}s:33:\"field_ept_tabs_target_revision_id\";a:1:{i:0;s:33:\"field_ept_tabs_target_revision_id\";}}}s:34:\"paragraph_revision__field_ept_tabs\";a:4:{s:11:\"description\";s:60:\"Revision archive storage for paragraph field field_ept_tabs.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tabs_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:33:\"field_ept_tabs_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_tabs_target_id\";a:1:{i:0;s:24:\"field_ept_tabs_target_id\";}s:33:\"field_ept_tabs_target_revision_id\";a:1:{i:0;s:33:\"field_ept_tabs_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_block',_binary 'a:2:{s:30:\"paragraph__field_ept_tab_block\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_tab_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_tab_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:28:\"field_ept_tab_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_tab_block_plugin_id\";a:1:{i:0;s:29:\"field_ept_tab_block_plugin_id\";}}}s:39:\"paragraph_revision__field_ept_tab_block\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_tab_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_tab_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:28:\"field_ept_tab_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_tab_block_plugin_id\";a:1:{i:0;s:29:\"field_ept_tab_block_plugin_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_content',_binary 'a:2:{s:32:\"paragraph__field_ept_tab_content\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ept_tab_content.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_tab_content_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_tab_content_value\";a:1:{i:0;s:27:\"field_ept_tab_content_value\";}}}s:41:\"paragraph_revision__field_ept_tab_content\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ept_tab_content.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_tab_content_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_tab_content_value\";a:1:{i:0;s:27:\"field_ept_tab_content_value\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_page',_binary 'a:2:{s:29:\"paragraph__field_ept_tab_page\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ept_tab_page.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_tab_page_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_tab_page_target_id\";a:1:{i:0;s:28:\"field_ept_tab_page_target_id\";}}}s:38:\"paragraph_revision__field_ept_tab_page\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ept_tab_page.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_tab_page_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_tab_page_target_id\";a:1:{i:0;s:28:\"field_ept_tab_page_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_text',_binary 'a:2:{s:29:\"paragraph__field_ept_tab_text\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ept_tab_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tab_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:25:\"field_ept_tab_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_tab_text_format\";a:1:{i:0;s:25:\"field_ept_tab_text_format\";}}}s:38:\"paragraph_revision__field_ept_tab_text\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ept_tab_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tab_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:25:\"field_ept_tab_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_tab_text_format\";a:1:{i:0;s:25:\"field_ept_tab_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_title',_binary 'a:2:{s:30:\"paragraph__field_ept_tab_title\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_tab_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_tab_title_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:26:\"field_ept_tab_title_format\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_ept_tab_title_format\";a:1:{i:0;s:26:\"field_ept_tab_title_format\";}}}s:39:\"paragraph_revision__field_ept_tab_title\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_tab_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_tab_title_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:26:\"field_ept_tab_title_format\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_ept_tab_title_format\";a:1:{i:0;s:26:\"field_ept_tab_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_views',_binary 'a:2:{s:30:\"paragraph__field_ept_tab_views\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_tab_views.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_tab_views_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ept_tab_views_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:24:\"field_ept_tab_views_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_tab_views_target_id\";a:1:{i:0;s:29:\"field_ept_tab_views_target_id\";}s:30:\"field_ept_tab_views_display_id\";a:1:{i:0;s:30:\"field_ept_tab_views_display_id\";}}}s:39:\"paragraph_revision__field_ept_tab_views\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_tab_views.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_tab_views_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ept_tab_views_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:24:\"field_ept_tab_views_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_tab_views_target_id\";a:1:{i:0;s:29:\"field_ept_tab_views_target_id\";}s:30:\"field_ept_tab_views_display_id\";a:1:{i:0;s:30:\"field_ept_tab_views_display_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_text',_binary 'a:2:{s:25:\"paragraph__field_ept_text\";a:4:{s:11:\"description\";s:48:\"Data storage for paragraph field field_ept_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_ept_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:21:\"field_ept_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_ept_text_format\";a:1:{i:0;s:21:\"field_ept_text_format\";}}}s:34:\"paragraph_revision__field_ept_text\";a:4:{s:11:\"description\";s:60:\"Revision archive storage for paragraph field field_ept_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_ept_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:21:\"field_ept_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_ept_text_format\";a:1:{i:0;s:21:\"field_ept_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tiles',_binary 'a:2:{s:26:\"paragraph__field_ept_tiles\";a:4:{s:11:\"description\";s:49:\"Data storage for paragraph field field_ept_tiles.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_tiles_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ept_tiles_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_tiles_target_id\";a:1:{i:0;s:25:\"field_ept_tiles_target_id\";}s:34:\"field_ept_tiles_target_revision_id\";a:1:{i:0;s:34:\"field_ept_tiles_target_revision_id\";}}}s:35:\"paragraph_revision__field_ept_tiles\";a:4:{s:11:\"description\";s:61:\"Revision archive storage for paragraph field field_ept_tiles.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_tiles_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ept_tiles_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_tiles_target_id\";a:1:{i:0;s:25:\"field_ept_tiles_target_id\";}s:34:\"field_ept_tiles_target_revision_id\";a:1:{i:0;s:34:\"field_ept_tiles_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tiles_image',_binary 'a:2:{s:32:\"paragraph__field_ept_tiles_image\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ept_tiles_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_tiles_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_tiles_image_target_id\";a:1:{i:0;s:31:\"field_ept_tiles_image_target_id\";}}}s:41:\"paragraph_revision__field_ept_tiles_image\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ept_tiles_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_tiles_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_tiles_image_target_id\";a:1:{i:0;s:31:\"field_ept_tiles_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tiles_link',_binary 'a:2:{s:31:\"paragraph__field_ept_tiles_link\";a:4:{s:11:\"description\";s:54:\"Data storage for paragraph field field_ept_tiles_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tiles_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ept_tiles_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ept_tiles_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_tiles_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ept_tiles_link_uri\";i:1;i:30;}}}}s:40:\"paragraph_revision__field_ept_tiles_link\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for paragraph field field_ept_tiles_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tiles_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ept_tiles_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ept_tiles_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_tiles_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ept_tiles_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tiles_text',_binary 'a:2:{s:31:\"paragraph__field_ept_tiles_text\";a:4:{s:11:\"description\";s:54:\"Data storage for paragraph field field_ept_tiles_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_ept_tiles_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:27:\"field_ept_tiles_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_tiles_text_format\";a:1:{i:0;s:27:\"field_ept_tiles_text_format\";}}}s:40:\"paragraph_revision__field_ept_tiles_text\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for paragraph field field_ept_tiles_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_ept_tiles_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:27:\"field_ept_tiles_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_tiles_text_format\";a:1:{i:0;s:27:\"field_ept_tiles_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tiles_title',_binary 'a:2:{s:32:\"paragraph__field_ept_tiles_title\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ept_tiles_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_tiles_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:28:\"field_ept_tiles_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_tiles_title_format\";a:1:{i:0;s:28:\"field_ept_tiles_title_format\";}}}s:41:\"paragraph_revision__field_ept_tiles_title\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ept_tiles_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_tiles_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:28:\"field_ept_tiles_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_tiles_title_format\";a:1:{i:0;s:28:\"field_ept_tiles_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_title',_binary 'a:2:{s:26:\"paragraph__field_ept_title\";a:4:{s:11:\"description\";s:49:\"Data storage for paragraph field field_ept_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_ept_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:22:\"field_ept_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"field_ept_title_format\";a:1:{i:0;s:22:\"field_ept_title_format\";}}}s:35:\"paragraph_revision__field_ept_title\";a:4:{s:11:\"description\";s:61:\"Revision archive storage for paragraph field field_ept_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_ept_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:22:\"field_ept_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"field_ept_title_format\";a:1:{i:0;s:22:\"field_ept_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_video',_binary 'a:2:{s:26:\"paragraph__field_ept_video\";a:4:{s:11:\"description\";s:49:\"Data storage for paragraph field field_ept_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_video_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_video_target_id\";a:1:{i:0;s:25:\"field_ept_video_target_id\";}}}s:35:\"paragraph_revision__field_ept_video\";a:4:{s:11:\"description\";s:61:\"Revision archive storage for paragraph field field_ept_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_video_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_video_target_id\";a:1:{i:0;s:25:\"field_ept_video_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_videos_and_images',_binary 'a:2:{s:38:\"paragraph__field_ept_videos_and_images\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_videos_and_images.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ept_videos_and_images_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:46:\"field_ept_videos_and_images_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ept_videos_and_images_target_id\";a:1:{i:0;s:37:\"field_ept_videos_and_images_target_id\";}s:46:\"field_ept_videos_and_images_target_revision_id\";a:1:{i:0;s:46:\"field_ept_videos_and_images_target_revision_id\";}}}s:47:\"paragraph_revision__field_ept_videos_and_images\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_videos_and_images.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ept_videos_and_images_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:46:\"field_ept_videos_and_images_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ept_videos_and_images_target_id\";a:1:{i:0;s:37:\"field_ept_videos_and_images_target_id\";}s:46:\"field_ept_videos_and_images_target_revision_id\";a:1:{i:0;s:46:\"field_ept_videos_and_images_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_views_view',_binary 'a:2:{s:31:\"paragraph__field_ept_views_view\";a:4:{s:11:\"description\";s:54:\"Data storage for paragraph field field_ept_views_view.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_views_view_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:31:\"field_ept_views_view_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:25:\"field_ept_views_view_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_views_view_target_id\";a:1:{i:0;s:30:\"field_ept_views_view_target_id\";}s:31:\"field_ept_views_view_display_id\";a:1:{i:0;s:31:\"field_ept_views_view_display_id\";}}}s:40:\"paragraph_revision__field_ept_views_view\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for paragraph field field_ept_views_view.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_views_view_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:31:\"field_ept_views_view_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:25:\"field_ept_views_view_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_views_view_target_id\";a:1:{i:0;s:30:\"field_ept_views_view_target_id\";}s:31:\"field_ept_views_view_display_id\";a:1:{i:0;s:31:\"field_ept_views_view_display_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_webform_form',_binary 'a:2:{s:33:\"paragraph__field_ept_webform_form\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_ept_webform_form.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_webform_form_target_id\";a:4:{s:11:\"description\";s:29:\"The ID of the webform entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}s:35:\"field_ept_webform_form_default_data\";a:3:{s:11:\"description\";s:24:\"Default submission data.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}s:29:\"field_ept_webform_form_status\";a:4:{s:11:\"description\";s:94:\"Flag to control whether this webform should be open, closed, or scheduled for new submissions.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:27:\"field_ept_webform_form_open\";a:4:{s:11:\"description\";s:19:\"The open date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:28:\"field_ept_webform_form_close\";a:4:{s:11:\"description\";s:20:\"The close date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_webform_form_target_id\";a:1:{i:0;s:32:\"field_ept_webform_form_target_id\";}}}s:42:\"paragraph_revision__field_ept_webform_form\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_ept_webform_form.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_webform_form_target_id\";a:4:{s:11:\"description\";s:29:\"The ID of the webform entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}s:35:\"field_ept_webform_form_default_data\";a:3:{s:11:\"description\";s:24:\"Default submission data.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}s:29:\"field_ept_webform_form_status\";a:4:{s:11:\"description\";s:94:\"Flag to control whether this webform should be open, closed, or scheduled for new submissions.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:27:\"field_ept_webform_form_open\";a:4:{s:11:\"description\";s:19:\"The open date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:28:\"field_ept_webform_form_close\";a:4:{s:11:\"description\";s:20:\"The close date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_webform_form_target_id\";a:1:{i:0;s:32:\"field_ept_webform_form_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_webform_popup_form',_binary 'a:2:{s:39:\"paragraph__field_ept_webform_popup_form\";a:4:{s:11:\"description\";s:62:\"Data storage for paragraph field field_ept_webform_popup_form.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:38:\"field_ept_webform_popup_form_target_id\";a:4:{s:11:\"description\";s:29:\"The ID of the webform entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}s:41:\"field_ept_webform_popup_form_default_data\";a:3:{s:11:\"description\";s:24:\"Default submission data.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}s:35:\"field_ept_webform_popup_form_status\";a:4:{s:11:\"description\";s:94:\"Flag to control whether this webform should be open, closed, or scheduled for new submissions.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:33:\"field_ept_webform_popup_form_open\";a:4:{s:11:\"description\";s:19:\"The open date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:34:\"field_ept_webform_popup_form_close\";a:4:{s:11:\"description\";s:20:\"The close date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:38:\"field_ept_webform_popup_form_target_id\";a:1:{i:0;s:38:\"field_ept_webform_popup_form_target_id\";}}}s:48:\"paragraph_revision__field_ept_webform_popup_form\";a:4:{s:11:\"description\";s:74:\"Revision archive storage for paragraph field field_ept_webform_popup_form.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:38:\"field_ept_webform_popup_form_target_id\";a:4:{s:11:\"description\";s:29:\"The ID of the webform entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}s:41:\"field_ept_webform_popup_form_default_data\";a:3:{s:11:\"description\";s:24:\"Default submission data.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}s:35:\"field_ept_webform_popup_form_status\";a:4:{s:11:\"description\";s:94:\"Flag to control whether this webform should be open, closed, or scheduled for new submissions.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:33:\"field_ept_webform_popup_form_open\";a:4:{s:11:\"description\";s:19:\"The open date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:34:\"field_ept_webform_popup_form_close\";a:4:{s:11:\"description\";s:20:\"The close date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:38:\"field_ept_webform_popup_form_target_id\";a:1:{i:0;s:38:\"field_ept_webform_popup_form_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.id',_binary 'a:4:{s:15:\"paragraphs_item\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.langcode',_binary 'a:4:{s:15:\"paragraphs_item\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.parent_field_name',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"parent_field_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"parent_field_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.parent_id',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"parent_id\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"parent_id\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.parent_type',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"parent_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"parent_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.revision_default',_binary 'a:1:{s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.revision_id',_binary 'a:4:{s:15:\"paragraphs_item\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.revision_translation_affected',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.status',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.type',_binary 'a:2:{s:15:\"paragraphs_item\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:32:\"paragraph_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:26:\"paragraphs_item_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:32:\"paragraph_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.uuid',_binary 'a:1:{s:15:\"paragraphs_item\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:28:\"paragraph_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','path_alias.entity_schema_data',_binary 'a:2:{s:10:\"path_alias\";a:3:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:7:\"indexes\";a:2:{s:36:\"path_alias__alias_langcode_id_status\";a:4:{i:0;s:5:\"alias\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}s:35:\"path_alias__path_langcode_id_status\";a:4:{i:0;s:4:\"path\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}}s:11:\"unique keys\";a:1:{s:23:\"path_alias__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:19:\"path_alias_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:3:{s:14:\"path_alias__id\";a:1:{i:0;s:2:\"id\";}s:45:\"path_alias_revision__alias_langcode_id_status\";a:4:{i:0;s:5:\"alias\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}s:44:\"path_alias_revision__path_langcode_id_status\";a:4:{i:0;s:4:\"path\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.alias',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:5:\"alias\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"alias\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.id',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.langcode',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.path',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:4:\"path\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"path\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.revision_default',_binary 'a:1:{s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.revision_id',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.status',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.uuid',_binary 'a:1:{s:10:\"path_alias\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:29:\"path_alias_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','shortcut.entity_schema_data',_binary 'a:2:{s:8:\"shortcut\";a:1:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}}s:19:\"shortcut_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:40:\"shortcut__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.default_langcode',_binary 'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.id',_binary 'a:2:{s:8:\"shortcut\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.langcode',_binary 'a:2:{s:8:\"shortcut\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.link',_binary 'a:1:{s:19:\"shortcut_field_data\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:25:\"shortcut_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.shortcut_set',_binary 'a:2:{s:8:\"shortcut\";a:2:{s:6:\"fields\";a:1:{s:12:\"shortcut_set\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:39:\"shortcut_field__shortcut_set__target_id\";a:1:{i:0;s:12:\"shortcut_set\";}}}s:19:\"shortcut_field_data\";a:2:{s:6:\"fields\";a:1:{s:12:\"shortcut_set\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:39:\"shortcut_field__shortcut_set__target_id\";a:1:{i:0;s:12:\"shortcut_set\";}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.title',_binary 'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.uuid',_binary 'a:1:{s:8:\"shortcut\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:27:\"shortcut_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.weight',_binary 'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.entity_schema_data',_binary 'a:5:{s:18:\"taxonomy_term_data\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"tid\";}s:11:\"unique keys\";a:1:{s:26:\"taxonomy_term__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:22:\"taxonomy_term_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:18:\"taxonomy_term__tid\";a:1:{i:0;s:3:\"tid\";}}}s:24:\"taxonomy_term_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"tid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:45:\"taxonomy_term__id__default_langcode__langcode\";a:3:{i:0;s:3:\"tid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:26:\"taxonomy_term__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"taxonomy_term__status_vid\";a:3:{i:0;s:6:\"status\";i:1;s:3:\"vid\";i:2;s:3:\"tid\";}s:19:\"taxonomy_term__tree\";a:3:{i:0;s:3:\"vid\";i:1;s:6:\"weight\";i:2;s:4:\"name\";}s:23:\"taxonomy_term__vid_name\";a:2:{i:0;s:3:\"vid\";i:1;s:4:\"name\";}}}s:28:\"taxonomy_term_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:45:\"taxonomy_term__id__default_langcode__langcode\";a:3:{i:0;s:3:\"tid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}s:14:\"taxonomy_index\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"nid\";i:1;s:3:\"tid\";}s:7:\"indexes\";a:1:{s:9:\"term_node\";a:4:{i:0;s:3:\"tid\";i:1;s:6:\"status\";i:2;s:6:\"sticky\";i:3;s:7:\"created\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.changed',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.default_langcode',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.description',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:2:{s:18:\"description__value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:19:\"description__format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:0:{}}s:28:\"taxonomy_term_field_revision\";a:2:{s:6:\"fields\";a:2:{s:18:\"description__value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:19:\"description__format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:40:\"taxonomy_term_field__description__format\";a:1:{i:0;s:19:\"description__format\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.langcode',_binary 'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.name',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:25:\"taxonomy_term_field__name\";a:1:{i:0;s:4:\"name\";}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.parent',_binary 'a:2:{s:21:\"taxonomy_term__parent\";a:4:{s:11:\"description\";s:44:\"Data storage for taxonomy_term field parent.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:16:\"parent_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:16:\"parent_target_id\";a:1:{i:0;s:16:\"parent_target_id\";}s:22:\"bundle_delta_target_id\";a:3:{i:0;s:6:\"bundle\";i:1;s:5:\"delta\";i:2;s:16:\"parent_target_id\";}}}s:30:\"taxonomy_term_revision__parent\";a:4:{s:11:\"description\";s:56:\"Revision archive storage for taxonomy_term field parent.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:16:\"parent_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:16:\"parent_target_id\";a:1:{i:0;s:16:\"parent_target_id\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_created',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_default',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_id',_binary 'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_log_message',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_translation_affected',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_user',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:45:\"taxonomy_term_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.status',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.tid',_binary 'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.uuid',_binary 'a:1:{s:18:\"taxonomy_term_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:32:\"taxonomy_term_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.vid',_binary 'a:2:{s:18:\"taxonomy_term_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:35:\"taxonomy_term_field__vid__target_id\";a:1:{i:0;s:3:\"vid\";}}}s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:0:{}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.weight',_binary 'a:1:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.entity_schema_data',_binary 'a:2:{s:5:\"users\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"uid\";}}s:16:\"users_field_data\";a:3:{s:11:\"primary key\";a:2:{i:0;s:3:\"uid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:36:\"user__id__default_langcode__langcode\";a:3:{i:0;s:3:\"uid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}s:11:\"unique keys\";a:1:{s:10:\"user__name\";a:2:{i:0;s:4:\"name\";i:1;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.access',_binary 'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:6:\"access\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:18:\"user_field__access\";a:1:{i:0;s:6:\"access\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.changed',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.created',_binary 'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"user_field__created\";a:1:{i:0;s:7:\"created\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.default_langcode',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.init',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"init\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.langcode',_binary 'a:2:{s:5:\"users\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.login',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"login\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.mail',_binary 'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"mail\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:16:\"user_field__mail\";a:1:{i:0;s:4:\"mail\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.name',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:60;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.pass',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"pass\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.preferred_admin_langcode',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:24:\"preferred_admin_langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.preferred_langcode',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:18:\"preferred_langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:0;}}}}');
INSERT INTO `key_value` VALUES ('entity.storage_schema.sql','user.field_schema_data.roles',_binary 'a:1:{s:11:\"user__roles\";a:4:{s:11:\"description\";s:34:\"Data storage for user field roles.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:15:\"roles_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:15:\"roles_target_id\";a:1:{i:0;s:15:\"roles_target_id\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.status',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.timezone',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"timezone\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.uid',_binary 'a:2:{s:5:\"users\";a:1:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.user_picture',_binary 'a:1:{s:18:\"user__user_picture\";a:5:{s:11:\"description\";s:41:\"Data storage for user field user_picture.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:22:\"user_picture_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:16:\"user_picture_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:18:\"user_picture_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:18:\"user_picture_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:19:\"user_picture_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"user_picture_target_id\";a:1:{i:0;s:22:\"user_picture_target_id\";}}s:12:\"foreign keys\";a:1:{s:22:\"user_picture_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:22:\"user_picture_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','user.field_schema_data.uuid',_binary 'a:1:{s:5:\"users\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"user_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','webform_submission.entity_schema_data',_binary 'a:2:{s:18:\"webform_submission\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"sid\";}}s:23:\"webform_submission_data\";a:2:{s:11:\"primary key\";a:4:{i:0;s:3:\"sid\";i:1;s:4:\"name\";i:2;s:8:\"property\";i:3;s:5:\"delta\";}s:7:\"indexes\";a:2:{s:10:\"webform_id\";a:1:{i:0;s:10:\"webform_id\";}s:14:\"sid_webform_id\";a:2:{i:0;s:3:\"sid\";i:1;s:10:\"webform_id\";}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.changed',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.completed',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:9:\"completed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.created',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.current_page',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:12:\"current_page\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.entity_id',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:9:\"entity_id\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.entity_type',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:11:\"entity_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.in_draft',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:8:\"in_draft\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.langcode',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.locked',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:6:\"locked\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.notes',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:5:\"notes\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.remote_addr',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:11:\"remote_addr\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.serial',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:6:\"serial\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.sid',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:3:\"sid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.sticky',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.token',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:5:\"token\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.uid',_binary 'a:1:{s:18:\"webform_submission\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:40:\"webform_submission_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.uri',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:3:\"uri\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2000;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.uuid',_binary 'a:1:{s:18:\"webform_submission\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:37:\"webform_submission_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.webform_id',_binary 'a:1:{s:18:\"webform_submission\";a:2:{s:6:\"fields\";a:1:{s:10:\"webform_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:47:\"webform_submission_field__webform_id__target_id\";a:1:{i:0;s:10:\"webform_id\";}}}}'),('entity_autocomplete','1RT8y00hnAegbkaPudRd6YNSms1XNHvM2c1YrFBVIR4',_binary 'a:4:{s:14:\"target_bundles\";N;s:11:\"auto_create\";i:0;s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('entity_autocomplete','2XDZ3WZw73Y9kz8zINAAoqxEP21BQ18RDPNosE-CqwI',_binary 'a:2:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('entity_autocomplete','mpfP6MRe74zWeoDZY2ZwHHQis-BMS4R54yzulVW88-4',_binary 'a:1:{s:17:\"include_anonymous\";b:0;}'),('entity_autocomplete','oCqAyICgycaLPyCC8BNsNQZgB6PNKexF5iPnrFBqfno',_binary 'a:0:{}'),('entity_autocomplete','s_Loi9pxw-H3eIRltdkO9vM8BPTQDIOXN-j95bVTQt0',_binary 'a:1:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}}'),('entity_autocomplete','TvzAUhftHwThqOCt8qicSUsWf_OzQQ0SDSVs6yU6vcI',_binary 'a:6:{s:14:\"target_bundles\";a:1:{s:4:\"page\";s:4:\"page\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('entity_autocomplete','ulRlcN57k02bDcfVxigoTUL10-L_7C_oc9uW_ONqlws',_binary 'a:4:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('entity_autocomplete','xUIbH_IjXNRLB3lbMNe7gNhIY7fMYTXmIHUOcmSMJDU',_binary 'a:5:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('media','oembed_providers',_binary 'a:2:{s:4:\"data\";a:330:{s:4:\"23HQ\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"23HQ\";s:6:\"\0*\0url\";s:19:\"http://www.23hq.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"http://www.23hq.com/23/oembed\";s:11:\"\0*\0provider\";r:3;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"http://www.23hq.com/*/photo/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:2:\"3Q\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:2:\"3Q\";s:6:\"\0*\0url\";s:17:\"https://3q.video/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://playout.3qsdn.com/oembed\";s:11:\"\0*\0provider\";r:14;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://playout.3qsdn.com/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Abraia\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Abraia\";s:6:\"\0*\0url\";s:17:\"https://abraia.me\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://api.abraia.me/oembed\";s:11:\"\0*\0provider\";r:25;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://store.abraia.me/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Acast\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Acast\";s:6:\"\0*\0url\";s:23:\"https://embed.acast.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://oembed.acast.com/v1/embed-player\";s:11:\"\0*\0provider\";r:36;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://play.acast.com/s/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"ActBlue\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"ActBlue\";s:6:\"\0*\0url\";s:26:\"https://secure.actblue.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://secure.actblue.com/cf/oembed\";s:11:\"\0*\0provider\";r:48;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"https://secure.actblue.com/donate/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Adilo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Adilo\";s:6:\"\0*\0url\";s:28:\"https://adilo.bigcommand.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://adilo.bigcommand.com/web/oembed\";s:11:\"\0*\0provider\";r:59;s:10:\"\0*\0schemes\";a:1:{i:0;s:36:\"https://adilo.bigcommand.com/watch/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"afreecaTV\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"afreecaTV\";s:6:\"\0*\0url\";s:26:\"https://www.sooplive.co.kr\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:47:\"https://openapi.sooplive.co.kr/oembed/embedinfo\";s:11:\"\0*\0provider\";r:71;s:10:\"\0*\0schemes\";a:5:{i:0;s:34:\"https://vod.sooplive.co.kr/player/\";i:1;s:22:\"https://v.afree.ca/ST/\";i:2;s:30:\"https://vod.sooplive.co.kr/ST/\";i:3;s:42:\"https://vod.sooplive.co.kr/PLAYER/STATION/\";i:4;s:28:\"https://play.sooplive.co.kr/\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Altium LLC\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Altium LLC\";s:6:\"\0*\0url\";s:18:\"https://altium.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://viewer.altium.com/shell/oembed\";s:11:\"\0*\0provider\";r:86;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://altium.com/viewer/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Altru\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Altru\";s:6:\"\0*\0url\";s:25:\"https://www.altrulabs.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:46:\"https://api.altrulabs.com/api/v1/social/oembed\";s:11:\"\0*\0provider\";r:98;s:10:\"\0*\0schemes\";a:2:{i:0;s:41:\"https://app.altrulabs.com/*/*?answer_id=*\";i:1;s:34:\"https://app.altrulabs.com/player/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:20:\"amCharts Live Editor\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:20:\"amCharts Live Editor\";s:6:\"\0*\0url\";s:26:\"https://live.amcharts.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://live.amcharts.com/oembed\";s:11:\"\0*\0provider\";r:111;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"http://live.amcharts.com/*\";i:1;s:27:\"https://live.amcharts.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"Amtraker\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Amtraker\";s:6:\"\0*\0url\";s:20:\"https://amtraker.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://api.amtraker.com/v3/oembed\";s:11:\"\0*\0provider\";r:123;s:10:\"\0*\0schemes\";a:4:{i:0;s:29:\"https://amtraker.com/trains/*\";i:1;s:31:\"https://amtraker.com/trains/*/*\";i:2;s:31:\"https://*.amtraker.com/trains/*\";i:3;s:33:\"https://*.amtraker.com/trains/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Animatron\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Animatron\";s:6:\"\0*\0url\";s:26:\"https://www.animatron.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://animatron.com/oembed/json\";s:11:\"\0*\0provider\";r:137;s:10:\"\0*\0schemes\";a:2:{i:0;s:35:\"https://www.animatron.com/project/*\";i:1;s:31:\"https://animatron.com/project/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Animoto\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Animoto\";s:6:\"\0*\0url\";s:19:\"http://animoto.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"http://animoto.com/oembeds/create\";s:11:\"\0*\0provider\";r:149;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"http://animoto.com/play/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"AnnieMusic\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"AnnieMusic\";s:6:\"\0*\0url\";s:22:\"https://anniemusic.app\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://api.anniemusic.app/api/v1/oembed\";s:11:\"\0*\0provider\";r:160;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://anniemusic.app/t/*\";i:1;s:26:\"https://anniemusic.app/p/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:16:\"ArcGIS StoryMaps\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"ArcGIS StoryMaps\";s:6:\"\0*\0url\";s:28:\"https://storymaps.arcgis.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://storymaps.arcgis.com/oembed\";s:11:\"\0*\0provider\";r:172;s:10:\"\0*\0schemes\";a:1:{i:0;s:38:\"https://storymaps.arcgis.com/stories/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Archivos\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Archivos\";s:6:\"\0*\0url\";s:28:\"https://app.archivos.digital\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://app.archivos.digital/oembed/\";s:11:\"\0*\0provider\";r:183;s:10:\"\0*\0schemes\";a:1:{i:0;s:39:\"https://app.archivos.digital/app/view/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"AssemblrWorld\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"AssemblrWorld\";s:6:\"\0*\0url\";s:26:\"https://assemblrworld.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://studio.assemblrworld.com/api/oembed\";s:11:\"\0*\0provider\";r:194;s:10:\"\0*\0schemes\";a:16:{i:0;s:44:\"http://*.studio.assemblrworld.com/creation/*\";i:1;s:42:\"http://studio.assemblrworld.com/creation/*\";i:2;s:45:\"http://*.app-edu.assemblrworld.com/Creation/*\";i:3;s:43:\"http://app-edu.assemblrworld.com/Creation/*\";i:4;s:23:\"http://assemblr.world/*\";i:5;s:33:\"http://editor.assemblrworld.com/*\";i:6;s:37:\"http://*.assemblrworld.com/creation/*\";i:7;s:37:\"http://*.assemblrworld.com/Creation/*\";i:8;s:45:\"https://*.studio.assemblrworld.com/creation/*\";i:9;s:43:\"https://studio.assemblrworld.com/creation/*\";i:10;s:46:\"https://*.app-edu.assemblrworld.com/Creation/*\";i:11;s:44:\"https://app-edu.assemblrworld.com/Creation/*\";i:12;s:24:\"https://assemblr.world/*\";i:13;s:34:\"https://editor.assemblrworld.com/*\";i:14;s:38:\"https://*.assemblrworld.com/creation/*\";i:15;s:38:\"https://*.assemblrworld.com/Creation/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"audio.com\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"audio.com\";s:6:\"\0*\0url\";s:18:\"https://audio.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://api.audio.com/oembed\";s:11:\"\0*\0provider\";r:220;s:10:\"\0*\0schemes\";a:4:{i:0;s:19:\"https://audio.com/*\";i:1;s:23:\"https://www.audio.com/*\";i:2;s:18:\"http://audio.com/*\";i:3;s:22:\"http://www.audio.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Audioboom\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Audioboom\";s:6:\"\0*\0url\";s:21:\"https://audioboom.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://audioboom.com/publishing/oembed.json\";s:11:\"\0*\0provider\";r:234;s:10:\"\0*\0schemes\";a:7:{i:0;s:32:\"https://audioboom.com/channels/*\";i:1;s:31:\"https://audioboom.com/channel/*\";i:2;s:33:\"https://audioboom.com/playlists/*\";i:3;s:32:\"https://audioboom.com/podcasts/*\";i:4;s:31:\"https://audioboom.com/podcast/*\";i:5;s:29:\"https://audioboom.com/posts/*\";i:6;s:32:\"https://audioboom.com/episodes/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:9:\"AudioClip\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"AudioClip\";s:6:\"\0*\0url\";s:27:\"https://audioclip.naver.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://audioclip.naver.com/oembed\";s:11:\"\0*\0provider\";r:253;s:10:\"\0*\0schemes\";a:2:{i:0;s:46:\"https://audioclip.naver.com/channels/*/clips/*\";i:1;s:40:\"https://audioclip.naver.com/audiobooks/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Audiomack\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Audiomack\";s:6:\"\0*\0url\";s:21:\"https://audiomack.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://audiomack.com/oembed\";s:11:\"\0*\0provider\";r:265;s:10:\"\0*\0schemes\";a:3:{i:0;s:30:\"https://audiomack.com/*/song/*\";i:1;s:31:\"https://audiomack.com/*/album/*\";i:2;s:34:\"https://audiomack.com/*/playlist/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Audiomeans\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Audiomeans\";s:6:\"\0*\0url\";s:21:\"https://audiomeans.fr\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:46:\"https://podcasts.audiomeans.fr/services/oembed\";s:11:\"\0*\0provider\";r:278;s:10:\"\0*\0schemes\";a:1:{i:0;s:32:\"https://podcasts.audiomeans.fr/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Backtracks\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Backtracks\";s:6:\"\0*\0url\";s:21:\"https://backtracks.fm\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://backtracks.fm/oembed\";s:11:\"\0*\0provider\";r:290;s:10:\"\0*\0schemes\";a:5:{i:0;s:29:\"https://backtracks.fm/*/*/e/*\";i:1;s:29:\"https://backtracks.fm/*/s/*/*\";i:2;s:35:\"https://backtracks.fm/*/*/*/*/e/*/*\";i:3;s:23:\"https://backtracks.fm/*\";i:4;s:22:\"http://backtracks.fm/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:14:\"Balsamiq Cloud\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Balsamiq Cloud\";s:6:\"\0*\0url\";s:23:\"https://balsamiq.cloud/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://balsamiq.cloud/oembed\";s:11:\"\0*\0provider\";r:305;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://balsamiq.cloud/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Beams.fm\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Beams.fm\";s:6:\"\0*\0url\";s:15:\"http://beams.fm\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://api.beams.fm/oEmbed\";s:11:\"\0*\0provider\";r:316;s:10:\"\0*\0schemes\";a:1:{i:0;s:18:\"https://beams.fm/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"Beautiful.AI\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Beautiful.AI\";s:6:\"\0*\0url\";s:25:\"https://www.beautiful.ai/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.beautiful.ai/api/oembed\";s:11:\"\0*\0provider\";r:327;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Behance\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Behance\";s:6:\"\0*\0url\";s:23:\"https://www.behance.net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://www.behance.net/services/oembed\";s:11:\"\0*\0provider\";r:337;s:10:\"\0*\0schemes\";a:2:{i:0;s:35:\"https://www.behance.net/gallery/*/*\";i:1;s:38:\"https://www.behance.net/*/services/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"biqnetwork\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"biqnetwork\";s:6:\"\0*\0url\";s:19:\"https://biqapp.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://biqapp.com/api/v1/video/oembed\";s:11:\"\0*\0provider\";r:350;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://cloud.biqapp.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Bitchute\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Bitchute\";s:6:\"\0*\0url\";s:21:\"https://bitchute.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://api.bitchute.com/oembed/\";s:11:\"\0*\0provider\";r:361;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"Blackfire.io\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Blackfire.io\";s:6:\"\0*\0url\";s:20:\"https://blackfire.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://blackfire.io/oembed\";s:11:\"\0*\0provider\";r:371;s:10:\"\0*\0schemes\";a:2:{i:0;s:37:\"https://blackfire.io/profiles/*/graph\";i:1;s:45:\"https://blackfire.io/profiles/compare/*/graph\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Blogcast\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Blogcast\";s:6:\"\0*\0url\";s:22:\"https://blogcast.host/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://blogcast.host/oembed\";s:11:\"\0*\0provider\";r:383;s:10:\"\0*\0schemes\";a:2:{i:0;s:29:\"https://blogcast.host/embed/*\";i:1;s:31:\"https://blogcast.host/embedly/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:14:\"Bluesky Social\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Bluesky Social\";s:6:\"\0*\0url\";s:16:\"https://bsky.app\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://embed.bsky.app/oembed\";s:11:\"\0*\0provider\";r:395;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://bsky.app/profile/*/post/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Bookingmood\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Bookingmood\";s:6:\"\0*\0url\";s:27:\"https://www.bookingmood.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://bookingmood.com/api/oembed\";s:11:\"\0*\0provider\";r:406;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://www.bookingmood.com/embed/*/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:14:\"Box Office Buz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Box Office Buz\";s:6:\"\0*\0url\";s:23:\"http://boxofficebuz.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"http://boxofficebuz.com/oembed\";s:11:\"\0*\0provider\";r:419;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"BrioVR\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"BrioVR\";s:6:\"\0*\0url\";s:24:\"https://view.briovr.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://view.briovr.com/api/v1/worlds/oembed/\";s:11:\"\0*\0provider\";r:429;s:10:\"\0*\0schemes\";a:1:{i:0;s:46:\"https://view.briovr.com/api/v1/worlds/oembed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Bumper\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Bumper\";s:6:\"\0*\0url\";s:21:\"http://www.bumper.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://www.bumper.com/oembed/bumper\";s:11:\"\0*\0provider\";r:440;s:10:\"\0*\0schemes\";a:2:{i:0;s:36:\"https://www.bumper.com/oembed/bumper\";i:1;s:38:\"https://www.bumper.com/oembed-s/bumper\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Bunny\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Bunny\";s:6:\"\0*\0url\";s:18:\"https://bunny.net/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://video.bunnycdn.com/OEmbed\";s:11:\"\0*\0provider\";r:452;s:10:\"\0*\0schemes\";a:4:{i:0;s:34:\"https://iframe.mediadelivery.net/*\";i:1;s:33:\"http://iframe.mediadelivery.net/*\";i:2;s:28:\"https://video.bunnycdn.com/*\";i:3;s:27:\"http://video.bunnycdn.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Buttondown\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Buttondown\";s:6:\"\0*\0url\";s:25:\"https://buttondown.email/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://buttondown.email/embed\";s:11:\"\0*\0provider\";r:467;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://buttondown.email/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:14:\"Byzart Project\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Byzart Project\";s:6:\"\0*\0url\";s:21:\"https://cmc.byzart.eu\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://cmc.byzart.eu/oembed/\";s:11:\"\0*\0provider\";r:479;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://cmc.byzart.eu/files/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Cacoo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Cacoo\";s:6:\"\0*\0url\";s:17:\"https://cacoo.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://cacoo.com/oembed.json\";s:11:\"\0*\0provider\";r:490;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://cacoo.com/diagrams/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Canva\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Canva\";s:6:\"\0*\0url\";s:21:\"https://www.canva.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://www.canva.com/_oembed\";s:11:\"\0*\0provider\";r:501;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"https://www.canva.com/design/*/view\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:13:\"Cardinal Blue\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Cardinal Blue\";s:6:\"\0*\0url\";s:26:\"https://minesweeper.today/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://minesweeper.today/api/oembed\";s:11:\"\0*\0provider\";r:512;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"http://minesweeper.today/*\";i:1;s:27:\"https://minesweeper.today/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"CatBoat\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"CatBoat\";s:6:\"\0*\0url\";s:20:\"http://img.catbo.at/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"http://img.catbo.at/oembed.json\";s:11:\"\0*\0provider\";r:524;s:10:\"\0*\0schemes\";a:1:{i:0;s:21:\"http://img.catbo.at/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Celero\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Celero\";s:6:\"\0*\0url\";s:21:\"https://www.celero.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://api.celero.io/api/oembed\";s:11:\"\0*\0provider\";r:536;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://embeds.celero.io/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Ceros\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Ceros\";s:6:\"\0*\0url\";s:21:\"http://www.ceros.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://view.ceros.com/oembed\";s:11:\"\0*\0provider\";r:548;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"http://view.ceros.com/*\";i:1;s:24:\"https://view.ceros.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Chainflix\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Chainflix\";s:6:\"\0*\0url\";s:21:\"https://chainflix.net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://www.chainflix.net/video/oembed\";s:11:\"\0*\0provider\";r:560;s:10:\"\0*\0schemes\";a:4:{i:0;s:29:\"https://chainflix.net/video/*\";i:1;s:35:\"https://chainflix.net/video/embed/*\";i:2;s:31:\"https://*.chainflix.net/video/*\";i:3;s:37:\"https://*.chainflix.net/video/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"ChartBlocks\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"ChartBlocks\";s:6:\"\0*\0url\";s:27:\"http://www.chartblocks.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"http://embed.chartblocks.com/1.0/oembed\";s:11:\"\0*\0provider\";r:574;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"http://public.chartblocks.com/c/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"chirbit.com\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"chirbit.com\";s:6:\"\0*\0url\";s:23:\"http://www.chirbit.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"http://chirb.it/oembed.json\";s:11:\"\0*\0provider\";r:585;s:10:\"\0*\0schemes\";a:1:{i:0;s:17:\"http://chirb.it/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"CHROCO\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"CHROCO\";s:6:\"\0*\0url\";s:19:\"https://chroco.ooo/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:24:\"https://chroco.ooo/embed\";s:11:\"\0*\0provider\";r:596;s:10:\"\0*\0schemes\";a:2:{i:0;s:27:\"https://chroco.ooo/mypage/*\";i:1;s:26:\"https://chroco.ooo/story/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"CircuitLab\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"CircuitLab\";s:6:\"\0*\0url\";s:27:\"https://www.circuitlab.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://www.circuitlab.com/circuit/oembed/\";s:11:\"\0*\0provider\";r:608;s:10:\"\0*\0schemes\";a:1:{i:0;s:36:\"https://www.circuitlab.com/circuit/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Clipland\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Clipland\";s:6:\"\0*\0url\";s:24:\"http://www.clipland.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.clipland.com/api/oembed\";s:11:\"\0*\0provider\";r:619;s:10:\"\0*\0schemes\";a:2:{i:0;s:27:\"http://www.clipland.com/v/*\";i:1;s:28:\"https://www.clipland.com/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Clyp\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Clyp\";s:6:\"\0*\0url\";s:15:\"http://clyp.it/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"http://api.clyp.it/oembed/\";s:11:\"\0*\0provider\";r:631;s:10:\"\0*\0schemes\";a:2:{i:0;s:16:\"http://clyp.it/*\";i:1;s:25:\"http://clyp.it/playlist/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"CoCo Corp\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"CoCo Corp\";s:6:\"\0*\0url\";s:23:\"https://ilovecoco.video\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://app.ilovecoco.video/api/oembed.json\";s:11:\"\0*\0provider\";r:643;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"https://app.ilovecoco.video/*/embed\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"CodeHS\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"CodeHS\";s:6:\"\0*\0url\";s:21:\"http://www.codehs.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:46:\"https://codehs.com/api/sharedprogram/1/oembed/\";s:11:\"\0*\0provider\";r:654;s:10:\"\0*\0schemes\";a:1:{i:0;s:40:\"https://codehs.com/editor/share_abacus/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"CodePen\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"CodePen\";s:6:\"\0*\0url\";s:18:\"https://codepen.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://codepen.io/api/oembed\";s:11:\"\0*\0provider\";r:665;s:10:\"\0*\0schemes\";a:2:{i:0;s:19:\"http://codepen.io/*\";i:1;s:20:\"https://codepen.io/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Codepoints\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Codepoints\";s:6:\"\0*\0url\";s:22:\"https://codepoints.net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://codepoints.net/api/v1/oembed\";s:11:\"\0*\0provider\";r:677;s:10:\"\0*\0schemes\";a:4:{i:0;s:23:\"http://codepoints.net/*\";i:1;s:24:\"https://codepoints.net/*\";i:2;s:27:\"http://www.codepoints.net/*\";i:3;s:28:\"https://www.codepoints.net/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"CodeSandbox\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"CodeSandbox\";s:6:\"\0*\0url\";s:22:\"https://codesandbox.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://codesandbox.io/oembed\";s:11:\"\0*\0provider\";r:691;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://codesandbox.io/s/*\";i:1;s:30:\"https://codesandbox.io/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"CollegeHumor\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"CollegeHumor\";s:6:\"\0*\0url\";s:28:\"http://www.collegehumor.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"http://www.collegehumor.com/oembed.json\";s:11:\"\0*\0provider\";r:703;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"http://www.collegehumor.com/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Commaful\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Commaful\";s:6:\"\0*\0url\";s:20:\"https://commaful.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://commaful.com/api/oembed/\";s:11:\"\0*\0provider\";r:714;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://commaful.com/play/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:4:\"Coub\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Coub\";s:6:\"\0*\0url\";s:16:\"http://coub.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"http://coub.com/api/oembed.json\";s:11:\"\0*\0provider\";r:725;s:10:\"\0*\0schemes\";a:2:{i:0;s:22:\"http://coub.com/view/*\";i:1;s:23:\"http://coub.com/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"Crowd Ranking\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Crowd Ranking\";s:6:\"\0*\0url\";s:23:\"http://crowdranking.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"http://crowdranking.com/api/oembed.json\";s:11:\"\0*\0provider\";r:737;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"http://crowdranking.com/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"Crumb.sh\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Crumb.sh\";s:6:\"\0*\0url\";s:16:\"https://crumb.sh\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:24:\"https://crumb.sh/oembed/\";s:11:\"\0*\0provider\";r:748;s:10:\"\0*\0schemes\";a:1:{i:0;s:18:\"https://crumb.sh/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:16:\"Cueup DJ Booking\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"Cueup DJ Booking\";s:6:\"\0*\0url\";s:16:\"https://cueup.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://gql.cueup.io/oembed\";s:11:\"\0*\0provider\";r:759;s:10:\"\0*\0schemes\";a:1:{i:0;s:32:\"https://cueup.io/user/*/sounds/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Curated\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Curated\";s:6:\"\0*\0url\";s:19:\"https://curated.co/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://api.curated.co/oembed\";s:11:\"\0*\0provider\";r:770;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://*.curated.co/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"CustomerDB\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"CustomerDB\";s:6:\"\0*\0url\";s:22:\"http://customerdb.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://app.customerdb.com/embed\";s:11:\"\0*\0provider\";r:782;s:10:\"\0*\0schemes\";a:1:{i:0;s:34:\"https://app.customerdb.com/share/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"dadan\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"dadan\";s:6:\"\0*\0url\";s:20:\"https://www.dadan.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://app.dadan.io/api/video/oembed\";s:11:\"\0*\0provider\";r:793;s:10:\"\0*\0schemes\";a:2:{i:0;s:22:\"https://app.dadan.io/*\";i:1;s:24:\"https://stage.dadan.io/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Dailymotion\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Dailymotion\";s:6:\"\0*\0url\";s:27:\"https://www.dailymotion.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://www.dailymotion.com/services/oembed\";s:11:\"\0*\0provider\";r:807;s:10:\"\0*\0schemes\";a:2:{i:0;s:35:\"https://www.dailymotion.com/video/*\";i:1;s:47:\"https://geo.dailymotion.com/player.html?video=*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"DALEXNI\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"DALEXNI\";s:6:\"\0*\0url\";s:20:\"https://dalexni.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://dalexni.com/oembed/\";s:11:\"\0*\0provider\";r:819;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://dalexni.com/i/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Datawrapper\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Datawrapper\";s:6:\"\0*\0url\";s:25:\"http://www.datawrapper.de\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://api.datawrapper.de/v3/oembed/\";s:11:\"\0*\0provider\";r:830;s:10:\"\0*\0schemes\";a:1:{i:0;s:31:\"https://datawrapper.dwcdn.net/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"Deseret News\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Deseret News\";s:6:\"\0*\0url\";s:23:\"https://www.deseret.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://embed.deseret.com/\";s:11:\"\0*\0provider\";r:841;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://*.deseret.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:14:\"Deviantart.com\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Deviantart.com\";s:6:\"\0*\0url\";s:25:\"http://www.deviantart.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"http://backend.deviantart.com/oembed\";s:11:\"\0*\0provider\";r:852;s:10:\"\0*\0schemes\";a:8:{i:0;s:29:\"http://*.deviantart.com/art/*\";i:1;s:29:\"http://*.deviantart.com/*#/d*\";i:2;s:15:\"http://fav.me/*\";i:3;s:15:\"http://sta.sh/*\";i:4;s:30:\"https://*.deviantart.com/art/*\";i:5;s:32:\"https://*.deviantart.com/*/art/*\";i:6;s:16:\"https://sta.sh/*\";i:7;s:30:\"https://*.deviantart.com/*#/d*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"Digiteka\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Digiteka\";s:6:\"\0*\0url\";s:26:\"https://www.ultimedia.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://www.ultimedia.com/api/search/oembed\";s:11:\"\0*\0provider\";r:870;s:10:\"\0*\0schemes\";a:3:{i:0;s:61:\"https://www.ultimedia.com/central/video/edit/id/*/topic_id/*/\";i:1;s:78:\"https://www.ultimedia.com/default/index/videogeneric/id/*/showtitle/1/viewnc/1\";i:2;s:57:\"https://www.ultimedia.com/default/index/videogeneric/id/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"DocDroid\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"DocDroid\";s:6:\"\0*\0url\";s:25:\"https://www.docdroid.net/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.docdroid.net/api/oembed\";s:11:\"\0*\0provider\";r:883;s:10:\"\0*\0schemes\";a:6:{i:0;s:24:\"https://*.docdroid.net/*\";i:1;s:23:\"http://*.docdroid.net/*\";i:2;s:19:\"https://docdro.id/*\";i:3;s:18:\"http://docdro.id/*\";i:4;s:24:\"https://*.docdroid.com/*\";i:5;s:23:\"http://*.docdroid.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Docswell\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Docswell\";s:6:\"\0*\0url\";s:20:\"https://docswell.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://www.docswell.com/service/oembed\";s:11:\"\0*\0provider\";r:900;s:10:\"\0*\0schemes\";a:4:{i:0;s:25:\"http://docswell.com/s/*/*\";i:1;s:26:\"https://docswell.com/s/*/*\";i:2;s:29:\"http://www.docswell.com/s/*/*\";i:3;s:30:\"https://www.docswell.com/s/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Dotsub\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Dotsub\";s:6:\"\0*\0url\";s:18:\"http://dotsub.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"http://dotsub.com/services/oembed\";s:11:\"\0*\0provider\";r:915;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"http://dotsub.com/view/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"Dream Broker\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Dream Broker\";s:6:\"\0*\0url\";s:23:\"https://dreambroker.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://dreambroker.com/channel/oembed\";s:11:\"\0*\0provider\";r:926;s:10:\"\0*\0schemes\";a:1:{i:0;s:39:\"https://www.dreambroker.com/channel/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"DTube\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"DTube\";s:6:\"\0*\0url\";s:15:\"https://d.tube/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://api.d.tube/oembed\";s:11:\"\0*\0provider\";r:937;s:10:\"\0*\0schemes\";a:1:{i:0;s:18:\"https://d.tube/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"EchoesHQ\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"EchoesHQ\";s:6:\"\0*\0url\";s:20:\"https://echoeshq.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://api.echoeshq.com/oembed\";s:11:\"\0*\0provider\";r:948;s:10:\"\0*\0schemes\";a:1:{i:0;s:31:\"http://app.echoeshq.com/embed/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"eduMedia\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"eduMedia\";s:6:\"\0*\0url\";s:34:\"https://www.edumedia-sciences.com/\";s:12:\"\0*\0endpoints\";a:2:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://www.edumedia-sciences.com/oembed.json\";s:11:\"\0*\0provider\";r:961;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}i:1;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://www.edumedia-sciences.com/oembed.xml\";s:11:\"\0*\0provider\";r:961;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"EgliseInfo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"EgliseInfo\";s:6:\"\0*\0url\";s:32:\"http://egliseinfo.catholique.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"http://egliseinfo.catholique.fr/api/oembed\";s:11:\"\0*\0provider\";r:977;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"http://egliseinfo.catholique.fr/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Embedery\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Embedery\";s:6:\"\0*\0url\";s:21:\"https://embedery.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://embedery.com/api/oembed\";s:11:\"\0*\0provider\";r:988;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://embedery.com/widget/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Ethfiddle\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Ethfiddle\";s:6:\"\0*\0url\";s:26:\"https://www.ethfiddle.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://ethfiddle.com/services/oembed/\";s:11:\"\0*\0provider\";r:999;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://ethfiddle.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"EventLive\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"EventLive\";s:6:\"\0*\0url\";s:21:\"https://eventlive.pro\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://evt.live/api/oembed\";s:11:\"\0*\0provider\";r:1010;s:10:\"\0*\0schemes\";a:4:{i:0;s:18:\"https://evt.live/*\";i:1;s:20:\"https://evt.live/*/*\";i:2;s:28:\"https://live.eventlive.pro/*\";i:3;s:30:\"https://live.eventlive.pro/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"everviz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"everviz\";s:6:\"\0*\0url\";s:19:\"https://everviz.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://api.everviz.com/oembed\";s:11:\"\0*\0provider\";r:1024;s:10:\"\0*\0schemes\";a:2:{i:0;s:31:\"https://app.everviz.com/embed/*\";i:1;s:30:\"http://app.everviz.com/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Ex.Co\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Ex.Co\";s:6:\"\0*\0url\";s:13:\"https://ex.co\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://oembed.ex.co/item\";s:11:\"\0*\0provider\";r:1036;s:10:\"\0*\0schemes\";a:2:{i:0;s:27:\"https://app.ex.co/stories/*\";i:1;s:26:\"https://www.playbuzz.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Eyrie\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Eyrie\";s:6:\"\0*\0url\";s:17:\"https://eyrie.io/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://eyrie.io/v1/oembed\";s:11:\"\0*\0provider\";r:1048;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"https://eyrie.io/board/*\";i:1;s:27:\"https://eyrie.io/sparkfun/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Facebook\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Facebook\";s:6:\"\0*\0url\";s:25:\"https://www.facebook.com/\";s:12:\"\0*\0endpoints\";a:3:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://graph.facebook.com/v16.0/oembed_post\";s:11:\"\0*\0provider\";r:1060;s:10:\"\0*\0schemes\";a:9:{i:0;s:34:\"https://www.facebook.com/*/posts/*\";i:1;s:37:\"https://www.facebook.com/*/activity/*\";i:2;s:35:\"https://www.facebook.com/*/photos/*\";i:3;s:41:\"https://www.facebook.com/photo.php?fbid=*\";i:4;s:33:\"https://www.facebook.com/photos/*\";i:5;s:51:\"https://www.facebook.com/permalink.php?story_fbid=*\";i:6;s:40:\"https://www.facebook.com/media/set?set=*\";i:7;s:36:\"https://www.facebook.com/questions/*\";i:8;s:36:\"https://www.facebook.com/notes/*/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}i:1;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://graph.facebook.com/v16.0/oembed_video\";s:11:\"\0*\0provider\";r:1060;s:10:\"\0*\0schemes\";a:3:{i:0;s:35:\"https://www.facebook.com/*/videos/*\";i:1;s:39:\"https://www.facebook.com/video.php?id=*\";i:2;s:38:\"https://www.facebook.com/video.php?v=*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}i:2;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://graph.facebook.com/v16.0/oembed_page\";s:11:\"\0*\0provider\";r:1060;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://www.facebook.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Fader\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Fader\";s:6:\"\0*\0url\";s:24:\"https://app.getfader.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://app.getfader.com/api/oembed\";s:11:\"\0*\0provider\";r:1095;s:10:\"\0*\0schemes\";a:1:{i:0;s:43:\"https://app.getfader.com/projects/*/publish\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"Faithlife TV\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Faithlife TV\";s:6:\"\0*\0url\";s:23:\"https://faithlifetv.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://faithlifetv.com/api/oembed\";s:11:\"\0*\0provider\";r:1107;s:10:\"\0*\0schemes\";a:5:{i:0;s:31:\"https://faithlifetv.com/items/*\";i:1;s:42:\"https://faithlifetv.com/items/resource/*/*\";i:2;s:31:\"https://faithlifetv.com/media/*\";i:3;s:38:\"https://faithlifetv.com/media/assets/*\";i:4;s:42:\"https://faithlifetv.com/media/resource/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Figma\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Figma\";s:6:\"\0*\0url\";s:21:\"https://www.figma.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://www.figma.com/api/oembed\";s:11:\"\0*\0provider\";r:1122;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://www.figma.com/file/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Firework\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Firework\";s:6:\"\0*\0url\";s:23:\"https://fireworktv.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.fireworktv.com/oembed\";s:11:\"\0*\0provider\";r:1133;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://*.fireworktv.com/*\";i:1;s:36:\"https://*.fireworktv.com/embed/*/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"FITE\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"FITE\";s:6:\"\0*\0url\";s:20:\"https://www.fite.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://www.fite.tv/oembed\";s:11:\"\0*\0provider\";r:1145;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://www.fite.tv/watch/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Flat\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Flat\";s:6:\"\0*\0url\";s:15:\"https://flat.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://flat.io/services/oembed\";s:11:\"\0*\0provider\";r:1156;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"https://flat.io/score/*\";i:1;s:25:\"https://*.flat.io/score/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Flickr\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Flickr\";s:6:\"\0*\0url\";s:23:\"https://www.flickr.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://www.flickr.com/services/oembed/\";s:11:\"\0*\0provider\";r:1168;s:10:\"\0*\0schemes\";a:8:{i:0;s:28:\"http://*.flickr.com/photos/*\";i:1;s:18:\"http://flic.kr/p/*\";i:2;s:18:\"http://flic.kr/s/*\";i:3;s:29:\"https://*.flickr.com/photos/*\";i:4;s:19:\"https://flic.kr/p/*\";i:5;s:19:\"https://flic.kr/s/*\";i:6;s:26:\"https://*.*.flickr.com/*/*\";i:7;s:25:\"http://*.*.flickr.com/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Flourish\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Flourish\";s:6:\"\0*\0url\";s:24:\"https://flourish.studio/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://app.flourish.studio/api/v1/oembed\";s:11:\"\0*\0provider\";r:1186;s:10:\"\0*\0schemes\";a:2:{i:0;s:46:\"https://public.flourish.studio/visualisation/*\";i:1;s:38:\"https://public.flourish.studio/story/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"FlowHubOrg\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"FlowHubOrg\";s:6:\"\0*\0url\";s:25:\"https://flows.flowhub.org\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://flowhub.org/o/embed\";s:11:\"\0*\0provider\";r:1198;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"https://flowhub.org/f/*\";i:1;s:23:\"https://flowhub.org/s/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Fooday\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Fooday\";s:6:\"\0*\0url\";s:18:\"https://fooday.app\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://fooday.app/oembed\";s:11:\"\0*\0provider\";r:1210;s:10:\"\0*\0schemes\";a:2:{i:0;s:30:\"https://fooday.app/*/reviews/*\";i:1;s:28:\"https://fooday.app/*/spots/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:20:\"FOX SPORTS Australia\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:20:\"FOX SPORTS Australia\";s:6:\"\0*\0url\";s:27:\"http://www.foxsports.com.au\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://fiso.foxsports.com.au/oembed\";s:11:\"\0*\0provider\";r:1222;s:10:\"\0*\0schemes\";a:2:{i:0;s:48:\"http://fiso.foxsports.com.au/isomorphic-widget/*\";i:1;s:49:\"https://fiso.foxsports.com.au/isomorphic-widget/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:9:\"Framatube\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Framatube\";s:6:\"\0*\0url\";s:22:\"https://framatube.org/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://framatube.org/services/oembed\";s:11:\"\0*\0provider\";r:1234;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://framatube.org/w/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:9:\"FrameBuzz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"FrameBuzz\";s:6:\"\0*\0url\";s:22:\"https://framebuzz.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://framebuzz.com/oembed/\";s:11:\"\0*\0provider\";r:1245;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"http://framebuzz.com/v/*\";i:1;s:25:\"https://framebuzz.com/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Framer\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Framer\";s:6:\"\0*\0url\";s:22:\"https://www.framer.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://api.framer.com/web/oembed\";s:11:\"\0*\0provider\";r:1257;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://framer.com/share/*\";i:1;s:26:\"https://framer.com/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:28:\"Geograph Britain and Ireland\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:28:\"Geograph Britain and Ireland\";s:6:\"\0*\0url\";s:28:\"https://www.geograph.org.uk/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"http://api.geograph.org.uk/api/oembed\";s:11:\"\0*\0provider\";r:1269;s:10:\"\0*\0schemes\";a:4:{i:0;s:26:\"http://*.geograph.org.uk/*\";i:1;s:25:\"http://*.geograph.co.uk/*\";i:2;s:22:\"http://*.geograph.ie/*\";i:3;s:42:\"http://*.wikimedia.org/*_geograph.org.uk_*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:24:\"Geograph Channel Islands\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:24:\"Geograph Channel Islands\";s:6:\"\0*\0url\";s:36:\"http://channel-islands.geograph.org/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"http://www.geograph.org.gg/api/oembed\";s:11:\"\0*\0provider\";r:1283;s:10:\"\0*\0schemes\";a:5:{i:0;s:26:\"http://*.geograph.org.gg/*\";i:1;s:26:\"http://*.geograph.org.je/*\";i:2;s:37:\"http://channel-islands.geograph.org/*\";i:3;s:38:\"http://channel-islands.geographs.org/*\";i:4;s:32:\"http://*.channel.geographs.org/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:16:\"Geograph Germany\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"Geograph Germany\";s:6:\"\0*\0url\";s:23:\"http://geo-en.hlipp.de/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"http://geo.hlipp.de/restapi.php/api/oembed\";s:11:\"\0*\0provider\";r:1298;s:10:\"\0*\0schemes\";a:3:{i:0;s:24:\"http://geo-en.hlipp.de/*\";i:1;s:21:\"http://geo.hlipp.de/*\";i:2;s:29:\"http://germany.geograph.org/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"Getty Images\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Getty Images\";s:6:\"\0*\0url\";s:27:\"http://www.gettyimages.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"http://embed.gettyimages.com/oembed\";s:11:\"\0*\0provider\";r:1311;s:10:\"\0*\0schemes\";a:1:{i:0;s:15:\"http://gty.im/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Gifnote\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Gifnote\";s:6:\"\0*\0url\";s:24:\"https://www.gifnote.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://www.gifnote.com/services/oembed\";s:11:\"\0*\0provider\";r:1323;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://www.gifnote.com/play/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"GIPHY\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"GIPHY\";s:6:\"\0*\0url\";s:17:\"https://giphy.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://giphy.com/services/oembed\";s:11:\"\0*\0provider\";r:1334;s:10:\"\0*\0schemes\";a:4:{i:0;s:24:\"https://giphy.com/gifs/*\";i:1;s:25:\"https://giphy.com/clips/*\";i:2;s:15:\"http://gph.is/*\";i:3;s:41:\"https://media.giphy.com/media/*/giphy.gif\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"GloriaTV\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"GloriaTV\";s:6:\"\0*\0url\";s:18:\"https://gloria.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://gloria.tv/oembed/\";s:11:\"\0*\0provider\";r:1348;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"GMetri\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"GMetri\";s:6:\"\0*\0url\";s:23:\"https://www.gmetri.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://embed.gmetri.com/oembed/\";s:11:\"\0*\0provider\";r:1358;s:10:\"\0*\0schemes\";a:2:{i:0;s:25:\"https://view.gmetri.com/*\";i:1;s:22:\"https://*.gmetri.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Gong\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Gong\";s:6:\"\0*\0url\";s:20:\"https://www.gong.io/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://app.gong.io/oembed\";s:11:\"\0*\0provider\";r:1370;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://app.gong.io/call?id=*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Grain\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Grain\";s:6:\"\0*\0url\";s:17:\"https://grain.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://api.grain.com/_/api/oembed\";s:11:\"\0*\0provider\";r:1382;s:10:\"\0*\0schemes\";a:3:{i:0;s:28:\"https://grain.co/highlight/*\";i:1;s:24:\"https://grain.co/share/*\";i:2;s:25:\"https://grain.com/share/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"GT Channel\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"GT Channel\";s:6:\"\0*\0url\";s:21:\"https://gtchannel.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://api.luminery.com/oembed\";s:11:\"\0*\0provider\";r:1395;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://gtchannel.com/watch/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Gumlet\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Gumlet\";s:6:\"\0*\0url\";s:23:\"https://www.gumlet.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://api.gumlet.com/v1/oembed\";s:11:\"\0*\0provider\";r:1406;s:10:\"\0*\0schemes\";a:3:{i:0;s:25:\"https://gumlet.tv/watch/*\";i:1;s:30:\"https://www.gumlet.com/watch/*\";i:2;s:30:\"https://play.gumlet.io/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Gyazo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Gyazo\";s:6:\"\0*\0url\";s:17:\"https://gyazo.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://api.gyazo.com/api/oembed\";s:11:\"\0*\0provider\";r:1419;s:10:\"\0*\0schemes\";a:1:{i:0;s:19:\"https://gyazo.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:4:\"HASH\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"HASH\";s:6:\"\0*\0url\";s:15:\"https://hash.ai\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://api.hash.ai/oembed\";s:11:\"\0*\0provider\";r:1431;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://core.hash.ai/@*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"hearthis.at\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"hearthis.at\";s:6:\"\0*\0url\";s:20:\"https://hearthis.at/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://hearthis.at/oembed/?format=json\";s:11:\"\0*\0provider\";r:1442;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"https://hearthis.at/*/*/\";i:1;s:28:\"https://hearthis.at/*/set/*/\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Heyzine\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Heyzine\";s:6:\"\0*\0url\";s:19:\"https://heyzine.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://heyzine.com/api1/oembed\";s:11:\"\0*\0provider\";r:1454;s:10:\"\0*\0schemes\";a:3:{i:0;s:31:\"https://heyzine.com/flip-book/*\";i:1;s:20:\"https://*.hflip.co/*\";i:2;s:20:\"https://*.aflip.in/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"hihaho\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"hihaho\";s:6:\"\0*\0url\";s:22:\"https://www.hihaho.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://player.hihaho.com/services/oembed\";s:11:\"\0*\0provider\";r:1467;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://player.hihaho.com/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"HippoVideo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"HippoVideo\";s:6:\"\0*\0url\";s:21:\"https://hippovideo.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://www.hippovideo.io/services/oembed\";s:11:\"\0*\0provider\";r:1480;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"http://*.hippovideo.io/*\";i:1;s:25:\"https://*.hippovideo.io/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Homey\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Homey\";s:6:\"\0*\0url\";s:17:\"https://homey.app\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://homey.app/api/oembed/flow\";s:11:\"\0*\0provider\";r:1492;s:10:\"\0*\0schemes\";a:2:{i:0;s:21:\"https://homey.app/f/*\";i:1;s:26:\"https://homey.app/*/flow/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Hopvue\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Hopvue\";s:6:\"\0*\0url\";s:22:\"https://www.hopvue.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://portal.hopvue.com/api/oembed/\";s:11:\"\0*\0provider\";r:1504;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://*.hopvue.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"HuffDuffer\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"HuffDuffer\";s:6:\"\0*\0url\";s:21:\"http://huffduffer.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://huffduffer.com/oembed\";s:11:\"\0*\0provider\";r:1515;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"http://huffduffer.com/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:4:\"Hulu\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Hulu\";s:6:\"\0*\0url\";s:20:\"http://www.hulu.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"http://www.hulu.com/api/oembed.json\";s:11:\"\0*\0provider\";r:1526;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"http://www.hulu.com/watch/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Ideamapper\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Ideamapper\";s:6:\"\0*\0url\";s:23:\"https://ideamapper.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://oembed.ideamapper.com/oembed\";s:11:\"\0*\0provider\";r:1537;s:10:\"\0*\0schemes\";a:1:{i:0;s:31:\"https://oembed.ideamapper.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Idomoo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Idomoo\";s:6:\"\0*\0url\";s:19:\"https://idomoo.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://oembed.idomoo.com/oembed\";s:11:\"\0*\0provider\";r:1548;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://*.idomoo.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"iFixit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"iFixit\";s:6:\"\0*\0url\";s:21:\"http://www.iFixit.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"http://www.ifixit.com/Embed\";s:11:\"\0*\0provider\";r:1560;s:10:\"\0*\0schemes\";a:1:{i:0;s:34:\"http://www.ifixit.com/Guide/View/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"IFTTT\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"IFTTT\";s:6:\"\0*\0url\";s:21:\"http://www.ifttt.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://www.ifttt.com/oembed/\";s:11:\"\0*\0provider\";r:1571;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"http://ifttt.com/recipes/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"iHeartRadio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"iHeartRadio\";s:6:\"\0*\0url\";s:22:\"https://www.iheart.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://www.iheart.com/oembed\";s:11:\"\0*\0provider\";r:1582;s:10:\"\0*\0schemes\";a:1:{i:0;s:34:\"https://www.iheart.com/podcast/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"iMenuPro\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"iMenuPro\";s:6:\"\0*\0url\";s:20:\"https://imenupro.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://qr.imenupro.com/api/oembed\";s:11:\"\0*\0provider\";r:1593;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"http://qr.imenupro.com/*\";i:1;s:25:\"https://qr.imenupro.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Incredible\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Incredible\";s:6:\"\0*\0url\";s:22:\"https://incredible.dev\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://oembed.incredible.dev/oembed\";s:11:\"\0*\0provider\";r:1606;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://incredible.dev/watch/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Indaco\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Indaco\";s:6:\"\0*\0url\";s:30:\"https://player.indacolive.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://player.indacolive.com/services/oembed\";s:11:\"\0*\0provider\";r:1618;s:10:\"\0*\0schemes\";a:1:{i:0;s:50:\"https://player.indacolive.com/player/jwp/clients/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"Infogram\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Infogram\";s:6:\"\0*\0url\";s:21:\"https://infogram.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://infogram.com/oembed\";s:11:\"\0*\0provider\";r:1630;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://infogram.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:9:\"Infoveave\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Infoveave\";s:6:\"\0*\0url\";s:22:\"https://infoveave.net/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://infoveave.net/services/oembed/\";s:11:\"\0*\0provider\";r:1641;s:10:\"\0*\0schemes\";a:2:{i:0;s:27:\"https://*.infoveave.net/E/*\";i:1;s:27:\"https://*.infoveave.net/P/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Injurymap\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Injurymap\";s:6:\"\0*\0url\";s:26:\"https://www.injurymap.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://www.injurymap.com/services/oembed\";s:11:\"\0*\0provider\";r:1653;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://www.injurymap.com/exercises/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Inoreader\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Inoreader\";s:6:\"\0*\0url\";s:25:\"https://www.inoreader.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://www.inoreader.com/oembed/api/\";s:11:\"\0*\0provider\";r:1664;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://www.inoreader.com/oembed/\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"inphood\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"inphood\";s:6:\"\0*\0url\";s:19:\"http://inphood.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"http://api.inphood.com/oembed\";s:11:\"\0*\0provider\";r:1675;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"http://*.inphood.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"Insight Timer\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Insight Timer\";s:6:\"\0*\0url\";s:25:\"https://insighttimer.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:48:\"https://widgets.insighttimer.com/services/oembed\";s:11:\"\0*\0provider\";r:1687;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://insighttimer.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Instagram\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Instagram\";s:6:\"\0*\0url\";s:21:\"https://instagram.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:49:\"https://graph.facebook.com/v16.0/instagram_oembed\";s:11:\"\0*\0provider\";r:1698;s:10:\"\0*\0schemes\";a:26:{i:0;s:27:\"http://instagram.com/*/p/*,\";i:1;s:31:\"http://www.instagram.com/*/p/*,\";i:2;s:28:\"https://instagram.com/*/p/*,\";i:3;s:32:\"https://www.instagram.com/*/p/*,\";i:4;s:24:\"http://instagram.com/p/*\";i:5;s:21:\"http://instagr.am/p/*\";i:6;s:28:\"http://www.instagram.com/p/*\";i:7;s:25:\"http://www.instagr.am/p/*\";i:8;s:25:\"https://instagram.com/p/*\";i:9;s:22:\"https://instagr.am/p/*\";i:10;s:29:\"https://www.instagram.com/p/*\";i:11;s:26:\"https://www.instagr.am/p/*\";i:12;s:25:\"http://instagram.com/tv/*\";i:13;s:22:\"http://instagr.am/tv/*\";i:14;s:29:\"http://www.instagram.com/tv/*\";i:15;s:26:\"http://www.instagr.am/tv/*\";i:16;s:26:\"https://instagram.com/tv/*\";i:17;s:23:\"https://instagr.am/tv/*\";i:18;s:30:\"https://www.instagram.com/tv/*\";i:19;s:27:\"https://www.instagr.am/tv/*\";i:20;s:31:\"http://www.instagram.com/reel/*\";i:21;s:32:\"https://www.instagram.com/reel/*\";i:22;s:27:\"http://instagram.com/reel/*\";i:23;s:28:\"https://instagram.com/reel/*\";i:24;s:24:\"http://instagr.am/reel/*\";i:25;s:25:\"https://instagr.am/reel/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:14:\"Insticator Inc\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Insticator Inc\";s:6:\"\0*\0url\";s:27:\"https://www.insticator.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.insticator.com/oembed\";s:11:\"\0*\0provider\";r:1735;s:10:\"\0*\0schemes\";a:1:{i:0;s:39:\"https://ppa.insticator.com/embed-unit/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Issuu\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Issuu\";s:6:\"\0*\0url\";s:18:\"https://issuu.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:24:\"https://issuu.com/oembed\";s:11:\"\0*\0provider\";r:1746;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://issuu.com/*/docs/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:16:\"Itabtech infosys\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"Itabtech infosys\";s:6:\"\0*\0url\";s:34:\"https://samay.itabtechinfosys.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://samay.itabtechinfosys.com/oembed/\";s:11:\"\0*\0provider\";r:1757;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"https://samay.itabtechinfosys.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:13:\"itemis CREATE\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"itemis CREATE\";s:6:\"\0*\0url\";s:22:\"https://play.itemis.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:46:\"https://create.storage.api.itemis.io/api/embed\";s:11:\"\0*\0provider\";r:1768;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://play.itemis.io/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Jovian\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Jovian\";s:6:\"\0*\0url\";s:19:\"https://jovian.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://api.jovian.com/oembed.json\";s:11:\"\0*\0provider\";r:1779;s:10:\"\0*\0schemes\";a:9:{i:0;s:19:\"https://jovian.ml/*\";i:1;s:25:\"https://jovian.ml/viewer*\";i:2;s:21:\"https://*.jovian.ml/*\";i:3;s:19:\"https://jovian.ai/*\";i:4;s:25:\"https://jovian.ai/viewer*\";i:5;s:21:\"https://*.jovian.ai/*\";i:6;s:20:\"https://jovian.com/*\";i:7;s:26:\"https://jovian.com/viewer*\";i:8;s:22:\"https://*.jovian.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"KakaoTv\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"KakaoTv\";s:6:\"\0*\0url\";s:21:\"https://tv.kakao.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://tv.kakao.com/oembed\";s:11:\"\0*\0provider\";r:1798;s:10:\"\0*\0schemes\";a:6:{i:0;s:41:\"https://tv.kakao.com/channel/*/cliplink/*\";i:1;s:43:\"https://tv.kakao.com/m/channel/*/cliplink/*\";i:2;s:32:\"https://tv.kakao.com/channel/v/*\";i:3;s:41:\"https://tv.kakao.com/channel/*/livelink/*\";i:4;s:43:\"https://tv.kakao.com/m/channel/*/livelink/*\";i:5;s:32:\"https://tv.kakao.com/channel/l/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Kickstarter\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Kickstarter\";s:6:\"\0*\0url\";s:26:\"http://www.kickstarter.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"http://www.kickstarter.com/services/oembed\";s:11:\"\0*\0provider\";r:1814;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"http://www.kickstarter.com/projects/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Kidoju\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Kidoju\";s:6:\"\0*\0url\";s:23:\"https://www.kidoju.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.kidoju.com/api/oembed\";s:11:\"\0*\0provider\";r:1825;s:10:\"\0*\0schemes\";a:2:{i:0;s:31:\"https://www.kidoju.com/en/x/*/*\";i:1;s:31:\"https://www.kidoju.com/fr/x/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Kirim.Email\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Kirim.Email\";s:6:\"\0*\0url\";s:20:\"https://kirim.email/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://halaman.email/service/oembed\";s:11:\"\0*\0provider\";r:1837;s:10:\"\0*\0schemes\";a:2:{i:0;s:28:\"https://halaman.email/form/*\";i:1;s:35:\"https://aplikasi.kirim.email/form/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:3:\"Kit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:3:\"Kit\";s:6:\"\0*\0url\";s:15:\"https://kit.co/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://embed.kit.co/oembed\";s:11:\"\0*\0provider\";r:1849;s:10:\"\0*\0schemes\";a:2:{i:0;s:17:\"http://kit.co/*/*\";i:1;s:18:\"https://kit.co/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Kitchenbowl\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Kitchenbowl\";s:6:\"\0*\0url\";s:26:\"http://www.kitchenbowl.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"http://www.kitchenbowl.com/oembed\";s:11:\"\0*\0provider\";r:1861;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"http://www.kitchenbowl.com/recipe/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"kmdr\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"kmdr\";s:6:\"\0*\0url\";s:15:\"https://kmdr.sh\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://api.kmdr.sh/services/oembed\";s:11:\"\0*\0provider\";r:1872;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"https://app.kmdr.sh/h/*\";i:1;s:29:\"https://app.kmdr.sh/history/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Knacki\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Knacki\";s:6:\"\0*\0url\";s:22:\"http://jdr.knacki.info\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://jdr.knacki.info/oembed\";s:11:\"\0*\0provider\";r:1884;s:10:\"\0*\0schemes\";a:2:{i:0;s:29:\"http://jdr.knacki.info/meuh/*\";i:1;s:30:\"https://jdr.knacki.info/meuh/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"Knowledge Pad\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Knowledge Pad\";s:6:\"\0*\0url\";s:24:\"https://knowledgepad.co/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://api.spoonacular.com/knowledge/oembed\";s:11:\"\0*\0provider\";r:1896;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://knowledgepad.co/#/knowledge/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Kooapp\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Kooapp\";s:6:\"\0*\0url\";s:18:\"https://kooapp.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://embed.kooapp.com/services/oembed\";s:11:\"\0*\0provider\";r:1908;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://*.kooapp.com/koo/*\";i:1;s:25:\"http://*.kooapp.com/koo/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Kurozora\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Kurozora\";s:6:\"\0*\0url\";s:21:\"https://kurozora.app/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://kurozora.app/oembed\";s:11:\"\0*\0provider\";r:1920;s:10:\"\0*\0schemes\";a:2:{i:0;s:31:\"https://kurozora.app/episodes/*\";i:1;s:28:\"https://kurozora.app/songs/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:16:\"LearningApps.org\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"LearningApps.org\";s:6:\"\0*\0url\";s:24:\"http://learningapps.org/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"http://learningapps.org/oembed.php\";s:11:\"\0*\0provider\";r:1932;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"http://learningapps.org/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"LeMans.Pod\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"LeMans.Pod\";s:6:\"\0*\0url\";s:36:\"https://umotion-test.univ-lemans.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://umotion-test.univ-lemans.fr/oembed\";s:11:\"\0*\0provider\";r:1943;s:10:\"\0*\0schemes\";a:1:{i:0;s:43:\"https://umotion-test.univ-lemans.fr/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Lille.Pod\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Lille.Pod\";s:6:\"\0*\0url\";s:26:\"https://pod.univ-lille.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://pod.univ-lille.fr/video/oembed\";s:11:\"\0*\0provider\";r:1954;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://pod.univ-lille.fr/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Line Place\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Line Place\";s:6:\"\0*\0url\";s:21:\"https://place.line.me\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://place.line.me/oembed\";s:11:\"\0*\0provider\";r:1965;s:10:\"\0*\0schemes\";a:1:{i:0;s:34:\"https://place.line.me/businesses/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Linkstackz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Linkstackz\";s:6:\"\0*\0url\";s:27:\"https://www.linkstackz.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://api.linkstackz.com/oembed\";s:11:\"\0*\0provider\";r:1976;s:10:\"\0*\0schemes\";a:2:{i:0;s:28:\"https://linkstackz.com/irf/*\";i:1;s:29:\"https://linkstackz.com/post/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Livestream\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Livestream\";s:6:\"\0*\0url\";s:23:\"https://livestream.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://livestream.com/oembed\";s:11:\"\0*\0provider\";r:1988;s:10:\"\0*\0schemes\";a:6:{i:0;s:42:\"https://livestream.com/accounts/*/events/*\";i:1;s:51:\"https://livestream.com/accounts/*/events/*/videos/*\";i:2;s:33:\"https://livestream.com/*/events/*\";i:3;s:42:\"https://livestream.com/*/events/*/videos/*\";i:4;s:26:\"https://livestream.com/*/*\";i:5;s:35:\"https://livestream.com/*/*/videos/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Loom\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Loom\";s:6:\"\0*\0url\";s:21:\"https://www.loom.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://www.loom.com/v1/oembed\";s:11:\"\0*\0provider\";r:2004;s:10:\"\0*\0schemes\";a:2:{i:0;s:20:\"https://loom.com/i/*\";i:1;s:24:\"https://loom.com/share/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"LottieFiles\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"LottieFiles\";s:6:\"\0*\0url\";s:24:\"https://lottiefiles.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://embed.lottiefiles.com/oembed\";s:11:\"\0*\0provider\";r:2016;s:10:\"\0*\0schemes\";a:4:{i:0;s:25:\"https://lottiefiles.com/*\";i:1;s:27:\"https://*.lottiefiles.com/*\";i:2;s:23:\"https://*.lottie.host/*\";i:3;s:21:\"https://lottie.host/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Ludus\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Ludus\";s:6:\"\0*\0url\";s:17:\"https://ludus.one\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://app.ludus.one/oembed\";s:11:\"\0*\0provider\";r:2031;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://app.ludus.one/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Lumiere\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Lumiere\";s:6:\"\0*\0url\";s:16:\"https://latd.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://admin.lumiere.is/api/services/oembed\";s:11:\"\0*\0provider\";r:2043;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://*.lumiere.is/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"MathEmbed\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"MathEmbed\";s:6:\"\0*\0url\";s:20:\"http://mathembed.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"http://mathembed.com/oembed\";s:11:\"\0*\0provider\";r:2054;s:10:\"\0*\0schemes\";a:2:{i:0;s:38:\"http://mathembed.com/latex?inputText=*\";i:1;s:38:\"http://mathembed.com/latex?inputText=*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Matterport\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Matterport\";s:6:\"\0*\0url\";s:23:\"https://matterport.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:47:\"https://my.matterport.com/api/v1/models/oembed/\";s:11:\"\0*\0provider\";r:2066;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"me.me\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"me.me\";s:6:\"\0*\0url\";s:14:\"https://me.me/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:20:\"https://me.me/oembed\";s:11:\"\0*\0provider\";r:2077;s:10:\"\0*\0schemes\";a:1:{i:0;s:17:\"https://me.me/i/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Mediastream\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Mediastream\";s:6:\"\0*\0url\";s:19:\"https://mdstrm.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://mdstrm.com/oembed\";s:11:\"\0*\0provider\";r:2088;s:10:\"\0*\0schemes\";a:3:{i:0;s:26:\"https://mdstrm.com/embed/*\";i:1;s:32:\"https://mdstrm.com/live-stream/*\";i:2;s:26:\"https://mdstrm.com/image/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:58:\"Medienarchiv der Künste - Zürcher Hochschule der Künste\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:58:\"Medienarchiv der Künste - Zürcher Hochschule der Künste\";s:6:\"\0*\0url\";s:29:\"https://medienarchiv.zhdk.ch/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://medienarchiv.zhdk.ch/oembed.json\";s:11:\"\0*\0provider\";r:2101;s:10:\"\0*\0schemes\";a:1:{i:0;s:38:\"https://medienarchiv.zhdk.ch/entries/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Mermaid Ink\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Mermaid Ink\";s:6:\"\0*\0url\";s:19:\"https://mermaid.ink\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://mermaid.ink/services/oembed\";s:11:\"\0*\0provider\";r:2112;s:10:\"\0*\0schemes\";a:2:{i:0;s:25:\"https://mermaid.ink/img/*\";i:1;s:25:\"https://mermaid.ink/svg/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:16:\"Microsoft Stream\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"Microsoft Stream\";s:6:\"\0*\0url\";s:28:\"https://stream.microsoft.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://web.microsoftstream.com/oembed\";s:11:\"\0*\0provider\";r:2124;s:10:\"\0*\0schemes\";a:2:{i:0;s:37:\"https://*.microsoftstream.com/video/*\";i:1;s:39:\"https://*.microsoftstream.com/channel/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Minerva\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Minerva\";s:6:\"\0*\0url\";s:28:\"https://www.minervaknows.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://oembed.minervaknows.com\";s:11:\"\0*\0provider\";r:2136;s:10:\"\0*\0schemes\";a:5:{i:0;s:47:\"https://www.minervaknows.com/featured-recipes/*\";i:1;s:37:\"https://www.minervaknows.com/themes/*\";i:2;s:47:\"https://www.minervaknows.com/themes/*/recipes/*\";i:3;s:38:\"https://app.minervaknows.com/recipes/*\";i:4;s:45:\"https://app.minervaknows.com/recipes/*/follow\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Miro\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Miro\";s:6:\"\0*\0url\";s:17:\"https://miro.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://miro.com/api/v1/oembed\";s:11:\"\0*\0provider\";r:2152;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://miro.com/app/board/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"MixCloud\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"MixCloud\";s:6:\"\0*\0url\";s:21:\"https://mixcloud.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://www.mixcloud.com/oembed/\";s:11:\"\0*\0provider\";r:2163;s:10:\"\0*\0schemes\";a:2:{i:0;s:28:\"http://www.mixcloud.com/*/*/\";i:1;s:29:\"https://www.mixcloud.com/*/*/\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"Mixpanel\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Mixpanel\";s:6:\"\0*\0url\";s:21:\"https://mixpanel.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://mixpanel.com/api/app/embed/oembed/\";s:11:\"\0*\0provider\";r:2175;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://mixpanel.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"Moby Picture\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Moby Picture\";s:6:\"\0*\0url\";s:26:\"http://www.mobypicture.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"http://api.mobypicture.com/oEmbed\";s:11:\"\0*\0provider\";r:2186;s:10:\"\0*\0schemes\";a:2:{i:0;s:40:\"http://www.mobypicture.com/user/*/view/*\";i:1;s:16:\"http://moby.to/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:17:\"Music Box Maniacs\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:17:\"Music Box Maniacs\";s:6:\"\0*\0url\";s:28:\"https://musicboxmaniacs.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://musicboxmaniacs.com/embed/\";s:11:\"\0*\0provider\";r:2198;s:10:\"\0*\0schemes\";a:1:{i:0;s:44:\"https://musicboxmaniacs.com/explore/melody/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"myBeweeg\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"myBeweeg\";s:6:\"\0*\0url\";s:20:\"https://mybeweeg.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://mybeweeg.com/services/oembed\";s:11:\"\0*\0provider\";r:2210;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://mybeweeg.com/w/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:20:\"MySQL Visual Explain\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:20:\"MySQL Visual Explain\";s:6:\"\0*\0url\";s:24:\"https://mysqlexplain.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://api.mysqlexplain.com/v2/oembed.json\";s:11:\"\0*\0provider\";r:2221;s:10:\"\0*\0schemes\";a:2:{i:0;s:34:\"https://mysqlexplain.com/explain/*\";i:1;s:40:\"https://embed.mysqlexplain.com/explain/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Namchey\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Namchey\";s:6:\"\0*\0url\";s:19:\"https://namchey.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://namchey.com/api/oembed\";s:11:\"\0*\0provider\";r:2234;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://namchey.com/embeds/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"nanoo.tv\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"nanoo.tv\";s:6:\"\0*\0url\";s:21:\"https://www.nanoo.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://www.nanoo.tv/services/oembed\";s:11:\"\0*\0provider\";r:2247;s:10:\"\0*\0schemes\";a:12:{i:0;s:24:\"http://*.nanoo.tv/link/*\";i:1;s:22:\"http://nanoo.tv/link/*\";i:2;s:25:\"http://*.nanoo.pro/link/*\";i:3;s:23:\"http://nanoo.pro/link/*\";i:4;s:25:\"https://*.nanoo.tv/link/*\";i:5;s:23:\"https://nanoo.tv/link/*\";i:6;s:26:\"https://*.nanoo.pro/link/*\";i:7;s:24:\"https://nanoo.pro/link/*\";i:8;s:31:\"http://media.zhdk.ch/signatur/*\";i:9;s:35:\"http://new.media.zhdk.ch/signatur/*\";i:10;s:32:\"https://media.zhdk.ch/signatur/*\";i:11;s:36:\"https://new.media.zhdk.ch/signatur/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:19:\"Nasjonalbiblioteket\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:19:\"Nasjonalbiblioteket\";s:6:\"\0*\0url\";s:18:\"https://www.nb.no/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://api.nb.no/catalog/v1/oembed\";s:11:\"\0*\0provider\";r:2269;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://www.nb.no/items/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:13:\"Natural Atlas\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Natural Atlas\";s:6:\"\0*\0url\";s:25:\"https://naturalatlas.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://naturalatlas.com/oembed.json\";s:11:\"\0*\0provider\";r:2280;s:10:\"\0*\0schemes\";a:4:{i:0;s:26:\"https://naturalatlas.com/*\";i:1;s:28:\"https://naturalatlas.com/*/*\";i:2;s:30:\"https://naturalatlas.com/*/*/*\";i:3;s:32:\"https://naturalatlas.com/*/*/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:39:\"NDLA - Norwegian Digital Learning Arena\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:39:\"NDLA - Norwegian Digital Learning Arena\";s:6:\"\0*\0url\";s:15:\"https://ndla.no\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:22:\"https://ndla.no/oembed\";s:11:\"\0*\0provider\";r:2295;s:10:\"\0*\0schemes\";a:6:{i:0;s:17:\"https://ndla.no/*\";i:1;s:25:\"https://ndla.no/article/*\";i:2;s:23:\"https://ndla.no/audio/*\";i:3;s:25:\"https://ndla.no/concept/*\";i:4;s:23:\"https://ndla.no/image/*\";i:5;s:23:\"https://ndla.no/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Nebula\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Nebula\";s:6:\"\0*\0url\";s:17:\"https://nebula.tv\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://nebula.tv/api/oembed\";s:11:\"\0*\0provider\";r:2311;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://nebula.tv/videos/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Nebula Beta\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Nebula Beta\";s:6:\"\0*\0url\";s:22:\"https://beta.nebula.tv\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://beta.nebula.tv/api/oembed\";s:11:\"\0*\0provider\";r:2323;s:10:\"\0*\0schemes\";a:1:{i:0;s:31:\"https://beta.nebula.tv/videos/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"neetoRecord\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"neetoRecord\";s:6:\"\0*\0url\";s:23:\"https://neetorecord.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://api.neetorecord.com/api/v1/oembed\";s:11:\"\0*\0provider\";r:2335;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://*.neetorecord.com/watch/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"nfb.ca\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"nfb.ca\";s:6:\"\0*\0url\";s:18:\"http://www.nfb.ca/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"http://www.nfb.ca/remote/services/oembed/\";s:11:\"\0*\0provider\";r:2346;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"http://*.nfb.ca/film/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"NoPaste\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"NoPaste\";s:6:\"\0*\0url\";s:18:\"https://nopaste.ml\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://oembed.nopaste.ml\";s:11:\"\0*\0provider\";r:2357;s:10:\"\0*\0schemes\";a:1:{i:0;s:20:\"https://nopaste.ml/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Observable\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Observable\";s:6:\"\0*\0url\";s:24:\"https://observablehq.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://api.observablehq.com/oembed\";s:11:\"\0*\0provider\";r:2368;s:10:\"\0*\0schemes\";a:3:{i:0;s:29:\"https://observablehq.com/@*/*\";i:1;s:28:\"https://observablehq.com/d/*\";i:2;s:32:\"https://observablehq.com/embed/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Odds.com.au\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Odds.com.au\";s:6:\"\0*\0url\";s:23:\"https://www.odds.com.au\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.odds.com.au/api/oembed/\";s:11:\"\0*\0provider\";r:2382;s:10:\"\0*\0schemes\";a:2:{i:0;s:25:\"https://www.odds.com.au/*\";i:1;s:21:\"https://odds.com.au/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:26:\"Odesli (formerly Songlink)\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:26:\"Odesli (formerly Songlink)\";s:6:\"\0*\0url\";s:17:\"https://odesli.co\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:24:\"https://song.link/oembed\";s:11:\"\0*\0provider\";r:2394;s:10:\"\0*\0schemes\";a:7:{i:0;s:19:\"https://song.link/*\";i:1;s:20:\"https://album.link/*\";i:2;s:21:\"https://artist.link/*\";i:3;s:23:\"https://playlist.link/*\";i:4;s:19:\"https://pods.link/*\";i:5;s:21:\"https://mylink.page/*\";i:6;s:19:\"https://odesli.co/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Odysee\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Odysee\";s:6:\"\0*\0url\";s:18:\"https://odysee.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://odysee.com/$/oembed\";s:11:\"\0*\0provider\";r:2412;s:10:\"\0*\0schemes\";a:2:{i:0;s:22:\"https://odysee.com/*/*\";i:1;s:20:\"https://odysee.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Official FM\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Official FM\";s:6:\"\0*\0url\";s:18:\"http://official.fm\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"http://official.fm/services/oembed.json\";s:11:\"\0*\0provider\";r:2424;s:10:\"\0*\0schemes\";a:2:{i:0;s:27:\"http://official.fm/tracks/*\";i:1;s:30:\"http://official.fm/playlists/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:9:\"Omniscope\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Omniscope\";s:6:\"\0*\0url\";s:21:\"https://omniscope.me/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://omniscope.me/_global_/oembed/json\";s:11:\"\0*\0provider\";r:2436;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://omniscope.me/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Omny Studio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Omny Studio\";s:6:\"\0*\0url\";s:22:\"https://omnystudio.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:22:\"https://omny.fm/oembed\";s:11:\"\0*\0provider\";r:2448;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://omny.fm/shows/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Orbitvu\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Orbitvu\";s:6:\"\0*\0url\";s:18:\"https://orbitvu.co\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"http://orbitvu.co/service/oembed\";s:11:\"\0*\0provider\";r:2460;s:10:\"\0*\0schemes\";a:10:{i:0;s:36:\"https://orbitvu.co/001/*/ov3601/view\";i:1;s:38:\"https://orbitvu.co/001/*/ov3601/*/view\";i:2;s:38:\"https://orbitvu.co/001/*/ov3602/*/view\";i:3;s:43:\"https://orbitvu.co/001/*/2/orbittour/*/view\";i:4;s:45:\"https://orbitvu.co/001/*/1/2/orbittour/*/view\";i:5;s:35:\"http://orbitvu.co/001/*/ov3601/view\";i:6;s:37:\"http://orbitvu.co/001/*/ov3601/*/view\";i:7;s:37:\"http://orbitvu.co/001/*/ov3602/*/view\";i:8;s:42:\"http://orbitvu.co/001/*/2/orbittour/*/view\";i:9;s:44:\"http://orbitvu.co/001/*/1/2/orbittour/*/view\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Origits\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Origits\";s:6:\"\0*\0url\";s:20:\"https://origits.com/\";s:12:\"\0*\0endpoints\";a:2:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://origits.net/oembed\";s:11:\"\0*\0provider\";r:2480;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://origits.com/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}i:1;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://origits.com/oembed\";s:11:\"\0*\0provider\";r:2480;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://origits.com/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"Outplayed.tv\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Outplayed.tv\";s:6:\"\0*\0url\";s:21:\"https://outplayed.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://outplayed.tv/oembed\";s:11:\"\0*\0provider\";r:2498;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://outplayed.tv/media/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Overflow\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Overflow\";s:6:\"\0*\0url\";s:19:\"https://overflow.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://overflow.io/services/oembed\";s:11:\"\0*\0provider\";r:2509;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"https://overflow.io/s/*\";i:1;s:27:\"https://overflow.io/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:2:\"OZ\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:2:\"OZ\";s:6:\"\0*\0url\";s:19:\"https://www.oz.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://core.oz.com/oembed\";s:11:\"\0*\0provider\";r:2521;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://www.oz.com/*/video/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Padlet\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Padlet\";s:6:\"\0*\0url\";s:19:\"https://padlet.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://padlet.com/oembed/\";s:11:\"\0*\0provider\";r:2534;s:10:\"\0*\0schemes\";a:1:{i:0;s:20:\"https://padlet.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Panda Video\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Panda Video\";s:6:\"\0*\0url\";s:23:\"https://pandavideo.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://api-v2.pandavideo.com.br/oembed\";s:11:\"\0*\0provider\";r:2545;s:10:\"\0*\0schemes\";a:3:{i:0;s:41:\"https://*.tv.pandavideo.com.br/embed/?v=*\";i:1;s:46:\"https://*.tv.pandavideo.com.br/*/playlist.m3u8\";i:2;s:46:\"https://dashboard.pandavideo.com.br/#/videos/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Pastery\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Pastery\";s:6:\"\0*\0url\";s:23:\"https://www.pastery.net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://www.pastery.net/oembed\";s:11:\"\0*\0provider\";r:2558;s:10:\"\0*\0schemes\";a:4:{i:0;s:20:\"http://pastery.net/*\";i:1;s:21:\"https://pastery.net/*\";i:2;s:24:\"http://www.pastery.net/*\";i:3;s:25:\"https://www.pastery.net/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"PeerTube.TV\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"PeerTube.TV\";s:6:\"\0*\0url\";s:20:\"https://peertube.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://peertube.tv/services/oembed\";s:11:\"\0*\0provider\";r:2572;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://peertube.tv/w/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Picturelfy\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Picturelfy\";s:6:\"\0*\0url\";s:27:\"https://www.picturelfy.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://api.picturelfy.com/service/oembed/\";s:11:\"\0*\0provider\";r:2583;s:10:\"\0*\0schemes\";a:2:{i:0;s:29:\"http://www.picturelfy.com/p/*\";i:1;s:30:\"https://www.picturelfy.com/p/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Piggy\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Piggy\";s:6:\"\0*\0url\";s:16:\"https://piggy.to\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:23:\"https://piggy.to/oembed\";s:11:\"\0*\0provider\";r:2595;s:10:\"\0*\0schemes\";a:2:{i:0;s:21:\"https://piggy.to/@*/*\";i:1;s:23:\"https://piggy.to/view/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Pikasso\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Pikasso\";s:6:\"\0*\0url\";s:27:\"https://builder.pikasso.xyz\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://builder.pikasso.xyz/api/oembed\";s:11:\"\0*\0provider\";r:2607;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://*.builder.pikasso.xyz/embed/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"PingVP\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"PingVP\";s:6:\"\0*\0url\";s:23:\"https://www.pingvp.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://beta.pingvp.com.kpnis.nl/p/oembed.php\";s:11:\"\0*\0provider\";r:2619;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Pinpoll\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Pinpoll\";s:6:\"\0*\0url\";s:38:\"https://www.pinpoll.com/products/tools\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://tools.pinpoll.com/oembed\";s:11:\"\0*\0provider\";r:2629;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://tools.pinpoll.com/embed/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Pinterest\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Pinterest\";s:6:\"\0*\0url\";s:25:\"https://www.pinterest.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://www.pinterest.com/oembed.json\";s:11:\"\0*\0provider\";r:2642;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://www.pinterest.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"PitchHub\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"PitchHub\";s:6:\"\0*\0url\";s:25:\"https://www.pitchhub.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://player.pitchhub.com/en/public/oembed\";s:11:\"\0*\0provider\";r:2653;s:10:\"\0*\0schemes\";a:1:{i:0;s:46:\"https://player.pitchhub.com/en/public/player/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Pixdor\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Pixdor\";s:6:\"\0*\0url\";s:22:\"http://www.pixdor.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://store.pixdor.com/oembed\";s:11:\"\0*\0provider\";r:2664;s:10:\"\0*\0schemes\";a:2:{i:0;s:51:\"https://store.pixdor.com/place-marker-widget/*/show\";i:1;s:35:\"https://store.pixdor.com/map/*/show\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Plusdocs\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Plusdocs\";s:6:\"\0*\0url\";s:19:\"http://plusdocs.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://app.plusdocs.com/oembed\";s:11:\"\0*\0provider\";r:2678;s:10:\"\0*\0schemes\";a:3:{i:0;s:38:\"https://app.plusdocs.com/*/snapshots/*\";i:1;s:39:\"https://app.plusdocs.com/*/pages/edit/*\";i:2;s:40:\"https://app.plusdocs.com/*/pages/share/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Podbean\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Podbean\";s:6:\"\0*\0url\";s:18:\"http://podbean.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://api.podbean.com/v1/oembed\";s:11:\"\0*\0provider\";r:2692;s:10:\"\0*\0schemes\";a:2:{i:0;s:25:\"https://*.podbean.com/e/*\";i:1;s:24:\"http://*.podbean.com/e/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Poll Daddy\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Poll Daddy\";s:6:\"\0*\0url\";s:20:\"http://polldaddy.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://polldaddy.com/oembed/\";s:11:\"\0*\0provider\";r:2704;s:10:\"\0*\0schemes\";a:3:{i:0;s:26:\"http://*.polldaddy.com/s/*\";i:1;s:29:\"http://*.polldaddy.com/poll/*\";i:2;s:32:\"http://*.polldaddy.com/ratings/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Portfolium\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Portfolium\";s:6:\"\0*\0url\";s:22:\"https://portfolium.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://api.portfolium.com/oembed\";s:11:\"\0*\0provider\";r:2717;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://portfolium.com/entry/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Present\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Present\";s:6:\"\0*\0url\";s:18:\"https://present.do\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:47:\"https://gateway.cobalt.run/present/decks/oembed\";s:11:\"\0*\0provider\";r:2728;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://present.do/decks/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Prezi Video\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Prezi Video\";s:6:\"\0*\0url\";s:18:\"https://prezi.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://prezi.com/v/oembed\";s:11:\"\0*\0provider\";r:2740;s:10:\"\0*\0schemes\";a:2:{i:0;s:21:\"https://prezi.com/v/*\";i:1;s:23:\"https://*.prezi.com/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"QTpi\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"QTpi\";s:6:\"\0*\0url\";s:16:\"https://qtpi.gg/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://qtpi.gg/fashion/oembed\";s:11:\"\0*\0provider\";r:2752;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://qtpi.gg/fashion/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Quiz.biz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Quiz.biz\";s:6:\"\0*\0url\";s:20:\"http://www.quiz.biz/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"http://www.quiz.biz/api/oembed\";s:11:\"\0*\0provider\";r:2763;s:10:\"\0*\0schemes\";a:1:{i:0;s:32:\"http://www.quiz.biz/quizz-*.html\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Quizz.biz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Quizz.biz\";s:6:\"\0*\0url\";s:21:\"http://www.quizz.biz/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"http://www.quizz.biz/api/oembed\";s:11:\"\0*\0provider\";r:2774;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"http://www.quizz.biz/quizz-*.html\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"RadioPublic\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"RadioPublic\";s:6:\"\0*\0url\";s:23:\"https://radiopublic.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://oembed.radiopublic.com/oembed\";s:11:\"\0*\0provider\";r:2785;s:10:\"\0*\0schemes\";a:7:{i:0;s:30:\"https://play.radiopublic.com/*\";i:1;s:25:\"https://radiopublic.com/*\";i:2;s:29:\"https://www.radiopublic.com/*\";i:3;s:29:\"http://play.radiopublic.com/*\";i:4;s:24:\"http://radiopublic.com/*\";i:5;s:28:\"http://www.radiopublic.com/*\";i:6;s:27:\"https://*.radiopublic.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Raindrop\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Raindrop\";s:6:\"\0*\0url\";s:19:\"https://raindrop.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://pub.raindrop.io/api/oembed\";s:11:\"\0*\0provider\";r:2802;s:10:\"\0*\0schemes\";a:4:{i:0;s:21:\"https://raindrop.io/*\";i:1;s:23:\"https://raindrop.io/*/*\";i:2;s:25:\"https://raindrop.io/*/*/*\";i:3;s:27:\"https://raindrop.io/*/*/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"rcvis\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"rcvis\";s:6:\"\0*\0url\";s:22:\"https://www.rcvis.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://animatron.com/oembed\";s:11:\"\0*\0provider\";r:2817;s:10:\"\0*\0schemes\";a:4:{i:0;s:25:\"https://www.rcvis.com/v/*\";i:1;s:33:\"https://www.rcvis.com/visualize=*\";i:2;s:26:\"https://www.rcvis.com/ve/*\";i:3;s:41:\"https://www.rcvis.com/visualizeEmbedded=*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Reddit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Reddit\";s:6:\"\0*\0url\";s:19:\"https://reddit.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://www.reddit.com/oembed\";s:11:\"\0*\0provider\";r:2831;s:10:\"\0*\0schemes\";a:2:{i:0;s:35:\"https://reddit.com/r/*/comments/*/*\";i:1;s:39:\"https://www.reddit.com/r/*/comments/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"ReleaseWire\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"ReleaseWire\";s:6:\"\0*\0url\";s:27:\"http://www.releasewire.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"http://publisher.releasewire.com/oembed/\";s:11:\"\0*\0provider\";r:2843;s:10:\"\0*\0schemes\";a:1:{i:0;s:18:\"http://rwire.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Replit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Replit\";s:6:\"\0*\0url\";s:19:\"https://replit.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://replit.com/data/oembed\";s:11:\"\0*\0provider\";r:2854;s:10:\"\0*\0schemes\";a:2:{i:0;s:20:\"https://repl.it/@*/*\";i:1;s:23:\"https://replit.com/@*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"ReverbNation\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"ReverbNation\";s:6:\"\0*\0url\";s:29:\"https://www.reverbnation.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.reverbnation.com/oembed\";s:11:\"\0*\0provider\";r:2866;s:10:\"\0*\0schemes\";a:2:{i:0;s:30:\"https://www.reverbnation.com/*\";i:1;s:38:\"https://www.reverbnation.com/*/songs/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Roomshare\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Roomshare\";s:6:\"\0*\0url\";s:19:\"http://roomshare.jp\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"http://roomshare.jp/en/oembed.json\";s:11:\"\0*\0provider\";r:2878;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"http://roomshare.jp/post/*\";i:1;s:29:\"http://roomshare.jp/en/post/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"RoosterTeeth\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"RoosterTeeth\";s:6:\"\0*\0url\";s:24:\"https://roosterteeth.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://roosterteeth.com/oembed\";s:11:\"\0*\0provider\";r:2890;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://roosterteeth.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Rumble\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Rumble\";s:6:\"\0*\0url\";s:19:\"https://rumble.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://rumble.com/api/Media/oembed.json\";s:11:\"\0*\0provider\";r:2902;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Runkit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Runkit\";s:6:\"\0*\0url\";s:18:\"https://runkit.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://embed.runkit.com/oembed\";s:11:\"\0*\0provider\";r:2912;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"http://embed.runkit.com/*,\";i:1;s:27:\"https://embed.runkit.com/*,\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Saooti\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Saooti\";s:6:\"\0*\0url\";s:26:\"https://octopus.saooti.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://octopus.saooti.com/oembed\";s:11:\"\0*\0provider\";r:2925;s:10:\"\0*\0schemes\";a:1:{i:0;s:45:\"https://octopus.saooti.com/main/pub/podcast/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Sapo Videos\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Sapo Videos\";s:6:\"\0*\0url\";s:21:\"http://videos.sapo.pt\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://videos.sapo.pt/oembed\";s:11:\"\0*\0provider\";r:2936;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"http://videos.sapo.pt/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"sbedit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"sbedit\";s:6:\"\0*\0url\";s:18:\"https://sbedit.net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://sbedit.net/oembed/\";s:11:\"\0*\0provider\";r:2947;s:10:\"\0*\0schemes\";a:1:{i:0;s:20:\"https://sbedit.net/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Screen9\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Screen9\";s:6:\"\0*\0url\";s:23:\"http://www.screen9.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://api.screen9.com/oembed\";s:11:\"\0*\0provider\";r:2958;s:10:\"\0*\0schemes\";a:2:{i:0;s:29:\"https://console.screen9.com/*\";i:1;s:22:\"https://*.screen9.tv/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:14:\"Screencast.com\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Screencast.com\";s:6:\"\0*\0url\";s:26:\"http://www.screencast.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://api.screencast.com/external/oembed\";s:11:\"\0*\0provider\";r:2970;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"http://www.screencast.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Screenr\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Screenr\";s:6:\"\0*\0url\";s:23:\"http://www.screenr.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"http://www.screenr.com/api/oembed.json\";s:11:\"\0*\0provider\";r:2981;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"http://www.screenr.com/*/\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"ScribbleMaps\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"ScribbleMaps\";s:6:\"\0*\0url\";s:24:\"https://scribblemaps.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:49:\"https://scribblemaps.com/api/services/oembed.json\";s:11:\"\0*\0provider\";r:2992;s:10:\"\0*\0schemes\";a:4:{i:0;s:39:\"http://www.scribblemaps.com/maps/view/*\";i:1;s:40:\"https://www.scribblemaps.com/maps/view/*\";i:2;s:35:\"http://scribblemaps.com/maps/view/*\";i:3;s:36:\"https://scribblemaps.com/maps/view/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Scribd\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Scribd\";s:6:\"\0*\0url\";s:22:\"http://www.scribd.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"http://www.scribd.com/services/oembed/\";s:11:\"\0*\0provider\";r:3006;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"http://www.scribd.com/doc/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"SendtoNews\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"SendtoNews\";s:6:\"\0*\0url\";s:26:\"http://www.sendtonews.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://embed.sendtonews.com/services/oembed\";s:11:\"\0*\0provider\";r:3017;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://embed.sendtonews.com/oembed/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"SharedFile\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"SharedFile\";s:6:\"\0*\0url\";s:42:\"https://shared-file-kappa.vercel.app/file/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:52:\"https://shared-file-kappa.vercel.app/file/api/oembed\";s:11:\"\0*\0provider\";r:3030;s:10:\"\0*\0schemes\";a:1:{i:0;s:43:\"https://shared-file-kappa.vercel.app/file/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Shopshare\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Shopshare\";s:6:\"\0*\0url\";s:20:\"https://shopshare.tv\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://shopshare.tv/api/shopcast/oembed\";s:11:\"\0*\0provider\";r:3041;s:10:\"\0*\0schemes\";a:2:{i:0;s:32:\"https://shopshare.tv/shopboard/*\";i:1;s:31:\"https://shopshare.tv/shopcast/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"ShortNote\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"ShortNote\";s:6:\"\0*\0url\";s:25:\"https://www.shortnote.jp/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://www.shortnote.jp/oembed/\";s:11:\"\0*\0provider\";r:3053;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://www.shortnote.jp/view/notes/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Shoudio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Shoudio\";s:6:\"\0*\0url\";s:18:\"http://shoudio.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"http://shoudio.com/api/oembed\";s:11:\"\0*\0provider\";r:3064;s:10:\"\0*\0schemes\";a:2:{i:0;s:20:\"http://shoudio.com/*\";i:1;s:17:\"http://shoud.io/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:16:\"Show by Animaker\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"Show by Animaker\";s:6:\"\0*\0url\";s:19:\"https://getshow.io/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://api.getshow.io/oembed.json\";s:11:\"\0*\0provider\";r:3076;s:10:\"\0*\0schemes\";a:2:{i:0;s:31:\"https://app.getshow.io/iframe/*\";i:1;s:28:\"https://*.getshow.io/share/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:38:\"Show the Way, actionable location info\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:38:\"Show the Way, actionable location info\";s:6:\"\0*\0url\";s:21:\"https://showtheway.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://showtheway.io/oembed\";s:11:\"\0*\0provider\";r:3088;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://showtheway.io/to/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Simplecast\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Simplecast\";s:6:\"\0*\0url\";s:22:\"https://simplecast.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://simplecast.com/oembed\";s:11:\"\0*\0provider\";r:3099;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://simplecast.com/s/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Sizzle\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Sizzle\";s:6:\"\0*\0url\";s:21:\"https://onsizzle.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://onsizzle.com/oembed\";s:11:\"\0*\0provider\";r:3111;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://onsizzle.com/i/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Sketchfab\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Sketchfab\";s:6:\"\0*\0url\";s:20:\"http://sketchfab.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"http://sketchfab.com/oembed\";s:11:\"\0*\0provider\";r:3122;s:10:\"\0*\0schemes\";a:3:{i:0;s:30:\"http://sketchfab.com/*models/*\";i:1;s:31:\"https://sketchfab.com/*models/*\";i:2;s:33:\"https://sketchfab.com/*/folders/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"SlideShare\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"SlideShare\";s:6:\"\0*\0url\";s:26:\"http://www.slideshare.net/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://www.slideshare.net/api/oembed/2\";s:11:\"\0*\0provider\";r:3136;s:10:\"\0*\0schemes\";a:10:{i:0;s:30:\"https://www.slideshare.net/*/*\";i:1;s:29:\"http://www.slideshare.net/*/*\";i:2;s:29:\"https://fr.slideshare.net/*/*\";i:3;s:28:\"http://fr.slideshare.net/*/*\";i:4;s:29:\"https://de.slideshare.net/*/*\";i:5;s:28:\"http://de.slideshare.net/*/*\";i:6;s:29:\"https://es.slideshare.net/*/*\";i:7;s:28:\"http://es.slideshare.net/*/*\";i:8;s:29:\"https://pt.slideshare.net/*/*\";i:9;s:28:\"http://pt.slideshare.net/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"SmashNotes\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"SmashNotes\";s:6:\"\0*\0url\";s:22:\"https://smashnotes.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://smashnotes.com/services/oembed\";s:11:\"\0*\0provider\";r:3156;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://smashnotes.com/p/*\";i:1;s:67:\"https://smashnotes.com/p/*/e/* - https://smashnotes.com/p/*/e/*/s/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Smeme\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Smeme\";s:6:\"\0*\0url\";s:17:\"https://smeme.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://open.smeme.com/api/oembed\";s:11:\"\0*\0provider\";r:3168;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://open.smeme.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Smrthi\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Smrthi\";s:6:\"\0*\0url\";s:22:\"https://www.smrthi.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.smrthi.com/api/oembed\";s:11:\"\0*\0provider\";r:3179;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://www.smrthi.com/book/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"SmugMug\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"SmugMug\";s:6:\"\0*\0url\";s:24:\"https://www.smugmug.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://api.smugmug.com/services/oembed/\";s:11:\"\0*\0provider\";r:3191;s:10:\"\0*\0schemes\";a:2:{i:0;s:22:\"http://*.smugmug.com/*\";i:1;s:23:\"https://*.smugmug.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:14:\"SocialExplorer\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"SocialExplorer\";s:6:\"\0*\0url\";s:31:\"https://www.socialexplorer.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:47:\"https://www.socialexplorer.com/services/oembed/\";s:11:\"\0*\0provider\";r:3203;s:10:\"\0*\0schemes\";a:4:{i:0;s:40:\"https://www.socialexplorer.com/*/explore\";i:1;s:37:\"https://www.socialexplorer.com/*/view\";i:2;s:37:\"https://www.socialexplorer.com/*/edit\";i:3;s:38:\"https://www.socialexplorer.com/*/embed\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"SoundCloud\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"SoundCloud\";s:6:\"\0*\0url\";s:22:\"http://soundcloud.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://soundcloud.com/oembed\";s:11:\"\0*\0provider\";r:3217;s:10:\"\0*\0schemes\";a:4:{i:0;s:23:\"http://soundcloud.com/*\";i:1;s:24:\"https://soundcloud.com/*\";i:2;s:27:\"https://on.soundcloud.com/*\";i:3;s:32:\"https://soundcloud.app.goog.gl/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"SpeakerDeck\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"SpeakerDeck\";s:6:\"\0*\0url\";s:23:\"https://speakerdeck.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://speakerdeck.com/oembed.json\";s:11:\"\0*\0provider\";r:3231;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"http://speakerdeck.com/*/*\";i:1;s:27:\"https://speakerdeck.com/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Spotify\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Spotify\";s:6:\"\0*\0url\";s:20:\"https://spotify.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://open.spotify.com/oembed\";s:11:\"\0*\0provider\";r:3244;s:10:\"\0*\0schemes\";a:3:{i:0;s:26:\"https://open.spotify.com/*\";i:1;s:9:\"spotify:*\";i:2;s:22:\"https://spotify.link/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Spotlightr\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Spotlightr\";s:6:\"\0*\0url\";s:22:\"https://spotlightr.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://api.spotlightr.com/getOEmbed\";s:11:\"\0*\0provider\";r:3257;s:10:\"\0*\0schemes\";a:4:{i:0;s:32:\"https://*.spotlightr.com/watch/*\";i:1;s:34:\"https://*.spotlightr.com/publish/*\";i:2;s:36:\"https://*.cdn.spotlightr.com/watch/*\";i:3;s:38:\"https://*.cdn.spotlightr.com/publish/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Spreaker\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Spreaker\";s:6:\"\0*\0url\";s:25:\"https://www.spreaker.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://api.spreaker.com/oembed\";s:11:\"\0*\0provider\";r:3271;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"http://*.spreaker.com/*\";i:1;s:24:\"https://*.spreaker.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"SproutVideo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"SproutVideo\";s:6:\"\0*\0url\";s:23:\"https://sproutvideo.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"http://sproutvideo.com/oembed.json\";s:11:\"\0*\0provider\";r:3283;s:10:\"\0*\0schemes\";a:2:{i:0;s:32:\"https://sproutvideo.com/videos/*\";i:1;s:26:\"https://*.vids.io/videos/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Spyke\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Spyke\";s:6:\"\0*\0url\";s:20:\"https://spyke.social\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://api.spyke.social/embed/oembed\";s:11:\"\0*\0provider\";r:3297;s:10:\"\0*\0schemes\";a:16:{i:0;s:23:\"http://spyke.social/p/*\";i:1;s:23:\"http://spyke.social/u/*\";i:2;s:23:\"http://spyke.social/g/*\";i:3;s:23:\"http://spyke.social/c/*\";i:4;s:24:\"https://spyke.social/p/*\";i:5;s:24:\"https://spyke.social/u/*\";i:6;s:24:\"https://spyke.social/g/*\";i:7;s:24:\"https://spyke.social/c/*\";i:8;s:27:\"http://www.spyke.social/p/*\";i:9;s:27:\"http://www.spyke.social/u/*\";i:10;s:27:\"http://www.spyke.social/g/*\";i:11;s:27:\"http://www.spyke.social/c/*\";i:12;s:28:\"https://www.spyke.social/p/*\";i:13;s:28:\"https://www.spyke.social/u/*\";i:14;s:28:\"https://www.spyke.social/g/*\";i:15;s:28:\"https://www.spyke.social/c/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:27:\"Stanford Digital Repository\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:27:\"Stanford Digital Repository\";s:6:\"\0*\0url\";s:26:\"https://purl.stanford.edu/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://purl.stanford.edu/embed.json\";s:11:\"\0*\0provider\";r:3324;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://purl.stanford.edu/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Streamable\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Streamable\";s:6:\"\0*\0url\";s:23:\"https://streamable.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://api.streamable.com/oembed.json\";s:11:\"\0*\0provider\";r:3335;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"http://streamable.com/*\";i:1;s:24:\"https://streamable.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Streamio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Streamio\";s:6:\"\0*\0url\";s:24:\"https://www.streamio.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://streamio.com/api/v1/oembed\";s:11:\"\0*\0provider\";r:3347;s:10:\"\0*\0schemes\";a:2:{i:0;s:16:\"https://s3m.io/*\";i:1;s:16:\"https://23m.io/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Subscribi\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Subscribi\";s:6:\"\0*\0url\";s:21:\"https://subscribi.io/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://subscribi.io/api/oembed\";s:11:\"\0*\0provider\";r:3359;s:10:\"\0*\0schemes\";a:1:{i:0;s:32:\"https://subscribi.io/api/oembed*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Sudomemo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Sudomemo\";s:6:\"\0*\0url\";s:25:\"https://www.sudomemo.net/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://www.sudomemo.net/oembed\";s:11:\"\0*\0provider\";r:3370;s:10:\"\0*\0schemes\";a:4:{i:0;s:32:\"https://www.sudomemo.net/watch/*\";i:1;s:31:\"http://www.sudomemo.net/watch/*\";i:2;s:20:\"https://flipnot.es/*\";i:3;s:19:\"http://flipnot.es/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Sutori\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Sutori\";s:6:\"\0*\0url\";s:23:\"https://www.sutori.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.sutori.com/api/oembed\";s:11:\"\0*\0provider\";r:3384;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://www.sutori.com/story/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Sway\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Sway\";s:6:\"\0*\0url\";s:20:\"https://www.sway.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://sway.com/api/v1.0/oembed\";s:11:\"\0*\0provider\";r:3396;s:10:\"\0*\0schemes\";a:2:{i:0;s:18:\"https://sway.com/*\";i:1;s:22:\"https://www.sway.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Sway Office\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Sway Office\";s:6:\"\0*\0url\";s:23:\"https://sway.office.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://sway.office.com/api/v1.0/oembed\";s:11:\"\0*\0provider\";r:3408;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://sway.office.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Synthesia\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Synthesia\";s:6:\"\0*\0url\";s:25:\"https://www.synthesia.io/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:69:\"https://69jr5v75rc.execute-api.eu-west-1.amazonaws.com/prod/v2/oembed\";s:11:\"\0*\0provider\";r:3419;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://share.synthesia.io/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:3:\"TED\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:3:\"TED\";s:6:\"\0*\0url\";s:19:\"https://www.ted.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://www.ted.com/services/v1/oembed.json\";s:11:\"\0*\0provider\";r:3431;s:10:\"\0*\0schemes\";a:3:{i:0;s:22:\"http://ted.com/talks/*\";i:1;s:23:\"https://ted.com/talks/*\";i:2;s:27:\"https://www.ted.com/talks/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:19:\"The DAM consultants\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:19:\"The DAM consultants\";s:6:\"\0*\0url\";s:51:\"https://hubspot-media-bridge.thedamconsultants.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:58:\"https://hubspot-media-bridge.thedamconsultants.com/oembed/\";s:11:\"\0*\0provider\";r:3444;s:10:\"\0*\0schemes\";a:1:{i:0;s:52:\"https://hubspot-media-bridge.thedamconsultants.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:18:\"The New York Times\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:18:\"The New York Times\";s:6:\"\0*\0url\";s:23:\"https://www.nytimes.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://www.nytimes.com/svc/oembed/json/\";s:11:\"\0*\0provider\";r:3455;s:10:\"\0*\0schemes\";a:3:{i:0;s:34:\"https://www.nytimes.com/svc/oembed\";i:1;s:21:\"https://nytimes.com/*\";i:2;s:23:\"https://*.nytimes.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"They Said So\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"They Said So\";s:6:\"\0*\0url\";s:23:\"https://theysaidso.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://theysaidso.com/extensions/oembed/\";s:11:\"\0*\0provider\";r:3468;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://theysaidso.com/image/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"TickCounter\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"TickCounter\";s:6:\"\0*\0url\";s:27:\"https://www.tickcounter.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://www.tickcounter.com/oembed\";s:11:\"\0*\0provider\";r:3479;s:10:\"\0*\0schemes\";a:12:{i:0;s:35:\"http://www.tickcounter.com/widget/*\";i:1;s:38:\"http://www.tickcounter.com/countdown/*\";i:2;s:36:\"http://www.tickcounter.com/countup/*\";i:3;s:35:\"http://www.tickcounter.com/ticker/*\";i:4;s:34:\"http://www.tickcounter.com/clock/*\";i:5;s:39:\"http://www.tickcounter.com/worldclock/*\";i:6;s:36:\"https://www.tickcounter.com/widget/*\";i:7;s:39:\"https://www.tickcounter.com/countdown/*\";i:8;s:37:\"https://www.tickcounter.com/countup/*\";i:9;s:36:\"https://www.tickcounter.com/ticker/*\";i:10;s:35:\"https://www.tickcounter.com/clock/*\";i:11;s:40:\"https://www.tickcounter.com/worldclock/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"TikTok\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"TikTok\";s:6:\"\0*\0url\";s:22:\"http://www.tiktok.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://www.tiktok.com/oembed\";s:11:\"\0*\0provider\";r:3501;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"https://www.tiktok.com/*\";i:1;s:32:\"https://www.tiktok.com/*/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Tonic Audio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Tonic Audio\";s:6:\"\0*\0url\";s:23:\"https://tonicaudio.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://tonicaudio.com/oembed\";s:11:\"\0*\0provider\";r:3513;s:10:\"\0*\0schemes\";a:4:{i:0;s:29:\"https://tonicaudio.com/take/*\";i:1;s:29:\"https://tonicaudio.com/song/*\";i:2;s:22:\"https://tnic.io/song/*\";i:3;s:22:\"https://tnic.io/take/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Toornament\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Toornament\";s:6:\"\0*\0url\";s:27:\"https://www.toornament.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://widget.toornament.com/oembed\";s:11:\"\0*\0provider\";r:3528;s:10:\"\0*\0schemes\";a:4:{i:0;s:52:\"https://www.toornament.com/tournaments/*/information\";i:1;s:54:\"https://www.toornament.com/tournaments/*/registration/\";i:2;s:57:\"https://www.toornament.com/tournaments/*/matches/schedule\";i:3;s:50:\"https://www.toornament.com/tournaments/*/stages/*/\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Topy\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Topy\";s:6:\"\0*\0url\";s:19:\"http://www.topy.se/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"http://www.topy.se/oembed/\";s:11:\"\0*\0provider\";r:3544;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"http://www.topy.se/image/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Totango\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Totango\";s:6:\"\0*\0url\";s:19:\"https://totango.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://app-test.totango.com/oembed\";s:11:\"\0*\0provider\";r:3555;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://app-test.totango.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Trackspace\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Trackspace\";s:6:\"\0*\0url\";s:29:\"http://trackspace.upitup.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://trackspace.upitup.com/oembed\";s:11:\"\0*\0provider\";r:3566;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"http://trackspace.upitup.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"Trinity Audio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Trinity Audio\";s:6:\"\0*\0url\";s:23:\"https://trinityaudio.ai\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://trinitymedia.ai/services/oembed\";s:11:\"\0*\0provider\";r:3577;s:10:\"\0*\0schemes\";a:3:{i:0;s:32:\"https://trinitymedia.ai/player/*\";i:1;s:34:\"https://trinitymedia.ai/player/*/*\";i:2;s:36:\"https://trinitymedia.ai/player/*/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Tumblr\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Tumblr\";s:6:\"\0*\0url\";s:22:\"https://www.tumblr.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.tumblr.com/oembed/1.0\";s:11:\"\0*\0provider\";r:3590;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://*.tumblr.com/post/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:4:\"Tuxx\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Tuxx\";s:6:\"\0*\0url\";s:20:\"https://www.tuxx.be/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.tuxx.be/services/oembed\";s:11:\"\0*\0provider\";r:3601;s:10:\"\0*\0schemes\";a:1:{i:0;s:21:\"https://www.tuxx.be/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"tvcf\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"tvcf\";s:6:\"\0*\0url\";s:17:\"http://tvcf.co.kr\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://play.tvcf.co.kr/rest/oembed\";s:11:\"\0*\0provider\";r:3612;s:10:\"\0*\0schemes\";a:2:{i:0;s:25:\"https://play.tvcf.co.kr/*\";i:1;s:22:\"https://*.tvcf.co.kr/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Twinmotion\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Twinmotion\";s:6:\"\0*\0url\";s:35:\"https://twinmotion.unrealengine.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://twinmotion.unrealengine.com/oembed\";s:11:\"\0*\0provider\";r:3624;s:10:\"\0*\0schemes\";a:2:{i:0;s:50:\"https://twinmotion.unrealengine.com/presentation/*\";i:1;s:46:\"https://twinmotion.unrealengine.com/panorama/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Twitter\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Twitter\";s:6:\"\0*\0url\";s:23:\"http://www.twitter.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://publish.twitter.com/oembed\";s:11:\"\0*\0provider\";r:3637;s:10:\"\0*\0schemes\";a:3:{i:0;s:21:\"https://twitter.com/*\";i:1;s:30:\"https://twitter.com/*/status/*\";i:2;s:32:\"https://*.twitter.com/*/status/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"TypeCast\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"TypeCast\";s:6:\"\0*\0url\";s:19:\"https://typecast.ai\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://play.typecast.ai/oembed\";s:11:\"\0*\0provider\";r:3650;s:10:\"\0*\0schemes\";a:3:{i:0;s:28:\"https://play.typecast.ai/s/*\";i:1;s:28:\"https://play.typecast.ai/e/*\";i:2;s:26:\"https://play.typecast.ai/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Typlog\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Typlog\";s:6:\"\0*\0url\";s:18:\"https://typlog.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://typlog.com/oembed\";s:11:\"\0*\0provider\";r:3663;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"UAPod\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"UAPod\";s:6:\"\0*\0url\";s:31:\"https://uapod.univ-antilles.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://uapod.univ-antilles.fr/oembed\";s:11:\"\0*\0provider\";r:3673;s:10:\"\0*\0schemes\";a:1:{i:0;s:38:\"https://uapod.univ-antilles.fr/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:27:\"University of Cambridge Map\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:27:\"University of Cambridge Map\";s:6:\"\0*\0url\";s:21:\"https://map.cam.ac.uk\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://map.cam.ac.uk/oembed/\";s:11:\"\0*\0provider\";r:3684;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://map.cam.ac.uk/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:14:\"UnivParis1.Pod\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"UnivParis1.Pod\";s:6:\"\0*\0url\";s:35:\"https://mediatheque.univ-paris1.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://mediatheque.univ-paris1.fr/oembed\";s:11:\"\0*\0provider\";r:3695;s:10:\"\0*\0schemes\";a:1:{i:0;s:42:\"https://mediatheque.univ-paris1.fr/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Upec.Pod\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Upec.Pod\";s:6:\"\0*\0url\";s:21:\"https://pod.u-pec.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://pod.u-pec.fr/oembed\";s:11:\"\0*\0provider\";r:3706;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://pod.u-pec.fr/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Ustream\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Ustream\";s:6:\"\0*\0url\";s:21:\"http://www.ustream.tv\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://www.ustream.tv/oembed\";s:11:\"\0*\0provider\";r:3717;s:10:\"\0*\0schemes\";a:2:{i:0;s:21:\"http://*.ustream.tv/*\";i:1;s:22:\"http://*.ustream.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"uStudio, Inc.\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"uStudio, Inc.\";s:6:\"\0*\0url\";s:23:\"https://www.ustudio.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://app.ustudio.com/api/v2/oembed\";s:11:\"\0*\0provider\";r:3730;s:10:\"\0*\0schemes\";a:2:{i:0;s:29:\"https://*.ustudio.com/embed/*\";i:1;s:31:\"https://*.ustudio.com/embed/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"VeeR VR\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"VeeR VR\";s:6:\"\0*\0url\";s:15:\"http://veer.tv/\";s:12:\"\0*\0endpoints\";a:2:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://api.veer.tv/oembed\";s:11:\"\0*\0provider\";r:3743;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"http://veer.tv/videos/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}i:1;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://api.veervr.tv/oembed\";s:11:\"\0*\0provider\";r:3743;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"http://veervr.tv/videos/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"VEVO\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"VEVO\";s:6:\"\0*\0url\";s:20:\"http://www.vevo.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://www.vevo.com/oembed\";s:11:\"\0*\0provider\";r:3761;s:10:\"\0*\0schemes\";a:2:{i:0;s:21:\"http://www.vevo.com/*\";i:1;s:22:\"https://www.vevo.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Videfit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Videfit\";s:6:\"\0*\0url\";s:20:\"https://videfit.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://videfit.com/oembed\";s:11:\"\0*\0provider\";r:3773;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://videfit.com/videos/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"VidMount\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"VidMount\";s:6:\"\0*\0url\";s:21:\"https://vidmount.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://vidmount.com/oembed\";s:11:\"\0*\0provider\";r:3784;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://vidmount.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Vidyard\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Vidyard\";s:6:\"\0*\0url\";s:19:\"https://vidyard.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://api.vidyard.com/dashboard/v1.1/oembed\";s:11:\"\0*\0provider\";r:3795;s:10:\"\0*\0schemes\";a:4:{i:0;s:22:\"http://*.vidyard.com/*\";i:1;s:23:\"https://*.vidyard.com/*\";i:2;s:27:\"http://*.hubs.vidyard.com/*\";i:3;s:28:\"https://*.hubs.vidyard.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Vimeo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Vimeo\";s:6:\"\0*\0url\";s:18:\"https://vimeo.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://vimeo.com/api/oembed.json\";s:11:\"\0*\0provider\";r:3809;s:10:\"\0*\0schemes\";a:7:{i:0;s:19:\"https://vimeo.com/*\";i:1;s:33:\"https://vimeo.com/album/*/video/*\";i:2;s:30:\"https://vimeo.com/channels/*/*\";i:3;s:35:\"https://vimeo.com/groups/*/videos/*\";i:4;s:30:\"https://vimeo.com/ondemand/*/*\";i:5;s:32:\"https://player.vimeo.com/video/*\";i:6;s:27:\"https://vimeo.com/event/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Viostream\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Viostream\";s:6:\"\0*\0url\";s:25:\"https://www.viostream.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://play.viostream.com/oembed\";s:11:\"\0*\0provider\";r:3826;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://share.viostream.com/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Viously\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Viously\";s:6:\"\0*\0url\";s:23:\"https://www.viously.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://www.viously.com/oembed\";s:11:\"\0*\0provider\";r:3839;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://www.viously.com/*/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Vizdom\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Vizdom\";s:6:\"\0*\0url\";s:18:\"https://vizdom.dev\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://vizdom.dev/api/v1/oembed\";s:11:\"\0*\0provider\";r:3852;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://vizdom.dev/link/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:3:\"xml\";i:1;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Vizydrop\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Vizydrop\";s:6:\"\0*\0url\";s:20:\"https://vizydrop.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://vizydrop.com/oembed\";s:11:\"\0*\0provider\";r:3865;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://vizydrop.com/shared/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Vlipsy\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Vlipsy\";s:6:\"\0*\0url\";s:19:\"https://vlipsy.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://vlipsy.com/oembed\";s:11:\"\0*\0provider\";r:3876;s:10:\"\0*\0schemes\";a:1:{i:0;s:20:\"https://vlipsy.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"VLIVE\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"VLIVE\";s:6:\"\0*\0url\";s:20:\"https://www.vlive.tv\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://www.vlive.tv/oembed\";s:11:\"\0*\0provider\";r:3887;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://www.vlive.tv/video/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Vouch\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Vouch\";s:6:\"\0*\0url\";s:25:\"https://www.vouchfor.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://embed.vouchfor.com/v1/oembed\";s:11:\"\0*\0provider\";r:3899;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://*.vouchfor.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"VoxSnap\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"VoxSnap\";s:6:\"\0*\0url\";s:20:\"https://voxsnap.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://data.voxsnap.com/oembed\";s:11:\"\0*\0provider\";r:3910;s:10:\"\0*\0schemes\";a:1:{i:0;s:31:\"https://article.voxsnap.com/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Waltrack\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Waltrack\";s:6:\"\0*\0url\";s:20:\"https://waltrack/net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://waltrack.net/oembed\";s:11:\"\0*\0provider\";r:3922;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://waltrack.net/product/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Wave.video\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Wave.video\";s:6:\"\0*\0url\";s:18:\"https://wave.video\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://embed.wave.video/oembed\";s:11:\"\0*\0provider\";r:3933;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://watch.wave.video/*\";i:1;s:26:\"https://embed.wave.video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:24:\"Web3 is Going Just Great\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:24:\"Web3 is Going Just Great\";s:6:\"\0*\0url\";s:33:\"https://www.web3isgoinggreat.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://www.web3isgoinggreat.com/api/oembed\";s:11:\"\0*\0provider\";r:3945;s:10:\"\0*\0schemes\";a:3:{i:0;s:38:\"https://www.web3isgoinggreat.com/?id=*\";i:1;s:41:\"https://www.web3isgoinggreat.com/single/*\";i:2;s:40:\"https://www.web3isgoinggreat.com/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Webcrumbs\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Webcrumbs\";s:6:\"\0*\0url\";s:22:\"https://webcrumbs.org/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"http://share.webcrumbs.org/\";s:11:\"\0*\0provider\";r:3958;s:10:\"\0*\0schemes\";a:3:{i:0;s:29:\"https://share.webcrumbs.org/*\";i:1;s:29:\"https://tools.webcrumbs.org/*\";i:2;s:27:\"https://www.webcrumbs.org/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"wecandeo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"wecandeo\";s:6:\"\0*\0url\";s:25:\"https://www.wecandeo.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://play.wecandeo.com/oembed/\";s:11:\"\0*\0provider\";r:3971;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"https://play.wecandeo.com/video/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Whimsical\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Whimsical\";s:6:\"\0*\0url\";s:25:\"https://www.whimsical.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://whimsical.com/api/oembed\";s:11:\"\0*\0provider\";r:3982;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://whimsical.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"Wistia, Inc.\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Wistia, Inc.\";s:6:\"\0*\0url\";s:19:\"https://wistia.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://fast.wistia.com/oembed.json\";s:11:\"\0*\0provider\";r:3993;s:10:\"\0*\0schemes\";a:3:{i:0;s:38:\"https://fast.wistia.com/embed/iframe/*\";i:1;s:41:\"https://fast.wistia.com/embed/playlists/*\";i:2;s:29:\"https://*.wistia.com/medias/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"wizer.me\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"wizer.me\";s:6:\"\0*\0url\";s:21:\"https://www.wizer.me/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://app.wizer.me/api/oembed.json\";s:11:\"\0*\0provider\";r:4006;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://*.wizer.me/learn/*\";i:1;s:28:\"https://*.wizer.me/preview/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Wokwi\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Wokwi\";s:6:\"\0*\0url\";s:17:\"https://wokwi.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://wokwi.com/api/oembed\";s:11:\"\0*\0provider\";r:4018;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://wokwi.com/share/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:13:\"Wolfram Cloud\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Wolfram Cloud\";s:6:\"\0*\0url\";s:28:\"https://www.wolframcloud.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.wolframcloud.com/oembed\";s:11:\"\0*\0provider\";r:4030;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://*.wolframcloud.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:13:\"WordPress.com\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"WordPress.com\";s:6:\"\0*\0url\";s:22:\"https://wordpress.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"http://public-api.wordpress.com/oembed/\";s:11:\"\0*\0provider\";r:4041;s:10:\"\0*\0schemes\";a:8:{i:0;s:23:\"https://wordpress.com/*\";i:1;s:22:\"http://wordpress.com/*\";i:2;s:25:\"https://*.wordpress.com/*\";i:3;s:24:\"http://*.wordpress.com/*\";i:4;s:27:\"https://*.*.wordpress.com/*\";i:5;s:26:\"http://*.*.wordpress.com/*\";i:6;s:15:\"https://wp.me/*\";i:7;s:14:\"http://wp.me/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:1:\"X\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:1:\"X\";s:6:\"\0*\0url\";s:17:\"http://www.x.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://publish.x.com/oembed\";s:11:\"\0*\0provider\";r:4059;s:10:\"\0*\0schemes\";a:3:{i:0;s:15:\"https://x.com/*\";i:1;s:24:\"https://x.com/*/status/*\";i:2;s:26:\"https://*.x.com/*/status/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"YouTube\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"YouTube\";s:6:\"\0*\0url\";s:24:\"https://www.youtube.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://www.youtube.com/oembed\";s:11:\"\0*\0provider\";r:4072;s:10:\"\0*\0schemes\";a:10:{i:0;s:28:\"https://*.youtube.com/watch*\";i:1;s:25:\"https://*.youtube.com/v/*\";i:2;s:18:\"https://youtu.be/*\";i:3;s:37:\"https://*.youtube.com/playlist?list=*\";i:4;s:35:\"https://youtube.com/playlist?list=*\";i:5;s:29:\"https://*.youtube.com/shorts*\";i:6;s:27:\"https://youtube.com/shorts*\";i:7;s:29:\"https://*.youtube.com/embed/*\";i:8;s:27:\"https://*.youtube.com/live*\";i:9;s:25:\"https://youtube.com/live*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"YUMPU\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"YUMPU\";s:6:\"\0*\0url\";s:22:\"https://www.yumpu.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://www.yumpu.com/services/oembed\";s:11:\"\0*\0provider\";r:4092;s:10:\"\0*\0schemes\";a:1:{i:0;s:41:\"https://www.yumpu.com/*/document/view/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Zeplin\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Zeplin\";s:6:\"\0*\0url\";s:17:\"https://zeplin.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://app.zeplin.io/embed\";s:11:\"\0*\0provider\";r:4103;s:10:\"\0*\0schemes\";a:4:{i:0;s:40:\"https://app.zeplin.io/project/*/screen/*\";i:1;s:50:\"https://app.zeplin.io/project/*/screen/*/version/*\";i:2;s:60:\"https://app.zeplin.io/project/*/styleguide/components?coid=*\";i:3;s:52:\"https://app.zeplin.io/styleguide/*/components?coid=*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"ZingSoft\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"ZingSoft\";s:6:\"\0*\0url\";s:24:\"https://app.zingsoft.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://app.zingsoft.com/oembed\";s:11:\"\0*\0provider\";r:4117;s:10:\"\0*\0schemes\";a:2:{i:0;s:32:\"https://app.zingsoft.com/embed/*\";i:1;s:31:\"https://app.zingsoft.com/view/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"ZnipeTV\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"ZnipeTV\";s:6:\"\0*\0url\";s:21:\"https://www.znipe.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://api.znipe.tv/v3/oembed/\";s:11:\"\0*\0provider\";r:4129;s:10:\"\0*\0schemes\";a:1:{i:0;s:20:\"https://*.znipe.tv/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Zoomable\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Zoomable\";s:6:\"\0*\0url\";s:20:\"https://zoomable.ca/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://srv2.zoomable.ca/oembed\";s:11:\"\0*\0provider\";r:4140;s:10:\"\0*\0schemes\";a:1:{i:0;s:36:\"https://srv2.zoomable.ca/viewer.php*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}}s:7:\"expires\";i:1736097063;}'),('post_update','existing_updates',_binary 'a:187:{i:0;s:70:\"system_post_update_convert_empty_country_and_timezone_settings_to_null\";i:1;s:32:\"system_post_update_sdc_uninstall\";i:2;s:64:\"system_post_update_recalculate_configuration_entity_dependencies\";i:3;s:48:\"system_post_update_add_region_to_entity_displays\";i:4;s:37:\"system_post_update_hashes_clear_cache\";i:5;s:36:\"system_post_update_timestamp_plugins\";i:6;s:41:\"system_post_update_classy_message_library\";i:7;s:37:\"system_post_update_field_type_plugins\";i:8;s:48:\"system_post_update_field_formatter_entity_schema\";i:9;s:36:\"system_post_update_fix_jquery_extend\";i:10;s:40:\"system_post_update_change_action_plugins\";i:11;s:47:\"system_post_update_change_delete_action_plugins\";i:12;s:41:\"system_post_update_language_item_callback\";i:13;s:31:\"system_post_update_extra_fields\";i:14;s:37:\"system_post_update_states_clear_cache\";i:15;s:64:\"system_post_update_add_expand_all_items_key_in_system_menu_block\";i:16;s:35:\"system_post_update_clear_menu_cache\";i:17;s:46:\"system_post_update_layout_plugin_schema_change\";i:18;s:60:\"system_post_update_entity_reference_autocomplete_match_limit\";i:19;s:44:\"system_post_update_extra_fields_form_display\";i:20;s:39:\"system_post_update_uninstall_simpletest\";i:21;s:52:\"system_post_update_uninstall_entity_reference_module\";i:22;s:54:\"system_post_update_entity_revision_metadata_bc_cleanup\";i:23;s:35:\"system_post_update_uninstall_classy\";i:24;s:35:\"system_post_update_uninstall_stable\";i:25;s:44:\"system_post_update_claro_dropbutton_variants\";i:26;s:37:\"system_post_update_schema_version_int\";i:27;s:38:\"system_post_update_delete_rss_settings\";i:28;s:52:\"system_post_update_remove_key_value_expire_all_index\";i:29;s:44:\"system_post_update_service_advisory_settings\";i:30;s:44:\"system_post_update_delete_authorize_settings\";i:31;s:34:\"system_post_update_sort_all_config\";i:32;s:50:\"system_post_update_enable_provider_database_driver\";i:33;s:35:\"system_post_update_linkset_settings\";i:34;s:48:\"system_post_update_enable_password_compatibility\";i:35;s:39:\"system_post_update_remove_asset_entries\";i:36;s:44:\"system_post_update_remove_asset_query_string\";i:37;s:54:\"system_post_update_add_description_to_entity_view_mode\";i:38;s:54:\"system_post_update_add_description_to_entity_form_mode\";i:39;s:44:\"system_post_update_set_blank_log_url_to_null\";i:40;s:38:\"system_post_update_mailer_dsn_settings\";i:41;s:49:\"system_post_update_mailer_structured_dsn_settings\";i:42;s:47:\"system_post_update_amend_config_sync_readme_url\";i:43;s:44:\"system_post_update_mail_notification_setting\";i:44;s:54:\"system_post_update_set_cron_logging_setting_to_boolean\";i:45;s:56:\"system_post_update_move_development_settings_to_keyvalue\";i:46;s:58:\"system_post_update_add_langcode_to_all_translatable_config\";i:47;s:45:\"user_post_update_enforce_order_of_permissions\";i:48;s:29:\"user_post_update_update_roles\";i:49;s:33:\"user_post_update_sort_permissions\";i:50;s:39:\"user_post_update_sort_permissions_again\";i:51;s:51:\"path_alias_post_update_drop_path_alias_status_index\";i:52;s:62:\"contact_post_update_add_message_redirect_field_to_contact_form\";i:53;s:50:\"contact_post_update_set_empty_default_form_to_null\";i:54;s:35:\"help_post_update_help_topics_search\";i:55;s:38:\"help_post_update_help_topics_uninstall\";i:56;s:41:\"help_post_update_add_permissions_to_roles\";i:57;s:39:\"big_pipe_post_update_html5_placeholders\";i:58;s:49:\"dblog_post_update_convert_recent_messages_to_view\";i:59;s:54:\"block_post_update_disable_blocks_with_missing_contexts\";i:60;s:40:\"block_post_update_disabled_region_update\";i:61;s:42:\"block_post_update_fix_negate_in_conditions\";i:62;s:45:\"block_post_update_replace_node_type_condition\";i:63;s:46:\"field_post_update_save_custom_storage_property\";i:64;s:50:\"field_post_update_entity_reference_handler_setting\";i:65;s:43:\"field_post_update_email_widget_size_setting\";i:66;s:47:\"field_post_update_remove_handler_submit_setting\";i:67;s:31:\"filter_post_update_sort_filters\";i:68;s:44:\"filter_post_update_consolidate_filter_config\";i:69;s:42:\"text_post_update_add_required_summary_flag\";i:70;s:55:\"text_post_update_add_required_summary_flag_form_display\";i:71;s:32:\"text_post_update_allowed_formats\";i:72;s:51:\"block_content_post_update_add_views_reusable_filter\";i:73;s:51:\"block_content_post_update_entity_changed_constraint\";i:74;s:51:\"block_content_post_update_move_custom_block_library\";i:75;s:55:\"block_content_post_update_block_library_view_permission\";i:76;s:42:\"block_content_post_update_sort_permissions\";i:77;s:39:\"block_content_post_update_revision_type\";i:78;s:54:\"file_post_update_add_txt_if_allows_insecure_extensions\";i:79;s:41:\"file_post_update_add_permissions_to_roles\";i:80;s:64:\"file_post_update_add_default_filename_sanitization_configuration\";i:81;s:56:\"editor_post_update_clear_cache_for_file_reference_filter\";i:82;s:34:\"editor_post_update_image_lazy_load\";i:83;s:49:\"editor_post_update_sanitize_image_upload_settings\";i:84;s:39:\"ckeditor5_post_update_alignment_buttons\";i:85;s:40:\"ckeditor5_post_update_image_toolbar_item\";i:86;s:51:\"ckeditor5_post_update_plugins_settings_export_order\";i:87;s:32:\"ckeditor5_post_update_code_block\";i:88;s:37:\"ckeditor5_post_update_list_multiblock\";i:89;s:41:\"ckeditor5_post_update_list_start_reversed\";i:90;s:45:\"comment_post_update_enable_comment_admin_view\";i:91;s:42:\"comment_post_update_add_ip_address_setting\";i:92;s:48:\"contextual_post_update_fixed_endpoint_and_markup\";i:93;s:46:\"node_post_update_configure_status_field_widget\";i:94;s:41:\"node_post_update_node_revision_views_data\";i:95;s:40:\"node_post_update_glossary_view_published\";i:96;s:45:\"node_post_update_rebuild_node_revision_routes\";i:97;s:50:\"node_post_update_modify_base_field_author_override\";i:98;s:59:\"node_post_update_set_node_type_description_and_help_to_null\";i:99;s:42:\"image_post_update_image_style_dependencies\";i:100;s:50:\"image_post_update_scale_and_crop_effect_add_anchor\";i:101;s:41:\"image_post_update_image_loading_attribute\";i:102;s:47:\"views_post_update_views_data_argument_plugin_id\";i:103;s:46:\"views_post_update_update_cacheability_metadata\";i:104;s:46:\"views_post_update_cleanup_duplicate_views_data\";i:105;s:46:\"views_post_update_field_formatter_dependencies\";i:106;s:36:\"views_post_update_taxonomy_index_tid\";i:107;s:41:\"views_post_update_serializer_dependencies\";i:108;s:39:\"views_post_update_boolean_filter_values\";i:109;s:33:\"views_post_update_grouped_filters\";i:110;s:42:\"views_post_update_revision_metadata_fields\";i:111;s:33:\"views_post_update_entity_link_url\";i:112;s:34:\"views_post_update_bulk_field_moved\";i:113;s:41:\"views_post_update_filter_placeholder_text\";i:114;s:47:\"views_post_update_views_data_table_dependencies\";i:115;s:45:\"views_post_update_table_display_cache_max_age\";i:116;s:53:\"views_post_update_exposed_filter_blocks_label_display\";i:117;s:48:\"views_post_update_make_placeholders_translatable\";i:118;s:41:\"views_post_update_limit_operator_defaults\";i:119;s:33:\"views_post_update_remove_core_key\";i:120;s:51:\"views_post_update_field_names_for_multivalue_fields\";i:121;s:52:\"views_post_update_configuration_entity_relationships\";i:122;s:48:\"views_post_update_rename_default_display_setting\";i:123;s:50:\"views_post_update_remove_sorting_global_text_field\";i:124;s:36:\"views_post_update_title_translations\";i:125;s:33:\"views_post_update_sort_identifier\";i:126;s:53:\"views_post_update_provide_revision_table_relationship\";i:127;s:33:\"views_post_update_image_lazy_load\";i:128;s:39:\"views_post_update_boolean_custom_titles\";i:129;s:35:\"views_post_update_oembed_eager_load\";i:130;s:44:\"views_post_update_responsive_image_lazy_load\";i:131;s:37:\"views_post_update_timestamp_formatter\";i:132;s:38:\"views_post_update_fix_revision_id_part\";i:133;s:36:\"views_post_update_add_missing_labels\";i:134;s:43:\"views_post_update_remove_skip_cache_setting\";i:135;s:50:\"views_post_update_remove_default_argument_skip_url\";i:136;s:46:\"views_post_update_taxonomy_filter_user_context\";i:137;s:31:\"views_post_update_pager_heading\";i:138;s:54:\"views_post_update_rendered_entity_field_cache_metadata\";i:139;s:65:\"menu_link_content_post_update_make_menu_link_content_revisionable\";i:140;s:49:\"path_post_update_create_language_content_settings\";i:141;s:43:\"taxonomy_post_update_clear_views_data_cache\";i:142;s:64:\"taxonomy_post_update_clear_entity_bundle_field_definitions_cache\";i:143;s:63:\"taxonomy_post_update_handle_publishing_status_addition_in_views\";i:144;s:55:\"taxonomy_post_update_remove_hierarchy_from_vocabularies\";i:145;s:52:\"taxonomy_post_update_make_taxonomy_term_revisionable\";i:146;s:50:\"taxonomy_post_update_configure_status_field_widget\";i:147;s:65:\"taxonomy_post_update_clear_views_argument_validator_plugins_cache\";i:148;s:37:\"taxonomy_post_update_set_new_revision\";i:149;s:55:\"taxonomy_post_update_set_vocabulary_description_to_null\";i:150;s:45:\"olivero_post_update_add_olivero_primary_color\";i:151;s:34:\"media_post_update_collection_route\";i:152;s:33:\"media_post_update_storage_handler\";i:153;s:39:\"media_post_update_enable_standalone_url\";i:154;s:41:\"media_post_update_add_status_extra_filter\";i:155;s:51:\"media_post_update_modify_base_field_author_override\";i:156;s:42:\"media_post_update_oembed_loading_attribute\";i:157;s:49:\"media_post_update_set_blank_iframe_domain_to_null\";i:158;s:56:\"media_post_update_remove_mappings_targeting_source_field\";i:159;s:39:\"media_library_post_update_display_modes\";i:160;s:39:\"media_library_post_update_table_display\";i:161;s:55:\"media_library_post_update_add_media_library_image_style\";i:162;s:49:\"media_library_post_update_add_status_extra_filter\";i:163;s:50:\"media_library_post_update_add_buttons_to_page_view\";i:164;s:54:\"media_library_post_update_update_8001_checkbox_classes\";i:165;s:70:\"media_library_post_update_default_administrative_list_to_table_display\";i:166;s:46:\"media_library_post_update_add_langcode_filters\";i:167;s:59:\"admin_toolbar_tools_post_update_helper_added_config_factory\";i:168;s:42:\"gin_toolbar_post_update_gin_toolbar_beta19\";i:169;s:42:\"gin_toolbar_post_update_gin_toolbar_beta21\";i:170;s:42:\"gin_toolbar_post_update_gin_toolbar_beta22\";i:171;s:42:\"gin_toolbar_post_update_update_gin_alpha32\";i:172;s:44:\"paragraphs_post_update_rebuild_parent_fields\";i:173;s:51:\"paragraphs_post_update_set_paragraphs_parent_fields\";i:174;s:28:\"field_group_post_update_0001\";i:175;s:73:\"layout_discovery_post_update_recalculate_entity_form_display_dependencies\";i:176;s:73:\"layout_discovery_post_update_recalculate_entity_view_display_dependencies\";i:177;s:49:\"webform_post_update_authenticated_user_permission\";i:178;s:28:\"webform_post_update_ckeditor\";i:179;s:30:\"webform_post_update_ckeditor01\";i:180;s:45:\"webform_post_update_confirmation_page_noindex\";i:181;s:50:\"webform_post_update_deprecate_jquery_ui_datepicker\";i:182;s:45:\"webform_post_update_deprecate_location_places\";i:183;s:39:\"webform_post_update_multiple_categories\";i:184;s:37:\"block_post_update_make_weight_integer\";i:185;s:50:\"media_post_update_media_author_views_filter_update\";i:186;s:57:\"path_alias_post_update_update_path_alias_revision_indexes\";}'),('state','announcements_feed.last_fetch',_binary 'i:1735492259;'),('state','asset.css_js_query_string',_binary 's:6:\"sp9rag\";'),('state','comment.maintain_entity_statistics',_binary 'b:1;'),('state','comment.node_comment_statistics_scale',_binary 'd:1;'),('state','field.field.deleted',_binary 'a:6:{s:36:\"795e03b0-b565-45a1-9686-fd18b39c1595\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:41:\"paragraph.ept_super_slider.field_ept_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"795e03b0-b565-45a1-9686-fd18b39c1595\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wD3U2zCwLSeMtZ3H8fU7nhKYXWBH8fyoOmtw944OIZ8\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:43:\"paragraphs.paragraphs_type.ept_super_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:41:\"paragraph.ept_super_slider.field_ept_text\";s:13:\"\0*\0field_name\";s:14:\"field_ept_text\";s:13:\"\0*\0field_type\";s:9:\"text_long\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:16:\"ept_super_slider\";s:8:\"\0*\0label\";s:4:\"Text\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";N;s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:1;}s:36:\"47715517-fe33-4350-ba95-15442ee63bb9\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:42:\"paragraph.ept_super_slider.field_ept_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"47715517-fe33-4350-ba95-15442ee63bb9\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hxOcdYND1GFLya7DHFT4rGO7Z6X1ORt1BE3jGI-SgMc\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_super_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:42:\"paragraph.ept_super_slider.field_ept_title\";s:13:\"\0*\0field_name\";s:15:\"field_ept_title\";s:13:\"\0*\0field_type\";s:9:\"text_long\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:16:\"ept_super_slider\";s:8:\"\0*\0label\";s:5:\"Title\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";N;s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:1;}s:36:\"7724357e-5eb1-47d2-8c55-3dec9dcc9189\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:45:\"paragraph.ept_super_slider.field_ept_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7724357e-5eb1-47d2-8c55-3dec9dcc9189\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"H0WbdHPVhYw_OsWzVHavoqAohmUM_QUn512jNP0NjkQ\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:43:\"paragraphs.paragraphs_type.ept_super_slider\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:45:\"paragraph.ept_super_slider.field_ept_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ept_settings\";s:13:\"\0*\0field_type\";s:12:\"ept_settings\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:16:\"ept_super_slider\";s:8:\"\0*\0label\";s:8:\"Settings\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:0:{}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";N;s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:1;}s:36:\"2e3bcec3-2475-4d41-9e96-c7979041209f\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.ept_bottle.field_ept_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"2e3bcec3-2475-4d41-9e96-c7979041209f\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wts_52qIuRuSjQFh1xIQfoh-pZ2TlBGAImr-hzd88uo\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:37:\"paragraphs.paragraphs_type.ept_bottle\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.ept_bottle.field_ept_text\";s:13:\"\0*\0field_name\";s:14:\"field_ept_text\";s:13:\"\0*\0field_type\";s:9:\"text_long\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:10:\"ept_bottle\";s:8:\"\0*\0label\";s:4:\"Text\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";N;s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:1;}s:36:\"eadd2db3-934b-4586-9059-a8c3e7e1fee2\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.ept_bottle.field_ept_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"eadd2db3-934b-4586-9059-a8c3e7e1fee2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RWAJQEE-QNajqg3KeVM4LHdfaEvoKgEKy9bIEX3Un3M\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:37:\"paragraphs.paragraphs_type.ept_bottle\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.ept_bottle.field_ept_title\";s:13:\"\0*\0field_name\";s:15:\"field_ept_title\";s:13:\"\0*\0field_type\";s:9:\"text_long\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:10:\"ept_bottle\";s:8:\"\0*\0label\";s:5:\"Title\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";N;s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:1;}s:36:\"8f34ae32-d86d-4533-bcaf-9ce8a0e319b2\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:39:\"paragraph.ept_bottle.field_ept_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"8f34ae32-d86d-4533-bcaf-9ce8a0e319b2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RqLxI0qUNjuNk9_88ip647hke-78FqHm-178ZbgS7oQ\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:37:\"paragraphs.paragraphs_type.ept_bottle\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:39:\"paragraph.ept_bottle.field_ept_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ept_settings\";s:13:\"\0*\0field_type\";s:12:\"ept_settings\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:10:\"ept_bottle\";s:8:\"\0*\0label\";s:8:\"Settings\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:0:{}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";N;s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:1;}}'),('state','field.storage.deleted',_binary 'a:0:{}'),('state','help_search_unindexed_count',_binary 's:1:\"0\";'),('state','install_task',_binary 's:4:\"done\";'),('state','install_time',_binary 'i:1728225671;'),('state','node.min_max_update_time',_binary 'a:2:{s:11:\"min_created\";s:10:\"1665904809\";s:11:\"max_created\";s:10:\"1729064448\";}'),('state','router.path_roots',_binary 'a:34:{i:0;s:5:\"admin\";i:1;s:8:\"run-cron\";i:2;s:8:\"big_pipe\";i:3;s:14:\"block-category\";i:4;s:5:\"block\";i:5;s:9:\"ckeditor5\";i:6;s:7:\"comment\";i:7;s:8:\"comments\";i:8;s:7:\"contact\";i:9;s:4:\"user\";i:10;s:10:\"contextual\";i:11;s:6:\"editor\";i:12;s:4:\"file\";i:13;s:6:\"filter\";i:14;s:7:\"history\";i:15;s:5:\"sites\";i:16;s:6:\"system\";i:17;s:25:\"layout-paragraphs-builder\";i:18;s:5:\"media\";i:19;s:13:\"media-library\";i:20;s:4:\"node\";i:21;s:4:\"cron\";i:22;s:0:\"\";i:23;s:9:\"<current>\";i:24;s:5:\"batch\";i:25;s:10:\"update.php\";i:26;s:29:\"entity_reference_autocomplete\";i:27;s:7:\"session\";i:28;s:8:\"taxonomy\";i:29;s:7:\"toolbar\";i:30;s:11:\".well-known\";i:31;s:7:\"webform\";i:32;s:7:\"rss.xml\";i:33;s:5:\"views\";}'),('state','routing.menu_masks.router',_binary 'a:55:{i:0;i:985;i:1;i:501;i:2;i:495;i:3;i:494;i:4;i:493;i:5;i:492;i:6;i:491;i:7;i:489;i:8;i:464;i:9;i:253;i:10;i:252;i:11;i:250;i:12;i:249;i:13;i:247;i:14;i:246;i:15;i:245;i:16;i:244;i:17;i:233;i:18;i:232;i:19;i:126;i:20;i:125;i:21;i:124;i:22;i:123;i:23;i:122;i:24;i:117;i:25;i:116;i:26;i:63;i:27;i:62;i:28;i:61;i:29;i:60;i:30;i:59;i:31;i:58;i:32;i:53;i:33;i:49;i:34;i:48;i:35;i:42;i:36;i:31;i:37;i:30;i:38;i:29;i:39;i:28;i:40;i:24;i:41;i:21;i:42;i:15;i:43;i:14;i:44;i:13;i:45;i:12;i:46;i:11;i:47;i:10;i:48;i:8;i:49;i:7;i:50;i:6;i:51;i:5;i:52;i:3;i:53;i:2;i:54;i:1;}'),('state','routing.non_admin_routes',_binary 'a:121:{i:0;s:22:\"admin_toolbar.run.cron\";i:1;s:13:\"big_pipe.nojs\";i:2;s:27:\"block.category_autocomplete\";i:3;s:22:\"block_content.add_page\";i:4;s:22:\"block_content.add_form\";i:5;s:31:\"ckeditor5.media_entity_metadata\";i:6;s:24:\"entity.comment.edit_form\";i:7;s:15:\"comment.approve\";i:8;s:24:\"entity.comment.canonical\";i:9;s:26:\"entity.comment.delete_form\";i:10;s:13:\"comment.reply\";i:11;s:31:\"comment.new_comments_node_links\";i:12;s:21:\"comment.node_redirect\";i:13;s:17:\"contact.site_page\";i:14;s:29:\"entity.contact_form.canonical\";i:15;s:24:\"entity.user.contact_form\";i:16;s:17:\"contextual.render\";i:17;s:17:\"editor.filter_xss\";i:18;s:18:\"file.ajax_progress\";i:19;s:15:\"filter.tips_all\";i:20;s:11:\"filter.tips\";i:21;s:26:\"history.get_last_node_view\";i:22;s:17:\"history.read_node\";i:23;s:18:\"image.style_public\";i:24;s:19:\"image.style_private\";i:25;s:35:\"layout_paragraphs.builder.formatter\";i:26;s:42:\"layout_paragraphs.builder.choose_component\";i:27;s:35:\"layout_paragraphs.builder.edit_item\";i:28;s:32:\"layout_paragraphs.builder.insert\";i:29;s:40:\"layout_paragraphs.builder.duplicate_item\";i:30;s:37:\"layout_paragraphs.builder.delete_item\";i:31;s:33:\"layout_paragraphs.builder.reorder\";i:32;s:19:\"media.oembed_iframe\";i:33;s:20:\"media.filter.preview\";i:34;s:16:\"media_library.ui\";i:35;s:13:\"node.add_page\";i:36;s:8:\"node.add\";i:37;s:19:\"entity.node.preview\";i:38;s:27:\"entity.node.version_history\";i:39;s:20:\"entity.node.revision\";i:40;s:28:\"node.revision_revert_confirm\";i:41;s:40:\"node.revision_revert_translation_confirm\";i:42;s:28:\"node.revision_delete_confirm\";i:43;s:19:\"shortcut.set_switch\";i:44;s:16:\"system.css_asset\";i:45;s:15:\"system.js_asset\";i:46;s:10:\"system.401\";i:47;s:10:\"system.403\";i:48;s:10:\"system.404\";i:49;s:10:\"system.4xx\";i:50;s:11:\"system.cron\";i:51;s:12:\"system.files\";i:52;s:28:\"system.private_file_download\";i:53;s:16:\"system.temporary\";i:54;s:7:\"<front>\";i:55;s:6:\"<none>\";i:56;s:8:\"<nolink>\";i:57;s:8:\"<button>\";i:58;s:9:\"<current>\";i:59;s:15:\"system.timezone\";i:60;s:22:\"system.batch_page.html\";i:61;s:16:\"system.db_update\";i:62;s:26:\"system.entity_autocomplete\";i:63;s:16:\"system.csrftoken\";i:64;s:30:\"entity.taxonomy_term.edit_form\";i:65;s:32:\"entity.taxonomy_term.delete_form\";i:66;s:16:\"toolbar.subtrees\";i:67;s:13:\"user.register\";i:68;s:11:\"user.logout\";i:69;s:19:\"user.logout.confirm\";i:70;s:9:\"user.pass\";i:71;s:9:\"user.page\";i:72;s:9:\"user.edit\";i:73;s:10:\"user.login\";i:74;s:19:\"user.cancel_confirm\";i:75;s:16:\"user.reset.login\";i:76;s:10:\"user.reset\";i:77;s:15:\"user.reset.form\";i:78;s:31:\"user.well-known.change_password\";i:79;s:24:\"entity.webform.canonical\";i:80;s:28:\"entity.webform.access_denied\";i:81;s:32:\"entity.webform.assets.javascript\";i:82;s:25:\"entity.webform.assets.css\";i:83;s:27:\"entity.webform.confirmation\";i:84;s:31:\"entity.webform.user.submissions\";i:85;s:26:\"entity.webform.user.drafts\";i:86;s:30:\"entity.webform.user.submission\";i:87;s:35:\"entity.webform.user.submission.edit\";i:88;s:37:\"entity.webform.user.submission.delete\";i:89;s:40:\"entity.webform.user.submission.duplicate\";i:90;s:24:\"entity.webform.test_form\";i:91;s:30:\"entity.webform_submission.user\";i:92;s:28:\"webform.element.autocomplete\";i:93;s:29:\"webform.element.message.close\";i:94;s:21:\"view.frontpage.feed_1\";i:95;s:21:\"view.frontpage.page_1\";i:96;s:25:\"view.taxonomy_term.feed_1\";i:97;s:25:\"view.taxonomy_term.page_1\";i:98;s:10:\"views.ajax\";i:99;s:23:\"entity.file.delete_form\";i:100;s:21:\"entity.media.add_page\";i:101;s:21:\"entity.media.add_form\";i:102;s:22:\"entity.media.canonical\";i:103;s:22:\"entity.media.edit_form\";i:104;s:24:\"entity.media.delete_form\";i:105;s:33:\"entity.media.delete_multiple_form\";i:106;s:28:\"entity.media.version_history\";i:107;s:21:\"entity.media.revision\";i:108;s:33:\"entity.media.revision_revert_form\";i:109;s:33:\"entity.media.revision_delete_form\";i:110;s:21:\"entity.node.canonical\";i:111;s:23:\"entity.node.delete_form\";i:112;s:21:\"entity.node.edit_form\";i:113;s:36:\"entity.taxonomy_term.version_history\";i:114;s:29:\"entity.taxonomy_term.revision\";i:115;s:41:\"entity.taxonomy_term.revision_revert_form\";i:116;s:41:\"entity.taxonomy_term.revision_delete_form\";i:117;s:21:\"entity.user.canonical\";i:118;s:21:\"entity.user.edit_form\";i:119;s:23:\"entity.user.cancel_form\";i:120;s:30:\"entity.taxonomy_term.canonical\";}'),('state','system.cron_key',_binary 's:74:\"3Mgpm8yeFKquH3xJ0co4IHN4uWiCfI-UUq-95wej3VNSj0F0za_e-QpaaWs8ILH25NKYMlQOUw\";'),('state','system.cron_last',_binary 'i:1735492259;'),('state','system.maintenance_mode',_binary 'b:0;'),('state','system.private_key',_binary 's:74:\"pYtrA91zgh_nDysu4T4CnnvzpZWXJwUqctYjV4XbnF7wHtM-QriFyxdnpc8YEsDY3VhfbBBQVw\";'),('state','system.profile.files',_binary 'a:4:{s:10:\"demo_umami\";s:44:\"core/profiles/demo_umami/demo_umami.info.yml\";s:4:\"fast\";s:27:\"profiles/fast/fast.info.yml\";s:7:\"minimal\";s:38:\"core/profiles/minimal/minimal.info.yml\";s:8:\"standard\";s:40:\"core/profiles/standard/standard.info.yml\";}'),('state','system.theme.files',_binary 'a:7:{s:5:\"claro\";s:32:\"core/themes/claro/claro.info.yml\";s:9:\"ept_light\";s:42:\"themes/custom/ept_light/ept_light.info.yml\";s:3:\"gin\";s:31:\"themes/contrib/gin/gin.info.yml\";s:7:\"olivero\";s:36:\"core/themes/olivero/olivero.info.yml\";s:7:\"stable9\";s:36:\"core/themes/stable9/stable9.info.yml\";s:5:\"stark\";s:32:\"core/themes/stark/stark.info.yml\";s:16:\"starterkit_theme\";s:54:\"core/themes/starterkit_theme/starterkit_theme.info.yml\";}'),('state','twig_extension_hash_prefix',_binary 'a:2:{s:19:\"twig_extension_hash\";s:43:\"qemy_o2jmFYwz7IZw2_fXp4Nh8_kA3v5UAkKPPbfKGE\";s:17:\"twig_cache_prefix\";s:13:\"67719bfec46ef\";}'),('state','update.last_check',_binary 'i:1735492272;'),('state','update.last_email_notification',_binary 'i:1735492259;'),('state','views.view_route_names',_binary 'a:16:{s:13:\"watchdog.page\";s:14:\"dblog.overview\";s:24:\"user_admin_people.page_1\";s:22:\"entity.user.collection\";s:20:\"taxonomy_term.page_1\";s:30:\"entity.taxonomy_term.canonical\";s:21:\"media.media_page_list\";s:23:\"entity.media.collection\";s:14:\"content.page_1\";s:20:\"system.admin_content\";s:23:\"comment.page_unapproved\";s:22:\"comment.admin_approval\";s:22:\"comment.page_published\";s:13:\"comment.admin\";s:20:\"block_content.page_1\";s:31:\"entity.block_content.collection\";s:12:\"files.page_1\";s:17:\"view.files.page_1\";s:12:\"files.page_2\";s:17:\"view.files.page_2\";s:16:\"frontpage.feed_1\";s:21:\"view.frontpage.feed_1\";s:16:\"frontpage.page_1\";s:21:\"view.frontpage.page_1\";s:18:\"media_library.page\";s:23:\"view.media_library.page\";s:20:\"media_library.widget\";s:25:\"view.media_library.widget\";s:26:\"media_library.widget_table\";s:31:\"view.media_library.widget_table\";s:20:\"taxonomy_term.feed_1\";s:25:\"view.taxonomy_term.feed_1\";}'),('state','webform.element.message',_binary 'a:0:{}'),('state','webform.version',_binary 's:12:\"6.3.0-alpha3\";'),('system.schema','admin_toolbar',_binary 'i:8003;'),('system.schema','admin_toolbar_tools',_binary 'i:8202;'),('system.schema','announcements_feed',_binary 'i:8000;'),('system.schema','automated_cron',_binary 'i:8000;'),('system.schema','better_exposed_filters',_binary 'i:10001;'),('system.schema','big_pipe',_binary 'i:8000;'),('system.schema','block',_binary 'i:8003;'),('system.schema','block_content',_binary 'i:10300;'),('system.schema','block_field',_binary 'i:8001;'),('system.schema','breakpoint',_binary 'i:8000;'),('system.schema','ckeditor5',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_auto_image',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_find_and_replace',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_font',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_highlight',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_indent_block',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_link_attributes',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_page_break',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_select_all',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_templates',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_text_transformation',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_todo_document_list',_binary 'i:8000;'),('system.schema','ckeditor5_premium_features_fullscreen',_binary 'i:8000;'),('system.schema','comment',_binary 'i:10100;'),('system.schema','config',_binary 'i:8000;'),('system.schema','contact',_binary 'i:8000;'),('system.schema','contextual',_binary 'i:8000;'),('system.schema','datetime',_binary 'i:8000;'),('system.schema','dblog',_binary 'i:10101;'),('system.schema','dynamic_page_cache',_binary 'i:8000;'),('system.schema','editor',_binary 'i:8001;'),('system.schema','entity_reference_revisions',_binary 'i:8000;'),('system.schema','ept_accordion',_binary 'i:8000;'),('system.schema','ept_basic_button',_binary 'i:8000;'),('system.schema','ept_block',_binary 'i:8000;'),('system.schema','ept_bootstrap_button',_binary 'i:8000;'),('system.schema','ept_carousel',_binary 'i:9102;'),('system.schema','ept_columns',_binary 'i:8000;'),('system.schema','ept_core',_binary 'i:8000;'),('system.schema','ept_core_starterkit',_binary 'i:8000;'),('system.schema','ept_countdown',_binary 'i:8000;'),('system.schema','ept_counter',_binary 'i:8000;'),('system.schema','ept_cta',_binary 'i:8000;'),('system.schema','ept_hero',_binary 'i:8000;'),('system.schema','ept_image',_binary 'i:8000;'),('system.schema','ept_image_gallery',_binary 'i:8000;'),('system.schema','ept_micromodal',_binary 'i:9001;'),('system.schema','ept_quote',_binary 'i:8000;'),('system.schema','ept_slick_slider',_binary 'i:8000;'),('system.schema','ept_slideshow',_binary 'i:8000;'),('system.schema','ept_stats',_binary 'i:8000;'),('system.schema','ept_tabs',_binary 'i:8000;'),('system.schema','ept_text',_binary 'i:8000;'),('system.schema','ept_tiles',_binary 'i:8000;'),('system.schema','ept_video',_binary 'i:8000;'),('system.schema','ept_video_and_image_gallery',_binary 'i:8000;'),('system.schema','ept_views',_binary 'i:8000;'),('system.schema','ept_webform',_binary 'i:9001;'),('system.schema','ept_webform_popup',_binary 'i:8000;'),('system.schema','fast',_binary 'i:8000;'),('system.schema','field',_binary 'i:8500;'),('system.schema','field_group',_binary 'i:8303;'),('system.schema','field_ui',_binary 'i:8000;'),('system.schema','file',_binary 'i:8700;'),('system.schema','file_mdm',_binary 'i:8201;'),('system.schema','file_mdm_exif',_binary 'i:8000;'),('system.schema','file_mdm_font',_binary 'i:8000;'),('system.schema','filter',_binary 'i:8000;'),('system.schema','gin_toolbar',_binary 'i:8000;'),('system.schema','glightbox',_binary 'i:8000;'),('system.schema','glightbox_media_video',_binary 'i:8000;'),('system.schema','help',_binary 'i:10200;'),('system.schema','history',_binary 'i:10100;'),('system.schema','image',_binary 'i:8201;'),('system.schema','image_effects',_binary 'i:8203;'),('system.schema','jquery_ui',_binary 'i:8000;'),('system.schema','jquery_ui_accordion',_binary 'i:8000;'),('system.schema','jquery_ui_tabs',_binary 'i:8000;'),('system.schema','layout_discovery',_binary 'i:8000;'),('system.schema','layout_paragraphs',_binary 'i:9002;'),('system.schema','link',_binary 'i:8000;'),('system.schema','link_attributes',_binary 'i:9001;'),('system.schema','link_attributes_menu_link_content',_binary 'i:8000;'),('system.schema','media',_binary 'i:8700;'),('system.schema','media_library',_binary 'i:8704;'),('system.schema','media_library_edit',_binary 'i:8000;'),('system.schema','media_library_form_element',_binary 'i:8000;'),('system.schema','menu_link_content',_binary 'i:8601;'),('system.schema','menu_ui',_binary 'i:8000;'),('system.schema','node',_binary 'i:8700;'),('system.schema','options',_binary 'i:8000;'),('system.schema','page_cache',_binary 'i:8000;'),('system.schema','paragraphs',_binary 'i:8022;'),('system.schema','path',_binary 'i:8200;'),('system.schema','path_alias',_binary 'i:8000;'),('system.schema','shortcut',_binary 'i:8000;'),('system.schema','system',_binary 'i:11102;'),('system.schema','taxonomy',_binary 'i:10100;'),('system.schema','tb_megamenu',_binary 'i:8001;'),('system.schema','text',_binary 'i:8000;'),('system.schema','toolbar',_binary 'i:8000;'),('system.schema','twig_tweak',_binary 'i:8000;'),('system.schema','update',_binary 'i:8001;'),('system.schema','user',_binary 'i:10000;'),('system.schema','views',_binary 'i:8500;'),('system.schema','viewsreference',_binary 'i:8103;'),('system.schema','views_ui',_binary 'i:8000;'),('system.schema','views_year_filter',_binary 'i:8000;'),('system.schema','webform',_binary 'i:8638;'),('update_fetch_task','admin_toolbar',_binary 'a:6:{s:4:\"name\";s:13:\"admin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Admin Toolbar\";s:7:\"package\";s:14:\"Administration\";s:7:\"version\";s:5:\"3.5.1\";s:7:\"project\";s:13:\"admin_toolbar\";s:9:\"datestamp\";i:1730409975;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1730409975;s:8:\"includes\";a:2:{s:13:\"admin_toolbar\";s:13:\"Admin Toolbar\";s:19:\"admin_toolbar_tools\";s:25:\"Admin Toolbar Extra Tools\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','ckeditor5_plugin_pack',_binary 'a:6:{s:4:\"name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.2.4\";s:7:\"project\";s:21:\"ckeditor5_plugin_pack\";s:9:\"datestamp\";i:1734514951;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734514951;s:8:\"includes\";a:12:{s:21:\"ckeditor5_plugin_pack\";s:22:\"CKEditor 5 Plugin Pack\";s:32:\"ckeditor5_plugin_pack_auto_image\";s:21:\"CKEditor 5 Auto Image\";s:38:\"ckeditor5_plugin_pack_find_and_replace\";s:27:\"CKEditor 5 Find And Replace\";s:26:\"ckeditor5_plugin_pack_font\";s:23:\"CKEditor 5 Font Plugins\";s:31:\"ckeditor5_plugin_pack_highlight\";s:20:\"CKEditor 5 Highlight\";s:34:\"ckeditor5_plugin_pack_indent_block\";s:28:\"CKEditor 5 Block Indentation\";s:37:\"ckeditor5_plugin_pack_link_attributes\";s:26:\"CKEditor 5 Link Attributes\";s:32:\"ckeditor5_plugin_pack_page_break\";s:21:\"CKEditor 5 Page Break\";s:32:\"ckeditor5_plugin_pack_select_all\";s:21:\"CKEditor 5 Select All\";s:31:\"ckeditor5_plugin_pack_templates\";s:20:\"CKEditor 5 Templates\";s:41:\"ckeditor5_plugin_pack_text_transformation\";s:30:\"CKEditor 5 Text Transformation\";s:40:\"ckeditor5_plugin_pack_todo_document_list\";s:21:\"CKEditor 5 To-do List\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','ckeditor5_premium_features',_binary 'a:6:{s:4:\"name\";s:26:\"ckeditor5_premium_features\";s:4:\"info\";a:6:{s:4:\"name\";s:27:\"CKEditor 5 Full-screen Mode\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.3.5\";s:7:\"project\";s:26:\"ckeditor5_premium_features\";s:9:\"datestamp\";i:1734513731;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1734513731;s:8:\"includes\";a:1:{s:37:\"ckeditor5_premium_features_fullscreen\";s:27:\"CKEditor 5 Full-screen Mode\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','drupal',_binary 'a:6:{s:4:\"name\";s:6:\"drupal\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Announcements\";s:7:\"version\";s:6:\"11.1.0\";s:7:\"package\";s:4:\"Core\";s:7:\"project\";s:6:\"drupal\";s:16:\"_info_file_ctime\";i:1735498473;s:9:\"datestamp\";i:0;}s:9:\"datestamp\";i:0;s:8:\"includes\";a:43:{s:18:\"announcements_feed\";s:13:\"Announcements\";s:14:\"automated_cron\";s:14:\"Automated Cron\";s:8:\"big_pipe\";s:7:\"BigPipe\";s:5:\"block\";s:5:\"Block\";s:13:\"block_content\";s:13:\"Block Content\";s:10:\"breakpoint\";s:10:\"Breakpoint\";s:9:\"ckeditor5\";s:10:\"CKEditor 5\";s:7:\"comment\";s:7:\"Comment\";s:6:\"config\";s:21:\"Configuration Manager\";s:7:\"contact\";s:7:\"Contact\";s:10:\"contextual\";s:16:\"Contextual Links\";s:8:\"datetime\";s:8:\"Datetime\";s:5:\"dblog\";s:16:\"Database Logging\";s:18:\"dynamic_page_cache\";s:27:\"Internal Dynamic Page Cache\";s:6:\"editor\";s:11:\"Text Editor\";s:5:\"field\";s:5:\"Field\";s:8:\"field_ui\";s:8:\"Field UI\";s:4:\"file\";s:4:\"File\";s:6:\"filter\";s:6:\"Filter\";s:4:\"help\";s:4:\"Help\";s:7:\"history\";s:7:\"History\";s:5:\"image\";s:5:\"Image\";s:16:\"layout_discovery\";s:16:\"Layout Discovery\";s:4:\"link\";s:4:\"Link\";s:5:\"media\";s:5:\"Media\";s:13:\"media_library\";s:13:\"Media Library\";s:17:\"menu_link_content\";s:17:\"Custom Menu Links\";s:7:\"menu_ui\";s:7:\"Menu UI\";s:4:\"node\";s:4:\"Node\";s:7:\"options\";s:7:\"Options\";s:10:\"page_cache\";s:19:\"Internal Page Cache\";s:4:\"path\";s:4:\"Path\";s:10:\"path_alias\";s:10:\"Path alias\";s:6:\"search\";s:6:\"Search\";s:8:\"shortcut\";s:8:\"Shortcut\";s:6:\"system\";s:6:\"System\";s:8:\"taxonomy\";s:8:\"Taxonomy\";s:4:\"text\";s:4:\"Text\";s:7:\"toolbar\";s:7:\"Toolbar\";s:6:\"update\";s:14:\"Update Manager\";s:4:\"user\";s:4:\"User\";s:5:\"views\";s:5:\"Views\";s:8:\"views_ui\";s:8:\"Views UI\";}s:12:\"project_type\";s:4:\"core\";s:14:\"project_status\";b:1;}'),('update_fetch_task','ept_carousel',_binary 'a:6:{s:4:\"name\";s:12:\"ept_carousel\";s:4:\"info\";a:6:{s:4:\"name\";s:37:\"Extra Paragraph Types (EPT): Carousel\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:12:\"ept_carousel\";s:9:\"datestamp\";i:1734284534;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1734284534;s:8:\"includes\";a:1:{s:12:\"ept_carousel\";s:37:\"Extra Paragraph Types (EPT): Carousel\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','ept_hero',_binary 'a:6:{s:4:\"name\";s:8:\"ept_hero\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Hero\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:8:\"ept_hero\";s:9:\"datestamp\";i:1733145602;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1733145602;s:8:\"includes\";a:1:{s:8:\"ept_hero\";s:33:\"Extra Paragraph Types (EPT): Hero\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','ept_tabs',_binary 'a:6:{s:4:\"name\";s:8:\"ept_tabs\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Tabs\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:8:\"ept_tabs\";s:9:\"datestamp\";i:1735472536;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1735472536;s:8:\"includes\";a:1:{s:8:\"ept_tabs\";s:33:\"Extra Paragraph Types (EPT): Tabs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','ept_webform',_binary 'a:6:{s:4:\"name\";s:11:\"ept_webform\";s:4:\"info\";a:6:{s:4:\"name\";s:36:\"Extra Paragraph Types (EPT): Webform\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:11:\"ept_webform\";s:9:\"datestamp\";i:1721384667;s:16:\"_info_file_ctime\";i:1735492408;}s:9:\"datestamp\";i:1721384667;s:8:\"includes\";a:1:{s:11:\"ept_webform\";s:36:\"Extra Paragraph Types (EPT): Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','ept_webform_popup',_binary 'a:6:{s:4:\"name\";s:17:\"ept_webform_popup\";s:4:\"info\";a:6:{s:4:\"name\";s:42:\"Extra Paragraph Types (EPT): Webform Popup\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:17:\"ept_webform_popup\";s:9:\"datestamp\";i:1721384667;s:16:\"_info_file_ctime\";i:1735492408;}s:9:\"datestamp\";i:1721384667;s:8:\"includes\";a:1:{s:17:\"ept_webform_popup\";s:42:\"Extra Paragraph Types (EPT): Webform Popup\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','gin',_binary 'a:6:{s:4:\"name\";s:3:\"gin\";s:4:\"info\";a:5:{s:4:\"name\";s:3:\"Gin\";s:7:\"version\";s:7:\"8.x-3.0\";s:7:\"project\";s:3:\"gin\";s:9:\"datestamp\";i:1734696851;s:16:\"_info_file_ctime\";i:1735498436;}s:9:\"datestamp\";i:1734696851;s:8:\"includes\";a:1:{s:3:\"gin\";s:3:\"Gin\";}s:12:\"project_type\";s:5:\"theme\";s:14:\"project_status\";b:1;}'),('update_fetch_task','gin_toolbar',_binary 'a:6:{s:4:\"name\";s:11:\"gin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Gin Toolbar\";s:7:\"version\";s:7:\"8.x-1.0\";s:7:\"project\";s:11:\"gin_toolbar\";s:9:\"datestamp\";i:1734698812;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734698812;s:8:\"includes\";a:1:{s:11:\"gin_toolbar\";s:11:\"Gin Toolbar\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','glightbox',_binary 'a:6:{s:4:\"name\";s:9:\"glightbox\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"GLightbox\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:6:\"1.0.13\";s:7:\"project\";s:9:\"glightbox\";s:9:\"datestamp\";i:1734093965;s:16:\"_info_file_ctime\";i:1735498429;}s:9:\"datestamp\";i:1734093965;s:8:\"includes\";a:1:{s:9:\"glightbox\";s:9:\"GLightbox\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','glightbox_media_video',_binary 'a:6:{s:4:\"name\";s:21:\"glightbox_media_video\";s:4:\"info\";a:6:{s:4:\"name\";s:21:\"GLightbox Media Video\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"1.0.3\";s:7:\"project\";s:21:\"glightbox_media_video\";s:9:\"datestamp\";i:1734297827;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734297827;s:8:\"includes\";a:1:{s:21:\"glightbox_media_video\";s:21:\"GLightbox Media Video\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','image_effects',_binary 'a:6:{s:4:\"name\";s:13:\"image_effects\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Image Effects\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"4.0.0\";s:7:\"project\";s:13:\"image_effects\";s:9:\"datestamp\";i:1733831440;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1733831440;s:8:\"includes\";a:1:{s:13:\"image_effects\";s:13:\"Image Effects\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','layout_paragraphs',_binary 'a:6:{s:4:\"name\";s:17:\"layout_paragraphs\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Layout Paragraphs\";s:7:\"package\";s:10:\"Paragraphs\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:17:\"layout_paragraphs\";s:9:\"datestamp\";i:1732724680;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1732724680;s:8:\"includes\";a:1:{s:17:\"layout_paragraphs\";s:17:\"Layout Paragraphs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','webform',_binary 'a:6:{s:4:\"name\";s:7:\"webform\";s:4:\"info\";a:6:{s:4:\"name\";s:7:\"Webform\";s:7:\"package\";s:7:\"Webform\";s:7:\"version\";s:12:\"6.3.0-alpha3\";s:7:\"project\";s:7:\"webform\";s:9:\"datestamp\";i:1733851313;s:16:\"_info_file_ctime\";i:1735492412;}s:9:\"datestamp\";i:1733851313;s:8:\"includes\";a:1:{s:7:\"webform\";s:7:\"Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}');
/*!40000 ALTER TABLE `key_value` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `key_value_expire`
--

DROP TABLE IF EXISTS `key_value_expire`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `key_value_expire` (
  `collection` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A named collection of key and value pairs.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The key of the key/value pair.',
  `value` longblob NOT NULL COMMENT 'The value of the key/value pair.',
  `expire` int NOT NULL DEFAULT '2147483647' COMMENT 'The time since Unix epoch in seconds when this item expires. Defaults to the maximum possible time.',
  PRIMARY KEY (`collection`,`name`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Generic key/value storage table with an expiration.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `key_value_expire`
--

LOCK TABLES `key_value_expire` WRITE;
/*!40000 ALTER TABLE `key_value_expire` DISABLE KEYS */;
INSERT INTO `key_value_expire` VALUES ('announcements_feed','announcements',_binary 'a:11:{i:0;a:7:{s:2:\"id\";s:7:\"3494304\";s:5:\"title\";s:30:\"Drupal 11.1.0 is now available\";s:12:\"content_html\";s:263:\"<p>The <a href=\"https://www.drupal.org/project/drupal/releases/11.1.0\" rel=\"nofollow\">first feature release of Drupal 11</a> improves the recipe system, introduces support for hooks written as classes, makes Workspaces more flexible and enhances performance.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-11-1-0\";s:13:\"date_modified\";s:25:\"2024-12-16T20:28:53+00:00\";s:14:\"date_published\";s:25:\"2024-12-16T17:50:29+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:2;a:7:{s:2:\"id\";s:7:\"3480615\";s:5:\"title\";s:58:\"DrupalCon Singapore 2024: What Awaits You in the Lion City\";s:12:\"content_html\";s:528:\"<p>It’s time to dust off those suitcases and start thinking about where your passport is - <a href=\"https://events.drupal.org/singapore2024\" rel=\"nofollow\">DrupalCon Singapore 2024</a> is just around the corner, and this year’s event promises to be amazing! From 9-11 December, our much-anticipated event will bring together the brightest minds and most passionate contributors from the Drupal community for three days of innovation, learning, and inspiration at the luxurious Parkroyal Collection Marina Bay, Singapore.</p>\";s:3:\"url\";s:105:\"https://www.drupal.org/about/announcements/blog/drupalcon-singapore-2024-what-awaits-you-in-the-lion-city\";s:13:\"date_modified\";s:25:\"2024-10-14T16:49:44+00:00\";s:14:\"date_published\";s:25:\"2024-10-14T16:49:44+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:3;a:7:{s:2:\"id\";s:7:\"3465580\";s:5:\"title\";s:18:\"Drupal 11 released\";s:12:\"content_html\";s:114:\"<p>Today is a big day for <a href=\"https://www.drupal.org/\">Drupal</a> as we officially released Drupal 11!</p>\n\";s:3:\"url\";s:46:\"https://www.drupal.org/blog/drupal-11-released\";s:13:\"date_modified\";s:25:\"2024-08-15T15:10:39+00:00\";s:14:\"date_published\";s:25:\"2024-08-01T22:57:58+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:1:\"*\";}}i:4;a:7:{s:2:\"id\";s:7:\"3456034\";s:5:\"title\";s:28:\"Drupal 10.3 is now available\";s:12:\"content_html\";s:370:\"<p>The <a href=\"https://www.drupal.org/project/drupal/releases/10.3.0\" rel=\"nofollow\">third and final feature release of Drupal 10</a> ships with a new experimental Navigation user interface, stable Workspaces functionality, stable Single-Directory Components support, simplified menu editing, taxonomy moderation support, new recipe and access policy APIs and more.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-3-0\";s:13:\"date_modified\";s:25:\"2024-09-05T23:00:47+00:00\";s:14:\"date_published\";s:25:\"2024-06-20T20:00:04+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:6;a:7:{s:2:\"id\";s:7:\"3427138\";s:5:\"title\";s:52:\"You\'re invited to DrupalCon Portland | 6-9 May, 2024\";s:12:\"content_html\";s:384:\"<p>DrupalCon is an event for developers, marketers/content editors, site owners, and the Drupal-curious to join with the community. You\'ll find incredible keynotes, session content from expert speakers who have helped to build Drupal, networking opportunities with your peers, fun social events, and the chance to deepen your connection by contributing to the open source project.</p>\";s:3:\"url\";s:96:\"https://www.drupal.org/about/announcements/blog/youre-invited-to-drupalcon-portland-6-9-may-2024\";s:13:\"date_modified\";s:25:\"2024-03-18T19:40:04+00:00\";s:14:\"date_published\";s:25:\"2024-03-11T16:49:53+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:7;a:7:{s:2:\"id\";s:7:\"3408836\";s:5:\"title\";s:28:\"Drupal 10.2 is now available\";s:12:\"content_html\";s:378:\"<p>The <a href=\"https://www.drupal.org/project/drupal/releases/10.2.0\">second feature release of Drupal 10</a> improves content modeling, block management, menu and taxonomy organization, and permission administration. New options to sanitize file names make it possible to clean up the names of uploaded files, and media item revisions now have a dedicated user interface.</p>\n\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-2-0\";s:13:\"date_modified\";s:25:\"2024-01-25T18:24:28+00:00\";s:14:\"date_published\";s:25:\"2023-12-15T18:27:47+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:8;a:7:{s:2:\"id\";s:7:\"3403229\";s:5:\"title\";s:75:\"Drupal 10 will be supported until the release of Drupal 12 in mid-late 2026\";s:12:\"content_html\";s:190:\"<p>Announcing a new major release schedule with long term support for Drupal 10 until mid-late 2026. Drupal 11 will be released in 2024 and work on the dedicated branch starts this week.</p>\";s:3:\"url\";s:103:\"https://www.drupal.org/blog/drupal-10-will-be-supported-until-the-release-of-drupal-12-in-mid-late-2026\";s:13:\"date_modified\";s:25:\"2024-01-25T18:31:05+00:00\";s:14:\"date_published\";s:25:\"2023-11-22T07:13:55+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:10;a:7:{s:2:\"id\";s:7:\"3368367\";s:5:\"title\";s:28:\"Drupal 10.1 is now available\";s:12:\"content_html\";s:257:\"<p>This first feature release of Drupal 10 is packed with amazing improvements! It makes customizing the look of your site easier, adds support for decoupled navigation, improves content modeling and editing, block management, performance and many more.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-1-0\";s:13:\"date_modified\";s:25:\"2023-10-30T16:22:24+00:00\";s:14:\"date_published\";s:25:\"2023-06-22T09:11:30+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:11;a:7:{s:2:\"id\";s:7:\"3347976\";s:5:\"title\";s:37:\"Contribute to Drupal and the Open Web\";s:12:\"content_html\";s:146:\"<p>Drupal is an open source project. But what does that mean? How can you as a site-owner participate in the project of building a better web?</p>\";s:3:\"url\";s:85:\"https://www.drupal.org/about/announcements/blog/contribute-to-drupal-and-the-open-web\";s:13:\"date_modified\";s:25:\"2023-03-14T19:43:12+00:00\";s:14:\"date_published\";s:25:\"2023-03-14T19:39:44+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:12;a:7:{s:2:\"id\";s:7:\"3343486\";s:5:\"title\";s:43:\"What to expect from the Announcements feed?\";s:12:\"content_html\";s:197:\"<p>Drupal is introducing a new project Announcements feature so that you can see news and updates about the Drupal project and community directly in your Drupal dashboard. Learn what to expect.</p>\";s:3:\"url\";s:90:\"https://www.drupal.org/about/announcements/blog/what-to-expect-from-the-announcements-feed\";s:13:\"date_modified\";s:25:\"2023-02-21T19:45:53+00:00\";s:14:\"date_published\";s:25:\"2023-02-21T19:45:53+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:13;a:7:{s:2:\"id\";s:7:\"3327047\";s:5:\"title\";s:26:\"Drupal 10.0.0 is available\";s:12:\"content_html\";s:296:\"<p>Thanks to 2129 contributors from 616 organizations resolving 4083 issues in the past two and a half years, Drupal 10.0.0 is available today! This new version sets Drupal up for continued stability and security for the longer term. All new features will be added to Drupal 10 going forward.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-0-0\";s:13:\"date_modified\";s:25:\"2023-10-30T16:21:38+00:00\";s:14:\"date_published\";s:25:\"2022-12-15T17:43:23+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}}',1735578659),('form','form-ybtwOuODcWAPLfPhQ0w9h6DFbPvTN6rvLuM7BYRMe3A',_binary 'a:33:{s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:29:\"entity-form-display-edit-form\";i:1;s:24:\"entity-form-display-form\";}s:20:\"data-drupal-selector\";s:29:\"entity-form-display-edit-form\";}s:6:\"#cache\";a:3:{s:8:\"contexts\";a:1:{i:0;s:24:\"user.roles:authenticated\";}s:4:\"tags\";a:2:{i:0;s:49:\"config:core.entity_form_display.node.page.default\";i:1;s:42:\"CACHE_MISS_IF_UNCACHEABLE_HTTP_METHOD:form\";}s:7:\"max-age\";i:-1;}s:8:\"#process\";a:1:{i:0;s:13:\"::processForm\";}s:12:\"#after_build\";a:1:{i:0;s:12:\"::afterBuild\";}s:12:\"#entity_type\";s:4:\"node\";s:7:\"#bundle\";s:4:\"page\";s:7:\"#fields\";a:9:{i:0;s:6:\"status\";i:1;s:3:\"uid\";i:2;s:5:\"title\";i:3;s:7:\"created\";i:4;s:7:\"promote\";i:5;s:6:\"sticky\";i:6;s:4:\"path\";i:7;s:4:\"body\";i:8;s:16:\"field_components\";}s:6:\"#extra\";a:0:{}s:6:\"fields\";a:15:{s:5:\"#type\";s:14:\"field_ui_table\";s:7:\"#header\";a:6:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;a:2:{s:4:\"data\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Machine name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"class\";a:2:{i:0;s:15:\"priority-medium\";i:1;s:12:\"machine-name\";}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:3;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Parent\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:4;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Region\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:5;a:2:{s:4:\"data\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"colspan\";i:3;}}s:8:\"#regions\";a:2:{s:7:\"content\";a:3:{s:5:\"title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"invisible\";b:1;s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"No field is displayed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:6:\"hidden\";a:2:{s:5:\"title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Disabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:6:\"Plural\";}}s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"No field is hidden.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:17:\"field-ui-overview\";}s:2:\"id\";s:22:\"field-display-overview\";}s:10:\"#tabledrag\";a:3:{i:0;a:3:{s:6:\"action\";s:5:\"order\";s:12:\"relationship\";s:7:\"sibling\";s:5:\"group\";s:12:\"field-weight\";}i:1;a:5:{s:6:\"action\";s:5:\"match\";s:12:\"relationship\";s:6:\"parent\";s:5:\"group\";s:12:\"field-parent\";s:8:\"subgroup\";s:12:\"field-parent\";s:6:\"source\";s:10:\"field-name\";}i:2;a:5:{s:6:\"action\";s:5:\"match\";s:12:\"relationship\";s:6:\"parent\";s:5:\"group\";s:12:\"field-region\";s:8:\"subgroup\";s:12:\"field-region\";s:6:\"source\";s:10:\"field-name\";}}s:6:\"status\";a:12:{s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:9:\"draggable\";i:1;s:14:\"tabledrag-leaf\";}}s:9:\"#row_type\";s:5:\"field\";s:16:\"#region_callback\";a:2:{i:0;O:46:\"Drupal\\field_ui\\Form\\EntityFormDisplayEditForm\":12:{s:15:\"\0*\0requestStack\";N;s:16:\"\0*\0configFactory\";N;s:13:\"\0*\0routeMatch\";N;s:14:\"\0*\0_serviceIds\";a:6:{s:17:\"stringTranslation\";s:18:\"string_translation\";s:13:\"moduleHandler\";s:14:\"module_handler\";s:17:\"entityTypeManager\";s:19:\"entity_type.manager\";s:13:\"pluginManager\";s:27:\"plugin.manager.field.widget\";s:23:\"entityDisplayRepository\";s:25:\"entity_display.repository\";s:18:\"entityFieldManager\";s:20:\"entity_field.manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:16:\"\0*\0loggerFactory\";N;s:12:\"\0*\0messenger\";N;s:22:\"\0*\0redirectDestination\";N;s:12:\"\0*\0operation\";s:4:\"edit\";s:9:\"\0*\0entity\";O:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\":15:{s:7:\"\0*\0uuid\";s:36:\"c6ec1d38-d434-4a7d-be65-080873fd0aff\";s:11:\"\0*\0langcode\";s:2:\"en\";s:9:\"\0*\0status\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:38:\"field.field.node.page.field_components\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:3:{i:0;s:17:\"layout_paragraphs\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:5:\"\0*\0id\";s:17:\"node.page.default\";s:19:\"\0*\0targetEntityType\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:7:\"\0*\0mode\";s:7:\"default\";s:10:\"\0*\0content\";a:11:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";s:2:\"31\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";s:2:\"10\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:16:\"field_components\";a:5:{s:4:\"type\";s:17:\"layout_paragraphs\";s:6:\"weight\";s:3:\"121\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";s:1:\"0\";s:13:\"empty_message\";s:0:\"\";s:15:\"require_layouts\";i:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";s:2:\"30\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";s:2:\"15\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";s:3:\"120\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";s:2:\"16\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";s:2:\"-5\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";s:1:\"5\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:12:\"revision_log\";a:5:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:2:{s:4:\"rows\";i:4;s:11:\"placeholder\";s:0:\"\";}s:6:\"region\";s:7:\"content\";s:20:\"third_party_settings\";a:0:{}}}s:9:\"\0*\0hidden\";a:0:{}s:15:\"\0*\0entityTypeId\";s:19:\"entity_form_display\";s:15:\"\0*\0enforceIsNew\";N;s:15:\"_serializedKeys\";a:15:{i:0;s:4:\"uuid\";i:1;s:8:\"langcode\";i:2;s:6:\"status\";i:3;s:12:\"dependencies\";i:4;s:5:\"_core\";i:5;s:2:\"id\";i:6;s:16:\"targetEntityType\";i:7;s:6:\"bundle\";i:8;s:4:\"mode\";i:9;s:7:\"content\";i:10;s:6:\"hidden\";i:11;s:12:\"entityTypeId\";i:12;s:12:\"enforceIsNew\";i:13;s:15:\"_serializedKeys\";i:14;s:11:\"initialized\";}s:14:\"\0*\0initialized\";b:1;}s:17:\"\0*\0displayContext\";s:4:\"form\";s:13:\"\0*\0fieldTypes\";a:34:{s:11:\"block_field\";a:14:{s:8:\"category\";s:9:\"reference\";s:6:\"weight\";i:0;s:5:\"no_ui\";b:0;s:16:\"definition_class\";s:37:\"\\Drupal\\Core\\TypedData\\DataDefinition\";s:21:\"list_definition_class\";s:41:\"\\Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;s:2:\"id\";s:11:\"block_field\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Block (plugin)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:53:\"Stores an instance of a configurable or custom block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"default_widget\";s:19:\"block_field_default\";s:17:\"default_formatter\";s:11:\"block_field\";s:5:\"class\";s:56:\"Drupal\\block_field\\Plugin\\Field\\FieldType\\BlockFieldItem\";s:8:\"provider\";s:11:\"block_field\";s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";}s:7:\"comment\";a:17:{s:5:\"class\";s:49:\"Drupal\\comment\\Plugin\\Field\\FieldType\\CommentItem\";s:8:\"provider\";s:7:\"comment\";s:2:\"id\";s:7:\"comment\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Comments\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:75:\"This field manages configuration and presentation of comments on an entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:15:\"comment_default\";s:17:\"default_formatter\";s:15:\"comment_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:35:\"Drupal\\comment\\CommentFieldItemList\";s:11:\"cardinality\";i:1;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:8:\"datetime\";a:17:{s:5:\"class\";s:51:\"Drupal\\datetime\\Plugin\\Field\\FieldType\\DateTimeItem\";s:8:\"provider\";s:8:\"datetime\";s:2:\"id\";s:8:\"datetime\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Date\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:79:\"Ideal when date and time needs to be input by users, like event dates and times\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:56:\"Date or date and time stored in a readable string format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Easy to read and understand for humans\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:9:\"date_time\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:16:\"datetime_default\";s:17:\"default_formatter\";s:16:\"datetime_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:60:\"Drupal\\datetime\\Plugin\\Field\\FieldType\\DateTimeFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:1:{s:14:\"DateTimeFormat\";a:0:{}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:26:\"entity_reference_revisions\";a:14:{s:8:\"category\";s:9:\"reference\";s:6:\"weight\";i:0;s:5:\"no_ui\";b:0;s:16:\"definition_class\";s:37:\"\\Drupal\\Core\\TypedData\\DataDefinition\";s:21:\"list_definition_class\";s:41:\"\\Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;s:2:\"id\";s:26:\"entity_reference_revisions\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Entity reference revisions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:70:\"An entity field containing an entity reference to a specific revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"class\";s:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\";s:10:\"list_class\";s:72:\"\\Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\";s:17:\"default_formatter\";s:38:\"entity_reference_revisions_entity_view\";s:14:\"default_widget\";s:39:\"entity_reference_revisions_autocomplete\";s:8:\"provider\";s:26:\"entity_reference_revisions\";}s:12:\"ept_settings\";a:14:{s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:5:\"no_ui\";b:0;s:16:\"definition_class\";s:37:\"\\Drupal\\Core\\TypedData\\DataDefinition\";s:21:\"list_definition_class\";s:41:\"\\Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;s:2:\"id\";s:12:\"ept_settings\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"EPT Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:57:\"This field stores EPT paragraph settings in the database.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"default_widget\";s:20:\"ept_settings_default\";s:17:\"default_formatter\";s:20:\"ept_settings_default\";s:5:\"class\";s:54:\"Drupal\\ept_core\\Plugin\\Field\\FieldType\\EptSettingsItem\";s:8:\"provider\";s:8:\"ept_core\";s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";}s:4:\"file\";a:17:{s:5:\"class\";s:43:\"Drupal\\file\\Plugin\\Field\\FieldType\\FileItem\";s:8:\"provider\";s:4:\"file\";s:2:\"id\";s:4:\"file\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"File\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"For uploading files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:86:\"Can be configured with options such as allowed file extensions and maximum upload size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:11:\"file_upload\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:12:\"file_generic\";s:17:\"default_formatter\";s:12:\"file_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:52:\"Drupal\\file\\Plugin\\Field\\FieldType\\FileFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:2:{s:15:\"ReferenceAccess\";a:0:{}s:14:\"FileValidation\";a:0:{}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:3:{s:9:\"target_id\";a:2:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"File\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;}s:7:\"display\";a:2:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;}s:11:\"description\";a:2:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;}}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:8:\"file_uri\";a:17:{s:5:\"class\";s:46:\"Drupal\\file\\Plugin\\Field\\FieldType\\FileUriItem\";s:8:\"provider\";s:4:\"file\";s:2:\"id\";s:8:\"file_uri\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"File URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"An entity field containing a file URI, and a computed root-relative file URL.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:3:\"uri\";s:17:\"default_formatter\";s:8:\"file_uri\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:5:\"image\";a:17:{s:5:\"class\";s:45:\"Drupal\\image\\Plugin\\Field\\FieldType\\ImageItem\";s:8:\"provider\";s:5:\"image\";s:2:\"id\";s:5:\"image\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Image\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"For uploading images\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:92:\"Allows a user to upload an image with configurable extensions, image dimensions, upload size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:122:\"Can be configured with options such as allowed file extensions, maximum upload size and image dimensions minimums/maximums\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:11:\"file_upload\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:11:\"image_image\";s:17:\"default_formatter\";s:5:\"image\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:52:\"Drupal\\file\\Plugin\\Field\\FieldType\\FileFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:2:{s:15:\"ReferenceAccess\";a:0:{}s:14:\"FileValidation\";a:0:{}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:3:{s:4:\"file\";a:3:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"File\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"columns\";a:3:{i:0;s:9:\"target_id\";i:1;s:5:\"width\";i:2;s:6:\"height\";}s:34:\"require_all_groups_for_translation\";b:1;}s:3:\"alt\";a:2:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Alt\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;}s:5:\"title\";a:2:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;}}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:4:\"link\";a:17:{s:5:\"class\";s:43:\"Drupal\\link\\Plugin\\Field\\FieldType\\LinkItem\";s:8:\"provider\";s:4:\"link\";s:2:\"id\";s:4:\"link\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:100:\"Stores a URL string, optional varchar link text, and optional blob of attributes to assemble a link.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:12:\"link_default\";s:17:\"default_formatter\";s:4:\"link\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:4:{s:8:\"LinkType\";a:0:{}s:10:\"LinkAccess\";a:0:{}s:21:\"LinkExternalProtocols\";a:0:{}s:23:\"LinkNotExistingInternal\";a:0:{}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:10:\"list_float\";a:17:{s:5:\"class\";s:51:\"Drupal\\options\\Plugin\\Field\\FieldType\\ListFloatItem\";s:8:\"provider\";s:7:\"options\";s:2:\"id\";s:10:\"list_float\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"List (float)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"Values stored are floating-point numbers\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"For example, \'Fraction\': 0 => 0, .25 => 1/4, .75 => 3/4, 1 => 1\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"selection_list\";s:6:\"weight\";i:-10;s:14:\"default_widget\";s:14:\"options_select\";s:17:\"default_formatter\";s:12:\"list_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:12:\"list_integer\";a:17:{s:5:\"class\";s:53:\"Drupal\\options\\Plugin\\Field\\FieldType\\ListIntegerItem\";s:8:\"provider\";s:7:\"options\";s:2:\"id\";s:12:\"list_integer\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"List (integer)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"Values stored are numbers without decimals\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:71:\"For example, \'Lifetime in days\': 1 => 1 day, 7 => 1 week, 31 => 1 month\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"selection_list\";s:6:\"weight\";i:-30;s:14:\"default_widget\";s:14:\"options_select\";s:17:\"default_formatter\";s:12:\"list_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:11:\"list_string\";a:17:{s:5:\"class\";s:52:\"Drupal\\options\\Plugin\\Field\\FieldType\\ListStringItem\";s:8:\"provider\";s:7:\"options\";s:2:\"id\";s:11:\"list_string\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"List (text)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Values stored are text values\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:67:\"For example, \'US States\': IL => Illinois, IA => Iowa, IN => Indiana\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"selection_list\";s:6:\"weight\";i:-50;s:14:\"default_widget\";s:14:\"options_select\";s:17:\"default_formatter\";s:12:\"list_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:4:\"path\";a:17:{s:5:\"class\";s:43:\"Drupal\\path\\Plugin\\Field\\FieldType\\PathItem\";s:8:\"provider\";s:4:\"path\";s:2:\"id\";s:4:\"path\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Path\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:57:\"An entity field containing a path alias and related data.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:4:\"path\";s:17:\"default_formatter\";N;s:5:\"no_ui\";b:1;s:10:\"list_class\";s:52:\"Drupal\\path\\Plugin\\Field\\FieldType\\PathFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:1:{s:9:\"PathAlias\";a:0:{}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:4:\"text\";a:17:{s:5:\"class\";s:43:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextItem\";s:8:\"provider\";s:4:\"text\";s:2:\"id\";s:4:\"text\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Text (formatted)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:4:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:85:\"Ideal for titles and names that need to support markup such as bold, italics or links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Efficient storage for short text\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Requires specifying a maximum length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:3;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:49:\"Good for fields with known or predictable lengths\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"formatted_text\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:14:\"text_textfield\";s:17:\"default_formatter\";s:12:\"text_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:52:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:9:\"text_long\";a:17:{s:5:\"class\";s:47:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextLongItem\";s:8:\"provider\";s:4:\"text\";s:2:\"id\";s:9:\"text_long\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Text (formatted, long)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:66:\"Ideal for longer texts, like body or description without a summary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"Supports long text without specifying a maximum length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"May use more storage and be slower for searching and sorting\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"formatted_text\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:13:\"text_textarea\";s:17:\"default_formatter\";s:12:\"text_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:52:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:17:\"text_with_summary\";a:17:{s:5:\"class\";s:54:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextWithSummaryItem\";s:8:\"provider\";s:4:\"text\";s:2:\"id\";s:17:\"text_with_summary\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Text (formatted, long, with summary)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:4:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"Ideal for longer texts, like body or description with a summary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"Allows specifying a summary for the text\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"Supports long text without specifying a maximum length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:3;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"May use more storage and be slower for searching and sorting\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"formatted_text\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:26:\"text_textarea_with_summary\";s:17:\"default_formatter\";s:12:\"text_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:52:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:14:\"viewsreference\";a:14:{s:8:\"category\";s:9:\"reference\";s:6:\"weight\";i:0;s:5:\"no_ui\";b:0;s:16:\"definition_class\";s:37:\"\\Drupal\\Core\\TypedData\\DataDefinition\";s:21:\"list_definition_class\";s:41:\"\\Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;s:2:\"id\";s:14:\"viewsreference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Views reference\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"A field reference to a view.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"default_widget\";s:27:\"viewsreference_autocomplete\";s:17:\"default_formatter\";s:24:\"viewsreference_formatter\";s:10:\"list_class\";s:63:\"\\Drupal\\viewsreference\\Plugin\\Field\\ViewsReferenceFieldItemList\";s:5:\"class\";s:63:\"Drupal\\viewsreference\\Plugin\\Field\\FieldType\\ViewsReferenceItem\";s:8:\"provider\";s:14:\"viewsreference\";}s:7:\"webform\";a:14:{s:8:\"category\";s:9:\"reference\";s:6:\"weight\";i:0;s:5:\"no_ui\";b:0;s:16:\"definition_class\";s:37:\"\\Drupal\\Core\\TypedData\\DataDefinition\";s:21:\"list_definition_class\";s:41:\"\\Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;s:2:\"id\";s:7:\"webform\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"A webform containing default submission values.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"default_widget\";s:31:\"webform_entity_reference_select\";s:17:\"default_formatter\";s:36:\"webform_entity_reference_entity_view\";s:10:\"list_class\";s:74:\"\\Drupal\\webform\\Plugin\\Field\\FieldType\\WebformEntityReferenceFieldItemList\";s:5:\"class\";s:64:\"Drupal\\webform\\Plugin\\Field\\FieldType\\WebformEntityReferenceItem\";s:8:\"provider\";s:7:\"webform\";}s:7:\"boolean\";a:17:{s:5:\"class\";s:52:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\BooleanItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:7:\"boolean\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Boolean\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"Field to store a true or false value.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:16:\"boolean_checkbox\";s:17:\"default_formatter\";s:7:\"boolean\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:7:\"changed\";a:17:{s:5:\"class\";s:52:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\ChangedItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:7:\"changed\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Last changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:85:\"An entity field containing a UNIX timestamp of when the entity has been last updated.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:18:\"datetime_timestamp\";s:17:\"default_formatter\";s:9:\"timestamp\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:38:\"Drupal\\Core\\Field\\ChangedFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:7:\"created\";a:17:{s:5:\"class\";s:52:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\CreatedItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:7:\"created\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:80:\"An entity field containing a UNIX timestamp of when the entity has been created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:18:\"datetime_timestamp\";s:17:\"default_formatter\";s:9:\"timestamp\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:7:\"decimal\";a:17:{s:5:\"class\";s:52:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\DecimalItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:7:\"decimal\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Number (decimal)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:84:\"Ideal for exact counts and measures (prices, temperatures, distances, volumes, etc.)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:57:\"Stores a number in the database in a fixed decimal format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:104:\"For example, 12.34 km or € when used for further detailed calculations (such as summing many of these)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:6:\"number\";s:6:\"weight\";i:-30;s:14:\"default_widget\";s:6:\"number\";s:17:\"default_formatter\";s:14:\"number_decimal\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:5:\"email\";a:17:{s:5:\"class\";s:50:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\EmailItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:5:\"email\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Field to store an email address.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:13:\"email_default\";s:17:\"default_formatter\";s:12:\"basic_string\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:16:\"entity_reference\";a:17:{s:5:\"class\";s:60:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\EntityReferenceItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:16:\"entity_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Entity reference\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"An entity field containing an entity reference.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:9:\"reference\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:29:\"entity_reference_autocomplete\";s:17:\"default_formatter\";s:22:\"entity_reference_label\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:46:\"Drupal\\Core\\Field\\EntityReferenceFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:5:\"float\";a:17:{s:5:\"class\";s:50:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\FloatItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:5:\"float\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Number (float)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:130:\"In most instances, it is best to use Number (decimal) instead, as decimal numbers stored as floats may contain errors in precision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:130:\"This type of field offers faster processing and more compact storage, but the differences are typically negligible on modern sites\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:86:\"For example, 123.4 km when used in imprecise contexts such as a walking trail distance\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:6:\"number\";s:6:\"weight\";i:-10;s:14:\"default_widget\";s:6:\"number\";s:17:\"default_formatter\";s:14:\"number_decimal\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:7:\"integer\";a:17:{s:5:\"class\";s:52:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\IntegerItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:7:\"integer\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Number (integer)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Number without decimals\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"For example, 123\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:6:\"number\";s:6:\"weight\";i:-50;s:14:\"default_widget\";s:6:\"number\";s:17:\"default_formatter\";s:14:\"number_integer\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:8:\"language\";a:17:{s:5:\"class\";s:53:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\LanguageItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:8:\"language\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"An entity field referencing a language.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:15:\"language_select\";s:17:\"default_formatter\";s:8:\"language\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:6:\"Length\";a:1:{s:3:\"max\";i:12;}}}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:3:\"map\";a:17:{s:5:\"class\";s:48:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\MapItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:3:\"map\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Map\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:57:\"An entity field for storing a serialized array of values.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";N;s:17:\"default_formatter\";N;s:5:\"no_ui\";b:1;s:10:\"list_class\";s:34:\"Drupal\\Core\\Field\\MapFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:8:\"password\";a:17:{s:5:\"class\";s:53:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\PasswordItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:8:\"password\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Password\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"An entity field containing a password value.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";N;s:17:\"default_formatter\";N;s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:6:\"string\";a:17:{s:5:\"class\";s:51:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\StringItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"string\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Text (plain)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:4:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Ideal for titles and names\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Efficient storage for short text\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Requires specifying a maximum length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:3;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Good for fields with known or predictable length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:10:\"plain_text\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:16:\"string_textfield\";s:17:\"default_formatter\";s:6:\"string\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:11:\"string_long\";a:17:{s:5:\"class\";s:55:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\StringLongItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:11:\"string_long\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Text (plain, long)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Ideal for longer texts, like body or description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"Supports long text without specifying a maximum length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"May use more storage and be slower for searching and sorting\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:10:\"plain_text\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:15:\"string_textarea\";s:17:\"default_formatter\";s:12:\"basic_string\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:9:\"timestamp\";a:17:{s:5:\"class\";s:54:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\TimestampItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:9:\"timestamp\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Timestamp\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:57:\"Ideal for using date and time calculations or comparisons\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:71:\"Date and time stored in the form of seconds since January 1, 1970 (UTC)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"Compact and efficient for storage, sorting and calculations\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:9:\"date_time\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:18:\"datetime_timestamp\";s:17:\"default_formatter\";s:9:\"timestamp\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:5:\"Range\";a:2:{s:3:\"min\";s:11:\"-2147483648\";s:3:\"max\";s:10:\"2147483648\";}}}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:3:\"uri\";a:17:{s:5:\"class\";s:48:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\UriItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:3:\"uri\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"An entity field containing a URI.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:3:\"uri\";s:17:\"default_formatter\";s:8:\"uri_link\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:4:\"uuid\";a:17:{s:5:\"class\";s:49:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\UuidItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:4:\"uuid\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"An entity field containing a UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";N;s:17:\"default_formatter\";s:6:\"string\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}}}i:1;s:12:\"getRowRegion\";}s:12:\"#js_settings\";a:2:{s:10:\"rowHandler\";s:5:\"field\";s:13:\"defaultPlugin\";s:16:\"boolean_checkbox\";}s:10:\"human_name\";a:1:{s:11:\"#plain_text\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"machine_name\";a:2:{s:7:\"#markup\";s:6:\"status\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"machine-name\";}}}s:6:\"weight\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Weight for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1251;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:14:\"#default_value\";s:3:\"120\";s:5:\"#size\";i:3;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-weight\";}}}s:14:\"parent_wrapper\";a:2:{s:6:\"parent\";a:8:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Label display for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1251;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:0:{}s:12:\"#empty_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:15:\"js-field-parent\";i:1;s:12:\"field-parent\";}}s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:6:\"status\";i:2;s:6:\"parent\";}s:14:\"#default_value\";s:0:\"\";}s:11:\"hidden_name\";a:3:{s:5:\"#type\";s:6:\"hidden\";s:14:\"#default_value\";s:6:\"status\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:10:\"field-name\";}}}}s:6:\"region\";a:6:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Region for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1251;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:7:\"content\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Disabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:6:\"Plural\";}}}s:14:\"#default_value\";s:7:\"content\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-region\";}}}s:6:\"plugin\";a:3:{s:4:\"type\";a:7:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Plugin for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1251;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:16:\"boolean_checkbox\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Single on/off checkbox\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"options_buttons\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Check boxes/radio buttons\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:16:\"boolean_checkbox\";s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:6:\"status\";i:2;s:4:\"type\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:17:\"field-plugin-type\";}}}s:18:\"settings_edit_form\";a:0:{}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Formatter for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1251;}s:10:\"\0*\0options\";a:0:{}}}s:16:\"settings_summary\";a:4:{s:5:\"#type\";s:15:\"inline_template\";s:9:\"#template\";s:73:\"<div class=\"field-plugin-summary\">{{ summary|safe_join(\"<br />\") }}</div>\";s:8:\"#context\";a:1:{s:7:\"summary\";a:1:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:31:\"Use field label: @display_label\";s:12:\"\0*\0arguments\";a:1:{s:14:\"@display_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Yes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"\0*\0options\";a:0:{}}}}s:16:\"#cell_attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:25:\"field-plugin-summary-cell\";}}}s:13:\"settings_edit\";a:11:{s:7:\"#submit\";a:1:{i:0;s:17:\"::multistepSubmit\";}s:5:\"#ajax\";a:3:{s:8:\"callback\";s:15:\"::multistepAjax\";s:7:\"wrapper\";s:30:\"field-display-overview-wrapper\";s:6:\"effect\";s:4:\"fade\";}s:11:\"#field_name\";s:6:\"status\";s:5:\"#type\";s:12:\"image_button\";s:5:\"#name\";s:20:\"status_settings_edit\";s:4:\"#src\";s:30:\"core/misc/icons/787878/cog.svg\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:26:\"field-plugin-settings-edit\";}s:3:\"alt\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:3:\"#op\";s:4:\"edit\";s:24:\"#limit_validation_errors\";a:1:{i:0;a:3:{i:0;s:6:\"fields\";i:1;s:6:\"status\";i:2;s:4:\"type\";}}s:7:\"#prefix\";s:48:\"<div class=\"field-plugin-settings-edit-wrapper\">\";s:7:\"#suffix\";s:6:\"</div>\";}}s:3:\"uid\";a:12:{s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:9:\"draggable\";i:1;s:14:\"tabledrag-leaf\";}}s:9:\"#row_type\";s:5:\"field\";s:16:\"#region_callback\";a:2:{i:0;r:113;i:1;s:12:\"getRowRegion\";}s:12:\"#js_settings\";a:2:{s:10:\"rowHandler\";s:5:\"field\";s:13:\"defaultPlugin\";s:29:\"entity_reference_autocomplete\";}s:10:\"human_name\";a:1:{s:11:\"#plain_text\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"machine_name\";a:2:{s:7:\"#markup\";s:3:\"uid\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"machine-name\";}}}s:6:\"weight\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Weight for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1408;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:14:\"#default_value\";s:1:\"5\";s:5:\"#size\";i:3;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-weight\";}}}s:14:\"parent_wrapper\";a:2:{s:6:\"parent\";a:8:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Label display for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1408;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:0:{}s:12:\"#empty_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:15:\"js-field-parent\";i:1;s:12:\"field-parent\";}}s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:3:\"uid\";i:2;s:6:\"parent\";}s:14:\"#default_value\";s:0:\"\";}s:11:\"hidden_name\";a:3:{s:5:\"#type\";s:6:\"hidden\";s:14:\"#default_value\";s:3:\"uid\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:10:\"field-name\";}}}}s:6:\"region\";a:6:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Region for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1408;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:7:\"content\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Disabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:6:\"Plural\";}}}s:14:\"#default_value\";s:7:\"content\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-region\";}}}s:6:\"plugin\";a:3:{s:4:\"type\";a:7:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Plugin for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1408;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:4:{s:34:\"entity_reference_autocomplete_tags\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Autocomplete (Tags style)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:29:\"entity_reference_autocomplete\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Autocomplete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"options_buttons\";r:1335;s:14:\"options_select\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Select list\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:29:\"entity_reference_autocomplete\";s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:3:\"uid\";i:2;s:4:\"type\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:17:\"field-plugin-type\";}}}s:18:\"settings_edit_form\";a:0:{}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Formatter for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1408;}s:10:\"\0*\0options\";a:0:{}}}s:16:\"settings_summary\";a:4:{s:5:\"#type\";s:15:\"inline_template\";s:9:\"#template\";s:73:\"<div class=\"field-plugin-summary\">{{ summary|safe_join(\"<br />\") }}</div>\";s:8:\"#context\";a:1:{s:7:\"summary\";a:4:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Autocomplete matching: @match_operator\";s:12:\"\0*\0arguments\";a:1:{s:15:\"@match_operator\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Contains\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"Autocomplete suggestion list size: @size\";s:12:\"\0*\0arguments\";a:1:{s:5:\"@size\";i:10;}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Textfield size: @size\";s:12:\"\0*\0arguments\";a:1:{s:5:\"@size\";i:60;}s:10:\"\0*\0options\";a:0:{}}i:3;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"No placeholder\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:16:\"#cell_attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:25:\"field-plugin-summary-cell\";}}}s:13:\"settings_edit\";a:11:{s:7:\"#submit\";a:1:{i:0;s:17:\"::multistepSubmit\";}s:5:\"#ajax\";a:3:{s:8:\"callback\";s:15:\"::multistepAjax\";s:7:\"wrapper\";s:30:\"field-display-overview-wrapper\";s:6:\"effect\";s:4:\"fade\";}s:11:\"#field_name\";s:3:\"uid\";s:5:\"#type\";s:12:\"image_button\";s:5:\"#name\";s:17:\"uid_settings_edit\";s:4:\"#src\";s:30:\"core/misc/icons/787878/cog.svg\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:26:\"field-plugin-settings-edit\";}s:3:\"alt\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:3:\"#op\";s:4:\"edit\";s:24:\"#limit_validation_errors\";a:1:{i:0;a:3:{i:0;s:6:\"fields\";i:1;s:3:\"uid\";i:2;s:4:\"type\";}}s:7:\"#prefix\";s:48:\"<div class=\"field-plugin-settings-edit-wrapper\">\";s:7:\"#suffix\";s:6:\"</div>\";}}s:5:\"title\";a:12:{s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:9:\"draggable\";i:1;s:14:\"tabledrag-leaf\";}}s:9:\"#row_type\";s:5:\"field\";s:16:\"#region_callback\";a:2:{i:0;r:113;i:1;s:12:\"getRowRegion\";}s:12:\"#js_settings\";a:2:{s:10:\"rowHandler\";s:5:\"field\";s:13:\"defaultPlugin\";s:16:\"string_textfield\";}s:10:\"human_name\";a:1:{s:11:\"#plain_text\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"machine_name\";a:2:{s:7:\"#markup\";s:5:\"title\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"machine-name\";}}}s:6:\"weight\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Weight for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1584;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:14:\"#default_value\";s:2:\"-5\";s:5:\"#size\";i:3;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-weight\";}}}s:14:\"parent_wrapper\";a:2:{s:6:\"parent\";a:8:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Label display for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1584;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:0:{}s:12:\"#empty_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:15:\"js-field-parent\";i:1;s:12:\"field-parent\";}}s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:5:\"title\";i:2;s:6:\"parent\";}s:14:\"#default_value\";s:0:\"\";}s:11:\"hidden_name\";a:3:{s:5:\"#type\";s:6:\"hidden\";s:14:\"#default_value\";s:5:\"title\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:10:\"field-name\";}}}}s:6:\"region\";a:6:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Region for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1584;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:7:\"content\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Disabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:6:\"Plural\";}}}s:14:\"#default_value\";s:7:\"content\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-region\";}}}s:6:\"plugin\";a:3:{s:4:\"type\";a:7:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Plugin for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1584;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:1:{s:16:\"string_textfield\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Textfield\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:16:\"string_textfield\";s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:5:\"title\";i:2;s:4:\"type\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:17:\"field-plugin-type\";}}}s:18:\"settings_edit_form\";a:0:{}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Formatter for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1584;}s:10:\"\0*\0options\";a:0:{}}}s:16:\"settings_summary\";a:4:{s:5:\"#type\";s:15:\"inline_template\";s:9:\"#template\";s:73:\"<div class=\"field-plugin-summary\">{{ summary|safe_join(\"<br />\") }}</div>\";s:8:\"#context\";a:1:{s:7:\"summary\";a:1:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Textfield size: @size\";s:12:\"\0*\0arguments\";a:1:{s:5:\"@size\";i:60;}s:10:\"\0*\0options\";a:0:{}}}}s:16:\"#cell_attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:25:\"field-plugin-summary-cell\";}}}s:13:\"settings_edit\";a:11:{s:7:\"#submit\";a:1:{i:0;s:17:\"::multistepSubmit\";}s:5:\"#ajax\";a:3:{s:8:\"callback\";s:15:\"::multistepAjax\";s:7:\"wrapper\";s:30:\"field-display-overview-wrapper\";s:6:\"effect\";s:4:\"fade\";}s:11:\"#field_name\";s:5:\"title\";s:5:\"#type\";s:12:\"image_button\";s:5:\"#name\";s:19:\"title_settings_edit\";s:4:\"#src\";s:30:\"core/misc/icons/787878/cog.svg\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:26:\"field-plugin-settings-edit\";}s:3:\"alt\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:3:\"#op\";s:4:\"edit\";s:24:\"#limit_validation_errors\";a:1:{i:0;a:3:{i:0;s:6:\"fields\";i:1;s:5:\"title\";i:2;s:4:\"type\";}}s:7:\"#prefix\";s:48:\"<div class=\"field-plugin-settings-edit-wrapper\">\";s:7:\"#suffix\";s:6:\"</div>\";}}s:7:\"created\";a:12:{s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:9:\"draggable\";i:1;s:14:\"tabledrag-leaf\";}}s:9:\"#row_type\";s:5:\"field\";s:16:\"#region_callback\";a:2:{i:0;r:113;i:1;s:12:\"getRowRegion\";}s:12:\"#js_settings\";a:2:{s:10:\"rowHandler\";s:5:\"field\";s:13:\"defaultPlugin\";s:18:\"datetime_timestamp\";}s:10:\"human_name\";a:1:{s:11:\"#plain_text\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"machine_name\";a:2:{s:7:\"#markup\";s:7:\"created\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"machine-name\";}}}s:6:\"weight\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Weight for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1734;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:14:\"#default_value\";s:2:\"10\";s:5:\"#size\";i:3;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-weight\";}}}s:14:\"parent_wrapper\";a:2:{s:6:\"parent\";a:8:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Label display for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1734;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:0:{}s:12:\"#empty_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:15:\"js-field-parent\";i:1;s:12:\"field-parent\";}}s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:7:\"created\";i:2;s:6:\"parent\";}s:14:\"#default_value\";s:0:\"\";}s:11:\"hidden_name\";a:3:{s:5:\"#type\";s:6:\"hidden\";s:14:\"#default_value\";s:7:\"created\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:10:\"field-name\";}}}}s:6:\"region\";a:6:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Region for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1734;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:7:\"content\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Disabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:6:\"Plural\";}}}s:14:\"#default_value\";s:7:\"content\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-region\";}}}s:6:\"plugin\";a:3:{s:4:\"type\";a:7:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Plugin for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1734;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:1:{s:18:\"datetime_timestamp\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Datetime Timestamp\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:18:\"datetime_timestamp\";s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:7:\"created\";i:2;s:4:\"type\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:17:\"field-plugin-type\";}}}s:18:\"settings_edit_form\";a:0:{}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Formatter for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:1734;}s:10:\"\0*\0options\";a:0:{}}}s:16:\"settings_summary\";a:0:{}s:13:\"settings_edit\";a:11:{s:7:\"#submit\";a:1:{i:0;s:17:\"::multistepSubmit\";}s:5:\"#ajax\";a:3:{s:8:\"callback\";s:15:\"::multistepAjax\";s:7:\"wrapper\";s:30:\"field-display-overview-wrapper\";s:6:\"effect\";s:4:\"fade\";}s:11:\"#field_name\";s:7:\"created\";s:5:\"#type\";s:12:\"image_button\";s:5:\"#name\";s:21:\"created_settings_edit\";s:4:\"#src\";s:30:\"core/misc/icons/787878/cog.svg\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:26:\"field-plugin-settings-edit\";}s:3:\"alt\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:3:\"#op\";s:4:\"edit\";s:24:\"#limit_validation_errors\";a:1:{i:0;a:3:{i:0;s:6:\"fields\";i:1;s:7:\"created\";i:2;s:4:\"type\";}}s:7:\"#prefix\";s:48:\"<div class=\"field-plugin-settings-edit-wrapper\">\";s:7:\"#suffix\";s:6:\"</div>\";}}s:7:\"promote\";a:12:{s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:9:\"draggable\";i:1;s:14:\"tabledrag-leaf\";}}s:9:\"#row_type\";s:5:\"field\";s:16:\"#region_callback\";a:2:{i:0;r:113;i:1;s:12:\"getRowRegion\";}s:12:\"#js_settings\";a:2:{s:10:\"rowHandler\";s:5:\"field\";s:13:\"defaultPlugin\";s:16:\"boolean_checkbox\";}s:10:\"human_name\";a:1:{s:11:\"#plain_text\";s:22:\"Promoted to front page\";}s:12:\"machine_name\";a:2:{s:7:\"#markup\";s:7:\"promote\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"machine-name\";}}}s:6:\"weight\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Weight for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:22:\"Promoted to front page\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:14:\"#default_value\";s:2:\"15\";s:5:\"#size\";i:3;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-weight\";}}}s:14:\"parent_wrapper\";a:2:{s:6:\"parent\";a:8:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Label display for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:22:\"Promoted to front page\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:0:{}s:12:\"#empty_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:15:\"js-field-parent\";i:1;s:12:\"field-parent\";}}s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:7:\"promote\";i:2;s:6:\"parent\";}s:14:\"#default_value\";s:0:\"\";}s:11:\"hidden_name\";a:3:{s:5:\"#type\";s:6:\"hidden\";s:14:\"#default_value\";s:7:\"promote\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:10:\"field-name\";}}}}s:6:\"region\";a:6:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Region for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:22:\"Promoted to front page\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:7:\"content\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Disabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:6:\"Plural\";}}}s:14:\"#default_value\";s:7:\"content\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-region\";}}}s:6:\"plugin\";a:3:{s:4:\"type\";a:7:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Plugin for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:22:\"Promoted to front page\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:16:\"boolean_checkbox\";r:1331;s:15:\"options_buttons\";r:1335;}s:14:\"#default_value\";s:16:\"boolean_checkbox\";s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:7:\"promote\";i:2;s:4:\"type\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:17:\"field-plugin-type\";}}}s:18:\"settings_edit_form\";a:0:{}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Formatter for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:22:\"Promoted to front page\";}s:10:\"\0*\0options\";a:0:{}}}s:16:\"settings_summary\";a:4:{s:5:\"#type\";s:15:\"inline_template\";s:9:\"#template\";s:73:\"<div class=\"field-plugin-summary\">{{ summary|safe_join(\"<br />\") }}</div>\";s:8:\"#context\";a:1:{s:7:\"summary\";a:1:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:31:\"Use field label: @display_label\";s:12:\"\0*\0arguments\";a:1:{s:14:\"@display_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Yes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"\0*\0options\";a:0:{}}}}s:16:\"#cell_attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:25:\"field-plugin-summary-cell\";}}}s:13:\"settings_edit\";a:11:{s:7:\"#submit\";a:1:{i:0;s:17:\"::multistepSubmit\";}s:5:\"#ajax\";a:3:{s:8:\"callback\";s:15:\"::multistepAjax\";s:7:\"wrapper\";s:30:\"field-display-overview-wrapper\";s:6:\"effect\";s:4:\"fade\";}s:11:\"#field_name\";s:7:\"promote\";s:5:\"#type\";s:12:\"image_button\";s:5:\"#name\";s:21:\"promote_settings_edit\";s:4:\"#src\";s:30:\"core/misc/icons/787878/cog.svg\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:26:\"field-plugin-settings-edit\";}s:3:\"alt\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:3:\"#op\";s:4:\"edit\";s:24:\"#limit_validation_errors\";a:1:{i:0;a:3:{i:0;s:6:\"fields\";i:1;s:7:\"promote\";i:2;s:4:\"type\";}}s:7:\"#prefix\";s:48:\"<div class=\"field-plugin-settings-edit-wrapper\">\";s:7:\"#suffix\";s:6:\"</div>\";}}s:6:\"sticky\";a:12:{s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:9:\"draggable\";i:1;s:14:\"tabledrag-leaf\";}}s:9:\"#row_type\";s:5:\"field\";s:16:\"#region_callback\";a:2:{i:0;r:113;i:1;s:12:\"getRowRegion\";}s:12:\"#js_settings\";a:2:{s:10:\"rowHandler\";s:5:\"field\";s:13:\"defaultPlugin\";s:16:\"boolean_checkbox\";}s:10:\"human_name\";a:1:{s:11:\"#plain_text\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Sticky at top of lists\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"machine_name\";a:2:{s:7:\"#markup\";s:6:\"sticky\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"machine-name\";}}}s:6:\"weight\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Weight for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:2020;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:14:\"#default_value\";s:2:\"16\";s:5:\"#size\";i:3;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-weight\";}}}s:14:\"parent_wrapper\";a:2:{s:6:\"parent\";a:8:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Label display for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:2020;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:0:{}s:12:\"#empty_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:15:\"js-field-parent\";i:1;s:12:\"field-parent\";}}s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:6:\"sticky\";i:2;s:6:\"parent\";}s:14:\"#default_value\";s:0:\"\";}s:11:\"hidden_name\";a:3:{s:5:\"#type\";s:6:\"hidden\";s:14:\"#default_value\";s:6:\"sticky\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:10:\"field-name\";}}}}s:6:\"region\";a:6:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Region for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:2020;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:7:\"content\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Disabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:6:\"Plural\";}}}s:14:\"#default_value\";s:7:\"content\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-region\";}}}s:6:\"plugin\";a:3:{s:4:\"type\";a:7:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Plugin for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:2020;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:16:\"boolean_checkbox\";r:1331;s:15:\"options_buttons\";r:1335;}s:14:\"#default_value\";s:16:\"boolean_checkbox\";s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:6:\"sticky\";i:2;s:4:\"type\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:17:\"field-plugin-type\";}}}s:18:\"settings_edit_form\";a:0:{}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Formatter for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:2020;}s:10:\"\0*\0options\";a:0:{}}}s:16:\"settings_summary\";a:4:{s:5:\"#type\";s:15:\"inline_template\";s:9:\"#template\";s:73:\"<div class=\"field-plugin-summary\">{{ summary|safe_join(\"<br />\") }}</div>\";s:8:\"#context\";a:1:{s:7:\"summary\";a:1:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:31:\"Use field label: @display_label\";s:12:\"\0*\0arguments\";a:1:{s:14:\"@display_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Yes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"\0*\0options\";a:0:{}}}}s:16:\"#cell_attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:25:\"field-plugin-summary-cell\";}}}s:13:\"settings_edit\";a:11:{s:7:\"#submit\";a:1:{i:0;s:17:\"::multistepSubmit\";}s:5:\"#ajax\";a:3:{s:8:\"callback\";s:15:\"::multistepAjax\";s:7:\"wrapper\";s:30:\"field-display-overview-wrapper\";s:6:\"effect\";s:4:\"fade\";}s:11:\"#field_name\";s:6:\"sticky\";s:5:\"#type\";s:12:\"image_button\";s:5:\"#name\";s:20:\"sticky_settings_edit\";s:4:\"#src\";s:30:\"core/misc/icons/787878/cog.svg\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:26:\"field-plugin-settings-edit\";}s:3:\"alt\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:3:\"#op\";s:4:\"edit\";s:24:\"#limit_validation_errors\";a:1:{i:0;a:3:{i:0;s:6:\"fields\";i:1;s:6:\"sticky\";i:2;s:4:\"type\";}}s:7:\"#prefix\";s:48:\"<div class=\"field-plugin-settings-edit-wrapper\">\";s:7:\"#suffix\";s:6:\"</div>\";}}s:4:\"path\";a:12:{s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:9:\"draggable\";i:1;s:14:\"tabledrag-leaf\";}}s:9:\"#row_type\";s:5:\"field\";s:16:\"#region_callback\";a:2:{i:0;r:113;i:1;s:12:\"getRowRegion\";}s:12:\"#js_settings\";a:2:{s:10:\"rowHandler\";s:5:\"field\";s:13:\"defaultPlugin\";s:4:\"path\";}s:10:\"human_name\";a:1:{s:11:\"#plain_text\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"machine_name\";a:2:{s:7:\"#markup\";s:4:\"path\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"machine-name\";}}}s:6:\"weight\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Weight for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:2171;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:14:\"#default_value\";s:2:\"30\";s:5:\"#size\";i:3;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-weight\";}}}s:14:\"parent_wrapper\";a:2:{s:6:\"parent\";a:8:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Label display for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:2171;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:0:{}s:12:\"#empty_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:15:\"js-field-parent\";i:1;s:12:\"field-parent\";}}s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:4:\"path\";i:2;s:6:\"parent\";}s:14:\"#default_value\";s:0:\"\";}s:11:\"hidden_name\";a:3:{s:5:\"#type\";s:6:\"hidden\";s:14:\"#default_value\";s:4:\"path\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:10:\"field-name\";}}}}s:6:\"region\";a:6:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Region for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:2171;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:7:\"content\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Disabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:6:\"Plural\";}}}s:14:\"#default_value\";s:7:\"content\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-region\";}}}s:6:\"plugin\";a:3:{s:4:\"type\";a:7:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Plugin for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:2171;}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:1:{s:4:\"path\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:4:\"path\";s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:4:\"path\";i:2;s:4:\"type\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:17:\"field-plugin-type\";}}}s:18:\"settings_edit_form\";a:0:{}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Formatter for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";r:2171;}s:10:\"\0*\0options\";a:0:{}}}s:16:\"settings_summary\";a:0:{}s:13:\"settings_edit\";a:11:{s:7:\"#submit\";a:1:{i:0;s:17:\"::multistepSubmit\";}s:5:\"#ajax\";a:3:{s:8:\"callback\";s:15:\"::multistepAjax\";s:7:\"wrapper\";s:30:\"field-display-overview-wrapper\";s:6:\"effect\";s:4:\"fade\";}s:11:\"#field_name\";s:4:\"path\";s:5:\"#type\";s:12:\"image_button\";s:5:\"#name\";s:18:\"path_settings_edit\";s:4:\"#src\";s:30:\"core/misc/icons/787878/cog.svg\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:26:\"field-plugin-settings-edit\";}s:3:\"alt\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:3:\"#op\";s:4:\"edit\";s:24:\"#limit_validation_errors\";a:1:{i:0;a:3:{i:0;s:6:\"fields\";i:1;s:4:\"path\";i:2;s:4:\"type\";}}s:7:\"#prefix\";s:48:\"<div class=\"field-plugin-settings-edit-wrapper\">\";s:7:\"#suffix\";s:6:\"</div>\";}}s:4:\"body\";a:12:{s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:9:\"draggable\";i:1;s:14:\"tabledrag-leaf\";}}s:9:\"#row_type\";s:5:\"field\";s:16:\"#region_callback\";a:2:{i:0;r:113;i:1;s:12:\"getRowRegion\";}s:12:\"#js_settings\";a:2:{s:10:\"rowHandler\";s:5:\"field\";s:13:\"defaultPlugin\";s:26:\"text_textarea_with_summary\";}s:10:\"human_name\";a:1:{s:11:\"#plain_text\";s:4:\"Body\";}s:12:\"machine_name\";a:2:{s:7:\"#markup\";s:4:\"body\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"machine-name\";}}}s:6:\"weight\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Weight for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:4:\"Body\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:14:\"#default_value\";s:2:\"31\";s:5:\"#size\";i:3;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-weight\";}}}s:14:\"parent_wrapper\";a:2:{s:6:\"parent\";a:8:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Label display for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:4:\"Body\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:0:{}s:12:\"#empty_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:15:\"js-field-parent\";i:1;s:12:\"field-parent\";}}s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:4:\"body\";i:2;s:6:\"parent\";}s:14:\"#default_value\";s:0:\"\";}s:11:\"hidden_name\";a:3:{s:5:\"#type\";s:6:\"hidden\";s:14:\"#default_value\";s:4:\"body\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:10:\"field-name\";}}}}s:6:\"region\";a:6:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Region for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:4:\"Body\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:7:\"content\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Disabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:6:\"Plural\";}}}s:14:\"#default_value\";s:7:\"content\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-region\";}}}s:6:\"plugin\";a:3:{s:4:\"type\";a:7:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Plugin for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:4:\"Body\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:1:{s:26:\"text_textarea_with_summary\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Text area with a summary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:26:\"text_textarea_with_summary\";s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:4:\"body\";i:2;s:4:\"type\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:17:\"field-plugin-type\";}}}s:18:\"settings_edit_form\";a:0:{}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Formatter for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:4:\"Body\";}s:10:\"\0*\0options\";a:0:{}}}s:16:\"settings_summary\";a:4:{s:5:\"#type\";s:15:\"inline_template\";s:9:\"#template\";s:73:\"<div class=\"field-plugin-summary\">{{ summary|safe_join(\"<br />\") }}</div>\";s:8:\"#context\";a:1:{s:7:\"summary\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Number of rows: @rows\";s:12:\"\0*\0arguments\";a:1:{s:5:\"@rows\";i:9;}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Number of summary rows: @rows\";s:12:\"\0*\0arguments\";a:1:{s:5:\"@rows\";i:3;}s:10:\"\0*\0options\";a:0:{}}}}s:16:\"#cell_attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:25:\"field-plugin-summary-cell\";}}}s:13:\"settings_edit\";a:11:{s:7:\"#submit\";a:1:{i:0;s:17:\"::multistepSubmit\";}s:5:\"#ajax\";a:3:{s:8:\"callback\";s:15:\"::multistepAjax\";s:7:\"wrapper\";s:30:\"field-display-overview-wrapper\";s:6:\"effect\";s:4:\"fade\";}s:11:\"#field_name\";s:4:\"body\";s:5:\"#type\";s:12:\"image_button\";s:5:\"#name\";s:18:\"body_settings_edit\";s:4:\"#src\";s:30:\"core/misc/icons/787878/cog.svg\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:26:\"field-plugin-settings-edit\";}s:3:\"alt\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:3:\"#op\";s:4:\"edit\";s:24:\"#limit_validation_errors\";a:1:{i:0;a:3:{i:0;s:6:\"fields\";i:1;s:4:\"body\";i:2;s:4:\"type\";}}s:7:\"#prefix\";s:48:\"<div class=\"field-plugin-settings-edit-wrapper\">\";s:7:\"#suffix\";s:6:\"</div>\";}}s:16:\"field_components\";a:12:{s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:9:\"draggable\";i:1;s:14:\"tabledrag-leaf\";}}s:9:\"#row_type\";s:5:\"field\";s:16:\"#region_callback\";a:2:{i:0;r:113;i:1;s:12:\"getRowRegion\";}s:12:\"#js_settings\";a:2:{s:10:\"rowHandler\";s:5:\"field\";s:13:\"defaultPlugin\";s:39:\"entity_reference_revisions_autocomplete\";}s:10:\"human_name\";a:1:{s:11:\"#plain_text\";s:10:\"Components\";}s:12:\"machine_name\";a:2:{s:7:\"#markup\";s:16:\"field_components\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"machine-name\";}}}s:6:\"weight\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Weight for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:10:\"Components\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:14:\"#default_value\";s:3:\"121\";s:5:\"#size\";i:3;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-weight\";}}}s:14:\"parent_wrapper\";a:2:{s:6:\"parent\";a:8:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Label display for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:10:\"Components\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:0:{}s:12:\"#empty_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:15:\"js-field-parent\";i:1;s:12:\"field-parent\";}}s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:16:\"field_components\";i:2;s:6:\"parent\";}s:14:\"#default_value\";s:0:\"\";}s:11:\"hidden_name\";a:3:{s:5:\"#type\";s:6:\"hidden\";s:14:\"#default_value\";s:16:\"field_components\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:10:\"field-name\";}}}}s:6:\"region\";a:6:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Region for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:10:\"Components\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:2:{s:7:\"content\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Disabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:6:\"Plural\";}}}s:14:\"#default_value\";s:7:\"content\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:12:\"field-region\";}}}s:6:\"plugin\";a:3:{s:4:\"type\";a:7:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Plugin for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:10:\"Components\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#title_display\";s:9:\"invisible\";s:8:\"#options\";a:3:{s:17:\"layout_paragraphs\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Layout Paragraphs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:27:\"entity_reference_paragraphs\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Paragraphs Legacy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:10:\"paragraphs\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Paragraphs (stable)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:17:\"layout_paragraphs\";s:8:\"#parents\";a:3:{i:0;s:6:\"fields\";i:1;s:16:\"field_components\";i:2;s:4:\"type\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:17:\"field-plugin-type\";}}}s:18:\"settings_edit_form\";a:0:{}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Formatter for @title\";s:12:\"\0*\0arguments\";a:1:{s:6:\"@title\";s:10:\"Components\";}s:10:\"\0*\0options\";a:0:{}}}s:16:\"settings_summary\";a:4:{s:5:\"#type\";s:15:\"inline_template\";s:9:\"#template\";s:73:\"<div class=\"field-plugin-summary\">{{ summary|safe_join(\"<br />\") }}</div>\";s:8:\"#context\";a:1:{s:7:\"summary\";a:5:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Rendered as @mode\";s:12:\"\0*\0arguments\";a:1:{s:5:\"@mode\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Default\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Preview view mode: @preview_mode\";s:12:\"\0*\0arguments\";a:1:{s:13:\"@preview_mode\";r:2572;}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"Form display mode: @form_display_mode\";s:12:\"\0*\0arguments\";a:1:{s:18:\"@form_display_mode\";s:7:\"default\";}s:10:\"\0*\0options\";a:0:{}}i:3;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"Maximum nesting depth: @max_depth\";s:12:\"\0*\0arguments\";a:1:{s:10:\"@max_depth\";s:1:\"0\";}s:10:\"\0*\0options\";a:0:{}}i:4;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Layouts are optional.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:16:\"#cell_attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:25:\"field-plugin-summary-cell\";}}}s:13:\"settings_edit\";a:11:{s:7:\"#submit\";a:1:{i:0;s:17:\"::multistepSubmit\";}s:5:\"#ajax\";a:3:{s:8:\"callback\";s:15:\"::multistepAjax\";s:7:\"wrapper\";s:30:\"field-display-overview-wrapper\";s:6:\"effect\";s:4:\"fade\";}s:11:\"#field_name\";s:16:\"field_components\";s:5:\"#type\";s:12:\"image_button\";s:5:\"#name\";s:30:\"field_components_settings_edit\";s:4:\"#src\";s:30:\"core/misc/icons/787878/cog.svg\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:26:\"field-plugin-settings-edit\";}s:3:\"alt\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:3:\"#op\";s:4:\"edit\";s:24:\"#limit_validation_errors\";a:1:{i:0;a:3:{i:0;s:6:\"fields\";i:1;s:16:\"field_components\";i:2;s:4:\"type\";}}s:7:\"#prefix\";s:48:\"<div class=\"field-plugin-settings-edit-wrapper\">\";s:7:\"#suffix\";s:6:\"</div>\";}}s:15:\"#parent_options\";a:0:{}}s:12:\"refresh_rows\";a:1:{s:5:\"#type\";s:6:\"hidden\";}s:7:\"refresh\";a:6:{s:5:\"#type\";s:6:\"submit\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Refresh\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:3:\"#op\";s:13:\"refresh_table\";s:7:\"#submit\";a:1:{i:0;s:17:\"::multistepSubmit\";}s:5:\"#ajax\";a:4:{s:8:\"callback\";s:15:\"::multistepAjax\";s:7:\"wrapper\";s:30:\"field-display-overview-wrapper\";s:6:\"effect\";s:4:\"fade\";s:8:\"progress\";s:4:\"none\";}s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:15:\"visually-hidden\";}s:8:\"tabindex\";s:2:\"-1\";}}s:7:\"actions\";a:2:{s:6:\"submit\";a:5:{s:5:\"#type\";s:6:\"submit\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Save\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"#submit\";a:3:{i:0;s:33:\"field_group_field_overview_submit\";i:1;s:12:\"::submitForm\";i:2;s:6:\"::save\";}s:12:\"#button_type\";s:7:\"primary\";s:7:\"#weight\";i:5;}s:5:\"#type\";s:7:\"actions\";}s:9:\"#attached\";a:2:{s:7:\"library\";a:2:{i:0;s:24:\"field_ui/drupal.field_ui\";i:1;s:20:\"field_group/field_ui\";}s:12:\"placeholders\";a:1:{s:55:\"form_action_p_pvdeGsVG5zNF_XLGPTvYSKCf43t8qZYSwcfZl2uzM\";a:1:{s:13:\"#lazy_builder\";a:2:{i:0;s:40:\"form_builder:renderPlaceholderFormAction\";i:1;a:0:{}}}}}s:8:\"#form_id\";s:29:\"entity_form_display_edit_form\";s:9:\"#build_id\";s:48:\"form-ybtwOuODcWAPLfPhQ0w9h6DFbPvTN6rvLuM7BYRMe3A\";s:5:\"#type\";s:4:\"form\";s:7:\"#action\";s:55:\"form_action_p_pvdeGsVG5zNF_XLGPTvYSKCf43t8qZYSwcfZl2uzM\";s:13:\"form_build_id\";a:5:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";s:48:\"form-ybtwOuODcWAPLfPhQ0w9h6DFbPvTN6rvLuM7BYRMe3A\";s:3:\"#id\";s:48:\"form-ybtwOuODcWAPLfPhQ0w9h6DFbPvTN6rvLuM7BYRMe3A\";s:5:\"#name\";s:13:\"form_build_id\";s:8:\"#parents\";a:1:{i:0;s:13:\"form_build_id\";}}s:6:\"#token\";s:66:\"form_token_placeholder_WyiknlIgCcooIgmyXMx0oKEk6Tx_D8wbTwTDvdA1ttg\";s:10:\"form_token\";a:5:{s:3:\"#id\";s:58:\"edit-entity-form-display-edit-form-form-token--bVo9tSvrpaE\";s:5:\"#type\";s:5:\"token\";s:14:\"#default_value\";s:66:\"form_token_placeholder_WyiknlIgCcooIgmyXMx0oKEk6Tx_D8wbTwTDvdA1ttg\";s:8:\"#parents\";a:1:{i:0;s:10:\"form_token\";}s:9:\"#attached\";a:1:{s:12:\"placeholders\";a:1:{s:66:\"form_token_placeholder_WyiknlIgCcooIgmyXMx0oKEk6Tx_D8wbTwTDvdA1ttg\";a:1:{s:13:\"#lazy_builder\";a:2:{i:0;s:39:\"form_builder:renderFormTokenPlaceholder\";i:1;a:1:{i:0;s:66:\"form_token_placeholder_WyiknlIgCcooIgmyXMx0oKEk6Tx_D8wbTwTDvdA1ttg\";}}}}}}s:7:\"form_id\";a:4:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";s:29:\"entity_form_display_edit_form\";s:3:\"#id\";s:47:\"edit-entity-form-display-edit-form--gHqKDNW_j30\";s:8:\"#parents\";a:1:{i:0;s:7:\"form_id\";}}s:3:\"#id\";s:42:\"entity-form-display-edit-form--u7ci3-1k5d0\";s:7:\"#method\";s:4:\"post\";s:15:\"#theme_wrappers\";a:1:{i:0;s:4:\"form\";}s:16:\"#defaults_loaded\";b:1;s:5:\"#tree\";b:0;s:8:\"#parents\";a:0:{}s:9:\"#validate\";a:1:{i:0;s:14:\"::validateForm\";}s:7:\"#submit\";a:1:{i:0;s:12:\"::submitForm\";}s:6:\"#theme\";a:2:{i:0;s:29:\"entity_form_display_edit_form\";i:1;s:24:\"entity_form_display_form\";}s:12:\"#fieldgroups\";a:0:{}s:8:\"#context\";r:129;s:12:\"#cache_token\";s:43:\"GCh-keVlKyEx0w6RaPi2b6HuHxioVkYVdtnthraKseI\";}',1735521554),('form_state','form-ybtwOuODcWAPLfPhQ0w9h6DFbPvTN6rvLuM7BYRMe3A',_binary 'a:9:{s:10:\"build_info\";a:5:{s:4:\"args\";a:0:{}s:5:\"files\";a:1:{s:33:\"field_group:includes/field_ui.inc\";a:3:{s:4:\"type\";s:3:\"inc\";s:6:\"module\";s:11:\"field_group\";s:4:\"name\";s:17:\"includes/field_ui\";}}s:15:\"callback_object\";O:46:\"Drupal\\field_ui\\Form\\EntityFormDisplayEditForm\":12:{s:15:\"\0*\0requestStack\";N;s:16:\"\0*\0configFactory\";N;s:13:\"\0*\0routeMatch\";N;s:14:\"\0*\0_serviceIds\";a:6:{s:17:\"stringTranslation\";s:18:\"string_translation\";s:13:\"moduleHandler\";s:14:\"module_handler\";s:17:\"entityTypeManager\";s:19:\"entity_type.manager\";s:13:\"pluginManager\";s:27:\"plugin.manager.field.widget\";s:23:\"entityDisplayRepository\";s:25:\"entity_display.repository\";s:18:\"entityFieldManager\";s:20:\"entity_field.manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:16:\"\0*\0loggerFactory\";N;s:12:\"\0*\0messenger\";N;s:22:\"\0*\0redirectDestination\";N;s:12:\"\0*\0operation\";s:4:\"edit\";s:9:\"\0*\0entity\";O:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\":15:{s:7:\"\0*\0uuid\";s:36:\"c6ec1d38-d434-4a7d-be65-080873fd0aff\";s:11:\"\0*\0langcode\";s:2:\"en\";s:9:\"\0*\0status\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:38:\"field.field.node.page.field_components\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:3:{i:0;s:17:\"layout_paragraphs\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:5:\"\0*\0id\";s:17:\"node.page.default\";s:19:\"\0*\0targetEntityType\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:7:\"\0*\0mode\";s:7:\"default\";s:10:\"\0*\0content\";a:11:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";s:2:\"31\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";s:2:\"10\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:16:\"field_components\";a:5:{s:4:\"type\";s:17:\"layout_paragraphs\";s:6:\"weight\";s:3:\"121\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";s:1:\"0\";s:13:\"empty_message\";s:0:\"\";s:15:\"require_layouts\";i:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";s:2:\"30\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";s:2:\"15\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";s:3:\"120\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";s:2:\"16\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";s:2:\"-5\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";s:1:\"5\";s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:12:\"revision_log\";a:5:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:2:{s:4:\"rows\";i:4;s:11:\"placeholder\";s:0:\"\";}s:6:\"region\";s:7:\"content\";s:20:\"third_party_settings\";a:0:{}}}s:9:\"\0*\0hidden\";a:0:{}s:15:\"\0*\0entityTypeId\";s:19:\"entity_form_display\";s:15:\"\0*\0enforceIsNew\";N;s:15:\"_serializedKeys\";a:15:{i:0;s:4:\"uuid\";i:1;s:8:\"langcode\";i:2;s:6:\"status\";i:3;s:12:\"dependencies\";i:4;s:5:\"_core\";i:5;s:2:\"id\";i:6;s:16:\"targetEntityType\";i:7;s:6:\"bundle\";i:8;s:4:\"mode\";i:9;s:7:\"content\";i:10;s:6:\"hidden\";i:11;s:12:\"entityTypeId\";i:12;s:12:\"enforceIsNew\";i:13;s:15:\"_serializedKeys\";i:14;s:11:\"initialized\";}s:14:\"\0*\0initialized\";b:1;}s:17:\"\0*\0displayContext\";s:4:\"form\";s:13:\"\0*\0fieldTypes\";a:34:{s:11:\"block_field\";a:14:{s:8:\"category\";s:9:\"reference\";s:6:\"weight\";i:0;s:5:\"no_ui\";b:0;s:16:\"definition_class\";s:37:\"\\Drupal\\Core\\TypedData\\DataDefinition\";s:21:\"list_definition_class\";s:41:\"\\Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;s:2:\"id\";s:11:\"block_field\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Block (plugin)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:53:\"Stores an instance of a configurable or custom block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"default_widget\";s:19:\"block_field_default\";s:17:\"default_formatter\";s:11:\"block_field\";s:5:\"class\";s:56:\"Drupal\\block_field\\Plugin\\Field\\FieldType\\BlockFieldItem\";s:8:\"provider\";s:11:\"block_field\";s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";}s:7:\"comment\";a:17:{s:5:\"class\";s:49:\"Drupal\\comment\\Plugin\\Field\\FieldType\\CommentItem\";s:8:\"provider\";s:7:\"comment\";s:2:\"id\";s:7:\"comment\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Comments\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:75:\"This field manages configuration and presentation of comments on an entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:15:\"comment_default\";s:17:\"default_formatter\";s:15:\"comment_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:35:\"Drupal\\comment\\CommentFieldItemList\";s:11:\"cardinality\";i:1;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:8:\"datetime\";a:17:{s:5:\"class\";s:51:\"Drupal\\datetime\\Plugin\\Field\\FieldType\\DateTimeItem\";s:8:\"provider\";s:8:\"datetime\";s:2:\"id\";s:8:\"datetime\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Date\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:79:\"Ideal when date and time needs to be input by users, like event dates and times\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:56:\"Date or date and time stored in a readable string format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Easy to read and understand for humans\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:9:\"date_time\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:16:\"datetime_default\";s:17:\"default_formatter\";s:16:\"datetime_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:60:\"Drupal\\datetime\\Plugin\\Field\\FieldType\\DateTimeFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:1:{s:14:\"DateTimeFormat\";a:0:{}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:26:\"entity_reference_revisions\";a:14:{s:8:\"category\";s:9:\"reference\";s:6:\"weight\";i:0;s:5:\"no_ui\";b:0;s:16:\"definition_class\";s:37:\"\\Drupal\\Core\\TypedData\\DataDefinition\";s:21:\"list_definition_class\";s:41:\"\\Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;s:2:\"id\";s:26:\"entity_reference_revisions\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Entity reference revisions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:70:\"An entity field containing an entity reference to a specific revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"class\";s:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\";s:10:\"list_class\";s:72:\"\\Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\";s:17:\"default_formatter\";s:38:\"entity_reference_revisions_entity_view\";s:14:\"default_widget\";s:39:\"entity_reference_revisions_autocomplete\";s:8:\"provider\";s:26:\"entity_reference_revisions\";}s:12:\"ept_settings\";a:14:{s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:5:\"no_ui\";b:0;s:16:\"definition_class\";s:37:\"\\Drupal\\Core\\TypedData\\DataDefinition\";s:21:\"list_definition_class\";s:41:\"\\Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;s:2:\"id\";s:12:\"ept_settings\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"EPT Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:57:\"This field stores EPT paragraph settings in the database.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"default_widget\";s:20:\"ept_settings_default\";s:17:\"default_formatter\";s:20:\"ept_settings_default\";s:5:\"class\";s:54:\"Drupal\\ept_core\\Plugin\\Field\\FieldType\\EptSettingsItem\";s:8:\"provider\";s:8:\"ept_core\";s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";}s:4:\"file\";a:17:{s:5:\"class\";s:43:\"Drupal\\file\\Plugin\\Field\\FieldType\\FileItem\";s:8:\"provider\";s:4:\"file\";s:2:\"id\";s:4:\"file\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"File\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"For uploading files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:86:\"Can be configured with options such as allowed file extensions and maximum upload size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:11:\"file_upload\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:12:\"file_generic\";s:17:\"default_formatter\";s:12:\"file_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:52:\"Drupal\\file\\Plugin\\Field\\FieldType\\FileFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:2:{s:15:\"ReferenceAccess\";a:0:{}s:14:\"FileValidation\";a:0:{}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:3:{s:9:\"target_id\";a:2:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"File\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;}s:7:\"display\";a:2:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;}s:11:\"description\";a:2:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;}}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:8:\"file_uri\";a:17:{s:5:\"class\";s:46:\"Drupal\\file\\Plugin\\Field\\FieldType\\FileUriItem\";s:8:\"provider\";s:4:\"file\";s:2:\"id\";s:8:\"file_uri\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"File URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"An entity field containing a file URI, and a computed root-relative file URL.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:3:\"uri\";s:17:\"default_formatter\";s:8:\"file_uri\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:5:\"image\";a:17:{s:5:\"class\";s:45:\"Drupal\\image\\Plugin\\Field\\FieldType\\ImageItem\";s:8:\"provider\";s:5:\"image\";s:2:\"id\";s:5:\"image\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Image\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"For uploading images\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:92:\"Allows a user to upload an image with configurable extensions, image dimensions, upload size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:122:\"Can be configured with options such as allowed file extensions, maximum upload size and image dimensions minimums/maximums\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:11:\"file_upload\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:11:\"image_image\";s:17:\"default_formatter\";s:5:\"image\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:52:\"Drupal\\file\\Plugin\\Field\\FieldType\\FileFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:2:{s:15:\"ReferenceAccess\";a:0:{}s:14:\"FileValidation\";a:0:{}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:3:{s:4:\"file\";a:3:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"File\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"columns\";a:3:{i:0;s:9:\"target_id\";i:1;s:5:\"width\";i:2;s:6:\"height\";}s:34:\"require_all_groups_for_translation\";b:1;}s:3:\"alt\";a:2:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Alt\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;}s:5:\"title\";a:2:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;}}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:4:\"link\";a:17:{s:5:\"class\";s:43:\"Drupal\\link\\Plugin\\Field\\FieldType\\LinkItem\";s:8:\"provider\";s:4:\"link\";s:2:\"id\";s:4:\"link\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:100:\"Stores a URL string, optional varchar link text, and optional blob of attributes to assemble a link.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:12:\"link_default\";s:17:\"default_formatter\";s:4:\"link\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:4:{s:8:\"LinkType\";a:0:{}s:10:\"LinkAccess\";a:0:{}s:21:\"LinkExternalProtocols\";a:0:{}s:23:\"LinkNotExistingInternal\";a:0:{}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:10:\"list_float\";a:17:{s:5:\"class\";s:51:\"Drupal\\options\\Plugin\\Field\\FieldType\\ListFloatItem\";s:8:\"provider\";s:7:\"options\";s:2:\"id\";s:10:\"list_float\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"List (float)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"Values stored are floating-point numbers\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"For example, \'Fraction\': 0 => 0, .25 => 1/4, .75 => 3/4, 1 => 1\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"selection_list\";s:6:\"weight\";i:-10;s:14:\"default_widget\";s:14:\"options_select\";s:17:\"default_formatter\";s:12:\"list_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:12:\"list_integer\";a:17:{s:5:\"class\";s:53:\"Drupal\\options\\Plugin\\Field\\FieldType\\ListIntegerItem\";s:8:\"provider\";s:7:\"options\";s:2:\"id\";s:12:\"list_integer\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"List (integer)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"Values stored are numbers without decimals\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:71:\"For example, \'Lifetime in days\': 1 => 1 day, 7 => 1 week, 31 => 1 month\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"selection_list\";s:6:\"weight\";i:-30;s:14:\"default_widget\";s:14:\"options_select\";s:17:\"default_formatter\";s:12:\"list_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:11:\"list_string\";a:17:{s:5:\"class\";s:52:\"Drupal\\options\\Plugin\\Field\\FieldType\\ListStringItem\";s:8:\"provider\";s:7:\"options\";s:2:\"id\";s:11:\"list_string\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"List (text)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Values stored are text values\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:67:\"For example, \'US States\': IL => Illinois, IA => Iowa, IN => Indiana\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"selection_list\";s:6:\"weight\";i:-50;s:14:\"default_widget\";s:14:\"options_select\";s:17:\"default_formatter\";s:12:\"list_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:4:\"path\";a:17:{s:5:\"class\";s:43:\"Drupal\\path\\Plugin\\Field\\FieldType\\PathItem\";s:8:\"provider\";s:4:\"path\";s:2:\"id\";s:4:\"path\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Path\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:57:\"An entity field containing a path alias and related data.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:4:\"path\";s:17:\"default_formatter\";N;s:5:\"no_ui\";b:1;s:10:\"list_class\";s:52:\"Drupal\\path\\Plugin\\Field\\FieldType\\PathFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:1:{s:9:\"PathAlias\";a:0:{}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:4:\"text\";a:17:{s:5:\"class\";s:43:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextItem\";s:8:\"provider\";s:4:\"text\";s:2:\"id\";s:4:\"text\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Text (formatted)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:4:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:85:\"Ideal for titles and names that need to support markup such as bold, italics or links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Efficient storage for short text\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Requires specifying a maximum length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:3;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:49:\"Good for fields with known or predictable lengths\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"formatted_text\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:14:\"text_textfield\";s:17:\"default_formatter\";s:12:\"text_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:52:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:9:\"text_long\";a:17:{s:5:\"class\";s:47:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextLongItem\";s:8:\"provider\";s:4:\"text\";s:2:\"id\";s:9:\"text_long\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Text (formatted, long)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:66:\"Ideal for longer texts, like body or description without a summary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"Supports long text without specifying a maximum length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"May use more storage and be slower for searching and sorting\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"formatted_text\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:13:\"text_textarea\";s:17:\"default_formatter\";s:12:\"text_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:52:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:17:\"text_with_summary\";a:17:{s:5:\"class\";s:54:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextWithSummaryItem\";s:8:\"provider\";s:4:\"text\";s:2:\"id\";s:17:\"text_with_summary\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Text (formatted, long, with summary)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:4:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"Ideal for longer texts, like body or description with a summary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"Allows specifying a summary for the text\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"Supports long text without specifying a maximum length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:3;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"May use more storage and be slower for searching and sorting\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:14:\"formatted_text\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:26:\"text_textarea_with_summary\";s:17:\"default_formatter\";s:12:\"text_default\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:52:\"Drupal\\text\\Plugin\\Field\\FieldType\\TextFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:14:\"viewsreference\";a:14:{s:8:\"category\";s:9:\"reference\";s:6:\"weight\";i:0;s:5:\"no_ui\";b:0;s:16:\"definition_class\";s:37:\"\\Drupal\\Core\\TypedData\\DataDefinition\";s:21:\"list_definition_class\";s:41:\"\\Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;s:2:\"id\";s:14:\"viewsreference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Views reference\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"A field reference to a view.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"default_widget\";s:27:\"viewsreference_autocomplete\";s:17:\"default_formatter\";s:24:\"viewsreference_formatter\";s:10:\"list_class\";s:63:\"\\Drupal\\viewsreference\\Plugin\\Field\\ViewsReferenceFieldItemList\";s:5:\"class\";s:63:\"Drupal\\viewsreference\\Plugin\\Field\\FieldType\\ViewsReferenceItem\";s:8:\"provider\";s:14:\"viewsreference\";}s:7:\"webform\";a:14:{s:8:\"category\";s:9:\"reference\";s:6:\"weight\";i:0;s:5:\"no_ui\";b:0;s:16:\"definition_class\";s:37:\"\\Drupal\\Core\\TypedData\\DataDefinition\";s:21:\"list_definition_class\";s:41:\"\\Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;s:2:\"id\";s:7:\"webform\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"A webform containing default submission values.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"default_widget\";s:31:\"webform_entity_reference_select\";s:17:\"default_formatter\";s:36:\"webform_entity_reference_entity_view\";s:10:\"list_class\";s:74:\"\\Drupal\\webform\\Plugin\\Field\\FieldType\\WebformEntityReferenceFieldItemList\";s:5:\"class\";s:64:\"Drupal\\webform\\Plugin\\Field\\FieldType\\WebformEntityReferenceItem\";s:8:\"provider\";s:7:\"webform\";}s:7:\"boolean\";a:17:{s:5:\"class\";s:52:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\BooleanItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:7:\"boolean\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Boolean\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"Field to store a true or false value.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:16:\"boolean_checkbox\";s:17:\"default_formatter\";s:7:\"boolean\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:7:\"changed\";a:17:{s:5:\"class\";s:52:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\ChangedItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:7:\"changed\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Last changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:85:\"An entity field containing a UNIX timestamp of when the entity has been last updated.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:18:\"datetime_timestamp\";s:17:\"default_formatter\";s:9:\"timestamp\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:38:\"Drupal\\Core\\Field\\ChangedFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:7:\"created\";a:17:{s:5:\"class\";s:52:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\CreatedItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:7:\"created\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:80:\"An entity field containing a UNIX timestamp of when the entity has been created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:18:\"datetime_timestamp\";s:17:\"default_formatter\";s:9:\"timestamp\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:7:\"decimal\";a:17:{s:5:\"class\";s:52:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\DecimalItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:7:\"decimal\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Number (decimal)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:84:\"Ideal for exact counts and measures (prices, temperatures, distances, volumes, etc.)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:57:\"Stores a number in the database in a fixed decimal format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:104:\"For example, 12.34 km or € when used for further detailed calculations (such as summing many of these)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:6:\"number\";s:6:\"weight\";i:-30;s:14:\"default_widget\";s:6:\"number\";s:17:\"default_formatter\";s:14:\"number_decimal\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:5:\"email\";a:17:{s:5:\"class\";s:50:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\EmailItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:5:\"email\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Field to store an email address.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:13:\"email_default\";s:17:\"default_formatter\";s:12:\"basic_string\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:16:\"entity_reference\";a:17:{s:5:\"class\";s:60:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\EntityReferenceItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:16:\"entity_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Entity reference\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"An entity field containing an entity reference.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:9:\"reference\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:29:\"entity_reference_autocomplete\";s:17:\"default_formatter\";s:22:\"entity_reference_label\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:46:\"Drupal\\Core\\Field\\EntityReferenceFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:5:\"float\";a:17:{s:5:\"class\";s:50:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\FloatItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:5:\"float\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Number (float)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:130:\"In most instances, it is best to use Number (decimal) instead, as decimal numbers stored as floats may contain errors in precision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:130:\"This type of field offers faster processing and more compact storage, but the differences are typically negligible on modern sites\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:86:\"For example, 123.4 km when used in imprecise contexts such as a walking trail distance\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:6:\"number\";s:6:\"weight\";i:-10;s:14:\"default_widget\";s:6:\"number\";s:17:\"default_formatter\";s:14:\"number_decimal\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:7:\"integer\";a:17:{s:5:\"class\";s:52:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\IntegerItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:7:\"integer\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Number (integer)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:2:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Number without decimals\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"For example, 123\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:6:\"number\";s:6:\"weight\";i:-50;s:14:\"default_widget\";s:6:\"number\";s:17:\"default_formatter\";s:14:\"number_integer\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:8:\"language\";a:17:{s:5:\"class\";s:53:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\LanguageItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:8:\"language\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"An entity field referencing a language.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:15:\"language_select\";s:17:\"default_formatter\";s:8:\"language\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:6:\"Length\";a:1:{s:3:\"max\";i:12;}}}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:3:\"map\";a:17:{s:5:\"class\";s:48:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\MapItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:3:\"map\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Map\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:57:\"An entity field for storing a serialized array of values.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";N;s:17:\"default_formatter\";N;s:5:\"no_ui\";b:1;s:10:\"list_class\";s:34:\"Drupal\\Core\\Field\\MapFieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:8:\"password\";a:17:{s:5:\"class\";s:53:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\PasswordItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:8:\"password\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Password\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"An entity field containing a password value.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";N;s:17:\"default_formatter\";N;s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:6:\"string\";a:17:{s:5:\"class\";s:51:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\StringItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"string\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Text (plain)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:4:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Ideal for titles and names\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Efficient storage for short text\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Requires specifying a maximum length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:3;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Good for fields with known or predictable length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:10:\"plain_text\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:16:\"string_textfield\";s:17:\"default_formatter\";s:6:\"string\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:11:\"string_long\";a:17:{s:5:\"class\";s:55:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\StringLongItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:11:\"string_long\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Text (plain, long)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Ideal for longer texts, like body or description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"Supports long text without specifying a maximum length\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"May use more storage and be slower for searching and sorting\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:10:\"plain_text\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:15:\"string_textarea\";s:17:\"default_formatter\";s:12:\"basic_string\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:9:\"timestamp\";a:17:{s:5:\"class\";s:54:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\TimestampItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:9:\"timestamp\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Timestamp\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";a:3:{i:0;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:57:\"Ideal for using date and time calculations or comparisons\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:1;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:71:\"Date and time stored in the form of seconds since January 1, 1970 (UTC)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}i:2;O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"Compact and efficient for storage, sorting and calculations\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:8:\"category\";s:9:\"date_time\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:18:\"datetime_timestamp\";s:17:\"default_formatter\";s:9:\"timestamp\";s:5:\"no_ui\";b:0;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:5:\"Range\";a:2:{s:3:\"min\";s:11:\"-2147483648\";s:3:\"max\";s:10:\"2147483648\";}}}}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:3:\"uri\";a:17:{s:5:\"class\";s:48:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\UriItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:3:\"uri\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"An entity field containing a URI.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";s:3:\"uri\";s:17:\"default_formatter\";s:8:\"uri_link\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}s:4:\"uuid\";a:17:{s:5:\"class\";s:49:\"Drupal\\Core\\Field\\Plugin\\Field\\FieldType\\UuidItem\";s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:4:\"uuid\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"An entity field containing a UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"category\";s:7:\"general\";s:6:\"weight\";i:0;s:14:\"default_widget\";N;s:17:\"default_formatter\";s:6:\"string\";s:5:\"no_ui\";b:1;s:10:\"list_class\";s:32:\"\\Drupal\\Core\\Field\\FieldItemList\";s:11:\"cardinality\";N;s:11:\"constraints\";a:0:{}s:19:\"config_dependencies\";a:0:{}s:13:\"column_groups\";a:0:{}s:25:\"serialized_property_names\";a:0:{}s:6:\"module\";N;}}}s:12:\"base_form_id\";s:24:\"entity_form_display_form\";s:7:\"form_id\";s:29:\"entity_form_display_edit_form\";}s:8:\"response\";N;s:10:\"programmed\";b:0;s:30:\"programmed_bypass_access_check\";b:1;s:13:\"process_input\";b:1;s:16:\"has_file_element\";N;s:7:\"storage\";a:4:{s:23:\"entity_form_initialized\";b:1;s:18:\"field_group_params\";O:8:\"stdClass\":8:{s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"context\";s:4:\"form\";s:6:\"groups\";a:0:{}s:7:\"parents\";a:0:{}s:17:\"available_regions\";a:2:{i:0;s:7:\"content\";i:1;s:6:\"hidden\";}s:14:\"default_region\";s:6:\"hidden\";}s:20:\"plugin_settings_edit\";N;s:22:\"plugin_settings_update\";N;}s:5:\"cache\";b:1;s:8:\"no_cache\";N;}',1735521554),('system','advisories_response',_binary 'a:0:{}',1735513859),('tempstore.private.layout_paragraphs','1:31b481f6f88ead7c6a9b878fa71bc963',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:28:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:43:\"paragraphs.paragraphs_type.ept_super_slider\";i:20;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:21;s:35:\"paragraphs.paragraphs_type.ept_text\";i:22;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:23;s:36:\"paragraphs.paragraphs_type.ept_video\";i:24;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:25;s:36:\"paragraphs.paragraphs_type.ept_views\";i:26;s:38:\"paragraphs.paragraphs_type.ept_webform\";i:27;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:26:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:16:\"ept_super_slider\";s:16:\"ept_super_slider\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:37:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:10:\"ept_bottle\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:0;}s:9:\"ept_cards\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:0;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:16:\"ept_super_slider\";a:2:{s:6:\"weight\";i:70;s:7:\"enabled\";b:1;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}s:11:\"ept_webform\";a:2:{s:6:\"weight\";i:73;s:7:\"enabled\";b:1;}s:17:\"ept_webform_popup\";a:2:{s:6:\"weight\";i:74;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:3:\"vid\";a:1:{s:9:\"x-default\";a:0:{}}s:3:\"nid\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"8cd20dac-399a-430f-96cf-31193fd25e7c\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:4:\"page\";}}}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499424;}}}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";a:0:{}}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:3:\"uid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:1:\"1\";}}}s:5:\"title\";a:1:{s:9:\"x-default\";a:0:{}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499424;}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499424;}}}s:7:\"promote\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:6:\"sticky\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"path\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:8:\"langcode\";s:2:\"en\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:4:\"page\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:0:{}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"31b481f6f88ead7c6a9b878fa71bc963\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1735499424;}',1736104224),('tempstore.private.layout_paragraphs','1:4e40f59c2f60f679cd6f69630c0d34d2',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:26:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:43:\"paragraphs.paragraphs_type.ept_super_slider\";i:20;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:21;s:35:\"paragraphs.paragraphs_type.ept_text\";i:22;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:23;s:36:\"paragraphs.paragraphs_type.ept_video\";i:24;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:25;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:24:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:16:\"ept_super_slider\";s:16:\"ept_super_slider\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:35:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:10:\"ept_bottle\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:0;}s:9:\"ept_cards\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:0;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:16:\"ept_super_slider\";a:2:{s:6:\"weight\";i:70;s:7:\"enabled\";b:1;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:3:\"vid\";a:1:{s:9:\"x-default\";a:0:{}}s:3:\"nid\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"f8eed5cc-6bb6-4128-8f6b-660c1e105a17\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:4:\"page\";}}}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499401;}}}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";a:0:{}}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:3:\"uid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:1:\"1\";}}}s:5:\"title\";a:1:{s:9:\"x-default\";a:0:{}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499401;}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499401;}}}s:7:\"promote\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:6:\"sticky\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"path\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:8:\"langcode\";s:2:\"en\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:0:{}}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:4:\"page\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:0:{}s:11:\"\0*\0langcode\";s:3:\"und\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"4e40f59c2f60f679cd6f69630c0d34d2\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1735499415;}',1736104215),('tempstore.private.layout_paragraphs','1:9d4a1c72c5b0f6e6f0ea335838315cda',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:28:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:43:\"paragraphs.paragraphs_type.ept_super_slider\";i:20;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:21;s:35:\"paragraphs.paragraphs_type.ept_text\";i:22;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:23;s:36:\"paragraphs.paragraphs_type.ept_video\";i:24;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:25;s:36:\"paragraphs.paragraphs_type.ept_views\";i:26;s:38:\"paragraphs.paragraphs_type.ept_webform\";i:27;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:26:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:16:\"ept_super_slider\";s:16:\"ept_super_slider\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:37:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:10:\"ept_bottle\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:0;}s:9:\"ept_cards\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:0;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:16:\"ept_super_slider\";a:2:{s:6:\"weight\";i:70;s:7:\"enabled\";b:1;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}s:11:\"ept_webform\";a:2:{s:6:\"weight\";i:73;s:7:\"enabled\";b:1;}s:17:\"ept_webform_popup\";a:2:{s:6:\"weight\";i:74;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:3:\"vid\";a:1:{s:9:\"x-default\";a:0:{}}s:3:\"nid\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"977bd8a0-b142-48b6-a540-98af2e3b8526\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:4:\"page\";}}}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499538;}}}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";a:0:{}}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:3:\"uid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:1:\"1\";}}}s:5:\"title\";a:1:{s:9:\"x-default\";a:0:{}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499538;}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499538;}}}s:7:\"promote\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:6:\"sticky\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"path\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:8:\"langcode\";s:2:\"en\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:4:\"page\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:0:{}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:0;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"9d4a1c72c5b0f6e6f0ea335838315cda\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1735499538;}',1736104338),('tempstore.private.layout_paragraphs','1:b05dad4ffe172c044bae149af03d0d58',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:27:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";i:25;s:38:\"paragraphs.paragraphs_type.ept_webform\";i:26;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:25:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:37:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:10:\"ept_bottle\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:0;}s:9:\"ept_cards\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:0;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:16:\"ept_super_slider\";a:2:{s:6:\"weight\";i:70;s:7:\"enabled\";b:1;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}s:11:\"ept_webform\";a:2:{s:6:\"weight\";i:73;s:7:\"enabled\";b:1;}s:17:\"ept_webform_popup\";a:2:{s:6:\"weight\";i:74;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:3:\"vid\";a:1:{s:9:\"x-default\";a:0:{}}s:3:\"nid\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"625c6712-269c-4b5e-8f59-01810a1d21f3\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:4:\"page\";}}}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735500582;}}}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";a:0:{}}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:3:\"uid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:1:\"1\";}}}s:5:\"title\";a:1:{s:9:\"x-default\";a:0:{}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735500582;}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735500582;}}}s:7:\"promote\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:6:\"sticky\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"path\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:8:\"langcode\";s:2:\"en\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:4:\"page\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:0:{}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:10;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"b05dad4ffe172c044bae149af03d0d58\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1735500582;}',1736105382),('tempstore.private.layout_paragraphs','1:c6523e6741e09e857ea1a2092a0fa7d6',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:28:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:43:\"paragraphs.paragraphs_type.ept_super_slider\";i:20;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:21;s:35:\"paragraphs.paragraphs_type.ept_text\";i:22;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:23;s:36:\"paragraphs.paragraphs_type.ept_video\";i:24;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:25;s:36:\"paragraphs.paragraphs_type.ept_views\";i:26;s:38:\"paragraphs.paragraphs_type.ept_webform\";i:27;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:26:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:16:\"ept_super_slider\";s:16:\"ept_super_slider\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:37:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:10:\"ept_bottle\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:0;}s:9:\"ept_cards\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:0;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:16:\"ept_super_slider\";a:2:{s:6:\"weight\";i:70;s:7:\"enabled\";b:1;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}s:11:\"ept_webform\";a:2:{s:6:\"weight\";i:73;s:7:\"enabled\";b:1;}s:17:\"ept_webform_popup\";a:2:{s:6:\"weight\";i:74;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:3:\"vid\";a:1:{s:9:\"x-default\";a:0:{}}s:3:\"nid\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"47a01717-8eb8-4087-8d21-0db2e50c8303\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:4:\"page\";}}}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499934;}}}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";a:0:{}}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:3:\"uid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:1:\"1\";}}}s:5:\"title\";a:1:{s:9:\"x-default\";a:0:{}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499934;}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499934;}}}s:7:\"promote\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:6:\"sticky\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"path\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:8:\"langcode\";s:2:\"en\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:4:\"page\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:0:{}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:10;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"c6523e6741e09e857ea1a2092a0fa7d6\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1735499934;}',1736104734),('tempstore.private.layout_paragraphs','1:da298ca2c0ffb99e047faa327dbe9f7e',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:28:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:43:\"paragraphs.paragraphs_type.ept_super_slider\";i:20;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:21;s:35:\"paragraphs.paragraphs_type.ept_text\";i:22;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:23;s:36:\"paragraphs.paragraphs_type.ept_video\";i:24;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:25;s:36:\"paragraphs.paragraphs_type.ept_views\";i:26;s:38:\"paragraphs.paragraphs_type.ept_webform\";i:27;s:44:\"paragraphs.paragraphs_type.ept_webform_popup\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:26:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";s:16:\"ept_super_slider\";s:16:\"ept_super_slider\";s:11:\"ept_webform\";s:11:\"ept_webform\";s:17:\"ept_webform_popup\";s:17:\"ept_webform_popup\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:37:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:10:\"ept_bottle\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:0;}s:9:\"ept_cards\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:0;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:16:\"ept_super_slider\";a:2:{s:6:\"weight\";i:70;s:7:\"enabled\";b:1;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}s:11:\"ept_webform\";a:2:{s:6:\"weight\";i:73;s:7:\"enabled\";b:1;}s:17:\"ept_webform_popup\";a:2:{s:6:\"weight\";i:74;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:3:\"vid\";a:1:{s:9:\"x-default\";a:0:{}}s:3:\"nid\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"3a135d0b-5369-423e-9be3-e68fb7185857\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:4:\"page\";}}}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499477;}}}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";a:0:{}}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:3:\"uid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:1:\"1\";}}}s:5:\"title\";a:1:{s:9:\"x-default\";a:0:{}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499477;}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1735499477;}}}s:7:\"promote\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:6:\"sticky\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"path\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:8:\"langcode\";s:2:\"en\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:4:\"page\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:0:{}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:6;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"da298ca2c0ffb99e047faa327dbe9f7e\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1735499477;}',1736104277),('update','update_project_data',_binary 'a:53:{s:6:\"drupal\";a:14:{s:4:\"name\";s:6:\"drupal\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Announcements\";s:7:\"version\";s:6:\"11.1.0\";s:7:\"package\";s:4:\"Core\";s:7:\"project\";s:6:\"drupal\";s:16:\"_info_file_ctime\";i:1735498473;s:9:\"datestamp\";i:0;}s:9:\"datestamp\";i:0;s:8:\"includes\";a:42:{s:18:\"announcements_feed\";s:13:\"Announcements\";s:14:\"automated_cron\";s:14:\"Automated Cron\";s:8:\"big_pipe\";s:7:\"BigPipe\";s:5:\"block\";s:5:\"Block\";s:13:\"block_content\";s:13:\"Block Content\";s:10:\"breakpoint\";s:10:\"Breakpoint\";s:9:\"ckeditor5\";s:10:\"CKEditor 5\";s:7:\"comment\";s:7:\"Comment\";s:6:\"config\";s:21:\"Configuration Manager\";s:7:\"contact\";s:7:\"Contact\";s:10:\"contextual\";s:16:\"Contextual Links\";s:8:\"datetime\";s:8:\"Datetime\";s:5:\"dblog\";s:16:\"Database Logging\";s:18:\"dynamic_page_cache\";s:27:\"Internal Dynamic Page Cache\";s:6:\"editor\";s:11:\"Text Editor\";s:5:\"field\";s:5:\"Field\";s:8:\"field_ui\";s:8:\"Field UI\";s:4:\"file\";s:4:\"File\";s:6:\"filter\";s:6:\"Filter\";s:4:\"help\";s:4:\"Help\";s:7:\"history\";s:7:\"History\";s:5:\"image\";s:5:\"Image\";s:16:\"layout_discovery\";s:16:\"Layout Discovery\";s:4:\"link\";s:4:\"Link\";s:5:\"media\";s:5:\"Media\";s:13:\"media_library\";s:13:\"Media Library\";s:17:\"menu_link_content\";s:17:\"Custom Menu Links\";s:7:\"menu_ui\";s:7:\"Menu UI\";s:4:\"node\";s:4:\"Node\";s:7:\"options\";s:7:\"Options\";s:10:\"page_cache\";s:19:\"Internal Page Cache\";s:4:\"path\";s:4:\"Path\";s:10:\"path_alias\";s:10:\"Path alias\";s:8:\"shortcut\";s:8:\"Shortcut\";s:6:\"system\";s:6:\"System\";s:8:\"taxonomy\";s:8:\"Taxonomy\";s:4:\"text\";s:4:\"Text\";s:7:\"toolbar\";s:7:\"Toolbar\";s:6:\"update\";s:14:\"Update Manager\";s:4:\"user\";s:4:\"User\";s:5:\"views\";s:5:\"Views\";s:8:\"views_ui\";s:8:\"Views UI\";}s:12:\"project_type\";s:4:\"core\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:6:\"11.1.0\";s:14:\"existing_major\";s:2:\"11\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:11:\"Drupal core\";s:4:\"link\";s:37:\"https://www.drupal.org/project/drupal\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:13:\"admin_toolbar\";a:14:{s:4:\"name\";s:13:\"admin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Admin Toolbar\";s:7:\"package\";s:14:\"Administration\";s:7:\"version\";s:5:\"3.5.1\";s:7:\"project\";s:13:\"admin_toolbar\";s:9:\"datestamp\";i:1730409975;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1730409975;s:8:\"includes\";a:2:{s:13:\"admin_toolbar\";s:13:\"Admin Toolbar\";s:19:\"admin_toolbar_tools\";s:25:\"Admin Toolbar Extra Tools\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"3.5.1\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:13:\"Admin Toolbar\";s:4:\"link\";s:44:\"https://www.drupal.org/project/admin_toolbar\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:22:\"better_exposed_filters\";a:15:{s:4:\"name\";s:22:\"better_exposed_filters\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"Better Exposed Filters\";s:7:\"package\";s:5:\"Views\";s:7:\"version\";s:5:\"7.0.2\";s:7:\"project\";s:22:\"better_exposed_filters\";s:9:\"datestamp\";i:1729001182;s:16:\"_info_file_ctime\";i:1729066392;}s:9:\"datestamp\";i:1729001182;s:8:\"includes\";a:1:{s:22:\"better_exposed_filters\";s:22:\"Better Exposed Filters\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"7.0.2\";s:14:\"existing_major\";s:1:\"7\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:22:\"Better Exposed Filters\";s:4:\"link\";s:53:\"https://www.drupal.org/project/better_exposed_filters\";s:14:\"latest_version\";s:5:\"7.0.2\";s:8:\"releases\";a:1:{s:5:\"7.0.2\";a:13:{s:4:\"name\";s:28:\"better_exposed_filters 7.0.2\";s:7:\"version\";s:5:\"7.0.2\";s:3:\"tag\";s:5:\"7.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/better_exposed_filters/releases/7.0.2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/better_exposed_filters-7.0.2.tar.gz\";s:4:\"date\";s:10:\"1729001179\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"7.0.2\";s:6:\"status\";i:5;}s:11:\"block_field\";a:15:{s:4:\"name\";s:11:\"block_field\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Block Field\";s:7:\"package\";s:5:\"Field\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:7:\"project\";s:11:\"block_field\";s:9:\"datestamp\";i:1723550579;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1723550579;s:8:\"includes\";a:1:{s:11:\"block_field\";s:11:\"Block Field\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:11:\"8.x-1.0-rc5\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:11:\"Block field\";s:4:\"link\";s:42:\"https://www.drupal.org/project/block_field\";s:14:\"latest_version\";s:11:\"8.x-1.0-rc5\";s:8:\"releases\";a:1:{s:11:\"8.x-1.0-rc5\";a:13:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1723550576\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";i:5;}s:21:\"ckeditor5_plugin_pack\";a:14:{s:4:\"name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.2.4\";s:7:\"project\";s:21:\"ckeditor5_plugin_pack\";s:9:\"datestamp\";i:1734514951;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734514951;s:8:\"includes\";a:12:{s:21:\"ckeditor5_plugin_pack\";s:22:\"CKEditor 5 Plugin Pack\";s:32:\"ckeditor5_plugin_pack_auto_image\";s:21:\"CKEditor 5 Auto Image\";s:38:\"ckeditor5_plugin_pack_find_and_replace\";s:27:\"CKEditor 5 Find And Replace\";s:26:\"ckeditor5_plugin_pack_font\";s:23:\"CKEditor 5 Font Plugins\";s:31:\"ckeditor5_plugin_pack_highlight\";s:20:\"CKEditor 5 Highlight\";s:34:\"ckeditor5_plugin_pack_indent_block\";s:28:\"CKEditor 5 Block Indentation\";s:37:\"ckeditor5_plugin_pack_link_attributes\";s:26:\"CKEditor 5 Link Attributes\";s:32:\"ckeditor5_plugin_pack_page_break\";s:21:\"CKEditor 5 Page Break\";s:32:\"ckeditor5_plugin_pack_select_all\";s:21:\"CKEditor 5 Select All\";s:31:\"ckeditor5_plugin_pack_templates\";s:20:\"CKEditor 5 Templates\";s:41:\"ckeditor5_plugin_pack_text_transformation\";s:30:\"CKEditor 5 Text Transformation\";s:40:\"ckeditor5_plugin_pack_todo_document_list\";s:21:\"CKEditor 5 To-do List\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.2.4\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:22:\"CKEditor 5 Plugin Pack\";s:4:\"link\";s:52:\"https://www.drupal.org/project/ckeditor5_plugin_pack\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:26:\"ckeditor5_premium_features\";a:14:{s:4:\"name\";s:26:\"ckeditor5_premium_features\";s:4:\"info\";a:6:{s:4:\"name\";s:27:\"CKEditor 5 Full-screen Mode\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.3.5\";s:7:\"project\";s:26:\"ckeditor5_premium_features\";s:9:\"datestamp\";i:1734513731;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1734513731;s:8:\"includes\";a:1:{s:37:\"ckeditor5_premium_features_fullscreen\";s:27:\"CKEditor 5 Full-screen Mode\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.3.5\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:27:\"CKEditor 5 Premium Features\";s:4:\"link\";s:57:\"https://www.drupal.org/project/ckeditor5_premium_features\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:26:\"entity_reference_revisions\";a:15:{s:4:\"name\";s:26:\"entity_reference_revisions\";s:4:\"info\";a:6:{s:4:\"name\";s:26:\"Entity Reference Revisions\";s:7:\"package\";s:11:\"Field types\";s:7:\"version\";s:8:\"8.x-1.12\";s:7:\"project\";s:26:\"entity_reference_revisions\";s:9:\"datestamp\";i:1722804499;s:16:\"_info_file_ctime\";i:1728223651;}s:9:\"datestamp\";i:1722804499;s:8:\"includes\";a:1:{s:26:\"entity_reference_revisions\";s:26:\"Entity Reference Revisions\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:8:\"8.x-1.12\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:26:\"Entity Reference Revisions\";s:4:\"link\";s:57:\"https://www.drupal.org/project/entity_reference_revisions\";s:14:\"latest_version\";s:8:\"8.x-1.12\";s:8:\"releases\";a:1:{s:8:\"8.x-1.12\";a:13:{s:4:\"name\";s:35:\"entity_reference_revisions 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:75:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.12\";s:13:\"download_link\";s:80:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1722804497\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:8:\"8.x-1.12\";s:6:\"status\";i:5;}s:13:\"ept_accordion\";a:15:{s:4:\"name\";s:13:\"ept_accordion\";s:4:\"info\";a:6:{s:4:\"name\";s:38:\"Extra Paragraph Types (EPT): Accordion\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:13:\"ept_accordion\";s:9:\"datestamp\";i:1721384047;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1721384047;s:8:\"includes\";a:1:{s:13:\"ept_accordion\";s:38:\"Extra Paragraph Types (EPT): Accordion\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.3\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:38:\"Extra Paragraph Types (EPT): Accordion\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ept_accordion\";s:14:\"latest_version\";s:5:\"1.4.3\";s:8:\"releases\";a:1:{s:5:\"1.4.3\";a:13:{s:4:\"name\";s:19:\"ept_accordion 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_accordion/releases/1.4.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384043\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.3\";s:6:\"status\";i:5;}s:16:\"ept_basic_button\";a:15:{s:4:\"name\";s:16:\"ept_basic_button\";s:4:\"info\";a:6:{s:4:\"name\";s:41:\"Extra Paragraph Types (EPT): Basic Button\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:16:\"ept_basic_button\";s:9:\"datestamp\";i:1721384074;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1721384074;s:8:\"includes\";a:1:{s:16:\"ept_basic_button\";s:41:\"Extra Paragraph Types (EPT): Basic Button\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.4\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:41:\"Extra Paragraph Types (EPT): Basic Button\";s:4:\"link\";s:47:\"https://www.drupal.org/project/ept_basic_button\";s:14:\"latest_version\";s:5:\"1.4.4\";s:8:\"releases\";a:1:{s:5:\"1.4.4\";a:13:{s:4:\"name\";s:22:\"ept_basic_button 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1721384071\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.4\";s:6:\"status\";i:5;}s:9:\"ept_block\";a:15:{s:4:\"name\";s:9:\"ept_block\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Block\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:9:\"ept_block\";s:9:\"datestamp\";i:1721384101;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1721384101;s:8:\"includes\";a:1:{s:9:\"ept_block\";s:34:\"Extra Paragraph Types (EPT): Block\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.2\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Block\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_block\";s:14:\"latest_version\";s:5:\"1.4.2\";s:8:\"releases\";a:1:{s:5:\"1.4.2\";a:13:{s:4:\"name\";s:15:\"ept_block 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_block/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_block-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384098\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.2\";s:6:\"status\";i:5;}s:20:\"ept_bootstrap_button\";a:15:{s:4:\"name\";s:20:\"ept_bootstrap_button\";s:4:\"info\";a:6:{s:4:\"name\";s:45:\"Extra Paragraph Types (EPT): Bootstrap Button\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:20:\"ept_bootstrap_button\";s:9:\"datestamp\";i:1721384123;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1721384123;s:8:\"includes\";a:1:{s:20:\"ept_bootstrap_button\";s:45:\"Extra Paragraph Types (EPT): Bootstrap Button\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.2\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:45:\"Extra Paragraph Types (EPT): Bootstrap Button\";s:4:\"link\";s:51:\"https://www.drupal.org/project/ept_bootstrap_button\";s:14:\"latest_version\";s:5:\"1.4.2\";s:8:\"releases\";a:1:{s:5:\"1.4.2\";a:13:{s:4:\"name\";s:26:\"ept_bootstrap_button 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384122\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.2\";s:6:\"status\";i:5;}s:12:\"ept_carousel\";a:14:{s:4:\"name\";s:12:\"ept_carousel\";s:4:\"info\";a:6:{s:4:\"name\";s:37:\"Extra Paragraph Types (EPT): Carousel\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:12:\"ept_carousel\";s:9:\"datestamp\";i:1734284534;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1734284534;s:8:\"includes\";a:1:{s:12:\"ept_carousel\";s:37:\"Extra Paragraph Types (EPT): Carousel\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.5\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:37:\"Extra Paragraph Types (EPT): Carousel\";s:4:\"link\";s:43:\"https://www.drupal.org/project/ept_carousel\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:11:\"ept_columns\";a:15:{s:4:\"name\";s:11:\"ept_columns\";s:4:\"info\";a:6:{s:4:\"name\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.6\";s:7:\"project\";s:11:\"ept_columns\";s:9:\"datestamp\";i:1721384281;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1721384281;s:8:\"includes\";a:1:{s:11:\"ept_columns\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.6\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";s:4:\"link\";s:42:\"https://www.drupal.org/project/ept_columns\";s:14:\"latest_version\";s:5:\"1.4.6\";s:8:\"releases\";a:1:{s:5:\"1.4.6\";a:13:{s:4:\"name\";s:17:\"ept_columns 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1721384279\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.6\";s:6:\"status\";i:5;}s:8:\"ept_core\";a:15:{s:4:\"name\";s:8:\"ept_core\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Core\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:6:\"1.4.17\";s:7:\"project\";s:8:\"ept_core\";s:9:\"datestamp\";i:1728849212;s:16:\"_info_file_ctime\";i:1728849872;}s:9:\"datestamp\";i:1728849212;s:8:\"includes\";a:2:{s:8:\"ept_core\";s:33:\"Extra Paragraph Types (EPT): Core\";s:19:\"ept_core_starterkit\";s:39:\"Extra Paragraph Types (EPT): Starterkit\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:6:\"1.4.17\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Core\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_core\";s:14:\"latest_version\";s:6:\"1.4.17\";s:8:\"releases\";a:1:{s:6:\"1.4.17\";a:13:{s:4:\"name\";s:15:\"ept_core 1.4.17\";s:7:\"version\";s:6:\"1.4.17\";s:3:\"tag\";s:6:\"1.4.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.17\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.17.tar.gz\";s:4:\"date\";s:10:\"1728849210\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:6:\"1.4.17\";s:6:\"status\";i:5;}s:13:\"ept_countdown\";a:15:{s:4:\"name\";s:13:\"ept_countdown\";s:4:\"info\";a:6:{s:4:\"name\";s:38:\"Extra Paragraph Types (EPT): Countdown\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:13:\"ept_countdown\";s:9:\"datestamp\";i:1721384295;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1721384295;s:8:\"includes\";a:1:{s:13:\"ept_countdown\";s:38:\"Extra Paragraph Types (EPT): Countdown\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.2\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:38:\"Extra Paragraph Types (EPT): Countdown\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ept_countdown\";s:14:\"latest_version\";s:5:\"1.4.2\";s:8:\"releases\";a:1:{s:5:\"1.4.2\";a:13:{s:4:\"name\";s:19:\"ept_countdown 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_countdown/releases/1.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384290\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.2\";s:6:\"status\";i:5;}s:11:\"ept_counter\";a:15:{s:4:\"name\";s:11:\"ept_counter\";s:4:\"info\";a:6:{s:4:\"name\";s:36:\"Extra Paragraph Types (EPT): Counter\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:11:\"ept_counter\";s:9:\"datestamp\";i:1722410410;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722410410;s:8:\"includes\";a:1:{s:11:\"ept_counter\";s:36:\"Extra Paragraph Types (EPT): Counter\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.4\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:36:\"Extra Paragraph Types (EPT): Counter\";s:4:\"link\";s:42:\"https://www.drupal.org/project/ept_counter\";s:14:\"latest_version\";s:5:\"1.4.4\";s:8:\"releases\";a:1:{s:5:\"1.4.4\";a:13:{s:4:\"name\";s:17:\"ept_counter 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410408\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.4\";s:6:\"status\";i:5;}s:7:\"ept_cta\";a:15:{s:4:\"name\";s:7:\"ept_cta\";s:4:\"info\";a:6:{s:4:\"name\";s:43:\"Extra Paragraph Types (EPT): Call to Action\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:7:\"ept_cta\";s:9:\"datestamp\";i:1722410464;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722410464;s:8:\"includes\";a:1:{s:7:\"ept_cta\";s:43:\"Extra Paragraph Types (EPT): Call to Action\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.4\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:43:\"Extra Paragraph Types (EPT): Call to Action\";s:4:\"link\";s:38:\"https://www.drupal.org/project/ept_cta\";s:14:\"latest_version\";s:5:\"1.4.4\";s:8:\"releases\";a:1:{s:5:\"1.4.4\";a:13:{s:4:\"name\";s:13:\"ept_cta 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410462\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.4\";s:6:\"status\";i:5;}s:8:\"ept_hero\";a:14:{s:4:\"name\";s:8:\"ept_hero\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Hero\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:8:\"ept_hero\";s:9:\"datestamp\";i:1733145602;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1733145602;s:8:\"includes\";a:1:{s:8:\"ept_hero\";s:33:\"Extra Paragraph Types (EPT): Hero\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.5\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Hero\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_hero\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:9:\"ept_image\";a:15:{s:4:\"name\";s:9:\"ept_image\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Image\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:9:\"ept_image\";s:9:\"datestamp\";i:1722410544;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722410544;s:8:\"includes\";a:1:{s:9:\"ept_image\";s:34:\"Extra Paragraph Types (EPT): Image\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.4\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Image\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_image\";s:14:\"latest_version\";s:5:\"1.4.4\";s:8:\"releases\";a:1:{s:5:\"1.4.4\";a:13:{s:4:\"name\";s:15:\"ept_image 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410542\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.4\";s:6:\"status\";i:5;}s:17:\"ept_image_gallery\";a:15:{s:4:\"name\";s:17:\"ept_image_gallery\";s:4:\"info\";a:6:{s:4:\"name\";s:42:\"Extra Paragraph Types (EPT): Image Gallery\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:17:\"ept_image_gallery\";s:9:\"datestamp\";i:1722411237;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722411237;s:8:\"includes\";a:1:{s:17:\"ept_image_gallery\";s:42:\"Extra Paragraph Types (EPT): Image Gallery\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.4\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:42:\"Extra Paragraph Types (EPT): Image Gallery\";s:4:\"link\";s:48:\"https://www.drupal.org/project/ept_image_gallery\";s:14:\"latest_version\";s:5:\"1.4.4\";s:8:\"releases\";a:1:{s:5:\"1.4.4\";a:13:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722411235\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.4\";s:6:\"status\";i:5;}s:14:\"ept_micromodal\";a:15:{s:4:\"name\";s:14:\"ept_micromodal\";s:4:\"info\";a:6:{s:4:\"name\";s:39:\"Extra Paragraph Types (EPT): Micromodal\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:14:\"ept_micromodal\";s:9:\"datestamp\";i:1721384363;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1721384363;s:8:\"includes\";a:1:{s:14:\"ept_micromodal\";s:39:\"Extra Paragraph Types (EPT): Micromodal\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.2\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:39:\"Extra Paragraph Types (EPT): Micromodal\";s:4:\"link\";s:45:\"https://www.drupal.org/project/ept_micromodal\";s:14:\"latest_version\";s:5:\"1.4.2\";s:8:\"releases\";a:1:{s:5:\"1.4.2\";a:13:{s:4:\"name\";s:20:\"ept_micromodal 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384358\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.2\";s:6:\"status\";i:5;}s:9:\"ept_quote\";a:15:{s:4:\"name\";s:9:\"ept_quote\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Quote\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:9:\"ept_quote\";s:9:\"datestamp\";i:1722411327;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722411327;s:8:\"includes\";a:1:{s:9:\"ept_quote\";s:34:\"Extra Paragraph Types (EPT): Quote\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.3\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Quote\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_quote\";s:14:\"latest_version\";s:5:\"1.4.3\";s:8:\"releases\";a:1:{s:5:\"1.4.3\";a:13:{s:4:\"name\";s:15:\"ept_quote 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_quote/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411325\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.3\";s:6:\"status\";i:5;}s:16:\"ept_slick_slider\";a:15:{s:4:\"name\";s:16:\"ept_slick_slider\";s:4:\"info\";a:6:{s:4:\"name\";s:41:\"Extra Paragraph Types (EPT): Slick Slider\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:16:\"ept_slick_slider\";s:9:\"datestamp\";i:1722411500;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722411500;s:8:\"includes\";a:1:{s:16:\"ept_slick_slider\";s:41:\"Extra Paragraph Types (EPT): Slick Slider\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.3\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:41:\"Extra Paragraph Types (EPT): Slick Slider\";s:4:\"link\";s:47:\"https://www.drupal.org/project/ept_slick_slider\";s:14:\"latest_version\";s:5:\"1.4.3\";s:8:\"releases\";a:1:{s:5:\"1.4.3\";a:13:{s:4:\"name\";s:22:\"ept_slick_slider 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411497\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.3\";s:6:\"status\";i:5;}s:13:\"ept_slideshow\";a:15:{s:4:\"name\";s:13:\"ept_slideshow\";s:4:\"info\";a:6:{s:4:\"name\";s:38:\"Extra Paragraph Types (EPT): Slideshow\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:13:\"ept_slideshow\";s:9:\"datestamp\";i:1722411524;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1722411524;s:8:\"includes\";a:1:{s:13:\"ept_slideshow\";s:38:\"Extra Paragraph Types (EPT): Slideshow\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.4\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:38:\"Extra Paragraph Types (EPT): Slideshow\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ept_slideshow\";s:14:\"latest_version\";s:5:\"1.4.4\";s:8:\"releases\";a:1:{s:5:\"1.4.4\";a:13:{s:4:\"name\";s:19:\"ept_slideshow 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722411522\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.4\";s:6:\"status\";i:5;}s:9:\"ept_stats\";a:15:{s:4:\"name\";s:9:\"ept_stats\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Stats\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:9:\"ept_stats\";s:9:\"datestamp\";i:1721384555;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1721384555;s:8:\"includes\";a:1:{s:9:\"ept_stats\";s:34:\"Extra Paragraph Types (EPT): Stats\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.2\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Stats\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_stats\";s:14:\"latest_version\";s:5:\"1.4.2\";s:8:\"releases\";a:1:{s:5:\"1.4.2\";a:13:{s:4:\"name\";s:15:\"ept_stats 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_stats/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384552\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.2\";s:6:\"status\";i:5;}s:8:\"ept_tabs\";a:14:{s:4:\"name\";s:8:\"ept_tabs\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Tabs\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:8:\"ept_tabs\";s:9:\"datestamp\";i:1735472536;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1735472536;s:8:\"includes\";a:1:{s:8:\"ept_tabs\";s:33:\"Extra Paragraph Types (EPT): Tabs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.5\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Tabs\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_tabs\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:8:\"ept_text\";a:15:{s:4:\"name\";s:8:\"ept_text\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Text\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:8:\"ept_text\";s:9:\"datestamp\";i:1721384582;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1721384582;s:8:\"includes\";a:1:{s:8:\"ept_text\";s:33:\"Extra Paragraph Types (EPT): Text\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.3\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Text\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_text\";s:14:\"latest_version\";s:5:\"1.4.3\";s:8:\"releases\";a:1:{s:5:\"1.4.3\";a:13:{s:4:\"name\";s:14:\"ept_text 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_text/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_text-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384579\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.3\";s:6:\"status\";i:5;}s:9:\"ept_tiles\";a:15:{s:4:\"name\";s:9:\"ept_tiles\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Tiles\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:9:\"ept_tiles\";s:9:\"datestamp\";i:1721384598;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1721384598;s:8:\"includes\";a:1:{s:9:\"ept_tiles\";s:34:\"Extra Paragraph Types (EPT): Tiles\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.4\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Tiles\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_tiles\";s:14:\"latest_version\";s:5:\"1.4.4\";s:8:\"releases\";a:1:{s:5:\"1.4.4\";a:13:{s:4:\"name\";s:15:\"ept_tiles 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_tiles/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1721384596\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.4\";s:6:\"status\";i:5;}s:9:\"ept_video\";a:15:{s:4:\"name\";s:9:\"ept_video\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Video\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:9:\"ept_video\";s:9:\"datestamp\";i:1722411736;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1722411736;s:8:\"includes\";a:1:{s:9:\"ept_video\";s:34:\"Extra Paragraph Types (EPT): Video\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.3\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Video\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_video\";s:14:\"latest_version\";s:5:\"1.4.3\";s:8:\"releases\";a:1:{s:5:\"1.4.3\";a:13:{s:4:\"name\";s:15:\"ept_video 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_video/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_video-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411733\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.3\";s:6:\"status\";i:5;}s:27:\"ept_video_and_image_gallery\";a:15:{s:4:\"name\";s:27:\"ept_video_and_image_gallery\";s:4:\"info\";a:6:{s:4:\"name\";s:52:\"Extra Paragraph Types (EPT): Video and Image Gallery\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:27:\"ept_video_and_image_gallery\";s:9:\"datestamp\";i:1722411779;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1722411779;s:8:\"includes\";a:1:{s:27:\"ept_video_and_image_gallery\";s:52:\"Extra Paragraph Types (EPT): Video and Image Gallery\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.5\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:52:\"Extra Paragraph Types (EPT): Video and Image Gallery\";s:4:\"link\";s:58:\"https://www.drupal.org/project/ept_video_and_image_gallery\";s:14:\"latest_version\";s:5:\"1.4.5\";s:8:\"releases\";a:1:{s:5:\"1.4.5\";a:13:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.5\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1722411776\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.5\";s:6:\"status\";i:5;}s:9:\"ept_views\";a:15:{s:4:\"name\";s:9:\"ept_views\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Views\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:9:\"ept_views\";s:9:\"datestamp\";i:1727007518;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1727007518;s:8:\"includes\";a:1:{s:9:\"ept_views\";s:34:\"Extra Paragraph Types (EPT): Views\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.4\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Views\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_views\";s:14:\"latest_version\";s:5:\"1.4.4\";s:8:\"releases\";a:1:{s:5:\"1.4.4\";a:13:{s:4:\"name\";s:15:\"ept_views 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1727007515\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"1.4.4\";s:6:\"status\";i:5;}s:11:\"ept_webform\";a:11:{s:4:\"name\";s:11:\"ept_webform\";s:4:\"info\";a:6:{s:4:\"name\";s:36:\"Extra Paragraph Types (EPT): Webform\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:11:\"ept_webform\";s:9:\"datestamp\";i:1721384667;s:16:\"_info_file_ctime\";i:1735492408;}s:9:\"datestamp\";i:1721384667;s:8:\"includes\";a:1:{s:11:\"ept_webform\";s:36:\"Extra Paragraph Types (EPT): Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.2\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:6:\"status\";i:-2;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"No available releases found\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"ept_webform_popup\";a:11:{s:4:\"name\";s:17:\"ept_webform_popup\";s:4:\"info\";a:6:{s:4:\"name\";s:42:\"Extra Paragraph Types (EPT): Webform Popup\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:17:\"ept_webform_popup\";s:9:\"datestamp\";i:1721384667;s:16:\"_info_file_ctime\";i:1735492408;}s:9:\"datestamp\";i:1721384667;s:8:\"includes\";a:1:{s:17:\"ept_webform_popup\";s:42:\"Extra Paragraph Types (EPT): Webform Popup\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.3\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:6:\"status\";i:-2;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"No available releases found\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:11:\"field_group\";a:16:{s:4:\"name\";s:11:\"field_group\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Field Group\";s:7:\"package\";s:6:\"Fields\";s:7:\"version\";s:7:\"8.x-3.6\";s:7:\"project\";s:11:\"field_group\";s:9:\"datestamp\";i:1722672513;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1722672513;s:8:\"includes\";a:1:{s:11:\"field_group\";s:11:\"Field Group\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-3.6\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:11:\"Field Group\";s:4:\"link\";s:42:\"https://www.drupal.org/project/field_group\";s:4:\"also\";a:1:{i:4;s:12:\"4.0.0-alpha1\";}s:8:\"releases\";a:2:{s:12:\"4.0.0-alpha1\";a:13:{s:4:\"name\";s:24:\"field_group 4.0.0-alpha1\";s:7:\"version\";s:12:\"4.0.0-alpha1\";s:3:\"tag\";s:12:\"4.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/field_group/releases/4.0.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/field_group-4.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1725952813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}s:7:\"8.x-3.6\";a:13:{s:4:\"name\";s:19:\"field_group 8.x-3.6\";s:7:\"version\";s:7:\"8.x-3.6\";s:3:\"tag\";s:7:\"8.x-3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.6.tar.gz\";s:4:\"date\";s:10:\"1722672510\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:14:\"latest_version\";s:7:\"8.x-3.6\";s:11:\"recommended\";s:7:\"8.x-3.6\";s:6:\"status\";i:5;}s:8:\"file_mdm\";a:15:{s:4:\"name\";s:8:\"file_mdm\";s:4:\"info\";a:6:{s:4:\"name\";s:21:\"File metadata manager\";s:7:\"package\";s:13:\"File metadata\";s:7:\"version\";s:5:\"3.1.0\";s:7:\"project\";s:8:\"file_mdm\";s:9:\"datestamp\";i:1718086270;s:16:\"_info_file_ctime\";i:1729024187;}s:9:\"datestamp\";i:1718086270;s:8:\"includes\";a:3:{s:8:\"file_mdm\";s:21:\"File metadata manager\";s:13:\"file_mdm_exif\";s:20:\"File metadata - EXIF\";s:13:\"file_mdm_font\";s:20:\"File metadata - Font\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"3.1.0\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:21:\"File metadata manager\";s:4:\"link\";s:39:\"https://www.drupal.org/project/file_mdm\";s:14:\"latest_version\";s:5:\"3.1.0\";s:8:\"releases\";a:1:{s:5:\"3.1.0\";a:13:{s:4:\"name\";s:14:\"file_mdm 3.1.0\";s:7:\"version\";s:5:\"3.1.0\";s:3:\"tag\";s:5:\"3.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/file_mdm/releases/3.1.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.0.tar.gz\";s:4:\"date\";s:10:\"1718086268\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"3.1.0\";s:6:\"status\";i:5;}s:11:\"gin_toolbar\";a:14:{s:4:\"name\";s:11:\"gin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Gin Toolbar\";s:7:\"version\";s:7:\"8.x-1.0\";s:7:\"project\";s:11:\"gin_toolbar\";s:9:\"datestamp\";i:1734698812;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734698812;s:8:\"includes\";a:1:{s:11:\"gin_toolbar\";s:11:\"Gin Toolbar\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-1.0\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:11:\"Gin Toolbar\";s:4:\"link\";s:42:\"https://www.drupal.org/project/gin_toolbar\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:9:\"glightbox\";a:14:{s:4:\"name\";s:9:\"glightbox\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"GLightbox\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:6:\"1.0.13\";s:7:\"project\";s:9:\"glightbox\";s:9:\"datestamp\";i:1734093965;s:16:\"_info_file_ctime\";i:1735498429;}s:9:\"datestamp\";i:1734093965;s:8:\"includes\";a:1:{s:9:\"glightbox\";s:9:\"GLightbox\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:6:\"1.0.13\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:9:\"GLightbox\";s:4:\"link\";s:40:\"https://www.drupal.org/project/glightbox\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:21:\"glightbox_media_video\";a:14:{s:4:\"name\";s:21:\"glightbox_media_video\";s:4:\"info\";a:6:{s:4:\"name\";s:21:\"GLightbox Media Video\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"1.0.3\";s:7:\"project\";s:21:\"glightbox_media_video\";s:9:\"datestamp\";i:1734297827;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734297827;s:8:\"includes\";a:1:{s:21:\"glightbox_media_video\";s:21:\"GLightbox Media Video\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.0.3\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:21:\"GLightbox Media Video\";s:4:\"link\";s:52:\"https://www.drupal.org/project/glightbox_media_video\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:13:\"image_effects\";a:14:{s:4:\"name\";s:13:\"image_effects\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Image Effects\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"4.0.0\";s:7:\"project\";s:13:\"image_effects\";s:9:\"datestamp\";i:1733831440;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1733831440;s:8:\"includes\";a:1:{s:13:\"image_effects\";s:13:\"Image Effects\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"4.0.0\";s:14:\"existing_major\";s:1:\"4\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:13:\"Image Effects\";s:4:\"link\";s:44:\"https://www.drupal.org/project/image_effects\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:9:\"jquery_ui\";a:15:{s:4:\"name\";s:9:\"jquery_ui\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"jQuery UI\";s:7:\"package\";s:9:\"jQuery UI\";s:7:\"version\";s:7:\"8.x-1.7\";s:7:\"project\";s:9:\"jquery_ui\";s:9:\"datestamp\";i:1717002101;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1717002101;s:8:\"includes\";a:1:{s:9:\"jquery_ui\";s:9:\"jQuery UI\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-1.7\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:9:\"jQuery UI\";s:4:\"link\";s:40:\"https://www.drupal.org/project/jquery_ui\";s:14:\"latest_version\";s:7:\"8.x-1.7\";s:8:\"releases\";a:1:{s:7:\"8.x-1.7\";a:13:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.7\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1717002098\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:7:\"8.x-1.7\";s:6:\"status\";i:5;}s:19:\"jquery_ui_accordion\";a:15:{s:4:\"name\";s:19:\"jquery_ui_accordion\";s:4:\"info\";a:6:{s:4:\"name\";s:19:\"jQuery UI Accordion\";s:7:\"package\";s:9:\"jQuery UI\";s:7:\"version\";s:5:\"2.1.0\";s:7:\"project\";s:19:\"jquery_ui_accordion\";s:9:\"datestamp\";i:1717015497;s:16:\"_info_file_ctime\";i:1728223651;}s:9:\"datestamp\";i:1717015497;s:8:\"includes\";a:1:{s:19:\"jquery_ui_accordion\";s:19:\"jQuery UI Accordion\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.1.0\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:19:\"jQuery UI Accordion\";s:4:\"link\";s:50:\"https://www.drupal.org/project/jquery_ui_accordion\";s:14:\"latest_version\";s:5:\"2.1.0\";s:8:\"releases\";a:1:{s:5:\"2.1.0\";a:13:{s:4:\"name\";s:25:\"jquery_ui_accordion 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jquery_ui_accordion/releases/2.1.0\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1717015495\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"2.1.0\";s:6:\"status\";i:5;}s:14:\"jquery_ui_tabs\";a:15:{s:4:\"name\";s:14:\"jquery_ui_tabs\";s:4:\"info\";a:6:{s:4:\"name\";s:14:\"jQuery UI Tabs\";s:7:\"package\";s:9:\"jQuery UI\";s:7:\"version\";s:5:\"2.1.0\";s:7:\"project\";s:14:\"jquery_ui_tabs\";s:9:\"datestamp\";i:1719935964;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1719935964;s:8:\"includes\";a:1:{s:14:\"jquery_ui_tabs\";s:14:\"jQuery UI Tabs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.1.0\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:14:\"jQuery UI Tabs\";s:4:\"link\";s:45:\"https://www.drupal.org/project/jquery_ui_tabs\";s:14:\"latest_version\";s:5:\"2.1.0\";s:8:\"releases\";a:1:{s:5:\"2.1.0\";a:13:{s:4:\"name\";s:20:\"jquery_ui_tabs 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/jquery_ui_tabs/releases/2.1.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1719935962\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"2.1.0\";s:6:\"status\";i:5;}s:17:\"layout_paragraphs\";a:14:{s:4:\"name\";s:17:\"layout_paragraphs\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Layout Paragraphs\";s:7:\"package\";s:10:\"Paragraphs\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:17:\"layout_paragraphs\";s:9:\"datestamp\";i:1732724680;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1732724680;s:8:\"includes\";a:1:{s:17:\"layout_paragraphs\";s:17:\"Layout Paragraphs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.1.1\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:17:\"Layout Paragraphs\";s:4:\"link\";s:48:\"https://www.drupal.org/project/layout_paragraphs\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:15:\"link_attributes\";a:15:{s:4:\"name\";s:15:\"link_attributes\";s:4:\"info\";a:6:{s:4:\"name\";s:15:\"Link attributes\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:15:\"link_attributes\";s:9:\"datestamp\";i:1721366574;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1728554822;}s:9:\"datestamp\";i:1721366574;s:8:\"includes\";a:2:{s:15:\"link_attributes\";s:15:\"Link attributes\";s:33:\"link_attributes_menu_link_content\";s:46:\"Link attributes: Menu Link Content integration\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.1.1\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:22:\"Link Attributes widget\";s:4:\"link\";s:46:\"https://www.drupal.org/project/link_attributes\";s:14:\"latest_version\";s:5:\"2.1.1\";s:8:\"releases\";a:1:{s:5:\"2.1.1\";a:13:{s:4:\"name\";s:21:\"link_attributes 2.1.1\";s:7:\"version\";s:5:\"2.1.1\";s:3:\"tag\";s:5:\"2.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.1.1.tar.gz\";s:4:\"date\";s:10:\"1721366572\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"2.1.1\";s:6:\"status\";i:5;}s:18:\"media_library_edit\";a:15:{s:4:\"name\";s:18:\"media_library_edit\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"Media Library Edit\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"3.0.4\";s:7:\"project\";s:18:\"media_library_edit\";s:9:\"datestamp\";i:1724357847;s:16:\"_info_file_ctime\";i:1728885051;}s:9:\"datestamp\";i:1724357847;s:8:\"includes\";a:1:{s:18:\"media_library_edit\";s:18:\"Media Library Edit\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"3.0.4\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:18:\"Media Library Edit\";s:4:\"link\";s:49:\"https://www.drupal.org/project/media_library_edit\";s:14:\"latest_version\";s:5:\"3.0.4\";s:8:\"releases\";a:1:{s:5:\"3.0.4\";a:13:{s:4:\"name\";s:24:\"media_library_edit 3.0.4\";s:7:\"version\";s:5:\"3.0.4\";s:3:\"tag\";s:5:\"3.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.4.tar.gz\";s:4:\"date\";s:10:\"1724357846\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"3.0.4\";s:6:\"status\";i:5;}s:26:\"media_library_form_element\";a:15:{s:4:\"name\";s:26:\"media_library_form_element\";s:4:\"info\";a:6:{s:4:\"name\";s:26:\"Media Library Form Element\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:26:\"media_library_form_element\";s:9:\"datestamp\";i:1724676086;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1724676086;s:8:\"includes\";a:1:{s:26:\"media_library_form_element\";s:26:\"Media Library Form Element\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.1.1\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:30:\"Media Library Form API Element\";s:4:\"link\";s:57:\"https://www.drupal.org/project/media_library_form_element\";s:14:\"latest_version\";s:5:\"2.1.1\";s:8:\"releases\";a:1:{s:5:\"2.1.1\";a:13:{s:4:\"name\";s:32:\"media_library_form_element 2.1.1\";s:7:\"version\";s:5:\"2.1.1\";s:3:\"tag\";s:5:\"2.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.1.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.1.1.tar.gz\";s:4:\"date\";s:10:\"1724676084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"2.1.1\";s:6:\"status\";i:5;}s:10:\"paragraphs\";a:15:{s:4:\"name\";s:10:\"paragraphs\";s:4:\"info\";a:6:{s:4:\"name\";s:10:\"Paragraphs\";s:7:\"package\";s:10:\"Paragraphs\";s:7:\"version\";s:8:\"8.x-1.18\";s:7:\"project\";s:10:\"paragraphs\";s:9:\"datestamp\";i:1723029150;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1723029150;s:8:\"includes\";a:1:{s:10:\"paragraphs\";s:10:\"Paragraphs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:8:\"8.x-1.18\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:10:\"Paragraphs\";s:4:\"link\";s:41:\"https://www.drupal.org/project/paragraphs\";s:14:\"latest_version\";s:8:\"8.x-1.18\";s:8:\"releases\";a:1:{s:8:\"8.x-1.18\";a:13:{s:4:\"name\";s:19:\"paragraphs 8.x-1.18\";s:7:\"version\";s:8:\"8.x-1.18\";s:3:\"tag\";s:8:\"8.x-1.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.18\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.18.tar.gz\";s:4:\"date\";s:10:\"1723029144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:8:\"8.x-1.18\";s:6:\"status\";i:5;}s:11:\"tb_megamenu\";a:16:{s:4:\"name\";s:11:\"tb_megamenu\";s:4:\"info\";a:6:{s:4:\"name\";s:20:\"The Better Mega Menu\";s:7:\"package\";s:4:\"Menu\";s:7:\"version\";s:7:\"8.x-1.9\";s:7:\"project\";s:11:\"tb_megamenu\";s:9:\"datestamp\";i:1712869463;s:16:\"_info_file_ctime\";i:1728227421;}s:9:\"datestamp\";i:1712869463;s:8:\"includes\";a:1:{s:11:\"tb_megamenu\";s:20:\"The Better Mega Menu\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-1.9\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:20:\"The Better Mega Menu\";s:4:\"link\";s:42:\"https://www.drupal.org/project/tb_megamenu\";s:4:\"also\";a:1:{i:3;s:12:\"3.0.0-alpha4\";}s:8:\"releases\";a:2:{s:12:\"3.0.0-alpha4\";a:13:{s:4:\"name\";s:24:\"tb_megamenu 3.0.0-alpha4\";s:7:\"version\";s:12:\"3.0.0-alpha4\";s:3:\"tag\";s:12:\"3.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/3.0.0-alpha4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1713052614\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}s:7:\"8.x-1.9\";a:13:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.9\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1712869460\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:14:\"latest_version\";s:7:\"8.x-1.9\";s:11:\"recommended\";s:7:\"8.x-1.9\";s:6:\"status\";i:5;}s:10:\"twig_tweak\";a:15:{s:4:\"name\";s:10:\"twig_tweak\";s:4:\"info\";a:6:{s:4:\"name\";s:10:\"Twig Tweak\";s:7:\"version\";s:5:\"3.4.0\";s:7:\"project\";s:10:\"twig_tweak\";s:9:\"datestamp\";i:1721562309;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1728244235;}s:9:\"datestamp\";i:1721562309;s:8:\"includes\";a:1:{s:10:\"twig_tweak\";s:10:\"Twig Tweak\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"3.4.0\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:10:\"Twig Tweak\";s:4:\"link\";s:41:\"https://www.drupal.org/project/twig_tweak\";s:14:\"latest_version\";s:5:\"3.4.0\";s:8:\"releases\";a:1:{s:5:\"3.4.0\";a:13:{s:4:\"name\";s:16:\"twig_tweak 3.4.0\";s:7:\"version\";s:5:\"3.4.0\";s:3:\"tag\";s:5:\"3.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.4.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.4.0.tar.gz\";s:4:\"date\";s:10:\"1721562308\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"3.4.0\";s:6:\"status\";i:5;}s:17:\"views_year_filter\";a:15:{s:4:\"name\";s:17:\"views_year_filter\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Views Year Filter\";s:7:\"package\";s:4:\"Date\";s:7:\"version\";s:5:\"2.1.5\";s:7:\"project\";s:17:\"views_year_filter\";s:9:\"datestamp\";i:1726675379;s:16:\"_info_file_ctime\";i:1729065968;}s:9:\"datestamp\";i:1726675379;s:8:\"includes\";a:1:{s:17:\"views_year_filter\";s:17:\"Views Year Filter\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.1.5\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:17:\"Views year filter\";s:4:\"link\";s:48:\"https://www.drupal.org/project/views_year_filter\";s:14:\"latest_version\";s:5:\"2.1.5\";s:8:\"releases\";a:1:{s:5:\"2.1.5\";a:13:{s:4:\"name\";s:23:\"views_year_filter 2.1.5\";s:7:\"version\";s:5:\"2.1.5\";s:3:\"tag\";s:5:\"2.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/views_year_filter/releases/2.1.5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/views_year_filter-2.1.5.tar.gz\";s:4:\"date\";s:10:\"1726675377\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:5:\"2.1.5\";s:6:\"status\";i:5;}s:14:\"viewsreference\";a:15:{s:4:\"name\";s:14:\"viewsreference\";s:4:\"info\";a:6:{s:4:\"name\";s:21:\"Views Reference Field\";s:7:\"package\";s:5:\"Views\";s:7:\"version\";s:14:\"8.x-2.0-beta10\";s:7:\"project\";s:14:\"viewsreference\";s:9:\"datestamp\";i:1725510908;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1725510908;s:8:\"includes\";a:1:{s:14:\"viewsreference\";s:21:\"Views Reference Field\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:14:\"8.x-2.0-beta10\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:21:\"Views Reference Field\";s:4:\"link\";s:45:\"https://www.drupal.org/project/viewsreference\";s:14:\"latest_version\";s:14:\"8.x-2.0-beta10\";s:8:\"releases\";a:1:{s:14:\"8.x-2.0-beta10\";a:13:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-beta10\";s:7:\"version\";s:14:\"8.x-2.0-beta10\";s:3:\"tag\";s:14:\"8.x-2.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta10\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1725510905\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:15:\"core_compatible\";b:1;s:26:\"core_compatibility_message\";s:28:\"Requires Drupal core: 11.1.0\";}}s:11:\"recommended\";s:14:\"8.x-2.0-beta10\";s:6:\"status\";i:5;}s:7:\"webform\";a:11:{s:4:\"name\";s:7:\"webform\";s:4:\"info\";a:6:{s:4:\"name\";s:7:\"Webform\";s:7:\"package\";s:7:\"Webform\";s:7:\"version\";s:12:\"6.3.0-alpha3\";s:7:\"project\";s:7:\"webform\";s:9:\"datestamp\";i:1733851313;s:16:\"_info_file_ctime\";i:1735492412;}s:9:\"datestamp\";i:1733851313;s:8:\"includes\";a:1:{s:7:\"webform\";s:7:\"Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:12:\"6.3.0-alpha3\";s:14:\"existing_major\";s:1:\"6\";s:12:\"install_type\";s:8:\"official\";s:6:\"status\";i:-2;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"No available releases found\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:3:\"gin\";a:14:{s:4:\"name\";s:3:\"gin\";s:4:\"info\";a:5:{s:4:\"name\";s:3:\"Gin\";s:7:\"version\";s:7:\"8.x-3.0\";s:7:\"project\";s:3:\"gin\";s:9:\"datestamp\";i:1734696851;s:16:\"_info_file_ctime\";i:1735498436;}s:9:\"datestamp\";i:1734696851;s:8:\"includes\";a:1:{s:3:\"gin\";s:3:\"Gin\";}s:12:\"project_type\";s:5:\"theme\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-3.0\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:15:\"Gin Admin Theme\";s:4:\"link\";s:34:\"https://www.drupal.org/project/gin\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}}',1735504658),('update','update_project_projects',_binary 'a:53:{s:6:\"drupal\";a:6:{s:4:\"name\";s:6:\"drupal\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Announcements\";s:7:\"version\";s:6:\"11.1.0\";s:7:\"package\";s:4:\"Core\";s:7:\"project\";s:6:\"drupal\";s:16:\"_info_file_ctime\";i:1735498473;s:9:\"datestamp\";i:0;}s:9:\"datestamp\";i:0;s:8:\"includes\";a:42:{s:18:\"announcements_feed\";s:13:\"Announcements\";s:14:\"automated_cron\";s:14:\"Automated Cron\";s:8:\"big_pipe\";s:7:\"BigPipe\";s:5:\"block\";s:5:\"Block\";s:13:\"block_content\";s:13:\"Block Content\";s:10:\"breakpoint\";s:10:\"Breakpoint\";s:9:\"ckeditor5\";s:10:\"CKEditor 5\";s:7:\"comment\";s:7:\"Comment\";s:6:\"config\";s:21:\"Configuration Manager\";s:7:\"contact\";s:7:\"Contact\";s:10:\"contextual\";s:16:\"Contextual Links\";s:8:\"datetime\";s:8:\"Datetime\";s:5:\"dblog\";s:16:\"Database Logging\";s:18:\"dynamic_page_cache\";s:27:\"Internal Dynamic Page Cache\";s:6:\"editor\";s:11:\"Text Editor\";s:5:\"field\";s:5:\"Field\";s:8:\"field_ui\";s:8:\"Field UI\";s:4:\"file\";s:4:\"File\";s:6:\"filter\";s:6:\"Filter\";s:4:\"help\";s:4:\"Help\";s:7:\"history\";s:7:\"History\";s:5:\"image\";s:5:\"Image\";s:16:\"layout_discovery\";s:16:\"Layout Discovery\";s:4:\"link\";s:4:\"Link\";s:5:\"media\";s:5:\"Media\";s:13:\"media_library\";s:13:\"Media Library\";s:17:\"menu_link_content\";s:17:\"Custom Menu Links\";s:7:\"menu_ui\";s:7:\"Menu UI\";s:4:\"node\";s:4:\"Node\";s:7:\"options\";s:7:\"Options\";s:10:\"page_cache\";s:19:\"Internal Page Cache\";s:4:\"path\";s:4:\"Path\";s:10:\"path_alias\";s:10:\"Path alias\";s:8:\"shortcut\";s:8:\"Shortcut\";s:6:\"system\";s:6:\"System\";s:8:\"taxonomy\";s:8:\"Taxonomy\";s:4:\"text\";s:4:\"Text\";s:7:\"toolbar\";s:7:\"Toolbar\";s:6:\"update\";s:14:\"Update Manager\";s:4:\"user\";s:4:\"User\";s:5:\"views\";s:5:\"Views\";s:8:\"views_ui\";s:8:\"Views UI\";}s:12:\"project_type\";s:4:\"core\";s:14:\"project_status\";b:1;}s:13:\"admin_toolbar\";a:6:{s:4:\"name\";s:13:\"admin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Admin Toolbar\";s:7:\"package\";s:14:\"Administration\";s:7:\"version\";s:5:\"3.5.1\";s:7:\"project\";s:13:\"admin_toolbar\";s:9:\"datestamp\";i:1730409975;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1730409975;s:8:\"includes\";a:2:{s:13:\"admin_toolbar\";s:13:\"Admin Toolbar\";s:19:\"admin_toolbar_tools\";s:25:\"Admin Toolbar Extra Tools\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:22:\"better_exposed_filters\";a:6:{s:4:\"name\";s:22:\"better_exposed_filters\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"Better Exposed Filters\";s:7:\"package\";s:5:\"Views\";s:7:\"version\";s:5:\"7.0.2\";s:7:\"project\";s:22:\"better_exposed_filters\";s:9:\"datestamp\";i:1729001182;s:16:\"_info_file_ctime\";i:1729066392;}s:9:\"datestamp\";i:1729001182;s:8:\"includes\";a:1:{s:22:\"better_exposed_filters\";s:22:\"Better Exposed Filters\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:11:\"block_field\";a:6:{s:4:\"name\";s:11:\"block_field\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Block Field\";s:7:\"package\";s:5:\"Field\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:7:\"project\";s:11:\"block_field\";s:9:\"datestamp\";i:1723550579;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1723550579;s:8:\"includes\";a:1:{s:11:\"block_field\";s:11:\"Block Field\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:21:\"ckeditor5_plugin_pack\";a:6:{s:4:\"name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.2.4\";s:7:\"project\";s:21:\"ckeditor5_plugin_pack\";s:9:\"datestamp\";i:1734514951;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734514951;s:8:\"includes\";a:12:{s:21:\"ckeditor5_plugin_pack\";s:22:\"CKEditor 5 Plugin Pack\";s:32:\"ckeditor5_plugin_pack_auto_image\";s:21:\"CKEditor 5 Auto Image\";s:38:\"ckeditor5_plugin_pack_find_and_replace\";s:27:\"CKEditor 5 Find And Replace\";s:26:\"ckeditor5_plugin_pack_font\";s:23:\"CKEditor 5 Font Plugins\";s:31:\"ckeditor5_plugin_pack_highlight\";s:20:\"CKEditor 5 Highlight\";s:34:\"ckeditor5_plugin_pack_indent_block\";s:28:\"CKEditor 5 Block Indentation\";s:37:\"ckeditor5_plugin_pack_link_attributes\";s:26:\"CKEditor 5 Link Attributes\";s:32:\"ckeditor5_plugin_pack_page_break\";s:21:\"CKEditor 5 Page Break\";s:32:\"ckeditor5_plugin_pack_select_all\";s:21:\"CKEditor 5 Select All\";s:31:\"ckeditor5_plugin_pack_templates\";s:20:\"CKEditor 5 Templates\";s:41:\"ckeditor5_plugin_pack_text_transformation\";s:30:\"CKEditor 5 Text Transformation\";s:40:\"ckeditor5_plugin_pack_todo_document_list\";s:21:\"CKEditor 5 To-do List\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:26:\"ckeditor5_premium_features\";a:6:{s:4:\"name\";s:26:\"ckeditor5_premium_features\";s:4:\"info\";a:6:{s:4:\"name\";s:27:\"CKEditor 5 Full-screen Mode\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.3.5\";s:7:\"project\";s:26:\"ckeditor5_premium_features\";s:9:\"datestamp\";i:1734513731;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1734513731;s:8:\"includes\";a:1:{s:37:\"ckeditor5_premium_features_fullscreen\";s:27:\"CKEditor 5 Full-screen Mode\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:26:\"entity_reference_revisions\";a:6:{s:4:\"name\";s:26:\"entity_reference_revisions\";s:4:\"info\";a:6:{s:4:\"name\";s:26:\"Entity Reference Revisions\";s:7:\"package\";s:11:\"Field types\";s:7:\"version\";s:8:\"8.x-1.12\";s:7:\"project\";s:26:\"entity_reference_revisions\";s:9:\"datestamp\";i:1722804499;s:16:\"_info_file_ctime\";i:1728223651;}s:9:\"datestamp\";i:1722804499;s:8:\"includes\";a:1:{s:26:\"entity_reference_revisions\";s:26:\"Entity Reference Revisions\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:13:\"ept_accordion\";a:6:{s:4:\"name\";s:13:\"ept_accordion\";s:4:\"info\";a:6:{s:4:\"name\";s:38:\"Extra Paragraph Types (EPT): Accordion\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:13:\"ept_accordion\";s:9:\"datestamp\";i:1721384047;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1721384047;s:8:\"includes\";a:1:{s:13:\"ept_accordion\";s:38:\"Extra Paragraph Types (EPT): Accordion\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:16:\"ept_basic_button\";a:6:{s:4:\"name\";s:16:\"ept_basic_button\";s:4:\"info\";a:6:{s:4:\"name\";s:41:\"Extra Paragraph Types (EPT): Basic Button\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:16:\"ept_basic_button\";s:9:\"datestamp\";i:1721384074;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1721384074;s:8:\"includes\";a:1:{s:16:\"ept_basic_button\";s:41:\"Extra Paragraph Types (EPT): Basic Button\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"ept_block\";a:6:{s:4:\"name\";s:9:\"ept_block\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Block\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:9:\"ept_block\";s:9:\"datestamp\";i:1721384101;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1721384101;s:8:\"includes\";a:1:{s:9:\"ept_block\";s:34:\"Extra Paragraph Types (EPT): Block\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:20:\"ept_bootstrap_button\";a:6:{s:4:\"name\";s:20:\"ept_bootstrap_button\";s:4:\"info\";a:6:{s:4:\"name\";s:45:\"Extra Paragraph Types (EPT): Bootstrap Button\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:20:\"ept_bootstrap_button\";s:9:\"datestamp\";i:1721384123;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1721384123;s:8:\"includes\";a:1:{s:20:\"ept_bootstrap_button\";s:45:\"Extra Paragraph Types (EPT): Bootstrap Button\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:12:\"ept_carousel\";a:6:{s:4:\"name\";s:12:\"ept_carousel\";s:4:\"info\";a:6:{s:4:\"name\";s:37:\"Extra Paragraph Types (EPT): Carousel\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:12:\"ept_carousel\";s:9:\"datestamp\";i:1734284534;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1734284534;s:8:\"includes\";a:1:{s:12:\"ept_carousel\";s:37:\"Extra Paragraph Types (EPT): Carousel\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:11:\"ept_columns\";a:6:{s:4:\"name\";s:11:\"ept_columns\";s:4:\"info\";a:6:{s:4:\"name\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.6\";s:7:\"project\";s:11:\"ept_columns\";s:9:\"datestamp\";i:1721384281;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1721384281;s:8:\"includes\";a:1:{s:11:\"ept_columns\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:8:\"ept_core\";a:6:{s:4:\"name\";s:8:\"ept_core\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Core\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:6:\"1.4.17\";s:7:\"project\";s:8:\"ept_core\";s:9:\"datestamp\";i:1728849212;s:16:\"_info_file_ctime\";i:1728849872;}s:9:\"datestamp\";i:1728849212;s:8:\"includes\";a:2:{s:8:\"ept_core\";s:33:\"Extra Paragraph Types (EPT): Core\";s:19:\"ept_core_starterkit\";s:39:\"Extra Paragraph Types (EPT): Starterkit\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:13:\"ept_countdown\";a:6:{s:4:\"name\";s:13:\"ept_countdown\";s:4:\"info\";a:6:{s:4:\"name\";s:38:\"Extra Paragraph Types (EPT): Countdown\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:13:\"ept_countdown\";s:9:\"datestamp\";i:1721384295;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1721384295;s:8:\"includes\";a:1:{s:13:\"ept_countdown\";s:38:\"Extra Paragraph Types (EPT): Countdown\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:11:\"ept_counter\";a:6:{s:4:\"name\";s:11:\"ept_counter\";s:4:\"info\";a:6:{s:4:\"name\";s:36:\"Extra Paragraph Types (EPT): Counter\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:11:\"ept_counter\";s:9:\"datestamp\";i:1722410410;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722410410;s:8:\"includes\";a:1:{s:11:\"ept_counter\";s:36:\"Extra Paragraph Types (EPT): Counter\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:7:\"ept_cta\";a:6:{s:4:\"name\";s:7:\"ept_cta\";s:4:\"info\";a:6:{s:4:\"name\";s:43:\"Extra Paragraph Types (EPT): Call to Action\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:7:\"ept_cta\";s:9:\"datestamp\";i:1722410464;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722410464;s:8:\"includes\";a:1:{s:7:\"ept_cta\";s:43:\"Extra Paragraph Types (EPT): Call to Action\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:8:\"ept_hero\";a:6:{s:4:\"name\";s:8:\"ept_hero\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Hero\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:8:\"ept_hero\";s:9:\"datestamp\";i:1733145602;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1733145602;s:8:\"includes\";a:1:{s:8:\"ept_hero\";s:33:\"Extra Paragraph Types (EPT): Hero\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"ept_image\";a:6:{s:4:\"name\";s:9:\"ept_image\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Image\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:9:\"ept_image\";s:9:\"datestamp\";i:1722410544;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722410544;s:8:\"includes\";a:1:{s:9:\"ept_image\";s:34:\"Extra Paragraph Types (EPT): Image\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:17:\"ept_image_gallery\";a:6:{s:4:\"name\";s:17:\"ept_image_gallery\";s:4:\"info\";a:6:{s:4:\"name\";s:42:\"Extra Paragraph Types (EPT): Image Gallery\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:17:\"ept_image_gallery\";s:9:\"datestamp\";i:1722411237;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722411237;s:8:\"includes\";a:1:{s:17:\"ept_image_gallery\";s:42:\"Extra Paragraph Types (EPT): Image Gallery\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:14:\"ept_micromodal\";a:6:{s:4:\"name\";s:14:\"ept_micromodal\";s:4:\"info\";a:6:{s:4:\"name\";s:39:\"Extra Paragraph Types (EPT): Micromodal\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:14:\"ept_micromodal\";s:9:\"datestamp\";i:1721384363;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1721384363;s:8:\"includes\";a:1:{s:14:\"ept_micromodal\";s:39:\"Extra Paragraph Types (EPT): Micromodal\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"ept_quote\";a:6:{s:4:\"name\";s:9:\"ept_quote\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Quote\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:9:\"ept_quote\";s:9:\"datestamp\";i:1722411327;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722411327;s:8:\"includes\";a:1:{s:9:\"ept_quote\";s:34:\"Extra Paragraph Types (EPT): Quote\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:16:\"ept_slick_slider\";a:6:{s:4:\"name\";s:16:\"ept_slick_slider\";s:4:\"info\";a:6:{s:4:\"name\";s:41:\"Extra Paragraph Types (EPT): Slick Slider\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:16:\"ept_slick_slider\";s:9:\"datestamp\";i:1722411500;s:16:\"_info_file_ctime\";i:1728223653;}s:9:\"datestamp\";i:1722411500;s:8:\"includes\";a:1:{s:16:\"ept_slick_slider\";s:41:\"Extra Paragraph Types (EPT): Slick Slider\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:13:\"ept_slideshow\";a:6:{s:4:\"name\";s:13:\"ept_slideshow\";s:4:\"info\";a:6:{s:4:\"name\";s:38:\"Extra Paragraph Types (EPT): Slideshow\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:13:\"ept_slideshow\";s:9:\"datestamp\";i:1722411524;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1722411524;s:8:\"includes\";a:1:{s:13:\"ept_slideshow\";s:38:\"Extra Paragraph Types (EPT): Slideshow\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"ept_stats\";a:6:{s:4:\"name\";s:9:\"ept_stats\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Stats\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:9:\"ept_stats\";s:9:\"datestamp\";i:1721384555;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1721384555;s:8:\"includes\";a:1:{s:9:\"ept_stats\";s:34:\"Extra Paragraph Types (EPT): Stats\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:8:\"ept_tabs\";a:6:{s:4:\"name\";s:8:\"ept_tabs\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Tabs\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:8:\"ept_tabs\";s:9:\"datestamp\";i:1735472536;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1735472536;s:8:\"includes\";a:1:{s:8:\"ept_tabs\";s:33:\"Extra Paragraph Types (EPT): Tabs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:8:\"ept_text\";a:6:{s:4:\"name\";s:8:\"ept_text\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Text\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:8:\"ept_text\";s:9:\"datestamp\";i:1721384582;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1721384582;s:8:\"includes\";a:1:{s:8:\"ept_text\";s:33:\"Extra Paragraph Types (EPT): Text\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"ept_tiles\";a:6:{s:4:\"name\";s:9:\"ept_tiles\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Tiles\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:9:\"ept_tiles\";s:9:\"datestamp\";i:1721384598;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1721384598;s:8:\"includes\";a:1:{s:9:\"ept_tiles\";s:34:\"Extra Paragraph Types (EPT): Tiles\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"ept_video\";a:6:{s:4:\"name\";s:9:\"ept_video\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Video\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:9:\"ept_video\";s:9:\"datestamp\";i:1722411736;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1722411736;s:8:\"includes\";a:1:{s:9:\"ept_video\";s:34:\"Extra Paragraph Types (EPT): Video\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:27:\"ept_video_and_image_gallery\";a:6:{s:4:\"name\";s:27:\"ept_video_and_image_gallery\";s:4:\"info\";a:6:{s:4:\"name\";s:52:\"Extra Paragraph Types (EPT): Video and Image Gallery\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:27:\"ept_video_and_image_gallery\";s:9:\"datestamp\";i:1722411779;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1722411779;s:8:\"includes\";a:1:{s:27:\"ept_video_and_image_gallery\";s:52:\"Extra Paragraph Types (EPT): Video and Image Gallery\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"ept_views\";a:6:{s:4:\"name\";s:9:\"ept_views\";s:4:\"info\";a:6:{s:4:\"name\";s:34:\"Extra Paragraph Types (EPT): Views\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.4\";s:7:\"project\";s:9:\"ept_views\";s:9:\"datestamp\";i:1727007518;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1727007518;s:8:\"includes\";a:1:{s:9:\"ept_views\";s:34:\"Extra Paragraph Types (EPT): Views\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:11:\"ept_webform\";a:6:{s:4:\"name\";s:11:\"ept_webform\";s:4:\"info\";a:6:{s:4:\"name\";s:36:\"Extra Paragraph Types (EPT): Webform\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:11:\"ept_webform\";s:9:\"datestamp\";i:1721384667;s:16:\"_info_file_ctime\";i:1735492408;}s:9:\"datestamp\";i:1721384667;s:8:\"includes\";a:1:{s:11:\"ept_webform\";s:36:\"Extra Paragraph Types (EPT): Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:17:\"ept_webform_popup\";a:6:{s:4:\"name\";s:17:\"ept_webform_popup\";s:4:\"info\";a:6:{s:4:\"name\";s:42:\"Extra Paragraph Types (EPT): Webform Popup\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:17:\"ept_webform_popup\";s:9:\"datestamp\";i:1721384667;s:16:\"_info_file_ctime\";i:1735492408;}s:9:\"datestamp\";i:1721384667;s:8:\"includes\";a:1:{s:17:\"ept_webform_popup\";s:42:\"Extra Paragraph Types (EPT): Webform Popup\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:11:\"field_group\";a:6:{s:4:\"name\";s:11:\"field_group\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Field Group\";s:7:\"package\";s:6:\"Fields\";s:7:\"version\";s:7:\"8.x-3.6\";s:7:\"project\";s:11:\"field_group\";s:9:\"datestamp\";i:1722672513;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1722672513;s:8:\"includes\";a:1:{s:11:\"field_group\";s:11:\"Field Group\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:8:\"file_mdm\";a:6:{s:4:\"name\";s:8:\"file_mdm\";s:4:\"info\";a:6:{s:4:\"name\";s:21:\"File metadata manager\";s:7:\"package\";s:13:\"File metadata\";s:7:\"version\";s:5:\"3.1.0\";s:7:\"project\";s:8:\"file_mdm\";s:9:\"datestamp\";i:1718086270;s:16:\"_info_file_ctime\";i:1729024187;}s:9:\"datestamp\";i:1718086270;s:8:\"includes\";a:3:{s:8:\"file_mdm\";s:21:\"File metadata manager\";s:13:\"file_mdm_exif\";s:20:\"File metadata - EXIF\";s:13:\"file_mdm_font\";s:20:\"File metadata - Font\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:11:\"gin_toolbar\";a:6:{s:4:\"name\";s:11:\"gin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Gin Toolbar\";s:7:\"version\";s:7:\"8.x-1.0\";s:7:\"project\";s:11:\"gin_toolbar\";s:9:\"datestamp\";i:1734698812;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734698812;s:8:\"includes\";a:1:{s:11:\"gin_toolbar\";s:11:\"Gin Toolbar\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"glightbox\";a:6:{s:4:\"name\";s:9:\"glightbox\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"GLightbox\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:6:\"1.0.13\";s:7:\"project\";s:9:\"glightbox\";s:9:\"datestamp\";i:1734093965;s:16:\"_info_file_ctime\";i:1735498429;}s:9:\"datestamp\";i:1734093965;s:8:\"includes\";a:1:{s:9:\"glightbox\";s:9:\"GLightbox\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:21:\"glightbox_media_video\";a:6:{s:4:\"name\";s:21:\"glightbox_media_video\";s:4:\"info\";a:6:{s:4:\"name\";s:21:\"GLightbox Media Video\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"1.0.3\";s:7:\"project\";s:21:\"glightbox_media_video\";s:9:\"datestamp\";i:1734297827;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734297827;s:8:\"includes\";a:1:{s:21:\"glightbox_media_video\";s:21:\"GLightbox Media Video\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:13:\"image_effects\";a:6:{s:4:\"name\";s:13:\"image_effects\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Image Effects\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"4.0.0\";s:7:\"project\";s:13:\"image_effects\";s:9:\"datestamp\";i:1733831440;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1733831440;s:8:\"includes\";a:1:{s:13:\"image_effects\";s:13:\"Image Effects\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"jquery_ui\";a:6:{s:4:\"name\";s:9:\"jquery_ui\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"jQuery UI\";s:7:\"package\";s:9:\"jQuery UI\";s:7:\"version\";s:7:\"8.x-1.7\";s:7:\"project\";s:9:\"jquery_ui\";s:9:\"datestamp\";i:1717002101;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1717002101;s:8:\"includes\";a:1:{s:9:\"jquery_ui\";s:9:\"jQuery UI\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:19:\"jquery_ui_accordion\";a:6:{s:4:\"name\";s:19:\"jquery_ui_accordion\";s:4:\"info\";a:6:{s:4:\"name\";s:19:\"jQuery UI Accordion\";s:7:\"package\";s:9:\"jQuery UI\";s:7:\"version\";s:5:\"2.1.0\";s:7:\"project\";s:19:\"jquery_ui_accordion\";s:9:\"datestamp\";i:1717015497;s:16:\"_info_file_ctime\";i:1728223651;}s:9:\"datestamp\";i:1717015497;s:8:\"includes\";a:1:{s:19:\"jquery_ui_accordion\";s:19:\"jQuery UI Accordion\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:14:\"jquery_ui_tabs\";a:6:{s:4:\"name\";s:14:\"jquery_ui_tabs\";s:4:\"info\";a:6:{s:4:\"name\";s:14:\"jQuery UI Tabs\";s:7:\"package\";s:9:\"jQuery UI\";s:7:\"version\";s:5:\"2.1.0\";s:7:\"project\";s:14:\"jquery_ui_tabs\";s:9:\"datestamp\";i:1719935964;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1719935964;s:8:\"includes\";a:1:{s:14:\"jquery_ui_tabs\";s:14:\"jQuery UI Tabs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:17:\"layout_paragraphs\";a:6:{s:4:\"name\";s:17:\"layout_paragraphs\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Layout Paragraphs\";s:7:\"package\";s:10:\"Paragraphs\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:17:\"layout_paragraphs\";s:9:\"datestamp\";i:1732724680;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1732724680;s:8:\"includes\";a:1:{s:17:\"layout_paragraphs\";s:17:\"Layout Paragraphs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:15:\"link_attributes\";a:6:{s:4:\"name\";s:15:\"link_attributes\";s:4:\"info\";a:6:{s:4:\"name\";s:15:\"Link attributes\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:15:\"link_attributes\";s:9:\"datestamp\";i:1721366574;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1728554822;}s:9:\"datestamp\";i:1721366574;s:8:\"includes\";a:2:{s:15:\"link_attributes\";s:15:\"Link attributes\";s:33:\"link_attributes_menu_link_content\";s:46:\"Link attributes: Menu Link Content integration\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:18:\"media_library_edit\";a:6:{s:4:\"name\";s:18:\"media_library_edit\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"Media Library Edit\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"3.0.4\";s:7:\"project\";s:18:\"media_library_edit\";s:9:\"datestamp\";i:1724357847;s:16:\"_info_file_ctime\";i:1728885051;}s:9:\"datestamp\";i:1724357847;s:8:\"includes\";a:1:{s:18:\"media_library_edit\";s:18:\"Media Library Edit\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:26:\"media_library_form_element\";a:6:{s:4:\"name\";s:26:\"media_library_form_element\";s:4:\"info\";a:6:{s:4:\"name\";s:26:\"Media Library Form Element\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:26:\"media_library_form_element\";s:9:\"datestamp\";i:1724676086;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1724676086;s:8:\"includes\";a:1:{s:26:\"media_library_form_element\";s:26:\"Media Library Form Element\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:10:\"paragraphs\";a:6:{s:4:\"name\";s:10:\"paragraphs\";s:4:\"info\";a:6:{s:4:\"name\";s:10:\"Paragraphs\";s:7:\"package\";s:10:\"Paragraphs\";s:7:\"version\";s:8:\"8.x-1.18\";s:7:\"project\";s:10:\"paragraphs\";s:9:\"datestamp\";i:1723029150;s:16:\"_info_file_ctime\";i:1728223652;}s:9:\"datestamp\";i:1723029150;s:8:\"includes\";a:1:{s:10:\"paragraphs\";s:10:\"Paragraphs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:11:\"tb_megamenu\";a:6:{s:4:\"name\";s:11:\"tb_megamenu\";s:4:\"info\";a:6:{s:4:\"name\";s:20:\"The Better Mega Menu\";s:7:\"package\";s:4:\"Menu\";s:7:\"version\";s:7:\"8.x-1.9\";s:7:\"project\";s:11:\"tb_megamenu\";s:9:\"datestamp\";i:1712869463;s:16:\"_info_file_ctime\";i:1728227421;}s:9:\"datestamp\";i:1712869463;s:8:\"includes\";a:1:{s:11:\"tb_megamenu\";s:20:\"The Better Mega Menu\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:10:\"twig_tweak\";a:6:{s:4:\"name\";s:10:\"twig_tweak\";s:4:\"info\";a:6:{s:4:\"name\";s:10:\"Twig Tweak\";s:7:\"version\";s:5:\"3.4.0\";s:7:\"project\";s:10:\"twig_tweak\";s:9:\"datestamp\";i:1721562309;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1728244235;}s:9:\"datestamp\";i:1721562309;s:8:\"includes\";a:1:{s:10:\"twig_tweak\";s:10:\"Twig Tweak\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:17:\"views_year_filter\";a:6:{s:4:\"name\";s:17:\"views_year_filter\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Views Year Filter\";s:7:\"package\";s:4:\"Date\";s:7:\"version\";s:5:\"2.1.5\";s:7:\"project\";s:17:\"views_year_filter\";s:9:\"datestamp\";i:1726675379;s:16:\"_info_file_ctime\";i:1729065968;}s:9:\"datestamp\";i:1726675379;s:8:\"includes\";a:1:{s:17:\"views_year_filter\";s:17:\"Views Year Filter\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:14:\"viewsreference\";a:6:{s:4:\"name\";s:14:\"viewsreference\";s:4:\"info\";a:6:{s:4:\"name\";s:21:\"Views Reference Field\";s:7:\"package\";s:5:\"Views\";s:7:\"version\";s:14:\"8.x-2.0-beta10\";s:7:\"project\";s:14:\"viewsreference\";s:9:\"datestamp\";i:1725510908;s:16:\"_info_file_ctime\";i:1728223654;}s:9:\"datestamp\";i:1725510908;s:8:\"includes\";a:1:{s:14:\"viewsreference\";s:21:\"Views Reference Field\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:7:\"webform\";a:6:{s:4:\"name\";s:7:\"webform\";s:4:\"info\";a:6:{s:4:\"name\";s:7:\"Webform\";s:7:\"package\";s:7:\"Webform\";s:7:\"version\";s:12:\"6.3.0-alpha3\";s:7:\"project\";s:7:\"webform\";s:9:\"datestamp\";i:1733851313;s:16:\"_info_file_ctime\";i:1735492412;}s:9:\"datestamp\";i:1733851313;s:8:\"includes\";a:1:{s:7:\"webform\";s:7:\"Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:3:\"gin\";a:6:{s:4:\"name\";s:3:\"gin\";s:4:\"info\";a:5:{s:4:\"name\";s:3:\"Gin\";s:7:\"version\";s:7:\"8.x-3.0\";s:7:\"project\";s:3:\"gin\";s:9:\"datestamp\";i:1734696851;s:16:\"_info_file_ctime\";i:1735498436;}s:9:\"datestamp\";i:1734696851;s:8:\"includes\";a:1:{s:3:\"gin\";s:3:\"Gin\";}s:12:\"project_type\";s:5:\"theme\";s:14:\"project_status\";b:1;}}',1735504658),('update_available_releases','admin_toolbar',_binary 'a:10:{s:5:\"title\";s:13:\"Admin Toolbar\";s:10:\"short_name\";s:13:\"admin_toolbar\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"3.4.,3.5.\";s:18:\"composer_namespace\";s:20:\"drupal/admin_toolbar\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/admin_toolbar\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:55:{s:5:\"3.5.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.5.1\";s:7:\"version\";s:5:\"3.5.1\";s:3:\"tag\";s:5:\"3.5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.5.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.5.1.tar.gz\";s:4:\"date\";s:10:\"1730409973\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";}s:5:\"3.5.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.5.0\";s:7:\"version\";s:5:\"3.5.0\";s:3:\"tag\";s:5:\"3.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.5.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.5.0.tar.gz\";s:4:\"date\";s:10:\"1722639094\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";}s:5:\"3.4.2\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.4.2\";s:7:\"version\";s:5:\"3.4.2\";s:3:\"tag\";s:5:\"3.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.4.2.tar.gz\";s:4:\"date\";s:10:\"1696006154\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.4.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.4.1\";s:7:\"version\";s:5:\"3.4.1\";s:3:\"tag\";s:5:\"3.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.4.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.4.1.tar.gz\";s:4:\"date\";s:10:\"1684944156\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.4.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.4.0\";s:7:\"version\";s:5:\"3.4.0\";s:3:\"tag\";s:5:\"3.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.4.0.tar.gz\";s:4:\"date\";s:10:\"1683730335\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.3.2\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.3.2\";s:7:\"version\";s:5:\"3.3.2\";s:3:\"tag\";s:5:\"3.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.3.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.3.2.tar.gz\";s:4:\"date\";s:10:\"1683055364\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.3.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.3.1\";s:7:\"version\";s:5:\"3.3.1\";s:3:\"tag\";s:5:\"3.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.3.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.3.1.tar.gz\";s:4:\"date\";s:10:\"1682689245\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.3.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.3.0\";s:7:\"version\";s:5:\"3.3.0\";s:3:\"tag\";s:5:\"3.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.3.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.3.0.tar.gz\";s:4:\"date\";s:10:\"1669567837\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"3.2.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.2.1\";s:7:\"version\";s:5:\"3.2.1\";s:3:\"tag\";s:5:\"3.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.2.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.2.1.tar.gz\";s:4:\"date\";s:10:\"1665044276\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.2.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.2.0\";s:7:\"version\";s:5:\"3.2.0\";s:3:\"tag\";s:5:\"3.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.2.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.2.0.tar.gz\";s:4:\"date\";s:10:\"1664981657\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.1.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.1.1\";s:7:\"version\";s:5:\"3.1.1\";s:3:\"tag\";s:5:\"3.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.1.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.1.1.tar.gz\";s:4:\"date\";s:10:\"1658801841\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:19:\"^8.8.0 || ^9 || ^10\";}s:5:\"3.1.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.1.0\";s:7:\"version\";s:5:\"3.1.0\";s:3:\"tag\";s:5:\"3.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.1.0.tar.gz\";s:4:\"date\";s:10:\"1643097060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:19:\"^8.8.0 || ^9 || ^10\";}s:5:\"3.0.3\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.3\";s:7:\"version\";s:5:\"3.0.3\";s:3:\"tag\";s:5:\"3.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.3.tar.gz\";s:4:\"date\";s:10:\"1632322068\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.0.2\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.2\";s:7:\"version\";s:5:\"3.0.2\";s:3:\"tag\";s:5:\"3.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.2.tar.gz\";s:4:\"date\";s:10:\"1629882675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.0.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.1\";s:7:\"version\";s:5:\"3.0.1\";s:3:\"tag\";s:5:\"3.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.1.tar.gz\";s:4:\"date\";s:10:\"1622644077\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1611311186\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1629883381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1601998853\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1592535597\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1585017179\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1584986458\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.7.7 || ^9.0\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1572370984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-2.0-beta2\";a:11:{s:4:\"name\";s:27:\"admin_toolbar 8.x-2.0-beta2\";s:7:\"version\";s:13:\"8.x-2.0-beta2\";s:3:\"tag\";s:13:\"8.x-2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.0-beta2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1567506785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:27:\"admin_toolbar 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1562269081\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.27\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.27\";s:7:\"version\";s:8:\"8.x-1.27\";s:3:\"tag\";s:8:\"8.x-1.27\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.27\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.27.tar.gz\";s:4:\"date\";s:10:\"1558552081\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.26\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.26\";s:7:\"version\";s:8:\"8.x-1.26\";s:3:\"tag\";s:8:\"8.x-1.26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.26\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.26.tar.gz\";s:4:\"date\";s:10:\"1549218480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.25\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.25\";s:7:\"version\";s:8:\"8.x-1.25\";s:3:\"tag\";s:8:\"8.x-1.25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.25\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.25.tar.gz\";s:4:\"date\";s:10:\"1542915180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.24\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.24\";s:7:\"version\";s:8:\"8.x-1.24\";s:3:\"tag\";s:8:\"8.x-1.24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.24\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.24.tar.gz\";s:4:\"date\";s:10:\"1527522480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.23\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.23\";s:7:\"version\";s:8:\"8.x-1.23\";s:3:\"tag\";s:8:\"8.x-1.23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.23\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.23.tar.gz\";s:4:\"date\";s:10:\"1517936581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.22\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.22\";s:7:\"version\";s:8:\"8.x-1.22\";s:3:\"tag\";s:8:\"8.x-1.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.22\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.22.tar.gz\";s:4:\"date\";s:10:\"1514888585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.21\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.21\";s:7:\"version\";s:8:\"8.x-1.21\";s:3:\"tag\";s:8:\"8.x-1.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.21\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.21.tar.gz\";s:4:\"date\";s:10:\"1511190785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.20\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.20\";s:7:\"version\";s:8:\"8.x-1.20\";s:3:\"tag\";s:8:\"8.x-1.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.20\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.20.tar.gz\";s:4:\"date\";s:10:\"1505199844\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.19\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.19\";s:7:\"version\";s:8:\"8.x-1.19\";s:3:\"tag\";s:8:\"8.x-1.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.19\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.19.tar.gz\";s:4:\"date\";s:10:\"1491487683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.18\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.18\";s:7:\"version\";s:8:\"8.x-1.18\";s:3:\"tag\";s:8:\"8.x-1.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.18\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.18.tar.gz\";s:4:\"date\";s:10:\"1480614184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.17\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.17\";s:7:\"version\";s:8:\"8.x-1.17\";s:3:\"tag\";s:8:\"8.x-1.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.17\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.17.tar.gz\";s:4:\"date\";s:10:\"1472585039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.16\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1469715839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.15\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1464016832\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.14\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1454942939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.13\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1454405939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.12\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1454402339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.11\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1449833341\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.10\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1445350439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.9\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1438248239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.8\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1437400139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.7\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1434972483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.6\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1433331481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1433329681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1432141381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1432129285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1432129285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1432048381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1431018181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"3.x-dev\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 3.x-dev\";s:7:\"version\";s:7:\"3.x-dev\";s:3:\"tag\";s:3:\"3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/3.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1731520679\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:25:\"admin_toolbar 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1649739022\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:25:\"admin_toolbar 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1567701780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}}s:10:\"last_fetch\";i:1735492268;}',1735578668),('update_available_releases','better_exposed_filters',_binary 'a:10:{s:5:\"title\";s:22:\"Better Exposed Filters\";s:10:\"short_name\";s:22:\"better_exposed_filters\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"6.0.,7.0.\";s:18:\"composer_namespace\";s:29:\"drupal/better_exposed_filters\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:53:\"https://www.drupal.org/project/better_exposed_filters\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:34:{s:5:\"7.0.2\";a:11:{s:4:\"name\";s:28:\"better_exposed_filters 7.0.2\";s:7:\"version\";s:5:\"7.0.2\";s:3:\"tag\";s:5:\"7.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/better_exposed_filters/releases/7.0.2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/better_exposed_filters-7.0.2.tar.gz\";s:4:\"date\";s:10:\"1729001179\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"7.0.1\";a:11:{s:4:\"name\";s:28:\"better_exposed_filters 7.0.1\";s:7:\"version\";s:5:\"7.0.1\";s:3:\"tag\";s:5:\"7.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/better_exposed_filters/releases/7.0.1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/better_exposed_filters-7.0.1.tar.gz\";s:4:\"date\";s:10:\"1724346308\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"7.0.0\";a:11:{s:4:\"name\";s:28:\"better_exposed_filters 7.0.0\";s:7:\"version\";s:5:\"7.0.0\";s:3:\"tag\";s:5:\"7.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/better_exposed_filters/releases/7.0.0\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/better_exposed_filters-7.0.0.tar.gz\";s:4:\"date\";s:10:\"1723753883\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:11:\"7.0.0-beta1\";a:11:{s:4:\"name\";s:34:\"better_exposed_filters 7.0.0-beta1\";s:7:\"version\";s:11:\"7.0.0-beta1\";s:3:\"tag\";s:11:\"7.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/better_exposed_filters/releases/7.0.0-beta1\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/better_exposed_filters-7.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1716398746\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"6.0.6\";a:11:{s:4:\"name\";s:28:\"better_exposed_filters 6.0.6\";s:7:\"version\";s:5:\"6.0.6\";s:3:\"tag\";s:5:\"6.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/better_exposed_filters/releases/6.0.6\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/better_exposed_filters-6.0.6.tar.gz\";s:4:\"date\";s:10:\"1716397541\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"6.0.5\";a:11:{s:4:\"name\";s:28:\"better_exposed_filters 6.0.5\";s:7:\"version\";s:5:\"6.0.5\";s:3:\"tag\";s:5:\"6.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/better_exposed_filters/releases/6.0.5\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/better_exposed_filters-6.0.5.tar.gz\";s:4:\"date\";s:10:\"1713570803\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"6.0.4\";a:11:{s:4:\"name\";s:28:\"better_exposed_filters 6.0.4\";s:7:\"version\";s:5:\"6.0.4\";s:3:\"tag\";s:5:\"6.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/better_exposed_filters/releases/6.0.4\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/better_exposed_filters-6.0.4.tar.gz\";s:4:\"date\";s:10:\"1713537663\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"6.0.3\";a:11:{s:4:\"name\";s:28:\"better_exposed_filters 6.0.3\";s:7:\"version\";s:5:\"6.0.3\";s:3:\"tag\";s:5:\"6.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/better_exposed_filters/releases/6.0.3\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/better_exposed_filters-6.0.3.tar.gz\";s:4:\"date\";s:10:\"1671541877\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"6.0.2\";a:11:{s:4:\"name\";s:28:\"better_exposed_filters 6.0.2\";s:7:\"version\";s:5:\"6.0.2\";s:3:\"tag\";s:5:\"6.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/better_exposed_filters/releases/6.0.2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/better_exposed_filters-6.0.2.tar.gz\";s:4:\"date\";s:10:\"1666017720\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"6.0.1\";a:11:{s:4:\"name\";s:28:\"better_exposed_filters 6.0.1\";s:7:\"version\";s:5:\"6.0.1\";s:3:\"tag\";s:5:\"6.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/better_exposed_filters/releases/6.0.1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/better_exposed_filters-6.0.1.tar.gz\";s:4:\"date\";s:10:\"1662993217\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:7:\"8.x-5.2\";a:11:{s:4:\"name\";s:30:\"better_exposed_filters 8.x-5.2\";s:7:\"version\";s:7:\"8.x-5.2\";s:3:\"tag\";s:7:\"8.x-5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-5.2\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-5.2.tar.gz\";s:4:\"date\";s:10:\"1657172286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-5.1\";a:11:{s:4:\"name\";s:30:\"better_exposed_filters 8.x-5.1\";s:7:\"version\";s:7:\"8.x-5.1\";s:3:\"tag\";s:7:\"8.x-5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-5.1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-5.1.tar.gz\";s:4:\"date\";s:10:\"1654277111\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-5.0\";a:11:{s:4:\"name\";s:30:\"better_exposed_filters 8.x-5.0\";s:7:\"version\";s:7:\"8.x-5.0\";s:3:\"tag\";s:7:\"8.x-5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-5.0\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-5.0.tar.gz\";s:4:\"date\";s:10:\"1634748723\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"8.x-5.0-beta3\";a:11:{s:4:\"name\";s:36:\"better_exposed_filters 8.x-5.0-beta3\";s:7:\"version\";s:13:\"8.x-5.0-beta3\";s:3:\"tag\";s:13:\"8.x-5.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-5.0-beta3\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-5.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1625665747\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"8.x-5.0-beta2\";a:11:{s:4:\"name\";s:36:\"better_exposed_filters 8.x-5.0-beta2\";s:7:\"version\";s:13:\"8.x-5.0-beta2\";s:3:\"tag\";s:13:\"8.x-5.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-5.0-beta2\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-5.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1624554647\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"8.x-5.0-beta1\";a:11:{s:4:\"name\";s:36:\"better_exposed_filters 8.x-5.0-beta1\";s:7:\"version\";s:13:\"8.x-5.0-beta1\";s:3:\"tag\";s:13:\"8.x-5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-5.0-beta1\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1594141892\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-4.1\";a:11:{s:4:\"name\";s:30:\"better_exposed_filters 8.x-4.1\";s:7:\"version\";s:7:\"8.x-4.1\";s:3:\"tag\";s:7:\"8.x-4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-4.1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-4.1.tar.gz\";s:4:\"date\";s:10:\"1654277347\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^8\";}s:7:\"8.x-4.0\";a:11:{s:4:\"name\";s:30:\"better_exposed_filters 8.x-4.0\";s:7:\"version\";s:7:\"8.x-4.0\";s:3:\"tag\";s:7:\"8.x-4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-4.0\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-4.0.tar.gz\";s:4:\"date\";s:10:\"1634748844\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^8\";}s:13:\"8.x-4.0-beta4\";a:11:{s:4:\"name\";s:36:\"better_exposed_filters 8.x-4.0-beta4\";s:7:\"version\";s:13:\"8.x-4.0-beta4\";s:3:\"tag\";s:13:\"8.x-4.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-4.0-beta4\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-4.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1625666046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^8\";}s:13:\"8.x-4.0-beta3\";a:11:{s:4:\"name\";s:36:\"better_exposed_filters 8.x-4.0-beta3\";s:7:\"version\";s:13:\"8.x-4.0-beta3\";s:3:\"tag\";s:13:\"8.x-4.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-4.0-beta3\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-4.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1624553721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^8\";}s:13:\"8.x-4.0-beta2\";a:11:{s:4:\"name\";s:36:\"better_exposed_filters 8.x-4.0-beta2\";s:7:\"version\";s:13:\"8.x-4.0-beta2\";s:3:\"tag\";s:13:\"8.x-4.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-4.0-beta2\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-4.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1594138017\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^8\";}s:13:\"8.x-4.0-beta1\";a:11:{s:4:\"name\";s:36:\"better_exposed_filters 8.x-4.0-beta1\";s:7:\"version\";s:13:\"8.x-4.0-beta1\";s:3:\"tag\";s:13:\"8.x-4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-4.0-beta1\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1587154928\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-4.0-alpha1\";a:11:{s:4:\"name\";s:37:\"better_exposed_filters 8.x-4.0-alpha1\";s:7:\"version\";s:14:\"8.x-4.0-alpha1\";s:3:\"tag\";s:14:\"8.x-4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:77:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-4.0-alpha1\";s:13:\"download_link\";s:82:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1572828784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-3.0-alpha6\";a:11:{s:4:\"name\";s:37:\"better_exposed_filters 8.x-3.0-alpha6\";s:7:\"version\";s:14:\"8.x-3.0-alpha6\";s:3:\"tag\";s:14:\"8.x-3.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:77:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-3.0-alpha6\";s:13:\"download_link\";s:82:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-3.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1550449381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-3.0-alpha5\";a:11:{s:4:\"name\";s:37:\"better_exposed_filters 8.x-3.0-alpha5\";s:7:\"version\";s:14:\"8.x-3.0-alpha5\";s:3:\"tag\";s:14:\"8.x-3.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:77:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-3.0-alpha5\";s:13:\"download_link\";s:82:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-3.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1540513084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-3.0-alpha4\";a:11:{s:4:\"name\";s:37:\"better_exposed_filters 8.x-3.0-alpha4\";s:7:\"version\";s:14:\"8.x-3.0-alpha4\";s:3:\"tag\";s:14:\"8.x-3.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:77:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-3.0-alpha4\";s:13:\"download_link\";s:82:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-3.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1525044484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-3.0-alpha3\";a:11:{s:4:\"name\";s:37:\"better_exposed_filters 8.x-3.0-alpha3\";s:7:\"version\";s:14:\"8.x-3.0-alpha3\";s:3:\"tag\";s:14:\"8.x-3.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:77:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-3.0-alpha3\";s:13:\"download_link\";s:82:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-3.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1501274342\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-3.0-alpha2\";a:11:{s:4:\"name\";s:37:\"better_exposed_filters 8.x-3.0-alpha2\";s:7:\"version\";s:14:\"8.x-3.0-alpha2\";s:3:\"tag\";s:14:\"8.x-3.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:77:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-3.0-alpha2\";s:13:\"download_link\";s:82:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-3.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1484626084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-3.0-alpha1\";a:11:{s:4:\"name\";s:37:\"better_exposed_filters 8.x-3.0-alpha1\";s:7:\"version\";s:14:\"8.x-3.0-alpha1\";s:3:\"tag\";s:14:\"8.x-3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:77:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-3.0-alpha1\";s:13:\"download_link\";s:82:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1466481839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"7.0.x-dev\";a:11:{s:4:\"name\";s:32:\"better_exposed_filters 7.0.x-dev\";s:7:\"version\";s:9:\"7.0.x-dev\";s:3:\"tag\";s:5:\"7.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/better_exposed_filters/releases/7.0.x-dev\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/better_exposed_filters-7.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734567181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"6.0.x-dev\";a:11:{s:4:\"name\";s:32:\"better_exposed_filters 6.0.x-dev\";s:7:\"version\";s:9:\"6.0.x-dev\";s:3:\"tag\";s:5:\"6.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/better_exposed_filters/releases/6.0.x-dev\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/better_exposed_filters-6.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734369283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-5.x-dev\";a:11:{s:4:\"name\";s:34:\"better_exposed_filters 8.x-5.x-dev\";s:7:\"version\";s:11:\"8.x-5.x-dev\";s:3:\"tag\";s:7:\"8.x-5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-5.x-dev\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1712848032\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";s:5:\"terms\";a:0:{}}s:11:\"8.x-4.x-dev\";a:11:{s:4:\"name\";s:34:\"better_exposed_filters 8.x-4.x-dev\";s:7:\"version\";s:11:\"8.x-4.x-dev\";s:3:\"tag\";s:7:\"8.x-4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-4.x-dev\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1657348596\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^8\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:34:\"better_exposed_filters 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/better_exposed_filters/releases/8.x-3.x-dev\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/better_exposed_filters-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1600190760\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492268;}',1735578668),('update_available_releases','block_field',_binary 'a:10:{s:5:\"title\";s:11:\"Block field\";s:10:\"short_name\";s:11:\"block_field\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:18:\"drupal/block_field\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/block_field\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:14:{s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1723550576\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1667511464\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1658858536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1621950813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1588279781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1536732480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1533866285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1525303380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1511317688\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1487611082\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1464034139\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1464016832\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1463668739\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721425360\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492268;}',1735578668),('update_available_releases','ckeditor5_plugin_pack',_binary 'a:10:{s:5:\"title\";s:22:\"CKEditor 5 Plugin Pack\";s:10:\"short_name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.2.\";s:18:\"composer_namespace\";s:28:\"drupal/ckeditor5_plugin_pack\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:52:\"https://www.drupal.org/project/ckeditor5_plugin_pack\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.2.4\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.4\";s:7:\"version\";s:5:\"1.2.4\";s:3:\"tag\";s:5:\"1.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.4\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.4.tar.gz\";s:4:\"date\";s:10:\"1734514948\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.3\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.3\";s:7:\"version\";s:5:\"1.2.3\";s:3:\"tag\";s:5:\"1.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.3\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.3.tar.gz\";s:4:\"date\";s:10:\"1731594715\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1727947517\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1723548212\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1722415813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.1.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.1.0\";s:7:\"version\";s:5:\"1.1.0\";s:3:\"tag\";s:5:\"1.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.1.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.1.0.tar.gz\";s:4:\"date\";s:10:\"1718271916\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.0.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1714466054\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.0.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1713945391\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492268;}',1735578668),('update_available_releases','ckeditor5_premium_features',_binary 'a:10:{s:5:\"title\";s:27:\"CKEditor 5 Premium Features\";s:10:\"short_name\";s:26:\"ckeditor5_premium_features\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.3.\";s:18:\"composer_namespace\";s:33:\"drupal/ckeditor5_premium_features\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:57:\"https://www.drupal.org/project/ckeditor5_premium_features\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:24:{s:5:\"1.3.5\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.5\";s:7:\"version\";s:5:\"1.3.5\";s:3:\"tag\";s:5:\"1.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.5\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.5.tar.gz\";s:4:\"date\";s:10:\"1734513727\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.4\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.4\";s:7:\"version\";s:5:\"1.3.4\";s:3:\"tag\";s:5:\"1.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.4\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.4.tar.gz\";s:4:\"date\";s:10:\"1733150653\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.3\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.3\";s:7:\"version\";s:5:\"1.3.3\";s:3:\"tag\";s:5:\"1.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.3\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.3.tar.gz\";s:4:\"date\";s:10:\"1731586774\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.2\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.2\";s:7:\"version\";s:5:\"1.3.2\";s:3:\"tag\";s:5:\"1.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.2\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.2.tar.gz\";s:4:\"date\";s:10:\"1727958023\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1723546977\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1722416832\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.9\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.9\";s:7:\"version\";s:5:\"1.2.9\";s:3:\"tag\";s:5:\"1.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.9\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.9.tar.gz\";s:4:\"date\";s:10:\"1718272066\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.8\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.8\";s:7:\"version\";s:5:\"1.2.8\";s:3:\"tag\";s:5:\"1.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.8\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.8.tar.gz\";s:4:\"date\";s:10:\"1713960338\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.7\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.7\";s:7:\"version\";s:5:\"1.2.7\";s:3:\"tag\";s:5:\"1.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.7\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.7.tar.gz\";s:4:\"date\";s:10:\"1713946256\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}s:5:\"1.2.6\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.6\";s:7:\"version\";s:5:\"1.2.6\";s:3:\"tag\";s:5:\"1.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.6\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.6.tar.gz\";s:4:\"date\";s:10:\"1709550478\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.5\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.5\";s:7:\"version\";s:5:\"1.2.5\";s:3:\"tag\";s:5:\"1.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.5\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.5.tar.gz\";s:4:\"date\";s:10:\"1706087373\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.4\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.4\";s:7:\"version\";s:5:\"1.2.4\";s:3:\"tag\";s:5:\"1.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.4\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.4.tar.gz\";s:4:\"date\";s:10:\"1702994815\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.3\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.3\";s:7:\"version\";s:5:\"1.2.3\";s:3:\"tag\";s:5:\"1.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.3\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.3.tar.gz\";s:4:\"date\";s:10:\"1699963145\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.2\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1693384282\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1688647071\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1687776512\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.1.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.1.1\";s:7:\"version\";s:5:\"1.1.1\";s:3:\"tag\";s:5:\"1.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.1.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.1.1.tar.gz\";s:4:\"date\";s:10:\"1684309128\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.1.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.1.0\";s:7:\"version\";s:5:\"1.1.0\";s:3:\"tag\";s:5:\"1.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.1.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.1.0.tar.gz\";s:4:\"date\";s:10:\"1683814836\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1681894913\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1677662363\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:9:\"1.0.0-rc2\";a:11:{s:4:\"name\";s:36:\"ckeditor5_premium_features 1.0.0-rc2\";s:7:\"version\";s:9:\"1.0.0-rc2\";s:3:\"tag\";s:9:\"1.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-rc2\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1671113465\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:9:\"1.0.0-rc1\";a:11:{s:4:\"name\";s:36:\"ckeditor5_premium_features 1.0.0-rc1\";s:7:\"version\";s:9:\"1.0.0-rc1\";s:3:\"tag\";s:9:\"1.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-rc1\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1667227760\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:11:\"1.0.0-beta2\";a:11:{s:4:\"name\";s:38:\"ckeditor5_premium_features 1.0.0-beta2\";s:7:\"version\";s:11:\"1.0.0-beta2\";s:3:\"tag\";s:11:\"1.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-beta2\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1663854316\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:38:\"ckeditor5_premium_features 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-beta1\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663684376\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492268;}',1735578668),('update_available_releases','drupal',_binary 'a:10:{s:5:\"title\";s:11:\"Drupal core\";s:10:\"short_name\";s:6:\"drupal\";s:4:\"type\";s:12:\"project_core\";s:18:\"supported_branches\";s:29:\"10.3.,10.4.,10.5.,11.0.,11.1.\";s:18:\"composer_namespace\";s:11:\"drupal/core\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:37:\"https://www.drupal.org/project/drupal\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:439:{s:6:\"11.1.0\";a:10:{s:4:\"name\";s:13:\"drupal 11.1.0\";s:7:\"version\";s:6:\"11.1.0\";s:3:\"tag\";s:6:\"11.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.1.0.tar.gz\";s:4:\"date\";s:10:\"1734369672\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"11.1.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 11.1.0-rc1\";s:7:\"version\";s:10:\"11.1.0-rc1\";s:3:\"tag\";s:10:\"11.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.1.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1733153182\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"11.1.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 11.1.0-beta1\";s:7:\"version\";s:12:\"11.1.0-beta1\";s:3:\"tag\";s:12:\"11.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/11.1.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-11.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1731695942\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"11.0.9\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.9\";s:7:\"version\";s:6:\"11.0.9\";s:3:\"tag\";s:6:\"11.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.9.tar.gz\";s:4:\"date\";s:10:\"1732283629\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.8\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.8\";s:7:\"version\";s:6:\"11.0.8\";s:3:\"tag\";s:6:\"11.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.8.tar.gz\";s:4:\"date\";s:10:\"1732132096\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.7\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.7\";s:7:\"version\";s:6:\"11.0.7\";s:3:\"tag\";s:6:\"11.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.7.tar.gz\";s:4:\"date\";s:10:\"1731407794\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.6\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.6\";s:7:\"version\";s:6:\"11.0.6\";s:3:\"tag\";s:6:\"11.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.6.tar.gz\";s:4:\"date\";s:10:\"1730969764\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.5\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.5\";s:7:\"version\";s:6:\"11.0.5\";s:3:\"tag\";s:6:\"11.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.5.tar.gz\";s:4:\"date\";s:10:\"1727946737\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.4\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.4\";s:7:\"version\";s:6:\"11.0.4\";s:3:\"tag\";s:6:\"11.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.4.tar.gz\";s:4:\"date\";s:10:\"1726136390\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.3\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.3\";s:7:\"version\";s:6:\"11.0.3\";s:3:\"tag\";s:6:\"11.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.3.tar.gz\";s:4:\"date\";s:10:\"1726074557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.2\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.2\";s:7:\"version\";s:6:\"11.0.2\";s:3:\"tag\";s:6:\"11.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.2.tar.gz\";s:4:\"date\";s:10:\"1725526703\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.1\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.1\";s:7:\"version\";s:6:\"11.0.1\";s:3:\"tag\";s:6:\"11.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.1.tar.gz\";s:4:\"date\";s:10:\"1723108396\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.0\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.0\";s:7:\"version\";s:6:\"11.0.0\";s:3:\"tag\";s:6:\"11.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.0.tar.gz\";s:4:\"date\";s:10:\"1722578454\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"11.0.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 11.0.0-rc1\";s:7:\"version\";s:10:\"11.0.0-rc1\";s:3:\"tag\";s:10:\"11.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.0.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1720736512\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"11.0.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 11.0.0-beta1\";s:7:\"version\";s:12:\"11.0.0-beta1\";s:3:\"tag\";s:12:\"11.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/11.0.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1715953266\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"11.0.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 11.0.0-alpha1\";s:7:\"version\";s:13:\"11.0.0-alpha1\";s:3:\"tag\";s:13:\"11.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/11.0.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1714797816\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"10.4.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.4.0\";s:7:\"version\";s:6:\"10.4.0\";s:3:\"tag\";s:6:\"10.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.4.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.4.0.tar.gz\";s:4:\"date\";s:10:\"1734475162\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.4.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.4.0-rc1\";s:7:\"version\";s:10:\"10.4.0-rc1\";s:3:\"tag\";s:10:\"10.4.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.4.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.4.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1733155673\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.4.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.4.0-beta1\";s:7:\"version\";s:12:\"10.4.0-beta1\";s:3:\"tag\";s:12:\"10.4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.4.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1731947109\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:7:\"10.3.10\";a:10:{s:4:\"name\";s:14:\"drupal 10.3.10\";s:7:\"version\";s:7:\"10.3.10\";s:3:\"tag\";s:7:\"10.3.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.3.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.3.10.tar.gz\";s:4:\"date\";s:10:\"1732284381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.9\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.9\";s:7:\"version\";s:6:\"10.3.9\";s:3:\"tag\";s:6:\"10.3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.9.tar.gz\";s:4:\"date\";s:10:\"1732132747\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.8\";s:7:\"version\";s:6:\"10.3.8\";s:3:\"tag\";s:6:\"10.3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.8.tar.gz\";s:4:\"date\";s:10:\"1731407050\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.7\";s:7:\"version\";s:6:\"10.3.7\";s:3:\"tag\";s:6:\"10.3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.7.tar.gz\";s:4:\"date\";s:10:\"1730969060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.6\";s:7:\"version\";s:6:\"10.3.6\";s:3:\"tag\";s:6:\"10.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.6.tar.gz\";s:4:\"date\";s:10:\"1727948888\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.5\";s:7:\"version\";s:6:\"10.3.5\";s:3:\"tag\";s:6:\"10.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.5.tar.gz\";s:4:\"date\";s:10:\"1726134993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.4\";s:7:\"version\";s:6:\"10.3.4\";s:3:\"tag\";s:6:\"10.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.4.tar.gz\";s:4:\"date\";s:10:\"1726072510\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.3\";s:7:\"version\";s:6:\"10.3.3\";s:3:\"tag\";s:6:\"10.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.3.tar.gz\";s:4:\"date\";s:10:\"1725528161\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.2\";s:7:\"version\";s:6:\"10.3.2\";s:3:\"tag\";s:6:\"10.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.2.tar.gz\";s:4:\"date\";s:10:\"1723109810\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.1\";s:7:\"version\";s:6:\"10.3.1\";s:3:\"tag\";s:6:\"10.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.1.tar.gz\";s:4:\"date\";s:10:\"1720094095\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.0\";s:7:\"version\";s:6:\"10.3.0\";s:3:\"tag\";s:6:\"10.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.0.tar.gz\";s:4:\"date\";s:10:\"1718911125\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.3.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.3.0-rc1\";s:7:\"version\";s:10:\"10.3.0-rc1\";s:3:\"tag\";s:10:\"10.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.3.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1717621189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.3.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.3.0-beta1\";s:7:\"version\";s:12:\"10.3.0-beta1\";s:3:\"tag\";s:12:\"10.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.3.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1715953149\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:7:\"10.2.12\";a:10:{s:4:\"name\";s:14:\"drupal 10.2.12\";s:7:\"version\";s:7:\"10.2.12\";s:3:\"tag\";s:7:\"10.2.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.2.12\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.2.12.tar.gz\";s:4:\"date\";s:10:\"1732281201\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.2.11\";a:10:{s:4:\"name\";s:14:\"drupal 10.2.11\";s:7:\"version\";s:7:\"10.2.11\";s:3:\"tag\";s:7:\"10.2.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.2.11\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.2.11.tar.gz\";s:4:\"date\";s:10:\"1732133662\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.2.10\";a:10:{s:4:\"name\";s:14:\"drupal 10.2.10\";s:7:\"version\";s:7:\"10.2.10\";s:3:\"tag\";s:7:\"10.2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.2.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.2.10.tar.gz\";s:4:\"date\";s:10:\"1729096989\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.9\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.9\";s:7:\"version\";s:6:\"10.2.9\";s:3:\"tag\";s:6:\"10.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.9.tar.gz\";s:4:\"date\";s:10:\"1728387439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.8\";s:7:\"version\";s:6:\"10.2.8\";s:3:\"tag\";s:6:\"10.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.8.tar.gz\";s:4:\"date\";s:10:\"1726073816\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.7\";s:7:\"version\";s:6:\"10.2.7\";s:3:\"tag\";s:6:\"10.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.7.tar.gz\";s:4:\"date\";s:10:\"1717660024\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.6\";s:7:\"version\";s:6:\"10.2.6\";s:3:\"tag\";s:6:\"10.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.6.tar.gz\";s:4:\"date\";s:10:\"1714597701\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.5\";s:7:\"version\";s:6:\"10.2.5\";s:3:\"tag\";s:6:\"10.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.5.tar.gz\";s:4:\"date\";s:10:\"1712130945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.4\";s:7:\"version\";s:6:\"10.2.4\";s:3:\"tag\";s:6:\"10.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.4.tar.gz\";s:4:\"date\";s:10:\"1709715366\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.3\";s:7:\"version\";s:6:\"10.2.3\";s:3:\"tag\";s:6:\"10.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.3.tar.gz\";s:4:\"date\";s:10:\"1707347611\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.2\";s:7:\"version\";s:6:\"10.2.2\";s:3:\"tag\";s:6:\"10.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.2.tar.gz\";s:4:\"date\";s:10:\"1705511786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.1\";s:7:\"version\";s:6:\"10.2.1\";s:3:\"tag\";s:6:\"10.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.1.tar.gz\";s:4:\"date\";s:10:\"1704448164\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.0\";s:7:\"version\";s:6:\"10.2.0\";s:3:\"tag\";s:6:\"10.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.0.tar.gz\";s:4:\"date\";s:10:\"1702681674\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.2.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.2.0-rc1\";s:7:\"version\";s:10:\"10.2.0-rc1\";s:3:\"tag\";s:10:\"10.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.2.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1701450971\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.2.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.2.0-beta1\";s:7:\"version\";s:12:\"10.2.0-beta1\";s:3:\"tag\";s:12:\"10.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.2.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1700578716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.2.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.2.0-alpha1\";s:7:\"version\";s:13:\"10.2.0-alpha1\";s:3:\"tag\";s:13:\"10.2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.2.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1699048959\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"10.1.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.8\";s:7:\"version\";s:6:\"10.1.8\";s:3:\"tag\";s:6:\"10.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.8.tar.gz\";s:4:\"date\";s:10:\"1705512711\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.7\";s:7:\"version\";s:6:\"10.1.7\";s:3:\"tag\";s:6:\"10.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.7.tar.gz\";s:4:\"date\";s:10:\"1701857745\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.6\";s:7:\"version\";s:6:\"10.1.6\";s:3:\"tag\";s:6:\"10.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.6.tar.gz\";s:4:\"date\";s:10:\"1698841286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.5\";s:7:\"version\";s:6:\"10.1.5\";s:3:\"tag\";s:6:\"10.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.5.tar.gz\";s:4:\"date\";s:10:\"1696456362\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.4\";s:7:\"version\";s:6:\"10.1.4\";s:3:\"tag\";s:6:\"10.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.4.tar.gz\";s:4:\"date\";s:10:\"1695227262\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.3\";s:7:\"version\";s:6:\"10.1.3\";s:3:\"tag\";s:6:\"10.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.3.tar.gz\";s:4:\"date\";s:10:\"1694101052\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.2\";s:7:\"version\";s:6:\"10.1.2\";s:3:\"tag\";s:6:\"10.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.2.tar.gz\";s:4:\"date\";s:10:\"1690972078\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.1\";s:7:\"version\";s:6:\"10.1.1\";s:3:\"tag\";s:6:\"10.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.1.tar.gz\";s:4:\"date\";s:10:\"1688632960\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.0\";s:7:\"version\";s:6:\"10.1.0\";s:3:\"tag\";s:6:\"10.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.0.tar.gz\";s:4:\"date\";s:10:\"1687424272\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.1.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.1.0-rc1\";s:7:\"version\";s:10:\"10.1.0-rc1\";s:3:\"tag\";s:10:\"10.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.1.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1686244833\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.1.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.1.0-beta1\";s:7:\"version\";s:12:\"10.1.0-beta1\";s:3:\"tag\";s:12:\"10.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.1.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1684130534\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.1.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.1.0-alpha1\";s:7:\"version\";s:13:\"10.1.0-alpha1\";s:3:\"tag\";s:13:\"10.1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.1.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1682694475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:7:\"10.0.11\";a:10:{s:4:\"name\";s:14:\"drupal 10.0.11\";s:7:\"version\";s:7:\"10.0.11\";s:3:\"tag\";s:7:\"10.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.0.11\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.0.11.tar.gz\";s:4:\"date\";s:10:\"1695228927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.0.10\";a:10:{s:4:\"name\";s:14:\"drupal 10.0.10\";s:7:\"version\";s:7:\"10.0.10\";s:3:\"tag\";s:7:\"10.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.0.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.0.10.tar.gz\";s:4:\"date\";s:10:\"1688549719\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.9\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.9\";s:7:\"version\";s:6:\"10.0.9\";s:3:\"tag\";s:6:\"10.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.9.tar.gz\";s:4:\"date\";s:10:\"1683108606\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.8\";s:7:\"version\";s:6:\"10.0.8\";s:3:\"tag\";s:6:\"10.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.8.tar.gz\";s:4:\"date\";s:10:\"1681921539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.7\";s:7:\"version\";s:6:\"10.0.7\";s:3:\"tag\";s:6:\"10.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.7.tar.gz\";s:4:\"date\";s:10:\"1679678060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.6\";s:7:\"version\";s:6:\"10.0.6\";s:3:\"tag\";s:6:\"10.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.6.tar.gz\";s:4:\"date\";s:10:\"1679664982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.5\";s:7:\"version\";s:6:\"10.0.5\";s:3:\"tag\";s:6:\"10.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.5.tar.gz\";s:4:\"date\";s:10:\"1678901067\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.4\";s:7:\"version\";s:6:\"10.0.4\";s:3:\"tag\";s:6:\"10.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.4.tar.gz\";s:4:\"date\";s:10:\"1677681486\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.3\";s:7:\"version\";s:6:\"10.0.3\";s:3:\"tag\";s:6:\"10.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.3.tar.gz\";s:4:\"date\";s:10:\"1675276709\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.2\";s:7:\"version\";s:6:\"10.0.2\";s:3:\"tag\";s:6:\"10.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.2.tar.gz\";s:4:\"date\";s:10:\"1674065542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.1\";s:7:\"version\";s:6:\"10.0.1\";s:3:\"tag\";s:6:\"10.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.1.tar.gz\";s:4:\"date\";s:10:\"1672847780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.0\";s:7:\"version\";s:6:\"10.0.0\";s:3:\"tag\";s:6:\"10.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.0.tar.gz\";s:4:\"date\";s:10:\"1671125939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.0.0-rc3\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc3\";s:7:\"version\";s:10:\"10.0.0-rc3\";s:3:\"tag\";s:10:\"10.0.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1670591784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:10:\"10.0.0-rc2\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc2\";s:7:\"version\";s:10:\"10.0.0-rc2\";s:3:\"tag\";s:10:\"10.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1670320927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:10:\"10.0.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc1\";s:7:\"version\";s:10:\"10.0.0-rc1\";s:3:\"tag\";s:10:\"10.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1668612993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.0.0-beta2\";a:10:{s:4:\"name\";s:19:\"drupal 10.0.0-beta2\";s:7:\"version\";s:12:\"10.0.0-beta2\";s:3:\"tag\";s:12:\"10.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.0.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1664462663\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"10.0.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.0.0-beta1\";s:7:\"version\";s:12:\"10.0.0-beta1\";s:3:\"tag\";s:12:\"10.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.0.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663358020\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha7\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha7\";s:7:\"version\";s:13:\"10.0.0-alpha7\";s:3:\"tag\";s:13:\"10.0.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha7\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1659633851\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha6\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha6\";s:7:\"version\";s:13:\"10.0.0-alpha6\";s:3:\"tag\";s:13:\"10.0.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1657218740\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha5\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha5\";s:7:\"version\";s:13:\"10.0.0-alpha5\";s:3:\"tag\";s:13:\"10.0.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1654722993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha4\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha4\";s:7:\"version\";s:13:\"10.0.0-alpha4\";s:3:\"tag\";s:13:\"10.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1651875601\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha3\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha3\";s:7:\"version\";s:13:\"10.0.0-alpha3\";s:3:\"tag\";s:13:\"10.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1649887793\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha2\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha2\";s:7:\"version\";s:13:\"10.0.0-alpha2\";s:3:\"tag\";s:13:\"10.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1645204305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha1\";s:7:\"version\";s:13:\"10.0.0-alpha1\";s:3:\"tag\";s:13:\"10.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1643404041\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.5.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.5.11\";s:7:\"version\";s:6:\"9.5.11\";s:3:\"tag\";s:6:\"9.5.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.5.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.5.11.tar.gz\";s:4:\"date\";s:10:\"1695228016\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.5.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.5.10\";s:7:\"version\";s:6:\"9.5.10\";s:3:\"tag\";s:6:\"9.5.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.5.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.5.10.tar.gz\";s:4:\"date\";s:10:\"1688550984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.9\";s:7:\"version\";s:5:\"9.5.9\";s:3:\"tag\";s:5:\"9.5.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.9.tar.gz\";s:4:\"date\";s:10:\"1683121532\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.8\";s:7:\"version\";s:5:\"9.5.8\";s:3:\"tag\";s:5:\"9.5.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.8.tar.gz\";s:4:\"date\";s:10:\"1681922649\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.7\";s:7:\"version\";s:5:\"9.5.7\";s:3:\"tag\";s:5:\"9.5.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.7.tar.gz\";s:4:\"date\";s:10:\"1679677448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.6\";s:7:\"version\";s:5:\"9.5.6\";s:3:\"tag\";s:5:\"9.5.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.6.tar.gz\";s:4:\"date\";s:10:\"1679664389\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.5\";s:7:\"version\";s:5:\"9.5.5\";s:3:\"tag\";s:5:\"9.5.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.5.tar.gz\";s:4:\"date\";s:10:\"1678902101\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.4\";s:7:\"version\";s:5:\"9.5.4\";s:3:\"tag\";s:5:\"9.5.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.4.tar.gz\";s:4:\"date\";s:10:\"1677680813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.3\";s:7:\"version\";s:5:\"9.5.3\";s:3:\"tag\";s:5:\"9.5.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.3.tar.gz\";s:4:\"date\";s:10:\"1675281829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.2\";s:7:\"version\";s:5:\"9.5.2\";s:3:\"tag\";s:5:\"9.5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.2.tar.gz\";s:4:\"date\";s:10:\"1674066112\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.1\";s:7:\"version\";s:5:\"9.5.1\";s:3:\"tag\";s:5:\"9.5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.1.tar.gz\";s:4:\"date\";s:10:\"1672849046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.0\";s:7:\"version\";s:5:\"9.5.0\";s:3:\"tag\";s:5:\"9.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.0.tar.gz\";s:4:\"date\";s:10:\"1671115839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.5.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.0-rc2\";s:7:\"version\";s:9:\"9.5.0-rc2\";s:3:\"tag\";s:9:\"9.5.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1670593040\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.5.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.0-rc1\";s:7:\"version\";s:9:\"9.5.0-rc1\";s:3:\"tag\";s:9:\"9.5.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1668611189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.5.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.5.0-beta2\";s:7:\"version\";s:11:\"9.5.0-beta2\";s:3:\"tag\";s:11:\"9.5.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.5.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1664463958\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.5.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.5.0-beta1\";s:7:\"version\";s:11:\"9.5.0-beta1\";s:3:\"tag\";s:11:\"9.5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.5.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663358587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"9.4.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.15\";s:7:\"version\";s:6:\"9.4.15\";s:3:\"tag\";s:6:\"9.4.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.15.tar.gz\";s:4:\"date\";s:10:\"1683122076\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.14\";s:7:\"version\";s:6:\"9.4.14\";s:3:\"tag\";s:6:\"9.4.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.14.tar.gz\";s:4:\"date\";s:10:\"1681922120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.13\";s:7:\"version\";s:6:\"9.4.13\";s:3:\"tag\";s:6:\"9.4.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.13.tar.gz\";s:4:\"date\";s:10:\"1679665413\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.12\";s:7:\"version\";s:6:\"9.4.12\";s:3:\"tag\";s:6:\"9.4.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.12.tar.gz\";s:4:\"date\";s:10:\"1678901516\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.11\";s:7:\"version\";s:6:\"9.4.11\";s:3:\"tag\";s:6:\"9.4.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.11.tar.gz\";s:4:\"date\";s:10:\"1675282255\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.10\";s:7:\"version\";s:6:\"9.4.10\";s:3:\"tag\";s:6:\"9.4.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.10.tar.gz\";s:4:\"date\";s:10:\"1674066615\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.9\";s:7:\"version\";s:5:\"9.4.9\";s:3:\"tag\";s:5:\"9.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.9.tar.gz\";s:4:\"date\";s:10:\"1670421053\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.8\";s:7:\"version\";s:5:\"9.4.8\";s:3:\"tag\";s:5:\"9.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.8.tar.gz\";s:4:\"date\";s:10:\"1665072393\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.7\";s:7:\"version\";s:5:\"9.4.7\";s:3:\"tag\";s:5:\"9.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.7.tar.gz\";s:4:\"date\";s:10:\"1664383239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.6\";s:7:\"version\";s:5:\"9.4.6\";s:3:\"tag\";s:5:\"9.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.6.tar.gz\";s:4:\"date\";s:10:\"1663681319\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.5\";s:7:\"version\";s:5:\"9.4.5\";s:3:\"tag\";s:5:\"9.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.5.tar.gz\";s:4:\"date\";s:10:\"1659545453\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.4\";s:7:\"version\";s:5:\"9.4.4\";s:3:\"tag\";s:5:\"9.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.4.tar.gz\";s:4:\"date\";s:10:\"1659037490\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.3\";s:7:\"version\";s:5:\"9.4.3\";s:3:\"tag\";s:5:\"9.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.3.tar.gz\";s:4:\"date\";s:10:\"1658333415\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.2\";s:7:\"version\";s:5:\"9.4.2\";s:3:\"tag\";s:5:\"9.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.2.tar.gz\";s:4:\"date\";s:10:\"1657157309\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.1\";s:7:\"version\";s:5:\"9.4.1\";s:3:\"tag\";s:5:\"9.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.1.tar.gz\";s:4:\"date\";s:10:\"1655845511\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.0\";s:7:\"version\";s:5:\"9.4.0\";s:3:\"tag\";s:5:\"9.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.0.tar.gz\";s:4:\"date\";s:10:\"1655311138\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.4.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.0-rc2\";s:7:\"version\";s:9:\"9.4.0-rc2\";s:3:\"tag\";s:9:\"9.4.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1654890055\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.4.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.0-rc1\";s:7:\"version\";s:9:\"9.4.0-rc1\";s:3:\"tag\";s:9:\"9.4.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1654740019\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.4.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.4.0-beta1\";s:7:\"version\";s:11:\"9.4.0-beta1\";s:3:\"tag\";s:11:\"9.4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.4.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1653938214\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.4.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.4.0-alpha1\";s:7:\"version\";s:12:\"9.4.0-alpha1\";s:3:\"tag\";s:12:\"9.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.4.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1651875606\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.3.22\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.22\";s:7:\"version\";s:6:\"9.3.22\";s:3:\"tag\";s:6:\"9.3.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.22\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.22.tar.gz\";s:4:\"date\";s:10:\"1664382666\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.21\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.21\";s:7:\"version\";s:6:\"9.3.21\";s:3:\"tag\";s:6:\"9.3.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.21\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.21.tar.gz\";s:4:\"date\";s:10:\"1659544886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.20\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.20\";s:7:\"version\";s:6:\"9.3.20\";s:3:\"tag\";s:6:\"9.3.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.20.tar.gz\";s:4:\"date\";s:10:\"1659037977\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.19\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.19\";s:7:\"version\";s:6:\"9.3.19\";s:3:\"tag\";s:6:\"9.3.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.19.tar.gz\";s:4:\"date\";s:10:\"1658333887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.18\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.18\";s:7:\"version\";s:6:\"9.3.18\";s:3:\"tag\";s:6:\"9.3.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.18.tar.gz\";s:4:\"date\";s:10:\"1657238772\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.17\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.17\";s:7:\"version\";s:6:\"9.3.17\";s:3:\"tag\";s:6:\"9.3.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.17.tar.gz\";s:4:\"date\";s:10:\"1655846622\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.16\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.16\";s:7:\"version\";s:6:\"9.3.16\";s:3:\"tag\";s:6:\"9.3.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.16.tar.gz\";s:4:\"date\";s:10:\"1654888736\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.15\";s:7:\"version\";s:6:\"9.3.15\";s:3:\"tag\";s:6:\"9.3.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.15.tar.gz\";s:4:\"date\";s:10:\"1654098765\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.14\";s:7:\"version\";s:6:\"9.3.14\";s:3:\"tag\";s:6:\"9.3.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.14.tar.gz\";s:4:\"date\";s:10:\"1653506291\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.13\";s:7:\"version\";s:6:\"9.3.13\";s:3:\"tag\";s:6:\"9.3.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.13.tar.gz\";s:4:\"date\";s:10:\"1652261874\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.12\";s:7:\"version\";s:6:\"9.3.12\";s:3:\"tag\";s:6:\"9.3.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.12.tar.gz\";s:4:\"date\";s:10:\"1650467536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.11\";s:7:\"version\";s:6:\"9.3.11\";s:3:\"tag\";s:6:\"9.3.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.11.tar.gz\";s:4:\"date\";s:10:\"1649897391\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.10\";s:7:\"version\";s:6:\"9.3.10\";s:3:\"tag\";s:6:\"9.3.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.10.tar.gz\";s:4:\"date\";s:10:\"1649890098\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.9\";s:7:\"version\";s:5:\"9.3.9\";s:3:\"tag\";s:5:\"9.3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.9.tar.gz\";s:4:\"date\";s:10:\"1647899360\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.8\";s:7:\"version\";s:5:\"9.3.8\";s:3:\"tag\";s:5:\"9.3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.8.tar.gz\";s:4:\"date\";s:10:\"1647446914\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.7\";s:7:\"version\";s:5:\"9.3.7\";s:3:\"tag\";s:5:\"9.3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.7.tar.gz\";s:4:\"date\";s:10:\"1646300599\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.6\";s:7:\"version\";s:5:\"9.3.6\";s:3:\"tag\";s:5:\"9.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.6.tar.gz\";s:4:\"date\";s:10:\"1645029460\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.5\";s:7:\"version\";s:5:\"9.3.5\";s:3:\"tag\";s:5:\"9.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.5.tar.gz\";s:4:\"date\";s:10:\"1644011676\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.4\";s:7:\"version\";s:5:\"9.3.4\";s:3:\"tag\";s:5:\"9.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.4.tar.gz\";s:4:\"date\";s:10:\"1643832805\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.3\";s:7:\"version\";s:5:\"9.3.3\";s:3:\"tag\";s:5:\"9.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.3.tar.gz\";s:4:\"date\";s:10:\"1642607769\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.2\";s:7:\"version\";s:5:\"9.3.2\";s:3:\"tag\";s:5:\"9.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.2.tar.gz\";s:4:\"date\";s:10:\"1641351799\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.1\";s:7:\"version\";s:5:\"9.3.1\";s:3:\"tag\";s:5:\"9.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.1.tar.gz\";s:4:\"date\";s:10:\"1641342679\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.0\";s:7:\"version\";s:5:\"9.3.0\";s:3:\"tag\";s:5:\"9.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.0.tar.gz\";s:4:\"date\";s:10:\"1639051276\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.3.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.3.0-rc1\";s:7:\"version\";s:9:\"9.3.0-rc1\";s:3:\"tag\";s:9:\"9.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.3.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1637959424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta3\";s:7:\"version\";s:11:\"9.3.0-beta3\";s:3:\"tag\";s:11:\"9.3.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1637764182\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta2\";s:7:\"version\";s:11:\"9.3.0-beta2\";s:3:\"tag\";s:11:\"9.3.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1637196496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta1\";s:7:\"version\";s:11:\"9.3.0-beta1\";s:3:\"tag\";s:11:\"9.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1636746050\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.3.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.3.0-alpha1\";s:7:\"version\";s:12:\"9.3.0-alpha1\";s:3:\"tag\";s:12:\"9.3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.3.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1635510285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.2.21\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.21\";s:7:\"version\";s:6:\"9.2.21\";s:3:\"tag\";s:6:\"9.2.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.21\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.21.tar.gz\";s:4:\"date\";s:10:\"1654889475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.20\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.20\";s:7:\"version\";s:6:\"9.2.20\";s:3:\"tag\";s:6:\"9.2.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.20.tar.gz\";s:4:\"date\";s:10:\"1653507225\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.19\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.19\";s:7:\"version\";s:6:\"9.2.19\";s:3:\"tag\";s:6:\"9.2.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.19.tar.gz\";s:4:\"date\";s:10:\"1652306637\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.18\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.18\";s:7:\"version\";s:6:\"9.2.18\";s:3:\"tag\";s:6:\"9.2.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.18.tar.gz\";s:4:\"date\";s:10:\"1650466972\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.17\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.17\";s:7:\"version\";s:6:\"9.2.17\";s:3:\"tag\";s:6:\"9.2.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.17.tar.gz\";s:4:\"date\";s:10:\"1649898006\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.16\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.16\";s:7:\"version\";s:6:\"9.2.16\";s:3:\"tag\";s:6:\"9.2.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.16.tar.gz\";s:4:\"date\";s:10:\"1647898826\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.15\";s:7:\"version\";s:6:\"9.2.15\";s:3:\"tag\";s:6:\"9.2.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.15.tar.gz\";s:4:\"date\";s:10:\"1647447411\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.14\";s:7:\"version\";s:6:\"9.2.14\";s:3:\"tag\";s:6:\"9.2.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.14.tar.gz\";s:4:\"date\";s:10:\"1647027629\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.13\";s:7:\"version\";s:6:\"9.2.13\";s:3:\"tag\";s:6:\"9.2.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.13.tar.gz\";s:4:\"date\";s:10:\"1645029955\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.12\";s:7:\"version\";s:6:\"9.2.12\";s:3:\"tag\";s:6:\"9.2.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.12.tar.gz\";s:4:\"date\";s:10:\"1644012448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.11\";s:7:\"version\";s:6:\"9.2.11\";s:3:\"tag\";s:6:\"9.2.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.11.tar.gz\";s:4:\"date\";s:10:\"1642608353\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.10\";s:7:\"version\";s:6:\"9.2.10\";s:3:\"tag\";s:6:\"9.2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.10.tar.gz\";s:4:\"date\";s:10:\"1637765544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.9\";s:7:\"version\";s:5:\"9.2.9\";s:3:\"tag\";s:5:\"9.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.9.tar.gz\";s:4:\"date\";s:10:\"1637184936\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.8\";s:7:\"version\";s:5:\"9.2.8\";s:3:\"tag\";s:5:\"9.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.8.tar.gz\";s:4:\"date\";s:10:\"1635961216\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.7\";s:7:\"version\";s:5:\"9.2.7\";s:3:\"tag\";s:5:\"9.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.7.tar.gz\";s:4:\"date\";s:10:\"1633544267\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.6\";s:7:\"version\";s:5:\"9.2.6\";s:3:\"tag\";s:5:\"9.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.6.tar.gz\";s:4:\"date\";s:10:\"1631721555\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.5\";s:7:\"version\";s:5:\"9.2.5\";s:3:\"tag\";s:5:\"9.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.5.tar.gz\";s:4:\"date\";s:10:\"1630534729\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.4\";s:7:\"version\";s:5:\"9.2.4\";s:3:\"tag\";s:5:\"9.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.4.tar.gz\";s:4:\"date\";s:10:\"1628791178\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.3\";s:7:\"version\";s:5:\"9.2.3\";s:3:\"tag\";s:5:\"9.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.3.tar.gz\";s:4:\"date\";s:10:\"1627997922\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.2\";s:7:\"version\";s:5:\"9.2.2\";s:3:\"tag\";s:5:\"9.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.2.tar.gz\";s:4:\"date\";s:10:\"1626882385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.1\";s:7:\"version\";s:5:\"9.2.1\";s:3:\"tag\";s:5:\"9.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.1.tar.gz\";s:4:\"date\";s:10:\"1625664286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.0\";s:7:\"version\";s:5:\"9.2.0\";s:3:\"tag\";s:5:\"9.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.0.tar.gz\";s:4:\"date\";s:10:\"1623847798\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.2.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.2.0-rc1\";s:7:\"version\";s:9:\"9.2.0-rc1\";s:3:\"tag\";s:9:\"9.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.2.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1623080867\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta3\";s:7:\"version\";s:11:\"9.2.0-beta3\";s:3:\"tag\";s:11:\"9.2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1622207568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta2\";s:7:\"version\";s:11:\"9.2.0-beta2\";s:3:\"tag\";s:11:\"9.2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1622068611\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta1\";s:7:\"version\";s:11:\"9.2.0-beta1\";s:3:\"tag\";s:11:\"9.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1621506248\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.2.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.2.0-alpha1\";s:7:\"version\";s:12:\"9.2.0-alpha1\";s:3:\"tag\";s:12:\"9.2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.2.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1620291652\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.1.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.15\";s:7:\"version\";s:6:\"9.1.15\";s:3:\"tag\";s:6:\"9.1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.15.tar.gz\";s:4:\"date\";s:10:\"1637766681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.14\";s:7:\"version\";s:6:\"9.1.14\";s:3:\"tag\";s:6:\"9.1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.14.tar.gz\";s:4:\"date\";s:10:\"1637185450\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.13\";s:7:\"version\";s:6:\"9.1.13\";s:3:\"tag\";s:6:\"9.1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.13.tar.gz\";s:4:\"date\";s:10:\"1631722011\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.12\";s:7:\"version\";s:6:\"9.1.12\";s:3:\"tag\";s:6:\"9.1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.12.tar.gz\";s:4:\"date\";s:10:\"1628791786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.11\";s:7:\"version\";s:6:\"9.1.11\";s:3:\"tag\";s:6:\"9.1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.11.tar.gz\";s:4:\"date\";s:10:\"1626882849\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.10\";s:7:\"version\";s:6:\"9.1.10\";s:3:\"tag\";s:6:\"9.1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.10.tar.gz\";s:4:\"date\";s:10:\"1622828120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.9\";s:7:\"version\";s:5:\"9.1.9\";s:3:\"tag\";s:5:\"9.1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.9.tar.gz\";s:4:\"date\";s:10:\"1622056478\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.8\";s:7:\"version\";s:5:\"9.1.8\";s:3:\"tag\";s:5:\"9.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.8.tar.gz\";s:4:\"date\";s:10:\"1620214182\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.7\";s:7:\"version\";s:5:\"9.1.7\";s:3:\"tag\";s:5:\"9.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.7.tar.gz\";s:4:\"date\";s:10:\"1619022156\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.6\";s:7:\"version\";s:5:\"9.1.6\";s:3:\"tag\";s:5:\"9.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.6.tar.gz\";s:4:\"date\";s:10:\"1617795446\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.5\";s:7:\"version\";s:5:\"9.1.5\";s:3:\"tag\";s:5:\"9.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.5.tar.gz\";s:4:\"date\";s:10:\"1614869503\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.4\";s:7:\"version\";s:5:\"9.1.4\";s:3:\"tag\";s:5:\"9.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.4.tar.gz\";s:4:\"date\";s:10:\"1612380948\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.3\";s:7:\"version\";s:5:\"9.1.3\";s:3:\"tag\";s:5:\"9.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.3.tar.gz\";s:4:\"date\";s:10:\"1611161215\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.2\";s:7:\"version\";s:5:\"9.1.2\";s:3:\"tag\";s:5:\"9.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.2.tar.gz\";s:4:\"date\";s:10:\"1609984407\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.1\";s:7:\"version\";s:5:\"9.1.1\";s:3:\"tag\";s:5:\"9.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.1.tar.gz\";s:4:\"date\";s:10:\"1609979034\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.0\";s:7:\"version\";s:5:\"9.1.0\";s:3:\"tag\";s:5:\"9.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.0.tar.gz\";s:4:\"date\";s:10:\"1606933254\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.1.0-rc3\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc3\";s:7:\"version\";s:9:\"9.1.0-rc3\";s:3:\"tag\";s:9:\"9.1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1606357271\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.1.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc2\";s:7:\"version\";s:9:\"9.1.0-rc2\";s:3:\"tag\";s:9:\"9.1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1606332982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.1.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc1\";s:7:\"version\";s:9:\"9.1.0-rc1\";s:3:\"tag\";s:9:\"9.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1605722782\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.1.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.1.0-beta1\";s:7:\"version\";s:11:\"9.1.0-beta1\";s:3:\"tag\";s:11:\"9.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.1.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1604672644\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.1.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.1.0-alpha1\";s:7:\"version\";s:12:\"9.1.0-alpha1\";s:3:\"tag\";s:12:\"9.1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.1.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1603466665\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.0.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.14\";s:7:\"version\";s:6:\"9.0.14\";s:3:\"tag\";s:6:\"9.0.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.14.tar.gz\";s:4:\"date\";s:10:\"1622055778\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.13\";s:7:\"version\";s:6:\"9.0.13\";s:3:\"tag\";s:6:\"9.0.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.13.tar.gz\";s:4:\"date\";s:10:\"1620218506\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.12\";s:7:\"version\";s:6:\"9.0.12\";s:3:\"tag\";s:6:\"9.0.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.12.tar.gz\";s:4:\"date\";s:10:\"1619020951\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.11\";s:7:\"version\";s:6:\"9.0.11\";s:3:\"tag\";s:6:\"9.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.11.tar.gz\";s:4:\"date\";s:10:\"1611161749\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.10\";s:7:\"version\";s:6:\"9.0.10\";s:3:\"tag\";s:6:\"9.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.10.tar.gz\";s:4:\"date\";s:10:\"1607029536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.9\";s:7:\"version\";s:5:\"9.0.9\";s:3:\"tag\";s:5:\"9.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.9.tar.gz\";s:4:\"date\";s:10:\"1606359757\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.8\";s:7:\"version\";s:5:\"9.0.8\";s:3:\"tag\";s:5:\"9.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.8.tar.gz\";s:4:\"date\";s:10:\"1605720638\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.7\";s:7:\"version\";s:5:\"9.0.7\";s:3:\"tag\";s:5:\"9.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.7.tar.gz\";s:4:\"date\";s:10:\"1602100055\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.6\";s:7:\"version\";s:5:\"9.0.6\";s:3:\"tag\";s:5:\"9.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.6.tar.gz\";s:4:\"date\";s:10:\"1600275813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.5\";s:7:\"version\";s:5:\"9.0.5\";s:3:\"tag\";s:5:\"9.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.5.tar.gz\";s:4:\"date\";s:10:\"1599167739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.4\";s:7:\"version\";s:5:\"9.0.4\";s:3:\"tag\";s:5:\"9.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.4.tar.gz\";s:4:\"date\";s:10:\"1599046734\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.3\";s:7:\"version\";s:5:\"9.0.3\";s:3:\"tag\";s:5:\"9.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.3.tar.gz\";s:4:\"date\";s:10:\"1596664575\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.2\";s:7:\"version\";s:5:\"9.0.2\";s:3:\"tag\";s:5:\"9.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.2.tar.gz\";s:4:\"date\";s:10:\"1594237418\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.1\";s:7:\"version\";s:5:\"9.0.1\";s:3:\"tag\";s:5:\"9.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.1.tar.gz\";s:4:\"date\";s:10:\"1592417721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.0\";s:7:\"version\";s:5:\"9.0.0\";s:3:\"tag\";s:5:\"9.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.0.tar.gz\";s:4:\"date\";s:10:\"1591221685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.0.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.0.0-rc1\";s:7:\"version\";s:9:\"9.0.0-rc1\";s:3:\"tag\";s:9:\"9.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.0.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1590187579\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta3\";s:7:\"version\";s:11:\"9.0.0-beta3\";s:3:\"tag\";s:11:\"9.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1589587936\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta2\";s:7:\"version\";s:11:\"9.0.0-beta2\";s:3:\"tag\";s:11:\"9.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1585597395\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta1\";s:7:\"version\";s:11:\"9.0.0-beta1\";s:3:\"tag\";s:11:\"9.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1584734060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.0.0-alpha2\";a:10:{s:4:\"name\";s:19:\"drupal 9.0.0-alpha2\";s:7:\"version\";s:12:\"9.0.0-alpha2\";s:3:\"tag\";s:12:\"9.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.0.0-alpha2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1583349043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:12:\"9.0.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.0.0-alpha1\";s:7:\"version\";s:12:\"9.0.0-alpha1\";s:3:\"tag\";s:12:\"9.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.0.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1581447927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.9.20\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.20\";s:7:\"version\";s:6:\"8.9.20\";s:3:\"tag\";s:6:\"8.9.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.20.tar.gz\";s:4:\"date\";s:10:\"1637185966\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.19\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.19\";s:7:\"version\";s:6:\"8.9.19\";s:3:\"tag\";s:6:\"8.9.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.19.tar.gz\";s:4:\"date\";s:10:\"1631722431\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.18\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.18\";s:7:\"version\";s:6:\"8.9.18\";s:3:\"tag\";s:6:\"8.9.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.18.tar.gz\";s:4:\"date\";s:10:\"1628792296\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.17\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.17\";s:7:\"version\";s:6:\"8.9.17\";s:3:\"tag\";s:6:\"8.9.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.17.tar.gz\";s:4:\"date\";s:10:\"1626883324\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.16\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.16\";s:7:\"version\";s:6:\"8.9.16\";s:3:\"tag\";s:6:\"8.9.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.16.tar.gz\";s:4:\"date\";s:10:\"1622058087\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.15\";s:7:\"version\";s:6:\"8.9.15\";s:3:\"tag\";s:6:\"8.9.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.15.tar.gz\";s:4:\"date\";s:10:\"1620216983\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.14\";s:7:\"version\";s:6:\"8.9.14\";s:3:\"tag\";s:6:\"8.9.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.14.tar.gz\";s:4:\"date\";s:10:\"1619021518\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.13\";s:7:\"version\";s:6:\"8.9.13\";s:3:\"tag\";s:6:\"8.9.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.13.tar.gz\";s:4:\"date\";s:10:\"1611162272\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.12\";s:7:\"version\";s:6:\"8.9.12\";s:3:\"tag\";s:6:\"8.9.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.12.tar.gz\";s:4:\"date\";s:10:\"1609977009\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.11\";s:7:\"version\";s:6:\"8.9.11\";s:3:\"tag\";s:6:\"8.9.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.11.tar.gz\";s:4:\"date\";s:10:\"1607030087\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.10\";s:7:\"version\";s:6:\"8.9.10\";s:3:\"tag\";s:6:\"8.9.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.10.tar.gz\";s:4:\"date\";s:10:\"1606360301\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.9\";s:7:\"version\";s:5:\"8.9.9\";s:3:\"tag\";s:5:\"8.9.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.9.tar.gz\";s:4:\"date\";s:10:\"1605721120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.8\";s:7:\"version\";s:5:\"8.9.8\";s:3:\"tag\";s:5:\"8.9.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.8.tar.gz\";s:4:\"date\";s:10:\"1604595269\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.7\";s:7:\"version\";s:5:\"8.9.7\";s:3:\"tag\";s:5:\"8.9.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.7.tar.gz\";s:4:\"date\";s:10:\"1602100507\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.6\";s:7:\"version\";s:5:\"8.9.6\";s:3:\"tag\";s:5:\"8.9.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.6.tar.gz\";s:4:\"date\";s:10:\"1600276267\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.5\";s:7:\"version\";s:5:\"8.9.5\";s:3:\"tag\";s:5:\"8.9.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.5.tar.gz\";s:4:\"date\";s:10:\"1599168205\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.4\";s:7:\"version\";s:5:\"8.9.4\";s:3:\"tag\";s:5:\"8.9.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.4.tar.gz\";s:4:\"date\";s:10:\"1599047691\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.3\";s:7:\"version\";s:5:\"8.9.3\";s:3:\"tag\";s:5:\"8.9.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.3.tar.gz\";s:4:\"date\";s:10:\"1596665051\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.2\";s:7:\"version\";s:5:\"8.9.2\";s:3:\"tag\";s:5:\"8.9.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.2.tar.gz\";s:4:\"date\";s:10:\"1594237961\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.1\";s:7:\"version\";s:5:\"8.9.1\";s:3:\"tag\";s:5:\"8.9.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.1.tar.gz\";s:4:\"date\";s:10:\"1592418237\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.0\";s:7:\"version\";s:5:\"8.9.0\";s:3:\"tag\";s:5:\"8.9.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.0.tar.gz\";s:4:\"date\";s:10:\"1591204117\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.9.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.9.0-rc1\";s:7:\"version\";s:9:\"8.9.0-rc1\";s:3:\"tag\";s:9:\"8.9.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.9.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1590189096\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta3\";s:7:\"version\";s:11:\"8.9.0-beta3\";s:3:\"tag\";s:11:\"8.9.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1589746375\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta2\";s:7:\"version\";s:11:\"8.9.0-beta2\";s:3:\"tag\";s:11:\"8.9.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1585863226\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta1\";s:7:\"version\";s:11:\"8.9.0-beta1\";s:3:\"tag\";s:11:\"8.9.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1585263710\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"8.8.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.12\";s:7:\"version\";s:6:\"8.8.12\";s:3:\"tag\";s:6:\"8.8.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.12.tar.gz\";s:4:\"date\";s:10:\"1606360866\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.8.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.11\";s:7:\"version\";s:6:\"8.8.11\";s:3:\"tag\";s:6:\"8.8.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.11.tar.gz\";s:4:\"date\";s:10:\"1605721628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.8.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.10\";s:7:\"version\";s:6:\"8.8.10\";s:3:\"tag\";s:6:\"8.8.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.10.tar.gz\";s:4:\"date\";s:10:\"1600276704\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.9\";s:7:\"version\";s:5:\"8.8.9\";s:3:\"tag\";s:5:\"8.8.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.9.tar.gz\";s:4:\"date\";s:10:\"1599168716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.8\";s:7:\"version\";s:5:\"8.8.8\";s:3:\"tag\";s:5:\"8.8.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.8.tar.gz\";s:4:\"date\";s:10:\"1592418750\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.7\";s:7:\"version\";s:5:\"8.8.7\";s:3:\"tag\";s:5:\"8.8.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.7.tar.gz\";s:4:\"date\";s:10:\"1591203837\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.6\";s:7:\"version\";s:5:\"8.8.6\";s:3:\"tag\";s:5:\"8.8.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.6.tar.gz\";s:4:\"date\";s:10:\"1589989060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.5\";s:7:\"version\";s:5:\"8.8.5\";s:3:\"tag\";s:5:\"8.8.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.5.tar.gz\";s:4:\"date\";s:10:\"1585861530\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.4\";s:7:\"version\";s:5:\"8.8.4\";s:3:\"tag\";s:5:\"8.8.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.4.tar.gz\";s:4:\"date\";s:10:\"1584560524\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.3\";s:7:\"version\";s:5:\"8.8.3\";s:3:\"tag\";s:5:\"8.8.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.3.tar.gz\";s:4:\"date\";s:10:\"1583347094\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.2\";s:7:\"version\";s:5:\"8.8.2\";s:3:\"tag\";s:5:\"8.8.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.2.tar.gz\";s:4:\"date\";s:10:\"1580598849\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.1\";s:7:\"version\";s:5:\"8.8.1\";s:3:\"tag\";s:5:\"8.8.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.1.tar.gz\";s:4:\"date\";s:10:\"1576695785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.0\";s:7:\"version\";s:5:\"8.8.0\";s:3:\"tag\";s:5:\"8.8.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.0.tar.gz\";s:4:\"date\";s:10:\"1575450481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.8.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.8.0-rc1\";s:7:\"version\";s:9:\"8.8.0-rc1\";s:3:\"tag\";s:9:\"8.8.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.8.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1574462580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.8.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.8.0-beta1\";s:7:\"version\";s:11:\"8.8.0-beta1\";s:3:\"tag\";s:11:\"8.8.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.8.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1573256280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.8.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.8.0-alpha1\";s:7:\"version\";s:12:\"8.8.0-alpha1\";s:3:\"tag\";s:12:\"8.8.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.8.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1571355784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.7.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.14\";s:7:\"version\";s:6:\"8.7.14\";s:3:\"tag\";s:6:\"8.7.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.14.tar.gz\";s:4:\"date\";s:10:\"1589988665\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.13\";s:7:\"version\";s:6:\"8.7.13\";s:3:\"tag\";s:6:\"8.7.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.13.tar.gz\";s:4:\"date\";s:10:\"1585861883\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.12\";s:7:\"version\";s:6:\"8.7.12\";s:3:\"tag\";s:6:\"8.7.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.12.tar.gz\";s:4:\"date\";s:10:\"1584552250\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.11\";s:7:\"version\";s:6:\"8.7.11\";s:3:\"tag\";s:6:\"8.7.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.11.tar.gz\";s:4:\"date\";s:10:\"1576695785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.10\";s:7:\"version\";s:6:\"8.7.10\";s:3:\"tag\";s:6:\"8.7.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.10.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.9\";s:7:\"version\";s:5:\"8.7.9\";s:3:\"tag\";s:5:\"8.7.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.9.tar.gz\";s:4:\"date\";s:10:\"1573063387\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.8\";s:7:\"version\";s:5:\"8.7.8\";s:3:\"tag\";s:5:\"8.7.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.8.tar.gz\";s:4:\"date\";s:10:\"1570044484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.7\";s:7:\"version\";s:5:\"8.7.7\";s:3:\"tag\";s:5:\"8.7.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.7.tar.gz\";s:4:\"date\";s:10:\"1567593185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.6\";s:7:\"version\";s:5:\"8.7.6\";s:3:\"tag\";s:5:\"8.7.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.6.tar.gz\";s:4:\"date\";s:10:\"1565206385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.5\";s:7:\"version\";s:5:\"8.7.5\";s:3:\"tag\";s:5:\"8.7.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.5.tar.gz\";s:4:\"date\";s:10:\"1563380885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.4\";s:7:\"version\";s:5:\"8.7.4\";s:3:\"tag\";s:5:\"8.7.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.4.tar.gz\";s:4:\"date\";s:10:\"1562225587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.3\";s:7:\"version\";s:5:\"8.7.3\";s:3:\"tag\";s:5:\"8.7.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.3.tar.gz\";s:4:\"date\";s:10:\"1559762581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.2\";s:7:\"version\";s:5:\"8.7.2\";s:3:\"tag\";s:5:\"8.7.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.2.tar.gz\";s:4:\"date\";s:10:\"1558597086\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.1\";s:7:\"version\";s:5:\"8.7.1\";s:3:\"tag\";s:5:\"8.7.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.1.tar.gz\";s:4:\"date\";s:10:\"1557335588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.0\";s:7:\"version\";s:5:\"8.7.0\";s:3:\"tag\";s:5:\"8.7.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.0.tar.gz\";s:4:\"date\";s:10:\"1556737085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.7.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.7.0-rc1\";s:7:\"version\";s:9:\"8.7.0-rc1\";s:3:\"tag\";s:9:\"8.7.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.7.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1555603385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.7.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.7.0-beta2\";s:7:\"version\";s:11:\"8.7.0-beta2\";s:3:\"tag\";s:11:\"8.7.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.7.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1554684784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.7.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.7.0-beta1\";s:7:\"version\";s:11:\"8.7.0-beta1\";s:3:\"tag\";s:11:\"8.7.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.7.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1553881681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.7.0-alpha2\";a:10:{s:4:\"name\";s:19:\"drupal 8.7.0-alpha2\";s:7:\"version\";s:12:\"8.7.0-alpha2\";s:3:\"tag\";s:12:\"8.7.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.7.0-alpha2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1553106180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:12:\"8.7.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.7.0-alpha1\";s:7:\"version\";s:12:\"8.7.0-alpha1\";s:3:\"tag\";s:12:\"8.7.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.7.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1552602484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.6.18\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.18\";s:7:\"version\";s:6:\"8.6.18\";s:3:\"tag\";s:6:\"8.6.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.18.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.17\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.17\";s:7:\"version\";s:6:\"8.6.17\";s:3:\"tag\";s:6:\"8.6.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.17.tar.gz\";s:4:\"date\";s:10:\"1560756785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.16\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.16\";s:7:\"version\";s:6:\"8.6.16\";s:3:\"tag\";s:6:\"8.6.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.16.tar.gz\";s:4:\"date\";s:10:\"1557335588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.15\";s:7:\"version\";s:6:\"8.6.15\";s:3:\"tag\";s:6:\"8.6.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.15.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.14\";s:7:\"version\";s:6:\"8.6.14\";s:3:\"tag\";s:6:\"8.6.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.14.tar.gz\";s:4:\"date\";s:10:\"1554688384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.13\";s:7:\"version\";s:6:\"8.6.13\";s:3:\"tag\";s:6:\"8.6.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.13.tar.gz\";s:4:\"date\";s:10:\"1553099584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.12\";s:7:\"version\";s:6:\"8.6.12\";s:3:\"tag\";s:6:\"8.6.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.12.tar.gz\";s:4:\"date\";s:10:\"1552601584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.11\";s:7:\"version\";s:6:\"8.6.11\";s:3:\"tag\";s:6:\"8.6.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.11.tar.gz\";s:4:\"date\";s:10:\"1552511584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.10\";s:7:\"version\";s:6:\"8.6.10\";s:3:\"tag\";s:6:\"8.6.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.10.tar.gz\";s:4:\"date\";s:10:\"1550691784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.9\";s:7:\"version\";s:5:\"8.6.9\";s:3:\"tag\";s:5:\"8.6.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.9.tar.gz\";s:4:\"date\";s:10:\"1549628580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.8\";s:7:\"version\";s:5:\"8.6.8\";s:3:\"tag\";s:5:\"8.6.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.8.tar.gz\";s:4:\"date\";s:10:\"1549466580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.7\";s:7:\"version\";s:5:\"8.6.7\";s:3:\"tag\";s:5:\"8.6.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.7.tar.gz\";s:4:\"date\";s:10:\"1547682180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.6\";s:7:\"version\";s:5:\"8.6.6\";s:3:\"tag\";s:5:\"8.6.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.6.tar.gz\";s:4:\"date\";s:10:\"1547663557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.5\";s:7:\"version\";s:5:\"8.6.5\";s:3:\"tag\";s:5:\"8.6.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.5.tar.gz\";s:4:\"date\";s:10:\"1546467485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.4\";s:7:\"version\";s:5:\"8.6.4\";s:3:\"tag\";s:5:\"8.6.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.4.tar.gz\";s:4:\"date\";s:10:\"1544011681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.3\";s:7:\"version\";s:5:\"8.6.3\";s:3:\"tag\";s:5:\"8.6.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.3.tar.gz\";s:4:\"date\";s:10:\"1541602684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.2\";s:7:\"version\";s:5:\"8.6.2\";s:3:\"tag\";s:5:\"8.6.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.2.tar.gz\";s:4:\"date\";s:10:\"1539816180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.1\";s:7:\"version\";s:5:\"8.6.1\";s:3:\"tag\";s:5:\"8.6.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.1.tar.gz\";s:4:\"date\";s:10:\"1536585780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.0\";s:7:\"version\";s:5:\"8.6.0\";s:3:\"tag\";s:5:\"8.6.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.0.tar.gz\";s:4:\"date\";s:10:\"1536186480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.6.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.6.0-rc1\";s:7:\"version\";s:9:\"8.6.0-rc1\";s:3:\"tag\";s:9:\"8.6.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.6.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1534532580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.6.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.6.0-beta2\";s:7:\"version\";s:11:\"8.6.0-beta2\";s:3:\"tag\";s:11:\"8.6.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.6.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1533298080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.6.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.6.0-beta1\";s:7:\"version\";s:11:\"8.6.0-beta1\";s:3:\"tag\";s:11:\"8.6.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.6.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1533270485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.6.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.6.0-alpha1\";s:7:\"version\";s:12:\"8.6.0-alpha1\";s:3:\"tag\";s:12:\"8.6.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.6.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1532033881\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.5.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.15\";s:7:\"version\";s:6:\"8.5.15\";s:3:\"tag\";s:6:\"8.5.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.15.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.14\";s:7:\"version\";s:6:\"8.5.14\";s:3:\"tag\";s:6:\"8.5.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.14.tar.gz\";s:4:\"date\";s:10:\"1553099584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.13\";s:7:\"version\";s:6:\"8.5.13\";s:3:\"tag\";s:6:\"8.5.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.13.tar.gz\";s:4:\"date\";s:10:\"1552601584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.12\";s:7:\"version\";s:6:\"8.5.12\";s:3:\"tag\";s:6:\"8.5.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.12.tar.gz\";s:4:\"date\";s:10:\"1552511584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.11\";s:7:\"version\";s:6:\"8.5.11\";s:3:\"tag\";s:6:\"8.5.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.11.tar.gz\";s:4:\"date\";s:10:\"1550691784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.10\";s:7:\"version\";s:6:\"8.5.10\";s:3:\"tag\";s:6:\"8.5.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.10.tar.gz\";s:4:\"date\";s:10:\"1547682180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.9\";s:7:\"version\";s:5:\"8.5.9\";s:3:\"tag\";s:5:\"8.5.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.9.tar.gz\";s:4:\"date\";s:10:\"1547663557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.8\";s:7:\"version\";s:5:\"8.5.8\";s:3:\"tag\";s:5:\"8.5.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.8.tar.gz\";s:4:\"date\";s:10:\"1539816180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.7\";s:7:\"version\";s:5:\"8.5.7\";s:3:\"tag\";s:5:\"8.5.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.7.tar.gz\";s:4:\"date\";s:10:\"1536187080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.6\";s:7:\"version\";s:5:\"8.5.6\";s:3:\"tag\";s:5:\"8.5.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.6.tar.gz\";s:4:\"date\";s:10:\"1533156780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.5\";s:7:\"version\";s:5:\"8.5.5\";s:3:\"tag\";s:5:\"8.5.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.5.tar.gz\";s:4:\"date\";s:10:\"1530738820\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.4\";s:7:\"version\";s:5:\"8.5.4\";s:3:\"tag\";s:5:\"8.5.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.4.tar.gz\";s:4:\"date\";s:10:\"1528319584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.3\";s:7:\"version\";s:5:\"8.5.3\";s:3:\"tag\";s:5:\"8.5.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.3.tar.gz\";s:4:\"date\";s:10:\"1524672780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.2\";s:7:\"version\";s:5:\"8.5.2\";s:3:\"tag\";s:5:\"8.5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.2.tar.gz\";s:4:\"date\";s:10:\"1524073147\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.1\";s:7:\"version\";s:5:\"8.5.1\";s:3:\"tag\";s:5:\"8.5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.1.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.0\";s:7:\"version\";s:5:\"8.5.0\";s:3:\"tag\";s:5:\"8.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.0.tar.gz\";s:4:\"date\";s:10:\"1520457780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.5.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.5.0-rc1\";s:7:\"version\";s:9:\"8.5.0-rc1\";s:3:\"tag\";s:9:\"8.5.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.5.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1519234680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";i:2;s:9:\"Bug fixes\";i:3;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.5.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.5.0-beta1\";s:7:\"version\";s:11:\"8.5.0-beta1\";s:3:\"tag\";s:11:\"8.5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.5.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1518211380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.5.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.5.0-alpha1\";s:7:\"version\";s:12:\"8.5.0-alpha1\";s:3:\"tag\";s:12:\"8.5.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.5.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1516320484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.4.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.8\";s:7:\"version\";s:5:\"8.4.8\";s:3:\"tag\";s:5:\"8.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.8.tar.gz\";s:4:\"date\";s:10:\"1524672780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.7\";s:7:\"version\";s:5:\"8.4.7\";s:3:\"tag\";s:5:\"8.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.7.tar.gz\";s:4:\"date\";s:10:\"1524073147\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.6\";s:7:\"version\";s:5:\"8.4.6\";s:3:\"tag\";s:5:\"8.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.6.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.5\";s:7:\"version\";s:5:\"8.4.5\";s:3:\"tag\";s:5:\"8.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.5.tar.gz\";s:4:\"date\";s:10:\"1519234680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.4\";s:7:\"version\";s:5:\"8.4.4\";s:3:\"tag\";s:5:\"8.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.4.tar.gz\";s:4:\"date\";s:10:\"1515021185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.3\";s:7:\"version\";s:5:\"8.4.3\";s:3:\"tag\";s:5:\"8.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.3.tar.gz\";s:4:\"date\";s:10:\"1512600784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.2\";s:7:\"version\";s:5:\"8.4.2\";s:3:\"tag\";s:5:\"8.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.2.tar.gz\";s:4:\"date\";s:10:\"1509719885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.1\";s:7:\"version\";s:5:\"8.4.1\";s:3:\"tag\";s:5:\"8.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.1.tar.gz\";s:4:\"date\";s:10:\"1509562384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.0\";s:7:\"version\";s:5:\"8.4.0\";s:3:\"tag\";s:5:\"8.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.0.tar.gz\";s:4:\"date\";s:10:\"1507146244\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.4.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.0-rc2\";s:7:\"version\";s:9:\"8.4.0-rc2\";s:3:\"tag\";s:9:\"8.4.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1505911444\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.4.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.0-rc1\";s:7:\"version\";s:9:\"8.4.0-rc1\";s:3:\"tag\";s:9:\"8.4.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1504733043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.4.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.4.0-beta1\";s:7:\"version\";s:11:\"8.4.0-beta1\";s:3:\"tag\";s:11:\"8.4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.4.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1502992144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.4.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.4.0-alpha1\";s:7:\"version\";s:12:\"8.4.0-alpha1\";s:3:\"tag\";s:12:\"8.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.4.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1501790944\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.3.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.9\";s:7:\"version\";s:5:\"8.3.9\";s:3:\"tag\";s:5:\"8.3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.9.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.8\";s:7:\"version\";s:5:\"8.3.8\";s:3:\"tag\";s:5:\"8.3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.8.tar.gz\";s:4:\"date\";s:10:\"1520881985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";i:2;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.7\";s:7:\"version\";s:5:\"8.3.7\";s:3:\"tag\";s:5:\"8.3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.7.tar.gz\";s:4:\"date\";s:10:\"1502903903\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.6\";s:7:\"version\";s:5:\"8.3.6\";s:3:\"tag\";s:5:\"8.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.6.tar.gz\";s:4:\"date\";s:10:\"1501688043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.5\";s:7:\"version\";s:5:\"8.3.5\";s:3:\"tag\";s:5:\"8.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.5.tar.gz\";s:4:\"date\";s:10:\"1499274843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.4\";s:7:\"version\";s:5:\"8.3.4\";s:3:\"tag\";s:5:\"8.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.4.tar.gz\";s:4:\"date\";s:10:\"1498069442\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.3\";s:7:\"version\";s:5:\"8.3.3\";s:3:\"tag\";s:5:\"8.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.3.tar.gz\";s:4:\"date\";s:10:\"1496858041\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.2\";s:7:\"version\";s:5:\"8.3.2\";s:3:\"tag\";s:5:\"8.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.2.tar.gz\";s:4:\"date\";s:10:\"1493834585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.1\";s:7:\"version\";s:5:\"8.3.1\";s:3:\"tag\";s:5:\"8.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.1.tar.gz\";s:4:\"date\";s:10:\"1492622946\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.0\";s:7:\"version\";s:5:\"8.3.0\";s:3:\"tag\";s:5:\"8.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.0.tar.gz\";s:4:\"date\";s:10:\"1491439084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.3.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.0-rc2\";s:7:\"version\";s:9:\"8.3.0-rc2\";s:3:\"tag\";s:9:\"8.3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1489613583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.3.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.0-rc1\";s:7:\"version\";s:9:\"8.3.0-rc1\";s:3:\"tag\";s:9:\"8.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1488383284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.3.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.3.0-beta1\";s:7:\"version\";s:11:\"8.3.0-beta1\";s:3:\"tag\";s:11:\"8.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.3.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1487175783\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.3.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.3.0-alpha1\";s:7:\"version\";s:12:\"8.3.0-alpha1\";s:3:\"tag\";s:12:\"8.3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.3.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1485968583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.2.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.8\";s:7:\"version\";s:5:\"8.2.8\";s:3:\"tag\";s:5:\"8.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.8.tar.gz\";s:4:\"date\";s:10:\"1492622852\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.7\";s:7:\"version\";s:5:\"8.2.7\";s:3:\"tag\";s:5:\"8.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.7.tar.gz\";s:4:\"date\";s:10:\"1489609638\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.6\";s:7:\"version\";s:5:\"8.2.6\";s:3:\"tag\";s:5:\"8.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.6.tar.gz\";s:4:\"date\";s:10:\"1485975485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.5\";s:7:\"version\";s:5:\"8.2.5\";s:3:\"tag\";s:5:\"8.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.5.tar.gz\";s:4:\"date\";s:10:\"1483529942\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.4\";s:7:\"version\";s:5:\"8.2.4\";s:3:\"tag\";s:5:\"8.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.4.tar.gz\";s:4:\"date\";s:10:\"1481136784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.3\";s:7:\"version\";s:5:\"8.2.3\";s:3:\"tag\";s:5:\"8.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.3.tar.gz\";s:4:\"date\";s:10:\"1479322439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.2\";s:7:\"version\";s:5:\"8.2.2\";s:3:\"tag\";s:5:\"8.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.2.tar.gz\";s:4:\"date\";s:10:\"1478106542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.1\";s:7:\"version\";s:5:\"8.2.1\";s:3:\"tag\";s:5:\"8.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.1.tar.gz\";s:4:\"date\";s:10:\"1476181439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.0\";s:7:\"version\";s:5:\"8.2.0\";s:3:\"tag\";s:5:\"8.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.0.tar.gz\";s:4:\"date\";s:10:\"1475660639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.2.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.0-rc2\";s:7:\"version\";s:9:\"8.2.0-rc2\";s:3:\"tag\";s:9:\"8.2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1474484358\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.2.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.0-rc1\";s:7:\"version\";s:9:\"8.2.0-rc1\";s:3:\"tag\";s:9:\"8.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1473285089\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta3\";s:7:\"version\";s:11:\"8.2.0-beta3\";s:3:\"tag\";s:11:\"8.2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1472222475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta2\";s:7:\"version\";s:11:\"8.2.0-beta2\";s:3:\"tag\";s:11:\"8.2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1471710839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta1\";s:7:\"version\";s:11:\"8.2.0-beta1\";s:3:\"tag\";s:11:\"8.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1470230639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"8.1.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.1.10\";s:7:\"version\";s:6:\"8.1.10\";s:3:\"tag\";s:6:\"8.1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.1.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.1.10.tar.gz\";s:4:\"date\";s:10:\"1474478939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.9\";s:7:\"version\";s:5:\"8.1.9\";s:3:\"tag\";s:5:\"8.1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.9.tar.gz\";s:4:\"date\";s:10:\"1473276313\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.8\";s:7:\"version\";s:5:\"8.1.8\";s:3:\"tag\";s:5:\"8.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.8.tar.gz\";s:4:\"date\";s:10:\"1470233647\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.7\";s:7:\"version\";s:5:\"8.1.7\";s:3:\"tag\";s:5:\"8.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.7.tar.gz\";s:4:\"date\";s:10:\"1468855358\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.6\";s:7:\"version\";s:5:\"8.1.6\";s:3:\"tag\";s:5:\"8.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.6.tar.gz\";s:4:\"date\";s:10:\"1468242539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.5\";s:7:\"version\";s:5:\"8.1.5\";s:3:\"tag\";s:5:\"8.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.5.tar.gz\";s:4:\"date\";s:10:\"1467884639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.4\";s:7:\"version\";s:5:\"8.1.4\";s:3:\"tag\";s:5:\"8.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.4.tar.gz\";s:4:\"date\";s:10:\"1467810839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.3\";s:7:\"version\";s:5:\"8.1.3\";s:3:\"tag\";s:5:\"8.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.3.tar.gz\";s:4:\"date\";s:10:\"1466021480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.2\";s:7:\"version\";s:5:\"8.1.2\";s:3:\"tag\";s:5:\"8.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.2.tar.gz\";s:4:\"date\";s:10:\"1464824339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.1\";s:7:\"version\";s:5:\"8.1.1\";s:3:\"tag\";s:5:\"8.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.1.tar.gz\";s:4:\"date\";s:10:\"1462361039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.0\";s:7:\"version\";s:5:\"8.1.0\";s:3:\"tag\";s:5:\"8.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.0.tar.gz\";s:4:\"date\";s:10:\"1461118190\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.1.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.1.0-rc1\";s:7:\"version\";s:9:\"8.1.0-rc1\";s:3:\"tag\";s:9:\"8.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1459976639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.1.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.1.0-beta2\";s:7:\"version\";s:11:\"8.1.0-beta2\";s:3:\"tag\";s:11:\"8.1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.1.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1458699840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.1.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.1.0-beta1\";s:7:\"version\";s:11:\"8.1.0-beta1\";s:3:\"tag\";s:11:\"8.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.1.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1456975758\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:5:\"8.0.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.6\";s:7:\"version\";s:5:\"8.0.6\";s:3:\"tag\";s:5:\"8.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.6.tar.gz\";s:4:\"date\";s:10:\"1459900439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.5\";s:7:\"version\";s:5:\"8.0.5\";s:3:\"tag\";s:5:\"8.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.5.tar.gz\";s:4:\"date\";s:10:\"1456914839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.4\";s:7:\"version\";s:5:\"8.0.4\";s:3:\"tag\";s:5:\"8.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.4.tar.gz\";s:4:\"date\";s:10:\"1456341749\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.3\";s:7:\"version\";s:5:\"8.0.3\";s:3:\"tag\";s:5:\"8.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.3.tar.gz\";s:4:\"date\";s:10:\"1454489043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.2\";s:7:\"version\";s:5:\"8.0.2\";s:3:\"tag\";s:5:\"8.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.2.tar.gz\";s:4:\"date\";s:10:\"1452119939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.1\";s:7:\"version\";s:5:\"8.0.1\";s:3:\"tag\";s:5:\"8.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.1.tar.gz\";s:4:\"date\";s:10:\"1449066839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.0\";s:7:\"version\";s:5:\"8.0.0\";s:3:\"tag\";s:5:\"8.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.0.tar.gz\";s:4:\"date\";s:10:\"1447941840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.0.0-rc4\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc4\";s:7:\"version\";s:9:\"8.0.0-rc4\";s:3:\"tag\";s:9:\"8.0.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc4\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1447413840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc3\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc3\";s:7:\"version\";s:9:\"8.0.0-rc3\";s:3:\"tag\";s:9:\"8.0.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1446633239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc2\";s:7:\"version\";s:9:\"8.0.0-rc2\";s:3:\"tag\";s:9:\"8.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1445468639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc1\";s:7:\"version\";s:9:\"8.0.0-rc1\";s:3:\"tag\";s:9:\"8.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1444253039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta16\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta16\";s:7:\"version\";s:12:\"8.0.0-beta16\";s:3:\"tag\";s:12:\"8.0.0-beta16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta16\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta16.tar.gz\";s:4:\"date\";s:10:\"1443746640\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta15\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta15\";s:7:\"version\";s:12:\"8.0.0-beta15\";s:3:\"tag\";s:12:\"8.0.0-beta15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta15\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta15.tar.gz\";s:4:\"date\";s:10:\"1441357140\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta14\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta14\";s:7:\"version\";s:12:\"8.0.0-beta14\";s:3:\"tag\";s:12:\"8.0.0-beta14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta14.tar.gz\";s:4:\"date\";s:10:\"1438593539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta13\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta13\";s:7:\"version\";s:12:\"8.0.0-beta13\";s:3:\"tag\";s:12:\"8.0.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1438194539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta12\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta12\";s:7:\"version\";s:12:\"8.0.0-beta12\";s:3:\"tag\";s:12:\"8.0.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1435601583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta11\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta11\";s:7:\"version\";s:12:\"8.0.0-beta11\";s:3:\"tag\";s:12:\"8.0.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1432758481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta10\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta10\";s:7:\"version\";s:12:\"8.0.0-beta10\";s:3:\"tag\";s:12:\"8.0.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1430314681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta9\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta9\";s:7:\"version\";s:11:\"8.0.0-beta9\";s:3:\"tag\";s:11:\"8.0.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1427299981\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta7\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta7\";s:7:\"version\";s:11:\"8.0.0-beta7\";s:3:\"tag\";s:11:\"8.0.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1424875381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta6\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta6\";s:7:\"version\";s:11:\"8.0.0-beta6\";s:3:\"tag\";s:11:\"8.0.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1422443800\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta4\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta4\";s:7:\"version\";s:11:\"8.0.0-beta4\";s:3:\"tag\";s:11:\"8.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1418825280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta3\";s:7:\"version\";s:11:\"8.0.0-beta3\";s:3:\"tag\";s:11:\"8.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1415797380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta2\";s:7:\"version\";s:11:\"8.0.0-beta2\";s:3:\"tag\";s:11:\"8.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1413394161\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta1\";s:7:\"version\";s:11:\"8.0.0-beta1\";s:3:\"tag\";s:11:\"8.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1412147030\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"8.0.0-alpha15\";a:10:{s:4:\"name\";s:20:\"drupal 8.0.0-alpha15\";s:7:\"version\";s:13:\"8.0.0-alpha15\";s:3:\"tag\";s:13:\"8.0.0-alpha15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/8.0.0-alpha15\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-alpha15.tar.gz\";s:4:\"date\";s:10:\"1411139628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"8.0.0-alpha14\";a:10:{s:4:\"name\";s:20:\"drupal 8.0.0-alpha14\";s:7:\"version\";s:13:\"8.0.0-alpha14\";s:3:\"tag\";s:13:\"8.0.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/8.0.0-alpha14\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1407344628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha13\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha13\";s:7:\"version\";s:11:\"8.0-alpha13\";s:3:\"tag\";s:11:\"8.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha13\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1404296627\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha12\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha12\";s:7:\"version\";s:11:\"8.0-alpha12\";s:3:\"tag\";s:11:\"8.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha12\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1401293627\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha11\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha11\";s:7:\"version\";s:11:\"8.0-alpha11\";s:3:\"tag\";s:11:\"8.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha11\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1398249227\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha10\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha10\";s:7:\"version\";s:11:\"8.0-alpha10\";s:3:\"tag\";s:11:\"8.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha10\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1395231556\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha9\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha9\";s:7:\"version\";s:10:\"8.0-alpha9\";s:3:\"tag\";s:10:\"8.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha9\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1392806005\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha8\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha8\";s:7:\"version\";s:10:\"8.0-alpha8\";s:3:\"tag\";s:10:\"8.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha8\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1390393105\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha7\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha7\";s:7:\"version\";s:10:\"8.0-alpha7\";s:3:\"tag\";s:10:\"8.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha7\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1387399705\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha6\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha6\";s:7:\"version\";s:10:\"8.0-alpha6\";s:3:\"tag\";s:10:\"8.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1385153305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha5\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha5\";s:7:\"version\";s:10:\"8.0-alpha5\";s:3:\"tag\";s:10:\"8.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1384850305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha4\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha4\";s:7:\"version\";s:10:\"8.0-alpha4\";s:3:\"tag\";s:10:\"8.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1382092313\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:12:\"New features\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha3\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha3\";s:7:\"version\";s:10:\"8.0-alpha3\";s:3:\"tag\";s:10:\"8.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1378303307\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:12:\"New features\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha2\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha2\";s:7:\"version\";s:10:\"8.0-alpha2\";s:3:\"tag\";s:10:\"8.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1372069563\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"11.1.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 11.1.x-dev\";s:7:\"version\";s:10:\"11.1.x-dev\";s:3:\"tag\";s:6:\"11.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735404171\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"11.0.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 11.0.x-dev\";s:7:\"version\";s:10:\"11.0.x-dev\";s:3:\"tag\";s:6:\"11.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735403731\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:8:\"11.x-dev\";a:10:{s:4:\"name\";s:15:\"drupal 11.x-dev\";s:7:\"version\";s:8:\"11.x-dev\";s:3:\"tag\";s:4:\"11.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/drupal/releases/11.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/drupal-11.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735453642\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:10:\"10.5.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.5.x-dev\";s:7:\"version\";s:10:\"10.5.x-dev\";s:3:\"tag\";s:6:\"10.5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.5.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735403304\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.4.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.4.x-dev\";s:7:\"version\";s:10:\"10.4.x-dev\";s:3:\"tag\";s:6:\"10.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.4.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735402879\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.3.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.3.x-dev\";s:7:\"version\";s:10:\"10.3.x-dev\";s:3:\"tag\";s:6:\"10.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.3.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735402455\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.2.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.2.x-dev\";s:7:\"version\";s:10:\"10.2.x-dev\";s:3:\"tag\";s:6:\"10.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.2.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1732287023\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.1.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.1.x-dev\";s:7:\"version\";s:10:\"10.1.x-dev\";s:3:\"tag\";s:6:\"10.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1713001795\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.0.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.x-dev\";s:7:\"version\";s:10:\"10.0.x-dev\";s:3:\"tag\";s:6:\"10.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1696930730\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"9.5.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.x-dev\";s:7:\"version\";s:9:\"9.5.x-dev\";s:3:\"tag\";s:5:\"9.5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1701801362\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.4.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.x-dev\";s:7:\"version\";s:9:\"9.4.x-dev\";s:3:\"tag\";s:5:\"9.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1683123227\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.3.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.3.x-dev\";s:7:\"version\";s:9:\"9.3.x-dev\";s:3:\"tag\";s:5:\"9.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.3.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1664385919\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"9.2.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.2.x-dev\";s:7:\"version\";s:9:\"9.2.x-dev\";s:3:\"tag\";s:5:\"9.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.2.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1654891907\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.1.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.x-dev\";s:7:\"version\";s:9:\"9.1.x-dev\";s:3:\"tag\";s:5:\"9.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1637766277\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.0.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.0.x-dev\";s:7:\"version\";s:9:\"9.0.x-dev\";s:3:\"tag\";s:5:\"9.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.0.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1622063424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.9.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.9.x-dev\";s:7:\"version\";s:9:\"8.9.x-dev\";s:3:\"tag\";s:5:\"8.9.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.9.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.9.x-dev.tar.gz\";s:4:\"date\";s:10:\"1637188625\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.8.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.8.x-dev\";s:7:\"version\";s:9:\"8.8.x-dev\";s:3:\"tag\";s:5:\"8.8.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.8.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.8.x-dev.tar.gz\";s:4:\"date\";s:10:\"1606364994\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.7.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.7.x-dev\";s:7:\"version\";s:9:\"8.7.x-dev\";s:3:\"tag\";s:5:\"8.7.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.7.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.7.x-dev.tar.gz\";s:4:\"date\";s:10:\"1589987612\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.6.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.6.x-dev\";s:7:\"version\";s:9:\"8.6.x-dev\";s:3:\"tag\";s:5:\"8.6.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.6.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.6.x-dev.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.5.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.5.x-dev\";s:7:\"version\";s:9:\"8.5.x-dev\";s:3:\"tag\";s:5:\"8.5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.5.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.4.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.x-dev\";s:7:\"version\";s:9:\"8.4.x-dev\";s:3:\"tag\";s:5:\"8.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1533047880\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.3.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.x-dev\";s:7:\"version\";s:9:\"8.3.x-dev\";s:3:\"tag\";s:5:\"8.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.2.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.x-dev\";s:7:\"version\";s:9:\"8.2.x-dev\";s:3:\"tag\";s:5:\"8.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1492624982\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.1.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.1.x-dev\";s:7:\"version\";s:9:\"8.1.x-dev\";s:3:\"tag\";s:5:\"8.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1474478393\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.0.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.x-dev\";s:7:\"version\";s:9:\"8.0.x-dev\";s:3:\"tag\";s:5:\"8.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1459900439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}}s:10:\"last_fetch\";i:1735492267;}',1735578667),('update_available_releases','entity_reference_revisions',_binary 'a:10:{s:5:\"title\";s:26:\"Entity Reference Revisions\";s:10:\"short_name\";s:26:\"entity_reference_revisions\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:33:\"drupal/entity_reference_revisions\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:57:\"https://www.drupal.org/project/entity_reference_revisions\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:18:{s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:35:\"entity_reference_revisions 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:75:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.12\";s:13:\"download_link\";s:80:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1722804497\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:35:\"entity_reference_revisions 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:75:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.11\";s:13:\"download_link\";s:80:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1705140721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:35:\"entity_reference_revisions 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:75:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.10\";s:13:\"download_link\";s:80:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1660664712\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.9\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1614805871\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.8\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1583961846\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.7\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1570284187\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.6\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1539588781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.5\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1527241084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.4\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1515143885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.3\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1495814284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.2\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1485790085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.1\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1485526384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1469725439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc7\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc7\";s:7:\"version\";s:11:\"8.x-1.0-rc7\";s:3:\"tag\";s:11:\"8.x-1.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc7\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1464727139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1460582040\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1447766339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1444419239\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.x-dev\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1731884394\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.1 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492268;}',1735578668),('update_available_releases','ept_accordion',_binary 'a:10:{s:5:\"title\";s:38:\"Extra Paragraph Types (EPT): Accordion\";s:10:\"short_name\";s:13:\"ept_accordion\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:20:\"drupal/ept_accordion\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ept_accordion\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:19:\"ept_accordion 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_accordion/releases/1.4.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384043\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:19:\"ept_accordion 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_accordion/releases/1.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1718776467\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:19:\"ept_accordion 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_accordion/releases/1.4.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714489328\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:19:\"ept_accordion 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_accordion/releases/1.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792727\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:26:\"ept_accordion 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_accordion/releases/1.4.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732066\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:26:\"ept_accordion 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_accordion/releases/1.4.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020115\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:26:\"ept_accordion 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_accordion/releases/1.4.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1692443900\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:23:\"ept_accordion 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_accordion/releases/1.4.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714489288\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492268;}',1735578668),('update_available_releases','ept_basic_button',_binary 'a:10:{s:5:\"title\";s:41:\"Extra Paragraph Types (EPT): Basic Button\";s:10:\"short_name\";s:16:\"ept_basic_button\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:23:\"drupal/ept_basic_button\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:47:\"https://www.drupal.org/project/ept_basic_button\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:11:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:22:\"ept_basic_button 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1721384071\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:22:\"ept_basic_button 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1720604132\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:22:\"ept_basic_button 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1720420232\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:22:\"ept_basic_button 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792787\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha7\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha7\";s:7:\"version\";s:12:\"1.4.0-alpha7\";s:3:\"tag\";s:12:\"1.4.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha7\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1697732075\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha6\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha6\";s:7:\"version\";s:12:\"1.4.0-alpha6\";s:3:\"tag\";s:12:\"1.4.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha6\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1696934220\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1696319554\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1695020210\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1692553614\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1692553208\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:26:\"ept_basic_button 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1720604082\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492268;}',1735578668),('update_available_releases','ept_block',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Block\";s:10:\"short_name\";s:9:\"ept_block\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_block\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_block\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:4:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_block 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_block/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_block-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384098\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_block 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_block/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_block-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721031434\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_block 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_block/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_block-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1705580708\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_block 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_block/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_block-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712789\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492268;}',1735578668),('update_available_releases','ept_bootstrap_button',_binary 'a:10:{s:5:\"title\";s:45:\"Extra Paragraph Types (EPT): Bootstrap Button\";s:10:\"short_name\";s:20:\"ept_bootstrap_button\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:27:\"drupal/ept_bootstrap_button\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:51:\"https://www.drupal.org/project/ept_bootstrap_button\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:7:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:26:\"ept_bootstrap_button 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384122\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:26:\"ept_bootstrap_button 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721030798\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:26:\"ept_bootstrap_button 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792837\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:33:\"ept_bootstrap_button 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.0-alpha4\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732086\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:33:\"ept_bootstrap_button 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.0-alpha3\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1695020260\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:33:\"ept_bootstrap_button 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.0-alpha2\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1692604880\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:30:\"ept_bootstrap_button 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.x-dev\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712585\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492268;}',1735578668),('update_available_releases','ept_carousel',_binary 'a:10:{s:5:\"title\";s:37:\"Extra Paragraph Types (EPT): Carousel\";s:10:\"short_name\";s:12:\"ept_carousel\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:19:\"drupal/ept_carousel\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:43:\"https://www.drupal.org/project/ept_carousel\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:10:{s:5:\"1.4.5\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1734284531\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722409993\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384164\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1714489408\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1707471100\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792944\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:25:\"ept_carousel 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ept_carousel/releases/1.4.0-alpha3\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732150\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:25:\"ept_carousel 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ept_carousel/releases/1.4.0-alpha2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020351\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:25:\"ept_carousel 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ept_carousel/releases/1.4.0-alpha1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1692689650\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:22:\"ept_carousel 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_carousel/releases/1.4.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734283572\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492269;}',1735578669),('update_available_releases','ept_columns',_binary 'a:10:{s:5:\"title\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";s:10:\"short_name\";s:11:\"ept_columns\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:18:\"drupal/ept_columns\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/ept_columns\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.6\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1721384279\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1721217525\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1714489646\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1714471360\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1714469260\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1713721134\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1711960728\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:21:\"ept_columns 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_columns/releases/1.4.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721215251\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492269;}',1735578669),('update_available_releases','ept_core',_binary 'a:10:{s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Core\";s:10:\"short_name\";s:8:\"ept_core\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ept_core\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:25:{s:6:\"1.4.17\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.17\";s:7:\"version\";s:6:\"1.4.17\";s:3:\"tag\";s:6:\"1.4.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.17\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.17.tar.gz\";s:4:\"date\";s:10:\"1728849210\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.16\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.16\";s:7:\"version\";s:6:\"1.4.16\";s:3:\"tag\";s:6:\"1.4.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.16\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.16.tar.gz\";s:4:\"date\";s:10:\"1728847500\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.15\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.15\";s:7:\"version\";s:6:\"1.4.15\";s:3:\"tag\";s:6:\"1.4.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.15\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.15.tar.gz\";s:4:\"date\";s:10:\"1728818487\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:6:\"1.4.14\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.14\";s:7:\"version\";s:6:\"1.4.14\";s:3:\"tag\";s:6:\"1.4.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.14\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.14.tar.gz\";s:4:\"date\";s:10:\"1721383996\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.13\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.13\";s:7:\"version\";s:6:\"1.4.13\";s:3:\"tag\";s:6:\"1.4.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.13\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.13.tar.gz\";s:4:\"date\";s:10:\"1721242210\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.12\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.12\";s:7:\"version\";s:6:\"1.4.12\";s:3:\"tag\";s:6:\"1.4.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.12\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.12.tar.gz\";s:4:\"date\";s:10:\"1721217306\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.11\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.11\";s:7:\"version\";s:6:\"1.4.11\";s:3:\"tag\";s:6:\"1.4.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.11\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.11.tar.gz\";s:4:\"date\";s:10:\"1720512693\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:6:\"1.4.10\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.10\";s:7:\"version\";s:6:\"1.4.10\";s:3:\"tag\";s:6:\"1.4.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.10\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.10.tar.gz\";s:4:\"date\";s:10:\"1718775833\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.9\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.9\";s:7:\"version\";s:5:\"1.4.9\";s:3:\"tag\";s:5:\"1.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.9\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.9.tar.gz\";s:4:\"date\";s:10:\"1715419475\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.8\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.8\";s:7:\"version\";s:5:\"1.4.8\";s:3:\"tag\";s:5:\"1.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.8\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.8.tar.gz\";s:4:\"date\";s:10:\"1715413979\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.7\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.7\";s:7:\"version\";s:5:\"1.4.7\";s:3:\"tag\";s:5:\"1.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.7\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.7.tar.gz\";s:4:\"date\";s:10:\"1714924340\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.6\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.6\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1714489789\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.5\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1713714097\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1711960476\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1709310495\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1708886906\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1708007013\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792691\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha5\";a:11:{s:4:\"name\";s:21:\"ept_core 1.4.0-alpha5\";s:7:\"version\";s:12:\"1.4.0-alpha5\";s:3:\"tag\";s:12:\"1.4.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_core/releases/1.4.0-alpha5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1697731614\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:21:\"ept_core 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_core/releases/1.4.0-alpha4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1696538022\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:21:\"ept_core 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_core/releases/1.4.0-alpha3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696506197\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:21:\"ept_core 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_core/releases/1.4.0-alpha2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1694968748\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:21:\"ept_core 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_core/releases/1.4.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1693757733\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:14:\"ept_core 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.0.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1699792566\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:18:\"ept_core 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_core/releases/1.4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_core-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1728848866\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492269;}',1735578669),('update_available_releases','ept_countdown',_binary 'a:10:{s:5:\"title\";s:38:\"Extra Paragraph Types (EPT): Countdown\";s:10:\"short_name\";s:13:\"ept_countdown\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:20:\"drupal/ept_countdown\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ept_countdown\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:7:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:19:\"ept_countdown 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_countdown/releases/1.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384290\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:19:\"ept_countdown 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_countdown/releases/1.4.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721030874\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:19:\"ept_countdown 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_countdown/releases/1.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792985\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:26:\"ept_countdown 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_countdown/releases/1.4.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732156\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:26:\"ept_countdown 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_countdown/releases/1.4.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020395\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:26:\"ept_countdown 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_countdown/releases/1.4.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1692778248\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:23:\"ept_countdown 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_countdown/releases/1.4.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712522\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492269;}',1735578669),('update_available_releases','ept_counter',_binary 'a:10:{s:5:\"title\";s:36:\"Extra Paragraph Types (EPT): Counter\";s:10:\"short_name\";s:11:\"ept_counter\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:18:\"drupal/ept_counter\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/ept_counter\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:17:\"ept_counter 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410408\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:17:\"ept_counter 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384316\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:17:\"ept_counter 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1718562283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:17:\"ept_counter 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714489891\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:17:\"ept_counter 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793022\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:24:\"ept_counter 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/ept_counter/releases/1.4.0-alpha3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732420\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:24:\"ept_counter 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/ept_counter/releases/1.4.0-alpha2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020452\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:24:\"ept_counter 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/ept_counter/releases/1.4.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1693207585\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:21:\"ept_counter 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_counter/releases/1.4.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1718907619\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492269;}',1735578669),('update_available_releases','ept_cta',_binary 'a:10:{s:5:\"title\";s:43:\"Extra Paragraph Types (EPT): Call to Action\";s:10:\"short_name\";s:7:\"ept_cta\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:14:\"drupal/ept_cta\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:38:\"https://www.drupal.org/project/ept_cta\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:10:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:13:\"ept_cta 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410462\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:13:\"ept_cta 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384167\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:13:\"ept_cta 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1720991536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:13:\"ept_cta 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1716387526\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:13:\"ept_cta 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792891\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:20:\"ept_cta 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_cta/releases/1.4.0-alpha4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732446\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:20:\"ept_cta 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_cta/releases/1.4.0-alpha3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696319604\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:20:\"ept_cta 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_cta/releases/1.4.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020301\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:20:\"ept_cta 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_cta/releases/1.4.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1693758608\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:17:\"ept_cta 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_cta/releases/1.4.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1720991032\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492269;}',1735578669),('update_available_releases','ept_hero',_binary 'a:10:{s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Hero\";s:10:\"short_name\";s:8:\"ept_hero\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ept_hero\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_hero\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"1.4.5\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.5\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1733145597\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410507\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384368\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1720603705\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1720426508\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1720419415\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}}s:10:\"last_fetch\";i:1735492269;}',1735578669),('update_available_releases','ept_image',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Image\";s:10:\"short_name\";s:9:\"ept_image\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_image\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_image\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:15:\"ept_image 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410542\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ept_image 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384323\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_image 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721030984\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_image 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1708353027\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_image 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793072\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:22:\"ept_image 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_image/releases/1.4.0-alpha3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_image-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697731932\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ept_image 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_image/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_image-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020495\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ept_image 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_image/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_image-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1693758273\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_image 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_image/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_image-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712339\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492270;}',1735578670),('update_available_releases','ept_image_gallery',_binary 'a:10:{s:5:\"title\";s:42:\"Extra Paragraph Types (EPT): Image Gallery\";s:10:\"short_name\";s:17:\"ept_image_gallery\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:24:\"drupal/ept_image_gallery\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:48:\"https://www.drupal.org/project/ept_image_gallery\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722411235\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384350\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1713943658\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1710340960\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793283\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:30:\"ept_image_gallery 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.0-alpha3\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732179\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:30:\"ept_image_gallery 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.0-alpha2\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020535\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:30:\"ept_image_gallery 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.0-alpha1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694461714\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:27:\"ept_image_gallery 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1731577548\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492270;}',1735578670),('update_available_releases','ept_micromodal',_binary 'a:10:{s:5:\"title\";s:39:\"Extra Paragraph Types (EPT): Micromodal\";s:10:\"short_name\";s:14:\"ept_micromodal\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:21:\"drupal/ept_micromodal\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/ept_micromodal\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:7:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:20:\"ept_micromodal 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384358\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:20:\"ept_micromodal 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721028333\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:20:\"ept_micromodal 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793347\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:27:\"ept_micromodal 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.0-alpha3\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732239\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:27:\"ept_micromodal 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.0-alpha2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020582\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:27:\"ept_micromodal 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.0-alpha1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694460759\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:24:\"ept_micromodal 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.x-dev\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1720418520\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492270;}',1735578670),('update_available_releases','ept_quote',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Quote\";s:10:\"short_name\";s:9:\"ept_quote\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_quote\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_quote\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ept_quote 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_quote/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411325\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_quote 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_quote/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384506\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_quote 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_quote/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721031062\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_quote 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_quote/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793452\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:22:\"ept_quote 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_quote/releases/1.4.0-alpha4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732241\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ept_quote 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_quote/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020634\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ept_quote 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_quote/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694461930\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_quote 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_quote/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712167\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492270;}',1735578670),('update_available_releases','ept_slick_slider',_binary 'a:10:{s:5:\"title\";s:41:\"Extra Paragraph Types (EPT): Slick Slider\";s:10:\"short_name\";s:16:\"ept_slick_slider\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:23:\"drupal/ept_slick_slider\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:47:\"https://www.drupal.org/project/ept_slick_slider\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:22:\"ept_slick_slider 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411497\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:22:\"ept_slick_slider 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384509\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:22:\"ept_slick_slider 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714490011\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:22:\"ept_slick_slider 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793405\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:29:\"ept_slick_slider 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.0-alpha3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732269\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:29:\"ept_slick_slider 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.0-alpha2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020685\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:29:\"ept_slick_slider 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694462501\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:26:\"ept_slick_slider 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714489937\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492270;}',1735578670),('update_available_releases','ept_slideshow',_binary 'a:10:{s:5:\"title\";s:38:\"Extra Paragraph Types (EPT): Slideshow\";s:10:\"short_name\";s:13:\"ept_slideshow\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:20:\"drupal/ept_slideshow\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ept_slideshow\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:19:\"ept_slideshow 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722411522\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:19:\"ept_slideshow 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384539\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:19:\"ept_slideshow 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1714490171\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:19:\"ept_slideshow 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793513\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:26:\"ept_slideshow 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.0-alpha4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732270\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:26:\"ept_slideshow 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1695880151\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:26:\"ept_slideshow 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020896\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:26:\"ept_slideshow 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694499626\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:23:\"ept_slideshow 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714490056\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492271;}',1735578671),('update_available_releases','ept_stats',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Stats\";s:10:\"short_name\";s:9:\"ept_stats\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_stats\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_stats\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_stats 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_stats/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384552\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_stats 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_stats/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714490449\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_stats 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_stats/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793563\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:22:\"ept_stats 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_stats/releases/1.4.0-alpha4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732311\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:22:\"ept_stats 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_stats/releases/1.4.0-alpha3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696750413\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ept_stats 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_stats/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695021127\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ept_stats 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_stats/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694500446\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_stats 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_stats/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714490389\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492271;}',1735578671),('update_available_releases','ept_tabs',_binary 'a:10:{s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Tabs\";s:10:\"short_name\";s:8:\"ept_tabs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ept_tabs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_tabs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:10:{s:5:\"1.4.5\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.5\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1735472534\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1729019768\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411586\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384552\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721031136\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793604\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:21:\"ept_tabs 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_tabs/releases/1.4.0-alpha3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732314\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:21:\"ept_tabs 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_tabs/releases/1.4.0-alpha2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695021196\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:21:\"ept_tabs 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_tabs/releases/1.4.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694519731\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:18:\"ept_tabs 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_tabs/releases/1.4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735471124\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492271;}',1735578671),('update_available_releases','ept_text',_binary 'a:10:{s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Text\";s:10:\"short_name\";s:8:\"ept_text\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ept_text\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_text\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ept_text 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_text/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_text-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384579\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ept_text 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_text/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_text-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721031205\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ept_text 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_text/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_text-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1704965319\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ept_text 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_text/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_text-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793728\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:21:\"ept_text 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_text/releases/1.4.0-alpha3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_text-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732346\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:21:\"ept_text 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_text/releases/1.4.0-alpha2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_text-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695021325\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:21:\"ept_text 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_text/releases/1.4.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_text-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1692442868\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:18:\"ept_text 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_text/releases/1.4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_text-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710707781\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492271;}',1735578671),('update_available_releases','ept_tiles',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Tiles\";s:10:\"short_name\";s:9:\"ept_tiles\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_tiles\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_tiles\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:15:\"ept_tiles 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_tiles/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1721384596\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ept_tiles 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_tiles/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1714488760\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_tiles 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_tiles/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1706861493\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_tiles 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_tiles/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793674\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:22:\"ept_tiles 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_tiles/releases/1.4.0-alpha4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732347\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:22:\"ept_tiles 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_tiles/releases/1.4.0-alpha3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696078892\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ept_tiles 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_tiles/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695888461\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ept_tiles 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_tiles/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1695579452\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_tiles 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_tiles/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1725277615\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492271;}',1735578671),('update_available_releases','ept_video',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Video\";s:10:\"short_name\";s:9:\"ept_video\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_video\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_video\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:11:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ept_video 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_video/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_video-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411733\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_video 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_video/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_video-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384620\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_video 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_video/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_video-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714490864\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_video 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_video/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793973\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha7\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha7\";s:7:\"version\";s:12:\"1.4.0-alpha7\";s:3:\"tag\";s:12:\"1.4.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1697732210\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha6\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha6\";s:7:\"version\";s:12:\"1.4.0-alpha6\";s:3:\"tag\";s:12:\"1.4.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1696687235\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha5\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha5\";s:7:\"version\";s:12:\"1.4.0-alpha5\";s:3:\"tag\";s:12:\"1.4.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1696539789\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1696537986\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1696531646\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1695573537\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_video 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_video/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_video-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714490714\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492271;}',1735578671),('update_available_releases','ept_video_and_image_gallery',_binary 'a:10:{s:5:\"title\";s:52:\"Extra Paragraph Types (EPT): Video and Image Gallery\";s:10:\"short_name\";s:27:\"ept_video_and_image_gallery\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:34:\"drupal/ept_video_and_image_gallery\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:58:\"https://www.drupal.org/project/ept_video_and_image_gallery\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:12:{s:5:\"1.4.5\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.5\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1722411776\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.4\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1721384619\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.3\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1714490933\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.2\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1713944254\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.1\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1713944053\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699794213\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha6\";a:11:{s:4:\"name\";s:40:\"ept_video_and_image_gallery 1.4.0-alpha6\";s:7:\"version\";s:12:\"1.4.0-alpha6\";s:3:\"tag\";s:12:\"1.4.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0-alpha6\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1697732380\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha5\";a:11:{s:4:\"name\";s:40:\"ept_video_and_image_gallery 1.4.0-alpha5\";s:7:\"version\";s:12:\"1.4.0-alpha5\";s:3:\"tag\";s:12:\"1.4.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0-alpha5\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1696687259\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:40:\"ept_video_and_image_gallery 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0-alpha4\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1696151181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:40:\"ept_video_and_image_gallery 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0-alpha3\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696149547\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:40:\"ept_video_and_image_gallery 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0-alpha2\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695713209\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:37:\"ept_video_and_image_gallery 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:77:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.x-dev\";s:13:\"download_link\";s:82:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714490789\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','ept_views',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Views\";s:10:\"short_name\";s:9:\"ept_views\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_views\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_views\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:15:\"ept_views 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1727007515\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ept_views 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384637\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_views 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721031270\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_views 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1705528653\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:15:\"ept_views 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.0.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1705528233\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_views 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_views/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_views-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1727007416\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','field_group',_binary 'a:10:{s:5:\"title\";s:11:\"Field Group\";s:10:\"short_name\";s:11:\"field_group\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"4.0.,8.x-3.\";s:18:\"composer_namespace\";s:18:\"drupal/field_group\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/field_group\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:19:{s:12:\"4.0.0-alpha1\";a:11:{s:4:\"name\";s:24:\"field_group 4.0.0-alpha1\";s:7:\"version\";s:12:\"4.0.0-alpha1\";s:3:\"tag\";s:12:\"4.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/field_group/releases/4.0.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/field_group-4.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1725952813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:7:\"8.x-3.6\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.6\";s:7:\"version\";s:7:\"8.x-3.6\";s:3:\"tag\";s:7:\"8.x-3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.6.tar.gz\";s:4:\"date\";s:10:\"1722672510\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:7:\"8.x-3.5\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.5\";s:7:\"version\";s:7:\"8.x-3.5\";s:3:\"tag\";s:7:\"8.x-3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.5.tar.gz\";s:4:\"date\";s:10:\"1722630494\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:7:\"8.x-3.4\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.4\";s:7:\"version\";s:7:\"8.x-3.4\";s:3:\"tag\";s:7:\"8.x-3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.4.tar.gz\";s:4:\"date\";s:10:\"1667241979\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-3.3\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.3\";s:7:\"version\";s:7:\"8.x-3.3\";s:3:\"tag\";s:7:\"8.x-3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.3.tar.gz\";s:4:\"date\";s:10:\"1663516404\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.2\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.2\";s:7:\"version\";s:7:\"8.x-3.2\";s:3:\"tag\";s:7:\"8.x-3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.2.tar.gz\";s:4:\"date\";s:10:\"1628513585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1591772567\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1580250787\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1574200085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1558647185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-3.0-beta1\";a:11:{s:4:\"name\";s:25:\"field_group 8.x-3.0-beta1\";s:7:\"version\";s:13:\"8.x-3.0-beta1\";s:3:\"tag\";s:13:\"8.x-3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1510352284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1510352885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1480365484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1480288380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1449771240\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1447385940\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"4.x-dev\";a:11:{s:4:\"name\";s:19:\"field_group 4.x-dev\";s:7:\"version\";s:7:\"4.x-dev\";s:3:\"tag\";s:3:\"4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1725952112\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1725973161\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1570214888\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','file_mdm',_binary 'a:10:{s:5:\"title\";s:21:\"File metadata manager\";s:10:\"short_name\";s:8:\"file_mdm\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"3.1.\";s:18:\"composer_namespace\";s:15:\"drupal/file_mdm\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/file_mdm\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:31:{s:5:\"3.1.0\";a:11:{s:4:\"name\";s:14:\"file_mdm 3.1.0\";s:7:\"version\";s:5:\"3.1.0\";s:3:\"tag\";s:5:\"3.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/file_mdm/releases/3.1.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.0.tar.gz\";s:4:\"date\";s:10:\"1718086268\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:11:\"3.1.0-beta2\";a:11:{s:4:\"name\";s:20:\"file_mdm 3.1.0-beta2\";s:7:\"version\";s:11:\"3.1.0-beta2\";s:3:\"tag\";s:11:\"3.1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/3.1.0-beta2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1716133805\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:11:\"3.1.0-beta1\";a:11:{s:4:\"name\";s:20:\"file_mdm 3.1.0-beta1\";s:7:\"version\";s:11:\"3.1.0-beta1\";s:3:\"tag\";s:11:\"3.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/3.1.0-beta1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1714414299\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.2\";s:5:\"terms\";a:0:{}}s:12:\"3.1.0-alpha1\";a:11:{s:4:\"name\";s:21:\"file_mdm 3.1.0-alpha1\";s:7:\"version\";s:12:\"3.1.0-alpha1\";s:3:\"tag\";s:12:\"3.1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/file_mdm/releases/3.1.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1705056866\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.2\";s:5:\"terms\";a:0:{}}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:14:\"file_mdm 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/file_mdm/releases/3.0.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/file_mdm-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1691421181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:9:\"3.0.0-rc1\";a:11:{s:4:\"name\";s:18:\"file_mdm 3.0.0-rc1\";s:7:\"version\";s:9:\"3.0.0-rc1\";s:3:\"tag\";s:9:\"3.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/file_mdm/releases/3.0.0-rc1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/file_mdm-3.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1688577226\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:12:\"3.0.0-alpha2\";a:11:{s:4:\"name\";s:21:\"file_mdm 3.0.0-alpha2\";s:7:\"version\";s:12:\"3.0.0-alpha2\";s:3:\"tag\";s:12:\"3.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/file_mdm/releases/3.0.0-alpha2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/file_mdm-3.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1687256944\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:12:\"3.0.0-alpha1\";a:11:{s:4:\"name\";s:21:\"file_mdm 3.0.0-alpha1\";s:7:\"version\";s:12:\"3.0.0-alpha1\";s:3:\"tag\";s:12:\"3.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/file_mdm/releases/3.0.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/file_mdm-3.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1677421044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:7:\"8.x-2.6\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.6\";s:7:\"version\";s:7:\"8.x-2.6\";s:3:\"tag\";s:7:\"8.x-2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.6\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.6.tar.gz\";s:4:\"date\";s:10:\"1688489716\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^9.3 | ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.5\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1663668519\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^9.3 | ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.4\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1645440700\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1644943374\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1639755096\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1586801064\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1576506188\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.0-rc1\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-2.0-rc1\";s:7:\"version\";s:11:\"8.x-2.0-rc1\";s:3:\"tag\";s:11:\"8.x-2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.0-rc1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1575543485\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:22:\"file_mdm 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1573293184\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1488273785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1487968683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1486564984\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1486127283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1485945784\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1483048683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:22:\"file_mdm 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1469723039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:22:\"file_mdm 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1467634468\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:22:\"file_mdm 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1466009639\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:17:\"8.x-1.0-unstable1\";a:11:{s:4:\"name\";s:26:\"file_mdm 8.x-1.0-unstable1\";s:7:\"version\";s:17:\"8.x-1.0-unstable1\";s:3:\"tag\";s:17:\"8.x-1.0-unstable1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-unstable1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-unstable1.tar.gz\";s:4:\"date\";s:10:\"1465294739\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:64:\"Unstable releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:9:\"3.1.x-dev\";a:11:{s:4:\"name\";s:18:\"file_mdm 3.1.x-dev\";s:7:\"version\";s:9:\"3.1.x-dev\";s:3:\"tag\";s:5:\"3.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/file_mdm/releases/3.1.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1733678862\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:9:\"3.0.x-dev\";a:11:{s:4:\"name\";s:18:\"file_mdm 3.0.x-dev\";s:7:\"version\";s:9:\"3.0.x-dev\";s:3:\"tag\";s:5:\"3.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/file_mdm/releases/3.0.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/file_mdm-3.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1699192268\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.x-dev\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1687253170\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^9.3 | ^10\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.x-dev\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1576326787\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','gin',_binary 'a:10:{s:5:\"title\";s:15:\"Gin Admin Theme\";s:10:\"short_name\";s:3:\"gin\";s:4:\"type\";s:13:\"project_theme\";s:18:\"supported_branches\";s:11:\"4.0.,8.x-3.\";s:18:\"composer_namespace\";s:10:\"drupal/gin\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:34:\"https://www.drupal.org/project/gin\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:93:{s:5:\"4.0.2\";a:11:{s:4:\"name\";s:9:\"gin 4.0.2\";s:7:\"version\";s:5:\"4.0.2\";s:3:\"tag\";s:5:\"4.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:49:\"https://www.drupal.org/project/gin/releases/4.0.2\";s:13:\"download_link\";s:54:\"https://ftp.drupal.org/files/projects/gin-4.0.2.tar.gz\";s:4:\"date\";s:10:\"1735404747\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"4.0.1\";a:11:{s:4:\"name\";s:9:\"gin 4.0.1\";s:7:\"version\";s:5:\"4.0.1\";s:3:\"tag\";s:5:\"4.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:49:\"https://www.drupal.org/project/gin/releases/4.0.1\";s:13:\"download_link\";s:54:\"https://ftp.drupal.org/files/projects/gin-4.0.1.tar.gz\";s:4:\"date\";s:10:\"1735326747\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"4.0.0\";a:11:{s:4:\"name\";s:9:\"gin 4.0.0\";s:7:\"version\";s:5:\"4.0.0\";s:3:\"tag\";s:5:\"4.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:49:\"https://www.drupal.org/project/gin/releases/4.0.0\";s:13:\"download_link\";s:54:\"https://ftp.drupal.org/files/projects/gin-4.0.0.tar.gz\";s:4:\"date\";s:10:\"1734696940\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:11:\"gin 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:51:\"https://www.drupal.org/project/gin/releases/8.x-3.0\";s:13:\"download_link\";s:56:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1734696845\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc16\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc16\";s:7:\"version\";s:12:\"8.x-3.0-rc16\";s:3:\"tag\";s:12:\"8.x-3.0-rc16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc16\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc16.tar.gz\";s:4:\"date\";s:10:\"1734527306\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc15\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc15\";s:7:\"version\";s:12:\"8.x-3.0-rc15\";s:3:\"tag\";s:12:\"8.x-3.0-rc15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc15\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc15.tar.gz\";s:4:\"date\";s:10:\"1733734246\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc14\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc14\";s:7:\"version\";s:12:\"8.x-3.0-rc14\";s:3:\"tag\";s:12:\"8.x-3.0-rc14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc14\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc14.tar.gz\";s:4:\"date\";s:10:\"1731015952\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc13\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc13\";s:7:\"version\";s:12:\"8.x-3.0-rc13\";s:3:\"tag\";s:12:\"8.x-3.0-rc13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc13\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc13.tar.gz\";s:4:\"date\";s:10:\"1720416342\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc12\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc12\";s:7:\"version\";s:12:\"8.x-3.0-rc12\";s:3:\"tag\";s:12:\"8.x-3.0-rc12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc12\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc12.tar.gz\";s:4:\"date\";s:10:\"1719568767\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc11\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc11\";s:7:\"version\";s:12:\"8.x-3.0-rc11\";s:3:\"tag\";s:12:\"8.x-3.0-rc11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc11\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc11.tar.gz\";s:4:\"date\";s:10:\"1718351205\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc10\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc10\";s:7:\"version\";s:12:\"8.x-3.0-rc10\";s:3:\"tag\";s:12:\"8.x-3.0-rc10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc10\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc10.tar.gz\";s:4:\"date\";s:10:\"1712686345\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc9\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc9\";s:7:\"version\";s:11:\"8.x-3.0-rc9\";s:3:\"tag\";s:11:\"8.x-3.0-rc9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc9.tar.gz\";s:4:\"date\";s:10:\"1706705034\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc8\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc8\";s:7:\"version\";s:11:\"8.x-3.0-rc8\";s:3:\"tag\";s:11:\"8.x-3.0-rc8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc8.tar.gz\";s:4:\"date\";s:10:\"1702729136\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc7\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc7\";s:7:\"version\";s:11:\"8.x-3.0-rc7\";s:3:\"tag\";s:11:\"8.x-3.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1697193234\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc6\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc6\";s:7:\"version\";s:11:\"8.x-3.0-rc6\";s:3:\"tag\";s:11:\"8.x-3.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1693299666\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc5\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc5\";s:7:\"version\";s:11:\"8.x-3.0-rc5\";s:3:\"tag\";s:11:\"8.x-3.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1689504430\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc4\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc4\";s:7:\"version\";s:11:\"8.x-3.0-rc4\";s:3:\"tag\";s:11:\"8.x-3.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1688474317\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc3\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc3\";s:7:\"version\";s:11:\"8.x-3.0-rc3\";s:3:\"tag\";s:11:\"8.x-3.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1682979025\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1678627668\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1669666691\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta5\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta5\";s:7:\"version\";s:13:\"8.x-3.0-beta5\";s:3:\"tag\";s:13:\"8.x-3.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1656068146\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta4\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta4\";s:7:\"version\";s:13:\"8.x-3.0-beta4\";s:3:\"tag\";s:13:\"8.x-3.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1656062400\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta3\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta3\";s:7:\"version\";s:13:\"8.x-3.0-beta3\";s:3:\"tag\";s:13:\"8.x-3.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1653469869\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta2\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta2\";s:7:\"version\";s:13:\"8.x-3.0-beta2\";s:3:\"tag\";s:13:\"8.x-3.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1649709347\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta1\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta1\";s:7:\"version\";s:13:\"8.x-3.0-beta1\";s:3:\"tag\";s:13:\"8.x-3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1646929485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:15:\"8.x-3.0-alpha37\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha37\";s:7:\"version\";s:15:\"8.x-3.0-alpha37\";s:3:\"tag\";s:15:\"8.x-3.0-alpha37\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha37\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha37.tar.gz\";s:4:\"date\";s:10:\"1632767973\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:15:\"8.x-3.0-alpha36\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha36\";s:7:\"version\";s:15:\"8.x-3.0-alpha36\";s:3:\"tag\";s:15:\"8.x-3.0-alpha36\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha36\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha36.tar.gz\";s:4:\"date\";s:10:\"1625232222\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha35\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha35\";s:7:\"version\";s:15:\"8.x-3.0-alpha35\";s:3:\"tag\";s:15:\"8.x-3.0-alpha35\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha35\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha35.tar.gz\";s:4:\"date\";s:10:\"1622412154\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha34\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha34\";s:7:\"version\";s:15:\"8.x-3.0-alpha34\";s:3:\"tag\";s:15:\"8.x-3.0-alpha34\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha34\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha34.tar.gz\";s:4:\"date\";s:10:\"1620394439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha33\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha33\";s:7:\"version\";s:15:\"8.x-3.0-alpha33\";s:3:\"tag\";s:15:\"8.x-3.0-alpha33\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha33\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha33.tar.gz\";s:4:\"date\";s:10:\"1611172829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha32\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha32\";s:7:\"version\";s:15:\"8.x-3.0-alpha32\";s:3:\"tag\";s:15:\"8.x-3.0-alpha32\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha32\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha32.tar.gz\";s:4:\"date\";s:10:\"1607370374\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha31\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha31\";s:7:\"version\";s:15:\"8.x-3.0-alpha31\";s:3:\"tag\";s:15:\"8.x-3.0-alpha31\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha31\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha31.tar.gz\";s:4:\"date\";s:10:\"1606944288\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha30\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha30\";s:7:\"version\";s:15:\"8.x-3.0-alpha30\";s:3:\"tag\";s:15:\"8.x-3.0-alpha30\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha30\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha30.tar.gz\";s:4:\"date\";s:10:\"1605395013\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha29\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha29\";s:7:\"version\";s:15:\"8.x-3.0-alpha29\";s:3:\"tag\";s:15:\"8.x-3.0-alpha29\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha29\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha29.tar.gz\";s:4:\"date\";s:10:\"1605375202\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha28\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha28\";s:7:\"version\";s:15:\"8.x-3.0-alpha28\";s:3:\"tag\";s:15:\"8.x-3.0-alpha28\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha28\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha28.tar.gz\";s:4:\"date\";s:10:\"1604868112\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha27\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha27\";s:7:\"version\";s:15:\"8.x-3.0-alpha27\";s:3:\"tag\";s:15:\"8.x-3.0-alpha27\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha27\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha27.tar.gz\";s:4:\"date\";s:10:\"1601291419\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha26\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha26\";s:7:\"version\";s:15:\"8.x-3.0-alpha26\";s:3:\"tag\";s:15:\"8.x-3.0-alpha26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha26\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha26.tar.gz\";s:4:\"date\";s:10:\"1598863786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha25\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha25\";s:7:\"version\";s:15:\"8.x-3.0-alpha25\";s:3:\"tag\";s:15:\"8.x-3.0-alpha25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha25\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha25.tar.gz\";s:4:\"date\";s:10:\"1597406186\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha24\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha24\";s:7:\"version\";s:15:\"8.x-3.0-alpha24\";s:3:\"tag\";s:15:\"8.x-3.0-alpha24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha24\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha24.tar.gz\";s:4:\"date\";s:10:\"1595854343\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha23\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha23\";s:7:\"version\";s:15:\"8.x-3.0-alpha23\";s:3:\"tag\";s:15:\"8.x-3.0-alpha23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha23\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha23.tar.gz\";s:4:\"date\";s:10:\"1594643695\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha22\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha22\";s:7:\"version\";s:15:\"8.x-3.0-alpha22\";s:3:\"tag\";s:15:\"8.x-3.0-alpha22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha22\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha22.tar.gz\";s:4:\"date\";s:10:\"1593766525\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha21\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha21\";s:7:\"version\";s:15:\"8.x-3.0-alpha21\";s:3:\"tag\";s:15:\"8.x-3.0-alpha21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha21\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha21.tar.gz\";s:4:\"date\";s:10:\"1593461879\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha20\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha20\";s:7:\"version\";s:15:\"8.x-3.0-alpha20\";s:3:\"tag\";s:15:\"8.x-3.0-alpha20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha20\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha20.tar.gz\";s:4:\"date\";s:10:\"1592855613\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha19\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha19\";s:7:\"version\";s:15:\"8.x-3.0-alpha19\";s:3:\"tag\";s:15:\"8.x-3.0-alpha19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha19\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha19.tar.gz\";s:4:\"date\";s:10:\"1592580886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha18\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha18\";s:7:\"version\";s:15:\"8.x-3.0-alpha18\";s:3:\"tag\";s:15:\"8.x-3.0-alpha18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha18\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha18.tar.gz\";s:4:\"date\";s:10:\"1592169349\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha17\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha17\";s:7:\"version\";s:15:\"8.x-3.0-alpha17\";s:3:\"tag\";s:15:\"8.x-3.0-alpha17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha17\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha17.tar.gz\";s:4:\"date\";s:10:\"1591349946\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:15:\"8.x-3.0-alpha16\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha16\";s:7:\"version\";s:15:\"8.x-3.0-alpha16\";s:3:\"tag\";s:15:\"8.x-3.0-alpha16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha16\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha16.tar.gz\";s:4:\"date\";s:10:\"1591188802\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha15\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha15\";s:7:\"version\";s:15:\"8.x-3.0-alpha15\";s:3:\"tag\";s:15:\"8.x-3.0-alpha15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha15\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha15.tar.gz\";s:4:\"date\";s:10:\"1591026800\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha14\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha14\";s:7:\"version\";s:15:\"8.x-3.0-alpha14\";s:3:\"tag\";s:15:\"8.x-3.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1590401622\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha13\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha13\";s:7:\"version\";s:15:\"8.x-3.0-alpha13\";s:3:\"tag\";s:15:\"8.x-3.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1590058790\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha12\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha12\";s:7:\"version\";s:15:\"8.x-3.0-alpha12\";s:3:\"tag\";s:15:\"8.x-3.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1588701093\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha11\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha11\";s:7:\"version\";s:15:\"8.x-3.0-alpha11\";s:3:\"tag\";s:15:\"8.x-3.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1588112180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha10\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha10\";s:7:\"version\";s:15:\"8.x-3.0-alpha10\";s:3:\"tag\";s:15:\"8.x-3.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1588110279\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha9\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha9\";s:7:\"version\";s:14:\"8.x-3.0-alpha9\";s:3:\"tag\";s:14:\"8.x-3.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1587598687\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha8\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha8\";s:7:\"version\";s:14:\"8.x-3.0-alpha8\";s:3:\"tag\";s:14:\"8.x-3.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1587403171\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha7\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha7\";s:7:\"version\";s:14:\"8.x-3.0-alpha7\";s:3:\"tag\";s:14:\"8.x-3.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1586889051\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha6\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha6\";s:7:\"version\";s:14:\"8.x-3.0-alpha6\";s:3:\"tag\";s:14:\"8.x-3.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1585911008\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha5\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha5\";s:7:\"version\";s:14:\"8.x-3.0-alpha5\";s:3:\"tag\";s:14:\"8.x-3.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1585758919\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha4\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha4\";s:7:\"version\";s:14:\"8.x-3.0-alpha4\";s:3:\"tag\";s:14:\"8.x-3.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1585218206\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha3\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha3\";s:7:\"version\";s:14:\"8.x-3.0-alpha3\";s:3:\"tag\";s:14:\"8.x-3.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1585056344\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha2\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha2\";s:7:\"version\";s:14:\"8.x-3.0-alpha2\";s:3:\"tag\";s:14:\"8.x-3.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1584823830\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha1\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha1\";s:7:\"version\";s:14:\"8.x-3.0-alpha1\";s:3:\"tag\";s:14:\"8.x-3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1584713675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-2.0-alpha13\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha13\";s:7:\"version\";s:15:\"8.x-2.0-alpha13\";s:3:\"tag\";s:15:\"8.x-2.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1582141618\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-2.0-alpha12\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha12\";s:7:\"version\";s:15:\"8.x-2.0-alpha12\";s:3:\"tag\";s:15:\"8.x-2.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1581799850\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-2.0-alpha11\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha11\";s:7:\"version\";s:15:\"8.x-2.0-alpha11\";s:3:\"tag\";s:15:\"8.x-2.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1581784971\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:15:\"8.x-2.0-alpha10\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha10\";s:7:\"version\";s:15:\"8.x-2.0-alpha10\";s:3:\"tag\";s:15:\"8.x-2.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1581670919\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha9\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha9\";s:7:\"version\";s:14:\"8.x-2.0-alpha9\";s:3:\"tag\";s:14:\"8.x-2.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1580894379\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha8\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha8\";s:7:\"version\";s:14:\"8.x-2.0-alpha8\";s:3:\"tag\";s:14:\"8.x-2.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1580892462\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha7\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha7\";s:7:\"version\";s:14:\"8.x-2.0-alpha7\";s:3:\"tag\";s:14:\"8.x-2.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1580374257\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha6\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha6\";s:7:\"version\";s:14:\"8.x-2.0-alpha6\";s:3:\"tag\";s:14:\"8.x-2.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1580139185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha5\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha5\";s:7:\"version\";s:14:\"8.x-2.0-alpha5\";s:3:\"tag\";s:14:\"8.x-2.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1579908781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha4\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha4\";s:7:\"version\";s:14:\"8.x-2.0-alpha4\";s:3:\"tag\";s:14:\"8.x-2.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1578573789\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha3\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha3\";s:7:\"version\";s:14:\"8.x-2.0-alpha3\";s:3:\"tag\";s:14:\"8.x-2.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1576589285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-2.0-alpha2\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha2\";s:7:\"version\";s:14:\"8.x-2.0-alpha2\";s:3:\"tag\";s:14:\"8.x-2.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1575496380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-2.0-alpha1\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha1\";s:7:\"version\";s:14:\"8.x-2.0-alpha1\";s:3:\"tag\";s:14:\"8.x-2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1575493680\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";s:5:\"terms\";a:0:{}}s:15:\"8.x-1.0-alpha14\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha14\";s:7:\"version\";s:15:\"8.x-1.0-alpha14\";s:3:\"tag\";s:15:\"8.x-1.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1582141601\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:15:\"8.x-1.0-alpha13\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha13\";s:7:\"version\";s:15:\"8.x-1.0-alpha13\";s:3:\"tag\";s:15:\"8.x-1.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1581799836\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:15:\"8.x-1.0-alpha12\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha12\";s:7:\"version\";s:15:\"8.x-1.0-alpha12\";s:3:\"tag\";s:15:\"8.x-1.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1581784989\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";s:5:\"terms\";a:0:{}}s:15:\"8.x-1.0-alpha11\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha11\";s:7:\"version\";s:15:\"8.x-1.0-alpha11\";s:3:\"tag\";s:15:\"8.x-1.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1581670945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:15:\"8.x-1.0-alpha10\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha10\";s:7:\"version\";s:15:\"8.x-1.0-alpha10\";s:3:\"tag\";s:15:\"8.x-1.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1580894364\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha9\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha9\";s:7:\"version\";s:14:\"8.x-1.0-alpha9\";s:3:\"tag\";s:14:\"8.x-1.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1580892445\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1580139185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1578905887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1578573789\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1576589285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1572892684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1572358984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1572007384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1570199287\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"4.0.x-dev\";a:11:{s:4:\"name\";s:13:\"gin 4.0.x-dev\";s:7:\"version\";s:9:\"4.0.x-dev\";s:3:\"tag\";s:5:\"4.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/gin/releases/4.0.x-dev\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/gin-4.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735404418\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734700815\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:15:\"gin 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-2.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1582387423\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:15:\"gin 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-1.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1582387472\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','gin_toolbar',_binary 'a:10:{s:5:\"title\";s:11:\"Gin Toolbar\";s:10:\"short_name\";s:11:\"gin_toolbar\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"2.0.,8.x-1.\";s:18:\"composer_namespace\";s:18:\"drupal/gin_toolbar\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/gin_toolbar\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:38:{s:5:\"2.0.0\";a:11:{s:4:\"name\";s:17:\"gin_toolbar 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin_toolbar/releases/2.0.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin_toolbar-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1734698921\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:19:\"gin_toolbar 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1734698810\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc8\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc8\";s:7:\"version\";s:11:\"8.x-1.0-rc8\";s:3:\"tag\";s:11:\"8.x-1.0-rc8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc8\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc8.tar.gz\";s:4:\"date\";s:10:\"1734527411\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:11:\"8.x-1.0-rc7\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc7\";s:7:\"version\";s:11:\"8.x-1.0-rc7\";s:3:\"tag\";s:11:\"8.x-1.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc7\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1733734483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1718368950\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1702727588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1697192878\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1688477489\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1688474912\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1669666835\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta22\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta22\";s:7:\"version\";s:14:\"8.x-1.0-beta22\";s:3:\"tag\";s:14:\"8.x-1.0-beta22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta22\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta22.tar.gz\";s:4:\"date\";s:10:\"1649709351\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta21\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta21\";s:7:\"version\";s:14:\"8.x-1.0-beta21\";s:3:\"tag\";s:14:\"8.x-1.0-beta21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta21\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta21.tar.gz\";s:4:\"date\";s:10:\"1646929714\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta20\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta20\";s:7:\"version\";s:14:\"8.x-1.0-beta20\";s:3:\"tag\";s:14:\"8.x-1.0-beta20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta20\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta20.tar.gz\";s:4:\"date\";s:10:\"1635149590\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta19\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta19\";s:7:\"version\";s:14:\"8.x-1.0-beta19\";s:3:\"tag\";s:14:\"8.x-1.0-beta19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta19\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta19.tar.gz\";s:4:\"date\";s:10:\"1626682027\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta18\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta18\";s:7:\"version\";s:14:\"8.x-1.0-beta18\";s:3:\"tag\";s:14:\"8.x-1.0-beta18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta18\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta18.tar.gz\";s:4:\"date\";s:10:\"1625232247\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta17\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta17\";s:7:\"version\";s:14:\"8.x-1.0-beta17\";s:3:\"tag\";s:14:\"8.x-1.0-beta17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta17\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta17.tar.gz\";s:4:\"date\";s:10:\"1622635843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta16\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta16\";s:7:\"version\";s:14:\"8.x-1.0-beta16\";s:3:\"tag\";s:14:\"8.x-1.0-beta16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta16\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta16.tar.gz\";s:4:\"date\";s:10:\"1622620508\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta15\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta15\";s:7:\"version\";s:14:\"8.x-1.0-beta15\";s:3:\"tag\";s:14:\"8.x-1.0-beta15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta15\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta15.tar.gz\";s:4:\"date\";s:10:\"1620393971\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta14\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta14\";s:7:\"version\";s:14:\"8.x-1.0-beta14\";s:3:\"tag\";s:14:\"8.x-1.0-beta14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta14\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta14.tar.gz\";s:4:\"date\";s:10:\"1607370428\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta13\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta13\";s:7:\"version\";s:14:\"8.x-1.0-beta13\";s:3:\"tag\";s:14:\"8.x-1.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta13\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1604868424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta12\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta12\";s:7:\"version\";s:14:\"8.x-1.0-beta12\";s:3:\"tag\";s:14:\"8.x-1.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta12\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1597406475\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-beta11\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta11\";s:7:\"version\";s:14:\"8.x-1.0-beta11\";s:3:\"tag\";s:14:\"8.x-1.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta11\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1594643490\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta10\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta10\";s:7:\"version\";s:14:\"8.x-1.0-beta10\";s:3:\"tag\";s:14:\"8.x-1.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta10\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1593766660\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta9\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta9\";s:7:\"version\";s:13:\"8.x-1.0-beta9\";s:3:\"tag\";s:13:\"8.x-1.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta9\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1593462042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta8\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta8\";s:7:\"version\";s:13:\"8.x-1.0-beta8\";s:3:\"tag\";s:13:\"8.x-1.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta8\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1592855833\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta7\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta7\";s:7:\"version\";s:13:\"8.x-1.0-beta7\";s:3:\"tag\";s:13:\"8.x-1.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta7\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1591349902\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta6\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta6\";s:7:\"version\";s:13:\"8.x-1.0-beta6\";s:3:\"tag\";s:13:\"8.x-1.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta6\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1590401639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1588460020\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1588342225\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1587403136\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1584829276\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1584713311\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1581785004\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1580139185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1579960985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1579958885\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:9:\"2.0.x-dev\";a:11:{s:4:\"name\";s:21:\"gin_toolbar 2.0.x-dev\";s:7:\"version\";s:9:\"2.0.x-dev\";s:3:\"tag\";s:5:\"2.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/gin_toolbar/releases/2.0.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/gin_toolbar-2.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735327030\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734511651\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','glightbox',_binary 'a:10:{s:5:\"title\";s:9:\"GLightbox\";s:10:\"short_name\";s:9:\"glightbox\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.0.\";s:18:\"composer_namespace\";s:16:\"drupal/glightbox\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:16:{s:6:\"1.0.13\";a:11:{s:4:\"name\";s:16:\"glightbox 1.0.13\";s:7:\"version\";s:6:\"1.0.13\";s:3:\"tag\";s:6:\"1.0.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/glightbox/releases/1.0.13\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/glightbox-1.0.13.tar.gz\";s:4:\"date\";s:10:\"1734093961\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.0.12\";a:11:{s:4:\"name\";s:16:\"glightbox 1.0.12\";s:7:\"version\";s:6:\"1.0.12\";s:3:\"tag\";s:6:\"1.0.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/glightbox/releases/1.0.12\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/glightbox-1.0.12.tar.gz\";s:4:\"date\";s:10:\"1731583765\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.0.11\";a:11:{s:4:\"name\";s:16:\"glightbox 1.0.11\";s:7:\"version\";s:6:\"1.0.11\";s:3:\"tag\";s:6:\"1.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/glightbox/releases/1.0.11\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/glightbox-1.0.11.tar.gz\";s:4:\"date\";s:10:\"1730572135\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.0.10\";a:11:{s:4:\"name\";s:16:\"glightbox 1.0.10\";s:7:\"version\";s:6:\"1.0.10\";s:3:\"tag\";s:6:\"1.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/glightbox/releases/1.0.10\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/glightbox-1.0.10.tar.gz\";s:4:\"date\";s:10:\"1730571218\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.9\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.9\";s:7:\"version\";s:5:\"1.0.9\";s:3:\"tag\";s:5:\"1.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.9.tar.gz\";s:4:\"date\";s:10:\"1727939818\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.8\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.8\";s:7:\"version\";s:5:\"1.0.8\";s:3:\"tag\";s:5:\"1.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.8.tar.gz\";s:4:\"date\";s:10:\"1726929656\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.7\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.7\";s:7:\"version\";s:5:\"1.0.7\";s:3:\"tag\";s:5:\"1.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.7.tar.gz\";s:4:\"date\";s:10:\"1713942568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.6\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.6\";s:7:\"version\";s:5:\"1.0.6\";s:3:\"tag\";s:5:\"1.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.6.tar.gz\";s:4:\"date\";s:10:\"1712003661\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.5\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.5\";s:7:\"version\";s:5:\"1.0.5\";s:3:\"tag\";s:5:\"1.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.5.tar.gz\";s:4:\"date\";s:10:\"1712002850\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.4\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.4\";s:7:\"version\";s:5:\"1.0.4\";s:3:\"tag\";s:5:\"1.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.4.tar.gz\";s:4:\"date\";s:10:\"1704707152\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.2\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.2\";s:7:\"version\";s:5:\"1.0.2\";s:3:\"tag\";s:5:\"1.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.2.tar.gz\";s:4:\"date\";s:10:\"1697006475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1690874897\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1670673111\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:21:\"glightbox 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/glightbox/releases/1.0.0-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1669550449\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.0.0-alpha1\";a:11:{s:4:\"name\";s:22:\"glightbox 1.0.0-alpha1\";s:7:\"version\";s:12:\"1.0.0-alpha1\";s:3:\"tag\";s:12:\"1.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/glightbox/releases/1.0.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1669124562\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:19:\"glightbox 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/glightbox/releases/1.0.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/glightbox-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734093579\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','glightbox_media_video',_binary 'a:10:{s:5:\"title\";s:21:\"GLightbox Media Video\";s:10:\"short_name\";s:21:\"glightbox_media_video\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.0.\";s:18:\"composer_namespace\";s:28:\"drupal/glightbox_media_video\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:52:\"https://www.drupal.org/project/glightbox_media_video\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:7:{s:5:\"1.0.3\";a:11:{s:4:\"name\";s:27:\"glightbox_media_video 1.0.3\";s:7:\"version\";s:5:\"1.0.3\";s:3:\"tag\";s:5:\"1.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.3\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.3.tar.gz\";s:4:\"date\";s:10:\"1734297824\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.2\";a:11:{s:4:\"name\";s:27:\"glightbox_media_video 1.0.2\";s:7:\"version\";s:5:\"1.0.2\";s:3:\"tag\";s:5:\"1.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.2.tar.gz\";s:4:\"date\";s:10:\"1733303221\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:27:\"glightbox_media_video 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1713942578\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:27:\"glightbox_media_video 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1705421893\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.0.0-alpha3\";a:11:{s:4:\"name\";s:34:\"glightbox_media_video 1.0.0-alpha3\";s:7:\"version\";s:12:\"1.0.0-alpha3\";s:3:\"tag\";s:12:\"1.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.0-alpha3\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697395686\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.0.0-alpha2\";a:11:{s:4:\"name\";s:34:\"glightbox_media_video 1.0.0-alpha2\";s:7:\"version\";s:12:\"1.0.0-alpha2\";s:3:\"tag\";s:12:\"1.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.0-alpha2\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1694768486\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:31:\"glightbox_media_video 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.x-dev\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734297549\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','image_effects',_binary 'a:10:{s:5:\"title\";s:13:\"Image Effects\";s:10:\"short_name\";s:13:\"image_effects\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"4.0.,8.x-3.\";s:18:\"composer_namespace\";s:20:\"drupal/image_effects\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/image_effects\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:37:{s:5:\"4.0.0\";a:11:{s:4:\"name\";s:19:\"image_effects 4.0.0\";s:7:\"version\";s:5:\"4.0.0\";s:3:\"tag\";s:5:\"4.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/image_effects/releases/4.0.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0.tar.gz\";s:4:\"date\";s:10:\"1733831437\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:9:\"4.0.0-rc3\";a:11:{s:4:\"name\";s:23:\"image_effects 4.0.0-rc3\";s:7:\"version\";s:9:\"4.0.0-rc3\";s:3:\"tag\";s:9:\"4.0.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/image_effects/releases/4.0.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1731519771\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:9:\"4.0.0-rc2\";a:11:{s:4:\"name\";s:23:\"image_effects 4.0.0-rc2\";s:7:\"version\";s:9:\"4.0.0-rc2\";s:3:\"tag\";s:9:\"4.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/image_effects/releases/4.0.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1731490531\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:9:\"4.0.0-rc1\";a:11:{s:4:\"name\";s:23:\"image_effects 4.0.0-rc1\";s:7:\"version\";s:9:\"4.0.0-rc1\";s:3:\"tag\";s:9:\"4.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/image_effects/releases/4.0.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1726321525\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:11:\"4.0.0-beta2\";a:11:{s:4:\"name\";s:25:\"image_effects 4.0.0-beta2\";s:7:\"version\";s:11:\"4.0.0-beta2\";s:3:\"tag\";s:11:\"4.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/4.0.0-beta2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1725133607\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";}s:11:\"4.0.0-beta1\";a:11:{s:4:\"name\";s:25:\"image_effects 4.0.0-beta1\";s:7:\"version\";s:11:\"4.0.0-beta1\";s:3:\"tag\";s:11:\"4.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/4.0.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1723547538\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:12:\"4.0.0-alpha2\";a:11:{s:4:\"name\";s:26:\"image_effects 4.0.0-alpha2\";s:7:\"version\";s:12:\"4.0.0-alpha2\";s:3:\"tag\";s:12:\"4.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/image_effects/releases/4.0.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1719673323\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:12:\"4.0.0-alpha1\";a:11:{s:4:\"name\";s:26:\"image_effects 4.0.0-alpha1\";s:7:\"version\";s:12:\"4.0.0-alpha1\";s:3:\"tag\";s:12:\"4.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/image_effects/releases/4.0.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1719174775\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.6\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.6\";s:7:\"version\";s:7:\"8.x-3.6\";s:3:\"tag\";s:7:\"8.x-3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.6\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.6.tar.gz\";s:4:\"date\";s:10:\"1705681111\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.5\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.5\";s:7:\"version\";s:7:\"8.x-3.5\";s:3:\"tag\";s:7:\"8.x-3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.5.tar.gz\";s:4:\"date\";s:10:\"1703018384\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.4\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.4\";s:7:\"version\";s:7:\"8.x-3.4\";s:3:\"tag\";s:7:\"8.x-3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.4.tar.gz\";s:4:\"date\";s:10:\"1664106631\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.3\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.3\";s:7:\"version\";s:7:\"8.x-3.3\";s:3:\"tag\";s:7:\"8.x-3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.3.tar.gz\";s:4:\"date\";s:10:\"1656755133\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:7:\"8.x-3.2\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.2\";s:7:\"version\";s:7:\"8.x-3.2\";s:3:\"tag\";s:7:\"8.x-3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.2.tar.gz\";s:4:\"date\";s:10:\"1639923532\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1607189720\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.9 || ^9\";}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1581702907\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:25:\"image_effects 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1579511590\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:25:\"image_effects 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1579013889\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-3.0-alpha1\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-3.0-alpha1\";s:7:\"version\";s:14:\"8.x-3.0-alpha1\";s:3:\"tag\";s:14:\"8.x-3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-3.0-alpha1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1573398784\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-2.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1547928180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-2.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1543319281\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-2.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1524304984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-2.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1507016344\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:27:\"image_effects 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/image_effects/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1503414544\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-1.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1547998080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-1.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1543322281\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1524304384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1492431842\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:27:\"image_effects 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1489994284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1487259483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1485631383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1479725943\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1459699439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1454614739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"4.0.x-dev\";a:11:{s:4:\"name\";s:23:\"image_effects 4.0.x-dev\";s:7:\"version\";s:9:\"4.0.x-dev\";s:3:\"tag\";s:5:\"4.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/image_effects/releases/4.0.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/image_effects-4.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1731518932\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:25:\"image_effects 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/8.x-3.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1718480779\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.2\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:25:\"image_effects 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/8.x-2.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1580899404\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:25:\"image_effects 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/8.x-1.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1554798486\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','jquery_ui',_binary 'a:10:{s:5:\"title\";s:9:\"jQuery UI\";s:10:\"short_name\";s:9:\"jquery_ui\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:16:\"drupal/jquery_ui\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/jquery_ui\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.7\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1717002098\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1668521197\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1668437968\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1582149957\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1582044456\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1571251084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1571242084\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1568823185\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:21:\"jquery_ui 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1716994751\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','jquery_ui_accordion',_binary 'a:10:{s:5:\"title\";s:19:\"jQuery UI Accordion\";s:10:\"short_name\";s:19:\"jquery_ui_accordion\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"2.0.,2.1.\";s:18:\"composer_namespace\";s:26:\"drupal/jquery_ui_accordion\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:50:\"https://www.drupal.org/project/jquery_ui_accordion\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"2.1.0\";a:11:{s:4:\"name\";s:25:\"jquery_ui_accordion 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jquery_ui_accordion/releases/2.1.0\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1717015495\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:25:\"jquery_ui_accordion 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jquery_ui_accordion/releases/2.0.0\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1670871459\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:27:\"jquery_ui_accordion 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jquery_ui_accordion/releases/8.x-1.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1584106477\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:27:\"jquery_ui_accordion 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jquery_ui_accordion/releases/8.x-1.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1568740983\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:27:\"jquery_ui_accordion 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jquery_ui_accordion/releases/2.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1717012942\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:31:\"jquery_ui_accordion 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/jquery_ui_accordion/releases/8.x-1.x-dev\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1584102992\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','jquery_ui_tabs',_binary 'a:10:{s:5:\"title\";s:14:\"jQuery UI Tabs\";s:10:\"short_name\";s:14:\"jquery_ui_tabs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"2.1.\";s:18:\"composer_namespace\";s:21:\"drupal/jquery_ui_tabs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/jquery_ui_tabs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:5:{s:5:\"2.1.0\";a:11:{s:4:\"name\";s:20:\"jquery_ui_tabs 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/jquery_ui_tabs/releases/2.1.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1719935962\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:20:\"jquery_ui_tabs 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/jquery_ui_tabs/releases/2.0.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1670948528\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:22:\"jquery_ui_tabs 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jquery_ui_tabs/releases/8.x-1.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1590102797\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:22:\"jquery_ui_tabs 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jquery_ui_tabs/releases/8.x-1.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1568819887\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:26:\"jquery_ui_tabs 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jquery_ui_tabs/releases/8.x-1.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1590102633\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','layout_paragraphs',_binary 'a:10:{s:5:\"title\";s:17:\"Layout Paragraphs\";s:10:\"short_name\";s:17:\"layout_paragraphs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"2.0.,2.1.\";s:18:\"composer_namespace\";s:24:\"drupal/layout_paragraphs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:48:\"https://www.drupal.org/project/layout_paragraphs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:33:{s:5:\"2.1.1\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.1.1\";s:7:\"version\";s:5:\"2.1.1\";s:3:\"tag\";s:5:\"2.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.1.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.1.1.tar.gz\";s:4:\"date\";s:10:\"1732724677\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"2.1.0\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.1.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1724879054\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"2.0.8\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.8\";s:7:\"version\";s:5:\"2.0.8\";s:3:\"tag\";s:5:\"2.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.8\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.8.tar.gz\";s:4:\"date\";s:10:\"1722385148\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:5:\"2.0.7\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.7\";s:7:\"version\";s:5:\"2.0.7\";s:3:\"tag\";s:5:\"2.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.7\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.7.tar.gz\";s:4:\"date\";s:10:\"1722017736\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.6\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.6\";s:7:\"version\";s:5:\"2.0.6\";s:3:\"tag\";s:5:\"2.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.6.tar.gz\";s:4:\"date\";s:10:\"1720734897\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.5\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.5\";s:7:\"version\";s:5:\"2.0.5\";s:3:\"tag\";s:5:\"2.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.5.tar.gz\";s:4:\"date\";s:10:\"1717779453\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.4\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.4\";s:7:\"version\";s:5:\"2.0.4\";s:3:\"tag\";s:5:\"2.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.4.tar.gz\";s:4:\"date\";s:10:\"1702252843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.3\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.3\";s:7:\"version\";s:5:\"2.0.3\";s:3:\"tag\";s:5:\"2.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.3.tar.gz\";s:4:\"date\";s:10:\"1683938207\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.2\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.2\";s:7:\"version\";s:5:\"2.0.2\";s:3:\"tag\";s:5:\"2.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.2.tar.gz\";s:4:\"date\";s:10:\"1671393656\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.1 || ^10\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1661260491\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1660593911\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta9\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta9\";s:7:\"version\";s:11:\"2.0.0-beta9\";s:3:\"tag\";s:11:\"2.0.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta9\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1649970500\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta8\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta8\";s:7:\"version\";s:11:\"2.0.0-beta8\";s:3:\"tag\";s:11:\"2.0.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta8\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1647014784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta7\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta7\";s:7:\"version\";s:11:\"2.0.0-beta7\";s:3:\"tag\";s:11:\"2.0.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta7\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1646947506\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta6\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta6\";s:7:\"version\";s:11:\"2.0.0-beta6\";s:3:\"tag\";s:11:\"2.0.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta6\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1641858451\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta5\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta5\";s:7:\"version\";s:11:\"2.0.0-beta5\";s:3:\"tag\";s:11:\"2.0.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta5\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1636558301\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta4\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta4\";s:7:\"version\";s:11:\"2.0.0-beta4\";s:3:\"tag\";s:11:\"2.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1636489464\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta3\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta3\";s:7:\"version\";s:11:\"2.0.0-beta3\";s:3:\"tag\";s:11:\"2.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1636388762\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta2\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta2\";s:7:\"version\";s:11:\"2.0.0-beta2\";s:3:\"tag\";s:11:\"2.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1635776878\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta1\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta1\";s:7:\"version\";s:11:\"2.0.0-beta1\";s:3:\"tag\";s:11:\"2.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1631717394\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha4\";a:11:{s:4:\"name\";s:30:\"layout_paragraphs 2.0.0-alpha4\";s:7:\"version\";s:12:\"2.0.0-alpha4\";s:3:\"tag\";s:12:\"2.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-alpha4\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1626282275\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha3\";a:11:{s:4:\"name\";s:30:\"layout_paragraphs 2.0.0-alpha3\";s:7:\"version\";s:12:\"2.0.0-alpha3\";s:3:\"tag\";s:12:\"2.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-alpha3\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1626108808\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha2\";a:11:{s:4:\"name\";s:30:\"layout_paragraphs 2.0.0-alpha2\";s:7:\"version\";s:12:\"2.0.0-alpha2\";s:3:\"tag\";s:12:\"2.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-alpha2\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1624480490\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha1\";a:11:{s:4:\"name\";s:30:\"layout_paragraphs 2.0.0-alpha1\";s:7:\"version\";s:12:\"2.0.0-alpha1\";s:3:\"tag\";s:12:\"2.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-alpha1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1621283252\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1621524309\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta5\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 1.0.0-beta5\";s:7:\"version\";s:11:\"1.0.0-beta5\";s:3:\"tag\";s:11:\"1.0.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0-beta5\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1614782452\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta4\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 1.0.0-beta4\";s:7:\"version\";s:11:\"1.0.0-beta4\";s:3:\"tag\";s:11:\"1.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0-beta4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1607441986\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta3\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 1.0.0-beta3\";s:7:\"version\";s:11:\"1.0.0-beta3\";s:3:\"tag\";s:11:\"1.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0-beta3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1594929046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta2\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 1.0.0-beta2\";s:7:\"version\";s:11:\"1.0.0-beta2\";s:3:\"tag\";s:11:\"1.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0-beta2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1594316314\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0-beta1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1593994369\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:9:\"2.1.x-dev\";a:11:{s:4:\"name\";s:27:\"layout_paragraphs 2.1.x-dev\";s:7:\"version\";s:9:\"2.1.x-dev\";s:3:\"tag\";s:5:\"2.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/layout_paragraphs/releases/2.1.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734749192\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"2.0.x-dev\";a:11:{s:4:\"name\";s:27:\"layout_paragraphs 2.0.x-dev\";s:7:\"version\";s:9:\"2.0.x-dev\";s:3:\"tag\";s:5:\"2.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1724777448\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:27:\"layout_paragraphs 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1635096355\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','link_attributes',_binary 'a:10:{s:5:\"title\";s:22:\"Link Attributes widget\";s:10:\"short_name\";s:15:\"link_attributes\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"2.1.\";s:18:\"composer_namespace\";s:22:\"drupal/link_attributes\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:46:\"https://www.drupal.org/project/link_attributes\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:25:{s:5:\"2.1.1\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.1.1\";s:7:\"version\";s:5:\"2.1.1\";s:3:\"tag\";s:5:\"2.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.1.1.tar.gz\";s:4:\"date\";s:10:\"1721366572\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:5:\"2.1.0\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1690356668\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.0.2\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.0.2\";s:7:\"version\";s:5:\"2.0.2\";s:3:\"tag\";s:5:\"2.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.0.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.0.2.tar.gz\";s:4:\"date\";s:10:\"1689299675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.0.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1689118258\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.0.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1687393829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.14\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1687393687\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.13\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1677018560\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.12\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1668801560\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.11\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1598323550\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.10\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1580259496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.9\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1564012686\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.8\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1560473286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.7\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1559689681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1554334381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1537173781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1537148883\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1526769180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1514787185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1500846243\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1481849583\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:30:\"link_attributes 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1479245341\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:30:\"link_attributes 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1467697426\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:30:\"link_attributes 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1467697426\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:23:\"link_attributes 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/2.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721366461\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:27:\"link_attributes 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1685694375\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','media_library_edit',_binary 'a:10:{s:5:\"title\";s:18:\"Media Library Edit\";s:10:\"short_name\";s:18:\"media_library_edit\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"3.0.\";s:18:\"composer_namespace\";s:25:\"drupal/media_library_edit\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:49:\"https://www.drupal.org/project/media_library_edit\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:15:{s:5:\"3.0.4\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.4\";s:7:\"version\";s:5:\"3.0.4\";s:3:\"tag\";s:5:\"3.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.4.tar.gz\";s:4:\"date\";s:10:\"1724357846\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"3.0.3\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.3\";s:7:\"version\";s:5:\"3.0.3\";s:3:\"tag\";s:5:\"3.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.3.tar.gz\";s:4:\"date\";s:10:\"1706394959\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.0.2\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.2\";s:7:\"version\";s:5:\"3.0.2\";s:3:\"tag\";s:5:\"3.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.2.tar.gz\";s:4:\"date\";s:10:\"1671913381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.0.1\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.1\";s:7:\"version\";s:5:\"3.0.1\";s:3:\"tag\";s:5:\"3.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.1.tar.gz\";s:4:\"date\";s:10:\"1667499767\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1667489719\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1653483531\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1638192802\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1634818379\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1607795681\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1607795644\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:33:\"media_library_edit 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1591618255\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:33:\"media_library_edit 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1573913585\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:9:\"3.0.x-dev\";a:11:{s:4:\"name\";s:28:\"media_library_edit 3.0.x-dev\";s:7:\"version\";s:9:\"3.0.x-dev\";s:3:\"tag\";s:5:\"3.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/media_library_edit/releases/3.0.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1724357732\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:30:\"media_library_edit 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.x-dev\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1667477923\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:30:\"media_library_edit 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.x-dev\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1593086545\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672);
INSERT INTO `key_value_expire` VALUES ('update_available_releases','media_library_form_element',_binary 'a:10:{s:5:\"title\";s:30:\"Media Library Form API Element\";s:10:\"short_name\";s:26:\"media_library_form_element\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"2.0.,2.1.\";s:18:\"composer_namespace\";s:33:\"drupal/media_library_form_element\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:57:\"https://www.drupal.org/project/media_library_form_element\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:28:{s:5:\"2.1.1\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.1.1\";s:7:\"version\";s:5:\"2.1.1\";s:3:\"tag\";s:5:\"2.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.1.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.1.1.tar.gz\";s:4:\"date\";s:10:\"1724676084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:5:\"2.1.0\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.1.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1719852877\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.3\";}s:5:\"2.0.6\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.6\";s:7:\"version\";s:5:\"2.0.6\";s:3:\"tag\";s:5:\"2.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.6\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.6.tar.gz\";s:4:\"date\";s:10:\"1674048931\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.5\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.5\";s:7:\"version\";s:5:\"2.0.5\";s:3:\"tag\";s:5:\"2.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.5\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.5.tar.gz\";s:4:\"date\";s:10:\"1673542646\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.4\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.4\";s:7:\"version\";s:5:\"2.0.4\";s:3:\"tag\";s:5:\"2.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.4\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.4.tar.gz\";s:4:\"date\";s:10:\"1659257104\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.3\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.3\";s:7:\"version\";s:5:\"2.0.3\";s:3:\"tag\";s:5:\"2.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.3\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.3.tar.gz\";s:4:\"date\";s:10:\"1608021997\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1607696048\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1592564249\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha1\";a:11:{s:4:\"name\";s:39:\"media_library_form_element 2.0.0-alpha1\";s:7:\"version\";s:12:\"2.0.0-alpha1\";s:3:\"tag\";s:12:\"2.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:79:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.0-alpha1\";s:13:\"download_link\";s:84:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1592563784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.3\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1608023001\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.2\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1607703376\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.1\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1607699562\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1592562569\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1592560499\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1592039969\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1589988383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1588247675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha9\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha9\";s:7:\"version\";s:14:\"8.x-1.0-alpha9\";s:3:\"tag\";s:14:\"8.x-1.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha9\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1588244814\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1587107544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1580121481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1578740587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1578645188\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1576831688\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1576246080\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1575558480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1571816584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/2.x-dev\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1724180723\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:38:\"media_library_form_element 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.x-dev\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1608021762\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','paragraphs',_binary 'a:10:{s:5:\"title\";s:10:\"Paragraphs\";s:10:\"short_name\";s:10:\"paragraphs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:17:\"drupal/paragraphs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:41:\"https://www.drupal.org/project/paragraphs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:24:{s:8:\"8.x-1.18\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.18\";s:7:\"version\";s:8:\"8.x-1.18\";s:3:\"tag\";s:8:\"8.x-1.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.18\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.18.tar.gz\";s:4:\"date\";s:10:\"1723029144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";}s:8:\"8.x-1.17\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.17\";s:7:\"version\";s:8:\"8.x-1.17\";s:3:\"tag\";s:8:\"8.x-1.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.17\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.17.tar.gz\";s:4:\"date\";s:10:\"1705234146\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.16\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1694007797\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.15\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1661440897\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1650520869\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1646121716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1590061335\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1581850829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1572617586\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1565881389\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1553618281\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1553087589\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1550669584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1541001780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1540628880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1527502684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1505802544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1487331784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1469725739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:22:\"paragraphs 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1464728039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:22:\"paragraphs 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1447766339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:25:\"paragraphs 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1421889780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:25:\"paragraphs 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1421790180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:22:\"paragraphs 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1732869655\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','tb_megamenu',_binary 'a:10:{s:5:\"title\";s:20:\"The Better Mega Menu\";s:10:\"short_name\";s:11:\"tb_megamenu\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"3.0.,8.x-1.\";s:18:\"composer_namespace\";s:18:\"drupal/tb_megamenu\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/tb_megamenu\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:29:{s:12:\"3.0.0-alpha4\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 3.0.0-alpha4\";s:7:\"version\";s:12:\"3.0.0-alpha4\";s:3:\"tag\";s:12:\"3.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/3.0.0-alpha4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1713052614\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";}s:12:\"3.0.0-alpha3\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 3.0.0-alpha3\";s:7:\"version\";s:12:\"3.0.0-alpha3\";s:3:\"tag\";s:12:\"3.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/3.0.0-alpha3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1711742804\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:12:\"3.0.0-alpha2\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 3.0.0-alpha2\";s:7:\"version\";s:12:\"3.0.0-alpha2\";s:3:\"tag\";s:12:\"3.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/3.0.0-alpha2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1686707445\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"^10\";}s:12:\"3.0.0-alpha1\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 3.0.0-alpha1\";s:7:\"version\";s:12:\"3.0.0-alpha1\";s:3:\"tag\";s:12:\"3.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/3.0.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1686670925\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"^10\";}s:12:\"2.0.0-alpha7\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha7\";s:7:\"version\";s:12:\"2.0.0-alpha7\";s:3:\"tag\";s:12:\"2.0.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha7\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1686707356\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha6\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha6\";s:7:\"version\";s:12:\"2.0.0-alpha6\";s:3:\"tag\";s:12:\"2.0.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha6\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1686671319\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha5\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha5\";s:7:\"version\";s:12:\"2.0.0-alpha5\";s:3:\"tag\";s:12:\"2.0.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha5\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1686670725\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:12:\"2.0.0-alpha4\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha4\";s:7:\"version\";s:12:\"2.0.0-alpha4\";s:3:\"tag\";s:12:\"2.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1686090563\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:12:\"2.0.0-alpha3\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha3\";s:7:\"version\";s:12:\"2.0.0-alpha3\";s:3:\"tag\";s:12:\"2.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1648217068\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha2\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha2\";s:7:\"version\";s:12:\"2.0.0-alpha2\";s:3:\"tag\";s:12:\"2.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1637335448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha1\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha1\";s:7:\"version\";s:12:\"2.0.0-alpha1\";s:3:\"tag\";s:12:\"2.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1637263588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.9\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1712869460\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.8\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1711743071\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.7\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1648215867\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1636411554\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1632512202\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1632256810\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1628694822\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1625679425\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1625676068\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1624642896\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"tb_megamenu 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1613058353\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:23:\"tb_megamenu 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1611863067\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:23:\"tb_megamenu 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1611795247\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:25:\"tb_megamenu 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1601668581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:25:\"tb_megamenu 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1599847241\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"3.x-dev\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 3.x-dev\";s:7:\"version\";s:7:\"3.x-dev\";s:3:\"tag\";s:3:\"3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/3.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1716413185\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/2.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1692374714\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"tb_megamenu 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1711725397\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','twig_tweak',_binary 'a:10:{s:5:\"title\";s:10:\"Twig Tweak\";s:10:\"short_name\";s:10:\"twig_tweak\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"3.3.,3.4.\";s:18:\"composer_namespace\";s:17:\"drupal/twig_tweak\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:41:\"https://www.drupal.org/project/twig_tweak\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:44:{s:5:\"3.4.0\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.4.0\";s:7:\"version\";s:5:\"3.4.0\";s:3:\"tag\";s:5:\"3.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.4.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.4.0.tar.gz\";s:4:\"date\";s:10:\"1721562308\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"3.3.0\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.3.0\";s:7:\"version\";s:5:\"3.3.0\";s:3:\"tag\";s:5:\"3.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.3.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.3.0.tar.gz\";s:4:\"date\";s:10:\"1708670116\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"3.2.1\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.2.1\";s:7:\"version\";s:5:\"3.2.1\";s:3:\"tag\";s:5:\"3.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.2.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.2.1.tar.gz\";s:4:\"date\";s:10:\"1677404306\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"3.2.0\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.2.0\";s:7:\"version\";s:5:\"3.2.0\";s:3:\"tag\";s:5:\"3.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.2.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.2.0.tar.gz\";s:4:\"date\";s:10:\"1664084754\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"3.1.3\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.1.3\";s:7:\"version\";s:5:\"3.1.3\";s:3:\"tag\";s:5:\"3.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.1.3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.1.3.tar.gz\";s:4:\"date\";s:10:\"1635338145\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:5:\"3.1.2\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.1.2\";s:7:\"version\";s:5:\"3.1.2\";s:3:\"tag\";s:5:\"3.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.1.2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.1.2.tar.gz\";s:4:\"date\";s:10:\"1625377167\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:5:\"3.1.1\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.1.1\";s:7:\"version\";s:5:\"3.1.1\";s:3:\"tag\";s:5:\"3.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.1.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.1.1.tar.gz\";s:4:\"date\";s:10:\"1619981432\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:5:\"3.1.0\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.1.0\";s:7:\"version\";s:5:\"3.1.0\";s:3:\"tag\";s:5:\"3.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.1.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.1.0.tar.gz\";s:4:\"date\";s:10:\"1619885672\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1608096096\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:9:\"3.0.0-rc2\";a:11:{s:4:\"name\";s:20:\"twig_tweak 3.0.0-rc2\";s:7:\"version\";s:9:\"3.0.0-rc2\";s:3:\"tag\";s:9:\"3.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0-rc2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1599738229\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^9\";}s:9:\"3.0.0-rc1\";a:11:{s:4:\"name\";s:20:\"twig_tweak 3.0.0-rc1\";s:7:\"version\";s:9:\"3.0.0-rc1\";s:3:\"tag\";s:9:\"3.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0-rc1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1596039349\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^9\";}s:11:\"3.0.0-beta3\";a:11:{s:4:\"name\";s:22:\"twig_tweak 3.0.0-beta3\";s:7:\"version\";s:11:\"3.0.0-beta3\";s:3:\"tag\";s:11:\"3.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0-beta3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1593957712\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^9\";}s:11:\"3.0.0-beta2\";a:11:{s:4:\"name\";s:22:\"twig_tweak 3.0.0-beta2\";s:7:\"version\";s:11:\"3.0.0-beta2\";s:3:\"tag\";s:11:\"3.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1588828286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^9\";}s:11:\"3.0.0-beta1\";a:11:{s:4:\"name\";s:22:\"twig_tweak 3.0.0-beta1\";s:7:\"version\";s:11:\"3.0.0-beta1\";s:3:\"tag\";s:11:\"3.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1585244745\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^9\";s:5:\"terms\";a:0:{}}s:8:\"8.x-2.10\";a:11:{s:4:\"name\";s:19:\"twig_tweak 8.x-2.10\";s:7:\"version\";s:8:\"8.x-2.10\";s:3:\"tag\";s:8:\"8.x-2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.10.tar.gz\";s:4:\"date\";s:10:\"1663947949\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.9\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.9\";s:7:\"version\";s:7:\"8.x-2.9\";s:3:\"tag\";s:7:\"8.x-2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.9.tar.gz\";s:4:\"date\";s:10:\"1608093728\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.8\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.8\";s:7:\"version\";s:7:\"8.x-2.8\";s:3:\"tag\";s:7:\"8.x-2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.8.tar.gz\";s:4:\"date\";s:10:\"1602156806\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.7\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.7\";s:7:\"version\";s:7:\"8.x-2.7\";s:3:\"tag\";s:7:\"8.x-2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.7.tar.gz\";s:4:\"date\";s:10:\"1601530189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.6\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.6\";s:7:\"version\";s:7:\"8.x-2.6\";s:3:\"tag\";s:7:\"8.x-2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.6.tar.gz\";s:4:\"date\";s:10:\"1589992479\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1583908076\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1563096785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1555516385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1555515190\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1531889025\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1523707084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc4\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-2.0-rc4\";s:7:\"version\";s:11:\"8.x-2.0-rc4\";s:3:\"tag\";s:11:\"8.x-2.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.0-rc4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1522232884\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc3\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-2.0-rc3\";s:7:\"version\";s:11:\"8.x-2.0-rc3\";s:3:\"tag\";s:11:\"8.x-2.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.0-rc3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1520442180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc2\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-2.0-rc2\";s:7:\"version\";s:11:\"8.x-2.0-rc2\";s:3:\"tag\";s:11:\"8.x-2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.0-rc2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1512379985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc1\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-2.0-rc1\";s:7:\"version\";s:11:\"8.x-2.0-rc1\";s:3:\"tag\";s:11:\"8.x-2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.0-rc1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1505466243\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:19:\"twig_tweak 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1582883089\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1505464444\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1495984083\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1493543043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1489930083\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1484994183\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1478691840\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1472818139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1464796439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1459421432\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1457772839\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"4.x-dev\";a:11:{s:4:\"name\";s:18:\"twig_tweak 4.x-dev\";s:7:\"version\";s:7:\"4.x-dev\";s:3:\"tag\";s:3:\"4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734264182\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^11.0\";s:5:\"terms\";a:0:{}}s:7:\"3.x-dev\";a:11:{s:4:\"name\";s:18:\"twig_tweak 3.x-dev\";s:7:\"version\";s:7:\"3.x-dev\";s:3:\"tag\";s:3:\"3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/3.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1733642066\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:14:\"^10.3 || ^11.0\";}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1664082283\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1582880828\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','viewsreference',_binary 'a:10:{s:5:\"title\";s:21:\"Views Reference Field\";s:10:\"short_name\";s:14:\"viewsreference\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-2.\";s:18:\"composer_namespace\";s:21:\"drupal/viewsreference\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/viewsreference\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:41:{s:14:\"8.x-2.0-beta10\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-beta10\";s:7:\"version\";s:14:\"8.x-2.0-beta10\";s:3:\"tag\";s:14:\"8.x-2.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta10\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1725510905\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:13:\"8.x-2.0-beta9\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta9\";s:7:\"version\";s:13:\"8.x-2.0-beta9\";s:3:\"tag\";s:13:\"8.x-2.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta9\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1722575139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:13:\"8.x-2.0-beta8\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta8\";s:7:\"version\";s:13:\"8.x-2.0-beta8\";s:3:\"tag\";s:13:\"8.x-2.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta8\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1717030540\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:13:\"8.x-2.0-beta7\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta7\";s:7:\"version\";s:13:\"8.x-2.0-beta7\";s:3:\"tag\";s:13:\"8.x-2.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta7\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1698849225\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta6\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta6\";s:7:\"version\";s:13:\"8.x-2.0-beta6\";s:3:\"tag\";s:13:\"8.x-2.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta6\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1691400463\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta5\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta5\";s:7:\"version\";s:13:\"8.x-2.0-beta5\";s:3:\"tag\";s:13:\"8.x-2.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta5\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1691399238\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta4\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta4\";s:7:\"version\";s:13:\"8.x-2.0-beta4\";s:3:\"tag\";s:13:\"8.x-2.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta4\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1664821610\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta3\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta3\";s:7:\"version\";s:13:\"8.x-2.0-beta3\";s:3:\"tag\";s:13:\"8.x-2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta3\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1658840434\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-2.0-beta2\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta2\";s:7:\"version\";s:13:\"8.x-2.0-beta2\";s:3:\"tag\";s:13:\"8.x-2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1597235052\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1595873106\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-2.0-alpha7\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha7\";s:7:\"version\";s:14:\"8.x-2.0-alpha7\";s:3:\"tag\";s:14:\"8.x-2.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha7\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1588510059\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-2.0-alpha6\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha6\";s:7:\"version\";s:14:\"8.x-2.0-alpha6\";s:3:\"tag\";s:14:\"8.x-2.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha6\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1576373887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha5\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha5\";s:7:\"version\";s:14:\"8.x-2.0-alpha5\";s:3:\"tag\";s:14:\"8.x-2.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha5\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1574807584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha4\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha4\";s:7:\"version\";s:14:\"8.x-2.0-alpha4\";s:3:\"tag\";s:14:\"8.x-2.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1515706384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha3\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha3\";s:7:\"version\";s:14:\"8.x-2.0-alpha3\";s:3:\"tag\";s:14:\"8.x-2.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1510927385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha2\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha2\";s:7:\"version\";s:14:\"8.x-2.0-alpha2\";s:3:\"tag\";s:14:\"8.x-2.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1508957945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha1\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha1\";s:7:\"version\";s:14:\"8.x-2.0-alpha1\";s:3:\"tag\";s:14:\"8.x-2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1508408044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.8\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1652694596\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1610571201\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1601529306\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1601512918\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1544740080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1544678580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1515538984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1515464888\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1502947144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1500699843\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1500437042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1500319442\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1500074043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1497764942\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1482381184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1480293783\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1480270680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1478134740\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1477682339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1473627239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1473283439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1473023939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1733950650\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1691455445\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672),('update_available_releases','views_year_filter',_binary 'a:10:{s:5:\"title\";s:17:\"Views year filter\";s:10:\"short_name\";s:17:\"views_year_filter\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"2.0.,2.1.\";s:18:\"composer_namespace\";s:24:\"drupal/views_year_filter\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:48:\"https://www.drupal.org/project/views_year_filter\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:15:{s:5:\"2.1.5\";a:11:{s:4:\"name\";s:23:\"views_year_filter 2.1.5\";s:7:\"version\";s:5:\"2.1.5\";s:3:\"tag\";s:5:\"2.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/views_year_filter/releases/2.1.5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/views_year_filter-2.1.5.tar.gz\";s:4:\"date\";s:10:\"1726675377\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:5:\"2.1.4\";a:11:{s:4:\"name\";s:23:\"views_year_filter 2.1.4\";s:7:\"version\";s:5:\"2.1.4\";s:3:\"tag\";s:5:\"2.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/views_year_filter/releases/2.1.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/views_year_filter-2.1.4.tar.gz\";s:4:\"date\";s:10:\"1718381908\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.1.3\";a:11:{s:4:\"name\";s:23:\"views_year_filter 2.1.3\";s:7:\"version\";s:5:\"2.1.3\";s:3:\"tag\";s:5:\"2.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/views_year_filter/releases/2.1.3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/views_year_filter-2.1.3.tar.gz\";s:4:\"date\";s:10:\"1708776643\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.1.2\";a:11:{s:4:\"name\";s:23:\"views_year_filter 2.1.2\";s:7:\"version\";s:5:\"2.1.2\";s:3:\"tag\";s:5:\"2.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/views_year_filter/releases/2.1.2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/views_year_filter-2.1.2.tar.gz\";s:4:\"date\";s:10:\"1700516275\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:5:\"2.1.1\";a:11:{s:4:\"name\";s:23:\"views_year_filter 2.1.1\";s:7:\"version\";s:5:\"2.1.1\";s:3:\"tag\";s:5:\"2.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/views_year_filter/releases/2.1.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/views_year_filter-2.1.1.tar.gz\";s:4:\"date\";s:10:\"1669398010\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:23:\"views_year_filter 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/views_year_filter/releases/2.0.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/views_year_filter-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1660679553\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:25:\"views_year_filter 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/views_year_filter/releases/8.x-1.7\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/views_year_filter-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1625182304\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:25:\"views_year_filter 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/views_year_filter/releases/8.x-1.6\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/views_year_filter-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1619740526\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:25:\"views_year_filter 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/views_year_filter/releases/8.x-1.5\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/views_year_filter-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1617923110\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:25:\"views_year_filter 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/views_year_filter/releases/8.x-1.4\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/views_year_filter-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1612306568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:25:\"views_year_filter 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/views_year_filter/releases/8.x-1.3\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/views_year_filter-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1608664713\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:25:\"views_year_filter 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/views_year_filter/releases/8.x-1.2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/views_year_filter-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1601896265\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:25:\"views_year_filter 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/views_year_filter/releases/8.x-1.1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/views_year_filter-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1588201892\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:25:\"views_year_filter 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/views_year_filter/releases/8.x-1.0\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/views_year_filter-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1569672484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:29:\"views_year_filter 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/views_year_filter/releases/8.x-1.x-dev\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/views_year_filter-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1660678174\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1735492272;}',1735578672);
/*!40000 ALTER TABLE `key_value_expire` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media`
--

DROP TABLE IF EXISTS `media`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media` (
  `mid` int unsigned NOT NULL AUTO_INCREMENT,
  `vid` int unsigned DEFAULT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`mid`),
  UNIQUE KEY `media_field__uuid__value` (`uuid`),
  UNIQUE KEY `media__vid` (`vid`),
  KEY `media_field__bundle__target_id` (`bundle`)
) ENGINE=InnoDB AUTO_INCREMENT=23 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for media entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media`
--

LOCK TABLES `media` WRITE;
/*!40000 ALTER TABLE `media` DISABLE KEYS */;
INSERT INTO `media` VALUES (1,1,'remote_video','09297b09-7e0f-4d3a-864c-a0cf5ab5350d','en'),(2,2,'image','0ad232e1-6107-4310-92c9-244c2bf555aa','en'),(3,3,'image','ecab1c87-0a5c-4eed-a4f8-8f75e26e209e','en'),(4,12,'image','e2688481-96fe-4e19-b8e0-5457b039e0c0','en'),(5,9,'image','c9674f24-0ae0-4b53-9471-b5b149c3e88b','en'),(6,10,'image','bcf6c7ff-7630-4757-8b1f-b63e327e82ef','en'),(7,11,'image','676d1c54-c3e2-425e-adde-d8205fde923e','en'),(8,13,'image','ccaa30f4-5032-4a50-be23-4cc574744493','en'),(9,14,'image','e087dd7a-cc44-4f25-bc04-76a7099eb5d6','en'),(10,15,'image','d521e7ca-5721-42ac-bf99-3393a2fa4ac8','en'),(11,16,'image','7aa39db3-5814-472b-b6ab-1b501a760f6e','en'),(12,17,'image','41e00732-a437-49d8-b8e2-078a9d1b0a32','en'),(13,18,'image','438b954b-bb63-469c-979c-5a5a14b53cfb','en'),(14,19,'image','28e6f9a8-1a9c-4020-8559-358e13575d33','en'),(15,20,'image','b5ffa8a9-e530-4537-86c3-8c5891fffb13','en'),(16,21,'image','6f51e936-b5c5-442c-b595-1c62afe53218','en'),(17,22,'image','097c4f46-932a-4f71-a580-7e0914bb0b25','en'),(18,23,'image','9ef37388-d32b-44ae-8954-3ae90ba6d589','en'),(19,25,'image','ee25d426-f054-4126-af7f-0b51834d0c81','en'),(20,26,'image','fe1311cb-0d4a-4ae3-9bfc-f9d5072d5110','en'),(21,27,'image','a94fd233-d617-4213-aadc-4d2c1cd994e2','en'),(22,28,'image','fa386fe6-9acc-488d-99ec-455f693c45eb','en');
/*!40000 ALTER TABLE `media` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media__field_media_audio_file`
--

DROP TABLE IF EXISTS `media__field_media_audio_file`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media__field_media_audio_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_audio_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_audio_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_audio_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_audio_file_target_id` (`field_media_audio_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_audio_file.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media__field_media_audio_file`
--

LOCK TABLES `media__field_media_audio_file` WRITE;
/*!40000 ALTER TABLE `media__field_media_audio_file` DISABLE KEYS */;
/*!40000 ALTER TABLE `media__field_media_audio_file` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media__field_media_document`
--

DROP TABLE IF EXISTS `media__field_media_document`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media__field_media_document` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_document_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_document_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_document_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_document_target_id` (`field_media_document_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_document.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media__field_media_document`
--

LOCK TABLES `media__field_media_document` WRITE;
/*!40000 ALTER TABLE `media__field_media_document` DISABLE KEYS */;
/*!40000 ALTER TABLE `media__field_media_document` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media__field_media_image`
--

DROP TABLE IF EXISTS `media__field_media_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media__field_media_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_media_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_media_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_media_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_image_target_id` (`field_media_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media__field_media_image`
--

LOCK TABLES `media__field_media_image` WRITE;
/*!40000 ALTER TABLE `media__field_media_image` DISABLE KEYS */;
INSERT INTO `media__field_media_image` VALUES ('image',0,2,2,'en',0,3,'bubbles 1','',1024,1024),('image',0,3,3,'en',0,4,'Bubbles 1','',826,831),('image',0,4,12,'en',0,5,'Extra Paragraph Types (EPT): Image Gallery','',632,405),('image',0,5,9,'en',0,6,'Extra Paragraph Types (EPT): Accordion','',440,415),('image',0,6,10,'en',0,7,'Extra Paragraph Types (EPT): Call to Action','',661,300),('image',0,7,11,'en',0,8,'Extra Paragraph Types (EPT): Tabs','',503,206),('image',0,8,13,'en',0,9,'bubbles 2','',1024,1024),('image',0,9,14,'en',0,10,'Extra Paragraph Types (EPT): Slick Slider','',1270,500),('image',0,10,15,'en',0,11,'Extra Paragraph Types (EPT): Carousel','',887,348),('image',0,11,16,'en',0,12,'Extra Paragraph Types (EPT): Slideshow','',947,652),('image',0,12,17,'en',0,13,'Extra Paragraph Types (EPT): Quote','',639,299),('image',0,13,18,'en',0,14,'Extra Paragraph Types (EPT): Tiles','',1186,615),('image',0,14,19,'en',0,15,'Extra Paragraph Types (EPT): Text','',1108,269),('image',0,15,20,'en',0,16,'Extra Block Types (EBT): Counter','',800,360),('image',0,16,21,'en',0,17,'GLightbox','',569,267),('image',0,17,22,'en',0,18,'Dark drop','',1280,777),('image',0,18,23,'en',0,19,'Footbal club','',1494,739),('image',0,19,25,'en',0,21,'bubbles 3','',1024,1024),('image',0,20,26,'en',0,22,'DOM Box','',1913,1049),('image',0,21,27,'en',0,23,'Background color, image or video','',1092,821),('image',0,22,28,'en',0,24,'Javascript plugins','',842,802);
/*!40000 ALTER TABLE `media__field_media_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media__field_media_oembed_video`
--

DROP TABLE IF EXISTS `media__field_media_oembed_video`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media__field_media_oembed_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_oembed_video_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_oembed_video.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media__field_media_oembed_video`
--

LOCK TABLES `media__field_media_oembed_video` WRITE;
/*!40000 ALTER TABLE `media__field_media_oembed_video` DISABLE KEYS */;
INSERT INTO `media__field_media_oembed_video` VALUES ('remote_video',0,1,1,'en',0,'https://youtu.be/zbdI7ugf6B8');
/*!40000 ALTER TABLE `media__field_media_oembed_video` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media__field_media_video_file`
--

DROP TABLE IF EXISTS `media__field_media_video_file`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media__field_media_video_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_video_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_video_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_video_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_video_file_target_id` (`field_media_video_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_video_file.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media__field_media_video_file`
--

LOCK TABLES `media__field_media_video_file` WRITE;
/*!40000 ALTER TABLE `media__field_media_video_file` DISABLE KEYS */;
/*!40000 ALTER TABLE `media__field_media_video_file` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_field_data`
--

DROP TABLE IF EXISTS `media_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_field_data` (
  `mid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `name` varchar(255) DEFAULT NULL,
  `thumbnail__target_id` int unsigned DEFAULT NULL COMMENT 'The ID of the file entity.',
  `thumbnail__alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `thumbnail__title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `thumbnail__width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `thumbnail__height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`mid`,`langcode`),
  KEY `media__id__default_langcode__langcode` (`mid`,`default_langcode`,`langcode`),
  KEY `media__vid` (`vid`),
  KEY `media_field__bundle__target_id` (`bundle`),
  KEY `media_field__uid__target_id` (`uid`),
  KEY `media_field__thumbnail__target_id` (`thumbnail__target_id`),
  KEY `media__status_bundle` (`status`,`bundle`,`mid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for media entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_field_data`
--

LOCK TABLES `media_field_data` WRITE;
/*!40000 ALTER TABLE `media_field_data` DISABLE KEYS */;
INSERT INTO `media_field_data` VALUES (1,1,'remote_video','en',1,1,'What\'s DrupalCon All About?',2,'',NULL,480,360,1728242872,1728242872,1,1),(2,2,'image','en',1,1,'333b8c43-dbee-469a-8766-c302f74bb595.jpg',3,'bubbles 1',NULL,1024,1024,1728819558,1728819558,1,1),(3,3,'image','en',1,1,'bg-image1.webp',4,'Bubbles 1',NULL,826,831,1728883281,1728883281,1,1),(4,12,'image','en',1,1,'fluid_grid_1.webp',5,'Fluid grid image gallery',NULL,632,405,1728884475,1728885349,1,1),(5,9,'image','en',1,1,'faq example.webp',6,'FAQ example',NULL,440,415,1728884651,1728885288,1,1),(6,10,'image','en',1,1,'2 columns CTA.webp',7,'2 Columns CTA',NULL,661,300,1728884846,1728885310,1,1),(7,11,'image','en',1,1,'EBT Tabs.webp',8,'EBT Tabs',NULL,503,206,1728885156,1728885331,1,1),(8,13,'image','en',1,1,'8af0c440-2152-4678-86c7-95ee5c055211.jpg',9,'bubbles 2',NULL,1024,1024,1728885422,1728885422,1,1),(9,14,'image','en',1,1,'ept-slick-slider.webp',10,'Extra Paragraph Types (EPT): Slick Slider',NULL,1270,500,1728885872,1728885872,1,1),(10,15,'image','en',1,1,'ebt carousel.webp',11,'Extra Paragraph Types (EPT): Carousel',NULL,887,348,1728887601,1728887601,1,1),(11,16,'image','en',1,1,'Home-Drupal-9_0.webp',12,'Extra Paragraph Types (EPT): Slideshow',NULL,947,652,1728887677,1728887677,1,1),(12,17,'image','en',1,1,'with_square_img_0.webp',13,'Extra Paragraph Types (EPT): Quote',NULL,639,299,1728887791,1728887791,1,1),(13,18,'image','en',1,1,'ept tiles.webp',14,'Extra Paragraph Types (EPT): Tiles',NULL,1186,615,1728887900,1728887900,1,1),(14,19,'image','en',1,1,'EPT text.webp',15,'Extra Paragraph Types (EPT): Text',NULL,1108,269,1728888003,1728888003,1,1),(15,20,'image','en',1,1,'ept counter.webp',16,'Extra Block Types (EBT): Counter',NULL,800,360,1728888321,1728888321,1,1),(16,21,'image','en',1,1,'glightbox.webp',17,'GLightbox',NULL,569,267,1728888670,1728888670,1,1),(17,22,'image','en',1,1,'dark drop.webp',18,'Dark drop',NULL,1280,777,1728889183,1728889183,1,1),(18,23,'image','en',1,1,'ept case.webp',19,'Footbal club',NULL,1494,739,1728933322,1728933322,1,1),(19,25,'image','en',1,1,'4950565d-af48-45ef-be68-c27550a02da9.webp',21,'bubbles 3',NULL,1024,1024,1728934033,1728935148,1,1),(20,26,'image','en',1,1,'DOM Box.webp',22,'DOM Box',NULL,1913,1049,1728936151,1728936151,1,1),(21,27,'image','en',1,1,'background image or video.webp',23,'Background color, image or video',NULL,1092,821,1728936355,1728936355,1,1),(22,28,'image','en',1,1,'javascript plugins.webp',24,'Javascript plugins',NULL,842,802,1728936556,1728936556,1,1);
/*!40000 ALTER TABLE `media_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_field_revision`
--

DROP TABLE IF EXISTS `media_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_field_revision` (
  `mid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `name` varchar(255) DEFAULT NULL,
  `thumbnail__target_id` int unsigned DEFAULT NULL COMMENT 'The ID of the file entity.',
  `thumbnail__alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `thumbnail__title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `thumbnail__width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `thumbnail__height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`,`langcode`),
  KEY `media__id__default_langcode__langcode` (`mid`,`default_langcode`,`langcode`),
  KEY `media_field__uid__target_id` (`uid`),
  KEY `media_field__thumbnail__target_id` (`thumbnail__target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for media entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_field_revision`
--

LOCK TABLES `media_field_revision` WRITE;
/*!40000 ALTER TABLE `media_field_revision` DISABLE KEYS */;
INSERT INTO `media_field_revision` VALUES (1,1,'en',1,1,'What\'s DrupalCon All About?',2,'',NULL,480,360,1728242872,1728242872,1,1),(2,2,'en',1,1,'333b8c43-dbee-469a-8766-c302f74bb595.jpg',3,'bubbles 1',NULL,1024,1024,1728819558,1728819558,1,1),(3,3,'en',1,1,'bg-image1.webp',4,'Bubbles 1',NULL,826,831,1728883281,1728883281,1,1),(4,4,'en',1,1,'fluid_grid_1.webp',5,'Fluid grid image gallery',NULL,632,405,1728884475,1728884475,1,1),(5,5,'en',1,1,'faq example.webp',6,'FAQ example',NULL,440,415,1728884651,1728884651,1,1),(6,6,'en',1,1,'2 columns CTA.webp',7,'2 Columns CTA',NULL,661,300,1728884846,1728884846,1,1),(7,7,'en',1,1,'EBT Tabs.webp',8,'EBT Tabs',NULL,503,206,1728885156,1728885156,1,1),(4,8,'en',1,1,'fluid_grid_1.webp',5,'Fluid grid image gallery',NULL,632,405,1728884475,1728885249,1,1),(5,9,'en',1,1,'faq example.webp',6,'FAQ example',NULL,440,415,1728884651,1728885288,1,1),(6,10,'en',1,1,'2 columns CTA.webp',7,'2 Columns CTA',NULL,661,300,1728884846,1728885310,1,1),(7,11,'en',1,1,'EBT Tabs.webp',8,'EBT Tabs',NULL,503,206,1728885156,1728885331,1,1),(4,12,'en',1,1,'fluid_grid_1.webp',5,'Fluid grid image gallery',NULL,632,405,1728884475,1728885349,1,1),(8,13,'en',1,1,'8af0c440-2152-4678-86c7-95ee5c055211.jpg',9,'bubbles 2',NULL,1024,1024,1728885422,1728885422,1,1),(9,14,'en',1,1,'ept-slick-slider.webp',10,'Extra Paragraph Types (EPT): Slick Slider',NULL,1270,500,1728885872,1728885872,1,1),(10,15,'en',1,1,'ebt carousel.webp',11,'Extra Paragraph Types (EPT): Carousel',NULL,887,348,1728887601,1728887601,1,1),(11,16,'en',1,1,'Home-Drupal-9_0.webp',12,'Extra Paragraph Types (EPT): Slideshow',NULL,947,652,1728887677,1728887677,1,1),(12,17,'en',1,1,'with_square_img_0.webp',13,'Extra Paragraph Types (EPT): Quote',NULL,639,299,1728887791,1728887791,1,1),(13,18,'en',1,1,'ept tiles.webp',14,'Extra Paragraph Types (EPT): Tiles',NULL,1186,615,1728887900,1728887900,1,1),(14,19,'en',1,1,'EPT text.webp',15,'Extra Paragraph Types (EPT): Text',NULL,1108,269,1728888003,1728888003,1,1),(15,20,'en',1,1,'ept counter.webp',16,'Extra Block Types (EBT): Counter',NULL,800,360,1728888321,1728888321,1,1),(16,21,'en',1,1,'glightbox.webp',17,'GLightbox',NULL,569,267,1728888670,1728888670,1,1),(17,22,'en',1,1,'dark drop.webp',18,'Dark drop',NULL,1280,777,1728889183,1728889183,1,1),(18,23,'en',1,1,'ept case.webp',19,'Footbal club',NULL,1494,739,1728933322,1728933322,1,1),(19,24,'en',1,1,'4950565d-af48-45ef-be68-c27550a02da9.jpg',20,'bubbles 3',NULL,1024,1024,1728934033,1728934033,1,1),(19,25,'en',1,1,'4950565d-af48-45ef-be68-c27550a02da9.webp',21,'bubbles 3',NULL,1024,1024,1728934033,1728935148,1,1),(20,26,'en',1,1,'DOM Box.webp',22,'DOM Box',NULL,1913,1049,1728936151,1728936151,1,1),(21,27,'en',1,1,'background image or video.webp',23,'Background color, image or video',NULL,1092,821,1728936355,1728936355,1,1),(22,28,'en',1,1,'javascript plugins.webp',24,'Javascript plugins',NULL,842,802,1728936556,1728936556,1,1);
/*!40000 ALTER TABLE `media_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision`
--

DROP TABLE IF EXISTS `media_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision` (
  `mid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`),
  KEY `media__mid` (`mid`),
  KEY `media_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB AUTO_INCREMENT=29 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for media entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision`
--

LOCK TABLES `media_revision` WRITE;
/*!40000 ALTER TABLE `media_revision` DISABLE KEYS */;
INSERT INTO `media_revision` VALUES (1,1,'en',NULL,1728242872,NULL,1),(2,2,'en',NULL,1728819558,NULL,1),(3,3,'en',NULL,1728883281,NULL,1),(4,4,'en',NULL,1728884475,NULL,1),(5,5,'en',NULL,1728884651,NULL,1),(6,6,'en',NULL,1728884846,NULL,1),(7,7,'en',NULL,1728885156,NULL,1),(4,8,'en',1,1728885249,NULL,1),(5,9,'en',1,1728885288,NULL,1),(6,10,'en',1,1728885310,NULL,1),(7,11,'en',1,1728885331,NULL,1),(4,12,'en',1,1728885349,NULL,1),(8,13,'en',NULL,1728885422,NULL,1),(9,14,'en',NULL,1728885872,NULL,1),(10,15,'en',NULL,1728887601,NULL,1),(11,16,'en',NULL,1728887677,NULL,1),(12,17,'en',NULL,1728887791,NULL,1),(13,18,'en',NULL,1728887900,NULL,1),(14,19,'en',NULL,1728888003,NULL,1),(15,20,'en',NULL,1728888321,NULL,1),(16,21,'en',NULL,1728888670,NULL,1),(17,22,'en',NULL,1728889183,NULL,1),(18,23,'en',NULL,1728933322,NULL,1),(19,24,'en',NULL,1728934033,NULL,1),(19,25,'en',1,1728935148,NULL,1),(20,26,'en',NULL,1728936151,NULL,1),(21,27,'en',NULL,1728936355,NULL,1),(22,28,'en',NULL,1728936556,NULL,1);
/*!40000 ALTER TABLE `media_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision__field_media_audio_file`
--

DROP TABLE IF EXISTS `media_revision__field_media_audio_file`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision__field_media_audio_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_audio_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_audio_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_audio_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_audio_file_target_id` (`field_media_audio_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_audio…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision__field_media_audio_file`
--

LOCK TABLES `media_revision__field_media_audio_file` WRITE;
/*!40000 ALTER TABLE `media_revision__field_media_audio_file` DISABLE KEYS */;
/*!40000 ALTER TABLE `media_revision__field_media_audio_file` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision__field_media_document`
--

DROP TABLE IF EXISTS `media_revision__field_media_document`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision__field_media_document` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_document_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_document_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_document_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_document_target_id` (`field_media_document_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision__field_media_document`
--

LOCK TABLES `media_revision__field_media_document` WRITE;
/*!40000 ALTER TABLE `media_revision__field_media_document` DISABLE KEYS */;
/*!40000 ALTER TABLE `media_revision__field_media_document` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision__field_media_image`
--

DROP TABLE IF EXISTS `media_revision__field_media_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision__field_media_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_media_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_media_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_media_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_image_target_id` (`field_media_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision__field_media_image`
--

LOCK TABLES `media_revision__field_media_image` WRITE;
/*!40000 ALTER TABLE `media_revision__field_media_image` DISABLE KEYS */;
INSERT INTO `media_revision__field_media_image` VALUES ('image',0,2,2,'en',0,3,'bubbles 1','',1024,1024),('image',0,3,3,'en',0,4,'Bubbles 1','',826,831),('image',0,4,4,'en',0,5,'Fluid grid image gallery','',632,405),('image',0,4,8,'en',0,5,'EPT Image Gallery','',632,405),('image',0,4,12,'en',0,5,'Extra Paragraph Types (EPT): Image Gallery','',632,405),('image',0,5,5,'en',0,6,'FAQ example','',440,415),('image',0,5,9,'en',0,6,'Extra Paragraph Types (EPT): Accordion','',440,415),('image',0,6,6,'en',0,7,'2 Columns CTA','',661,300),('image',0,6,10,'en',0,7,'Extra Paragraph Types (EPT): Call to Action','',661,300),('image',0,7,7,'en',0,8,'EBT Tabs','',503,206),('image',0,7,11,'en',0,8,'Extra Paragraph Types (EPT): Tabs','',503,206),('image',0,8,13,'en',0,9,'bubbles 2','',1024,1024),('image',0,9,14,'en',0,10,'Extra Paragraph Types (EPT): Slick Slider','',1270,500),('image',0,10,15,'en',0,11,'Extra Paragraph Types (EPT): Carousel','',887,348),('image',0,11,16,'en',0,12,'Extra Paragraph Types (EPT): Slideshow','',947,652),('image',0,12,17,'en',0,13,'Extra Paragraph Types (EPT): Quote','',639,299),('image',0,13,18,'en',0,14,'Extra Paragraph Types (EPT): Tiles','',1186,615),('image',0,14,19,'en',0,15,'Extra Paragraph Types (EPT): Text','',1108,269),('image',0,15,20,'en',0,16,'Extra Block Types (EBT): Counter','',800,360),('image',0,16,21,'en',0,17,'GLightbox','',569,267),('image',0,17,22,'en',0,18,'Dark drop','',1280,777),('image',0,18,23,'en',0,19,'Footbal club','',1494,739),('image',0,19,24,'en',0,20,'bubbles 3','',1024,1024),('image',0,19,25,'en',0,21,'bubbles 3','',1024,1024),('image',0,20,26,'en',0,22,'DOM Box','',1913,1049),('image',0,21,27,'en',0,23,'Background color, image or video','',1092,821),('image',0,22,28,'en',0,24,'Javascript plugins','',842,802);
/*!40000 ALTER TABLE `media_revision__field_media_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision__field_media_oembed_video`
--

DROP TABLE IF EXISTS `media_revision__field_media_oembed_video`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision__field_media_oembed_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_oembed_video_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_oembed…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision__field_media_oembed_video`
--

LOCK TABLES `media_revision__field_media_oembed_video` WRITE;
/*!40000 ALTER TABLE `media_revision__field_media_oembed_video` DISABLE KEYS */;
INSERT INTO `media_revision__field_media_oembed_video` VALUES ('remote_video',0,1,1,'en',0,'https://youtu.be/zbdI7ugf6B8');
/*!40000 ALTER TABLE `media_revision__field_media_oembed_video` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision__field_media_video_file`
--

DROP TABLE IF EXISTS `media_revision__field_media_video_file`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision__field_media_video_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_video_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_video_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_video_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_video_file_target_id` (`field_media_video_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_video…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision__field_media_video_file`
--

LOCK TABLES `media_revision__field_media_video_file` WRITE;
/*!40000 ALTER TABLE `media_revision__field_media_video_file` DISABLE KEYS */;
/*!40000 ALTER TABLE `media_revision__field_media_video_file` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content`
--

DROP TABLE IF EXISTS `menu_link_content`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `menu_link_content_field__uuid__value` (`uuid`),
  UNIQUE KEY `menu_link_content__revision_id` (`revision_id`)
) ENGINE=InnoDB AUTO_INCREMENT=15 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content`
--

LOCK TABLES `menu_link_content` WRITE;
/*!40000 ALTER TABLE `menu_link_content` DISABLE KEYS */;
INSERT INTO `menu_link_content` VALUES (1,1,'menu_link_content','d5043c53-9961-4a60-bb2a-a37bbaaa3961','en'),(3,3,'menu_link_content','9618e6db-485e-4fa0-84d3-b56e8936ef0d','en'),(4,4,'menu_link_content','9a831874-a895-4cc7-ac58-2de2055f7c4b','en'),(5,5,'menu_link_content','60ff628e-4af5-44f0-af2a-8bd88c057b15','en'),(6,6,'menu_link_content','0cdaaebf-f931-4b2e-a1ed-fed2026812e5','en'),(7,7,'menu_link_content','c099779d-431c-4fb8-831c-02e395b960b7','en'),(8,8,'menu_link_content','5ddd00be-7fb0-4648-8176-b3cdf1a8fbff','en'),(9,9,'menu_link_content','86cc3040-af4c-4f8b-901a-c9c517ae0ab6','en'),(10,10,'menu_link_content','f7dcb4f3-cc8d-40eb-944e-073aea38aad3','en'),(11,11,'menu_link_content','b7aae8ff-5c43-4ae2-a08a-7fec98be2568','en'),(12,12,'menu_link_content','99f46f29-6f08-4218-8291-d84b7e07ab0d','en'),(13,13,'menu_link_content','fa9e2736-9b20-41fa-9e2c-c19aad723aab','en'),(14,14,'menu_link_content','10f330e8-9bde-4bb7-a57c-c1f39e9a02fd','en');
/*!40000 ALTER TABLE `menu_link_content` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content_data`
--

DROP TABLE IF EXISTS `menu_link_content_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `enabled` tinyint NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `menu_name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `external` tinyint DEFAULT NULL,
  `rediscover` tinyint DEFAULT NULL,
  `weight` int DEFAULT NULL,
  `expanded` tinyint DEFAULT NULL,
  `parent` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `menu_link_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `menu_link_content__revision_id` (`revision_id`),
  KEY `menu_link_content_field__link__uri` (`link__uri`(30)),
  KEY `menu_link_content__enabled_bundle` (`enabled`,`bundle`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content_data`
--

LOCK TABLES `menu_link_content_data` WRITE;
/*!40000 ALTER TABLE `menu_link_content_data` DISABLE KEYS */;
INSERT INTO `menu_link_content_data` VALUES (1,1,'menu_link_content','en',0,'EPT modules',NULL,'main','https://www.drupal.org/project/ept_core','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-47,1,NULL,1729064670,1,1),(3,3,'menu_link_content','en',1,'LinkedIn',NULL,'footer','https://www.linkedin.com/in/ivan-abramenko/','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-49,0,NULL,1729021239,1,1),(4,4,'menu_link_content','en',1,'DrupalBook',NULL,'footer','https://drupalbook.org/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-46,0,NULL,1729021177,1,1),(5,5,'menu_link_content','en',1,'Drupal.org',NULL,'footer','https://www.drupal.org/user/1079574/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-48,0,NULL,1729021243,1,1),(6,6,'menu_link_content','en',1,'LinkedIn',NULL,'account','https://www.linkedin.com/in/ivan-abramenko/','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,0,0,NULL,1729020965,1,1),(7,7,'menu_link_content','en',1,'Drupal.org',NULL,'account','https://www.drupal.org/user/1079574/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,0,0,NULL,1729021101,1,1),(8,8,'menu_link_content','en',1,'Slack',NULL,'account','https://drupal.slack.com/archives/C07A942U72P','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,0,0,NULL,1729021132,1,1),(9,9,'menu_link_content','en',1,'Slack',NULL,'footer','https://drupal.slack.com/archives/C07A942U72P','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-47,0,NULL,1729021177,1,1),(10,10,'menu_link_content','en',1,'DrupalBook',NULL,'account','https://drupalbook.org/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,0,0,NULL,1729021302,1,1),(11,11,'menu_link_content','en',0,'EBT Modules',NULL,'main','https://www.drupal.org/project/ebt_core','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:5:\"_self\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-46,0,NULL,1729064670,1,1),(12,12,'menu_link_content','en',1,'Documentation',NULL,'main','https://drupalbook.org/ept/demo','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-45,0,NULL,1729064670,1,1),(13,13,'menu_link_content','en',1,'Listing Page',NULL,'main','entity:node/19','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-48,0,NULL,1729064670,1,1),(14,14,'menu_link_content','en',1,'Landing Page',NULL,'main','internal:/','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1,-49,0,NULL,1729064670,1,1);
/*!40000 ALTER TABLE `menu_link_content_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content_field_revision`
--

DROP TABLE IF EXISTS `menu_link_content_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content_field_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `enabled` tinyint NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `external` tinyint DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `menu_link_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `menu_link_content_field__link__uri` (`link__uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content_field_revision`
--

LOCK TABLES `menu_link_content_field_revision` WRITE;
/*!40000 ALTER TABLE `menu_link_content_field_revision` DISABLE KEYS */;
INSERT INTO `menu_link_content_field_revision` VALUES (1,1,'en',0,'EPT modules',NULL,'https://www.drupal.org/project/ept_core','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729064670,1,1),(3,3,'en',1,'LinkedIn',NULL,'https://www.linkedin.com/in/ivan-abramenko/','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021239,1,1),(4,4,'en',1,'DrupalBook',NULL,'https://drupalbook.org/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021177,1,1),(5,5,'en',1,'Drupal.org',NULL,'https://www.drupal.org/user/1079574/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021243,1,1),(6,6,'en',1,'LinkedIn',NULL,'https://www.linkedin.com/in/ivan-abramenko/','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729020965,1,1),(7,7,'en',1,'Drupal.org',NULL,'https://www.drupal.org/user/1079574/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021101,1,1),(8,8,'en',1,'Slack',NULL,'https://drupal.slack.com/archives/C07A942U72P','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021132,1,1),(9,9,'en',1,'Slack',NULL,'https://drupal.slack.com/archives/C07A942U72P','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021177,1,1),(10,10,'en',1,'DrupalBook',NULL,'https://drupalbook.org/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021302,1,1),(11,11,'en',0,'EBT Modules',NULL,'https://www.drupal.org/project/ebt_core','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:5:\"_self\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729064670,1,1),(12,12,'en',1,'Documentation',NULL,'https://drupalbook.org/ept/demo','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729064670,1,1),(13,13,'en',1,'Listing Page',NULL,'entity:node/19','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729064670,1,1),(14,14,'en',1,'Landing Page',NULL,'internal:/','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729064670,1,1);
/*!40000 ALTER TABLE `menu_link_content_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content_revision`
--

DROP TABLE IF EXISTS `menu_link_content_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `menu_link_content__id` (`id`),
  KEY `menu_link_content__ef029a1897` (`revision_user`)
) ENGINE=InnoDB AUTO_INCREMENT=15 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content_revision`
--

LOCK TABLES `menu_link_content_revision` WRITE;
/*!40000 ALTER TABLE `menu_link_content_revision` DISABLE KEYS */;
INSERT INTO `menu_link_content_revision` VALUES (1,1,'en',NULL,1728554708,NULL,1),(3,3,'en',NULL,1729020303,NULL,1),(4,4,'en',NULL,1729020367,NULL,1),(5,5,'en',NULL,1729020511,NULL,1),(6,6,'en',NULL,1729020965,NULL,1),(7,7,'en',NULL,1729021084,NULL,1),(8,8,'en',NULL,1729021132,NULL,1),(9,9,'en',NULL,1729021168,NULL,1),(10,10,'en',NULL,1729021302,NULL,1),(11,11,'en',NULL,1729021388,NULL,1),(12,12,'en',NULL,1729023766,NULL,1),(13,13,'en',NULL,1729064625,NULL,1),(14,14,'en',NULL,1729064649,NULL,1);
/*!40000 ALTER TABLE `menu_link_content_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_tree`
--

DROP TABLE IF EXISTS `menu_tree`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_tree` (
  `menu_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The menu name. All links with the same menu name (such as ''tools'') are part of the same menu.',
  `mlid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'The menu link ID (mlid) is the integer primary key.',
  `id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'Unique machine name: the plugin ID.',
  `parent` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The plugin ID for the parent of this link.',
  `route_name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The machine name of a defined Symfony Route this menu link represents.',
  `route_param_key` varchar(2048) DEFAULT NULL COMMENT 'An encoded string of route parameters for loading by route.',
  `route_parameters` longblob COMMENT 'Serialized array of route parameters of this menu link.',
  `url` varchar(2048) NOT NULL DEFAULT '' COMMENT 'The external path this link points to (when not using a route).',
  `title` longblob COMMENT 'The serialized title for the link. May be a TranslatableMarkup.',
  `description` longblob COMMENT 'The serialized description of this link - used for admin pages and title attribute. May be a TranslatableMarkup.',
  `class` text COMMENT 'The class for this link plugin.',
  `options` longblob COMMENT 'A serialized array of URL options, such as a query string or HTML attributes.',
  `provider` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'system' COMMENT 'The name of the module that generated this link.',
  `enabled` smallint NOT NULL DEFAULT '1' COMMENT 'A flag for whether the link should be rendered in menus. (0 = a disabled menu link that may be shown on admin screens, 1 = a normal, visible link)',
  `discovered` smallint NOT NULL DEFAULT '0' COMMENT 'A flag for whether the link was discovered, so can be purged on rebuild',
  `expanded` smallint NOT NULL DEFAULT '0' COMMENT 'Flag for whether this link should be rendered as expanded in menus - expanded links always have their child links displayed, instead of only when the link is in the active trail (1 = expanded, 0 = not expanded)',
  `weight` int NOT NULL DEFAULT '0' COMMENT 'Link weight among links in the same menu at the same depth.',
  `metadata` longblob COMMENT 'A serialized array of data that may be used by the plugin instance.',
  `has_children` smallint NOT NULL DEFAULT '0' COMMENT 'Flag indicating whether any enabled links have this link as a parent (1 = enabled children exist, 0 = no enabled children).',
  `depth` smallint NOT NULL DEFAULT '0' COMMENT 'The depth relative to the top level. A link with empty parent will have depth == 1.',
  `p1` int unsigned NOT NULL DEFAULT '0' COMMENT 'The first mlid in the materialized path. If N = depth, then pN must equal the mlid. If depth > 1 then p(N-1) must equal the parent link mlid. All pX where X > depth must equal zero. The columns p1 .. p9 are also called the parents.',
  `p2` int unsigned NOT NULL DEFAULT '0' COMMENT 'The second mlid in the materialized path. See p1.',
  `p3` int unsigned NOT NULL DEFAULT '0' COMMENT 'The third mlid in the materialized path. See p1.',
  `p4` int unsigned NOT NULL DEFAULT '0' COMMENT 'The fourth mlid in the materialized path. See p1.',
  `p5` int unsigned NOT NULL DEFAULT '0' COMMENT 'The fifth mlid in the materialized path. See p1.',
  `p6` int unsigned NOT NULL DEFAULT '0' COMMENT 'The sixth mlid in the materialized path. See p1.',
  `p7` int unsigned NOT NULL DEFAULT '0' COMMENT 'The seventh mlid in the materialized path. See p1.',
  `p8` int unsigned NOT NULL DEFAULT '0' COMMENT 'The eighth mlid in the materialized path. See p1.',
  `p9` int unsigned NOT NULL DEFAULT '0' COMMENT 'The ninth mlid in the materialized path. See p1.',
  `form_class` varchar(255) DEFAULT NULL COMMENT 'meh',
  PRIMARY KEY (`mlid`),
  UNIQUE KEY `id` (`id`),
  KEY `menu_parents` (`menu_name`,`p1`,`p2`,`p3`,`p4`,`p5`,`p6`,`p7`,`p8`,`p9`),
  KEY `menu_parent_expand_child` (`menu_name`,`expanded`,`has_children`,`parent`(16)),
  KEY `route_values` (`route_name`(32),`route_param_key`(16))
) ENGINE=InnoDB AUTO_INCREMENT=401 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Contains the menu tree hierarchy.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_tree`
--

LOCK TABLES `menu_tree` WRITE;
/*!40000 ALTER TABLE `menu_tree` DISABLE KEYS */;
INSERT INTO `menu_tree` VALUES ('footer',1,'contact.site_page','','contact.site_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Contact\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','contact',0,1,0,-50,_binary 'a:0:{}',0,1,1,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('tools',2,'filter.tips_all','','filter.tips_all','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Compose tips\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','filter',0,1,0,0,_binary 'a:0:{}',0,1,2,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('tools',3,'node.add_page','','node.add_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','node',1,1,0,0,_binary 'a:0:{}',0,1,3,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',6,'system.admin','','system.admin','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Administration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,9,_binary 'a:0:{}',1,1,6,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',7,'announcements_feed.announcement','system.admin','announcements_feed.announcement','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Announcements\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:49:\"Displays announcements from the Drupal community.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','announcements_feed',1,1,0,10,_binary 'a:0:{}',0,2,6,7,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',8,'help.main','system.admin','help.main','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Help\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Reference for usage, configuration, and modules.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','help',1,1,0,9,_binary 'a:0:{}',0,2,6,8,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',9,'system.admin_content','system.admin','system.admin_content','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Find and manage content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,2,6,9,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',10,'comment.admin','system.admin_content','comment.admin','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Comments\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"List and edit site comments and the comment approval queue.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','comment',1,1,0,0,_binary 'a:0:{}',0,3,6,9,10,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',11,'system.admin_structure','system.admin','system.admin_structure','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Structure\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Administer blocks, content types, menus, etc.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-8,_binary 'a:0:{}',1,2,6,11,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',12,'block.admin_display','system.admin_structure','block.admin_display','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Block layout\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:79:\"Configure what block content appears in your site\'s sidebars and other regions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','block',1,1,0,0,_binary 'a:0:{}',0,3,6,11,12,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',13,'entity.block_content_type.collection','system.admin_structure','entity.block_content_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Create and manage fields, forms, and display settings for your content blocks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','block_content',1,1,0,0,_binary 'a:0:{}',1,3,6,11,13,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',14,'entity.comment_type.collection','system.admin_structure','entity.comment_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Comment types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"Manage form and displays settings of comments.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','comment',1,1,0,0,_binary 'a:0:{}',1,3,6,11,14,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',15,'entity.contact_form.collection','system.admin_structure','entity.contact_form.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Create and manage contact forms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','contact',1,1,0,0,_binary 'a:0:{}',1,3,6,11,15,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',16,'field_ui.display_mode','system.admin_structure','field_ui.display_mode','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Display modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"Configure what displays are available for your content and forms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',1,3,6,11,16,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',17,'entity.entity_view_mode.collection','field_ui.display_mode','entity.entity_view_mode.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"View modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Manage custom view modes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',1,4,6,11,16,17,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',18,'entity.entity_form_mode.collection','field_ui.display_mode','entity.entity_form_mode.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Form modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Manage custom form modes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',1,4,6,11,16,18,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',19,'entity.menu.collection','system.admin_structure','entity.menu.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Manage menus and menu links.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','menu_ui',1,1,0,0,_binary 'a:0:{}',1,3,6,11,19,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',20,'entity.node_type.collection','system.admin_structure','entity.node_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:71:\"Create and manage fields, forms, and display settings for your content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','node',1,1,0,0,_binary 'a:0:{}',1,3,6,11,20,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',21,'entity.taxonomy_vocabulary.collection','system.admin_structure','entity.taxonomy_vocabulary.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Taxonomy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:67:\"Manage tagging, categorization, and classification of your content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','taxonomy',1,1,0,0,_binary 'a:0:{}',1,3,6,11,21,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',22,'entity.view.collection','system.admin_structure','entity.view.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"Manage customized lists of content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','views_ui',1,1,0,0,_binary 'a:0:{}',1,3,6,11,22,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',23,'system.themes_page','system.admin','system.themes_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Appearance\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Select and configure themes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-6,_binary 'a:0:{}',1,2,6,23,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',24,'system.modules_list','system.admin','system.modules_list','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Extend\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:53:\"Add and install modules to extend site functionality.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-2,_binary 'a:0:{}',1,2,6,24,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',25,'system.admin_config','system.admin','system.admin_config','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Administer settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',1,2,6,25,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',26,'system.admin_config_media','system.admin_config','system.admin_config_media','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,3,6,25,26,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',27,'entity.image_style.collection','system.admin_config_media','entity.image_style.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Configure styles that can be used for resizing or adjusting images on display.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','image',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,27,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',28,'system.file_system_settings','system.admin_config_media','system.file_system_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"File system\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:67:\"Configure the location of uploaded files and how they are accessed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,28,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',29,'system.image_toolkit_settings','system.admin_config_media','system.image_toolkit_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Image toolkit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:74:\"Choose which image toolkit to use if you have installed optional toolkits.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,20,_binary 'a:0:{}',0,4,6,25,26,29,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',30,'system.admin_config_services','system.admin_config','system.admin_config_services','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Web services\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',1,3,6,25,30,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',31,'system.rss_feeds_settings','system.admin_config_services','system.rss_feeds_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"RSS publishing\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:115:\"Configure the site description, the number of items per feed, and whether feeds should be titles/teasers/full-text.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',0,4,6,25,30,31,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',32,'system.linkset_settings','system.admin_config_services','system.linkset_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Menu Linkset Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Enable or disable the menu linkset endpoint\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,10,_binary 'a:0:{}',0,4,6,25,30,32,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',33,'system.admin_config_development','system.admin_config','system.admin_config_development','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Development\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Configure and use development tools.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,3,6,25,33,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',34,'config.sync','system.admin_config_development','config.sync','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Configuration synchronization\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"Import and export your configuration.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','config',1,1,0,0,_binary 'a:0:{}',1,4,6,25,33,34,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',35,'system.site_maintenance_mode','system.admin_config_development','system.site_maintenance_mode','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Maintenance mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:62:\"Take the site offline for updates and other maintenance tasks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',0,4,6,25,33,35,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',36,'system.performance_settings','system.admin_config_development','system.performance_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Performance\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Configure caching and bandwidth optimization.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',0,4,6,25,33,36,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',37,'system.development_settings','system.admin_config_development','system.development_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Development settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Configure theme development settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-19,_binary 'a:0:{}',0,4,6,25,33,37,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',38,'system.logging_settings','system.admin_config_development','system.logging_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Logging and errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:61:\"Configure the display of error messages and database logging.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-15,_binary 'a:0:{}',0,4,6,25,33,38,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',39,'system.admin_config_regional','system.admin_config','system.admin_config_regional','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Region and language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"Configure regional settings, localization, and translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-5,_binary 'a:0:{}',1,3,6,25,39,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',40,'system.regional_settings','system.admin_config_regional','system.regional_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Regional settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Configure the locale and timezone settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',0,4,6,25,39,40,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',41,'entity.date_format.collection','system.admin_config_regional','entity.date_format.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Date and time formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure how dates and times are displayed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-9,_binary 'a:0:{}',0,4,6,25,39,41,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',42,'system.admin_config_search','system.admin_config','system.admin_config_search','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Search and metadata\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:64:\"Configure site search, metadata, and search engine optimization.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,3,6,25,42,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',43,'entity.path_alias.collection','system.admin_config_search','entity.path_alias.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Add custom URLs to existing paths.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','path',1,1,0,-5,_binary 'a:0:{}',0,4,6,25,42,43,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',45,'system.admin_config_system','system.admin_config','system.admin_config_system','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"System\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:49:\"Configure basic site settings, actions, and cron.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',1,3,6,25,45,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',46,'system.site_information_settings','system.admin_config_system','system.site_information_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Basic site settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"Change site name, email address, slogan, default front page, and error pages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',0,4,6,25,45,46,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',47,'system.cron_settings','system.admin_config_system','system.cron_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Cron\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"Manage automatic site maintenance tasks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,20,_binary 'a:0:{}',0,4,6,25,45,47,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',48,'system.admin_config_ui','system.admin_config','system.admin_config_ui','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"User interface\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure the administrative user interface.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-15,_binary 'a:0:{}',1,3,6,25,48,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',49,'entity.shortcut_set.collection','system.admin_config_ui','entity.shortcut_set.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Shortcuts\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Add and modify shortcut sets.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','shortcut',1,1,0,0,_binary 'a:0:{}',0,4,6,25,48,49,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',50,'system.admin_config_workflow','system.admin_config','system.admin_config_workflow','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Workflow\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Manage the content workflow.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,5,_binary 'a:0:{}',0,3,6,25,50,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',51,'system.admin_config_content','system.admin_config','system.admin_config_content','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Content authoring\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Configure content formatting and authoring.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-15,_binary 'a:0:{}',1,3,6,25,51,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',52,'filter.admin_overview','system.admin_config_content','filter.admin_overview','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Text formats and editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Select and configure text editors, and how content is filtered when displayed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','filter',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,52,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',53,'user.admin_index','system.admin_config','user.admin_index','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"People\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Configure user accounts.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',1,1,0,-20,_binary 'a:0:{}',1,3,6,25,53,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',54,'entity.user.admin_form','user.admin_index','entity.user.admin_form','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Account settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:105:\"Configure default user account settings, including fields, registration requirements, and email messages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',1,1,0,-10,_binary 'a:0:{}',1,4,6,25,53,54,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',55,'system.admin_reports','system.admin','system.admin_reports','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Reports\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"View reports, updates, and errors.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,5,_binary 'a:0:{}',1,2,6,55,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',56,'dblog.overview','system.admin_reports','dblog.overview','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Recent log messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"View events that have recently been logged.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','dblog',1,1,0,-1,_binary 'a:0:{}',0,3,6,55,56,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',57,'dblog.page_not_found','system.admin_reports','dblog.page_not_found','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"Top \'page not found\' errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"View \'page not found\' errors (404s).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','dblog',1,1,0,0,_binary 'a:0:{}',0,3,6,55,57,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',58,'dblog.access_denied','system.admin_reports','dblog.access_denied','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Top \'access denied\' errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"View \'access denied\' errors (403s).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','dblog',1,1,0,0,_binary 'a:0:{}',0,3,6,55,58,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',59,'entity.field_storage_config.collection','system.admin_reports','entity.field_storage_config.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Field list\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Overview of fields on all entity types.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',1,3,6,55,59,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',60,'system.status','system.admin_reports','system.status','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Status report\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Get a status report about your site\'s operation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-60,_binary 'a:0:{}',0,3,6,55,60,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',61,'views_ui.reports_plugins','system.admin_reports','views_ui.reports_plugins','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Views plugins\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Overview of plugins used in all views.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','views_ui',1,1,0,0,_binary 'a:0:{}',0,3,6,55,61,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',63,'entity.user.collection','system.admin','entity.user.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"People\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Manage user accounts, roles, and permissions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',1,1,0,4,_binary 'a:0:{}',1,2,6,63,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('account',64,'user.page','','user.page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"My account\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',0,1,0,-10,_binary 'a:0:{}',0,1,64,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('account',65,'user.logout','','','',_binary 'a:0:{}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\user\\Plugin\\Menu\\LoginLogoutMenuLink',_binary 'a:0:{}','user',0,1,0,10,_binary 'a:0:{}',0,1,65,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',66,'update.status','system.admin_reports','update.status','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Available updates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:82:\"Get a status report about available updates for your installed modules and themes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','update',1,1,0,-50,_binary 'a:0:{}',0,3,6,55,66,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',67,'entity.media_type.collection','system.admin_structure','entity.media_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Media types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage media types.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','media',1,1,0,0,_binary 'a:0:{}',1,3,6,11,67,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',68,'media.settings','system.admin_config_media','media.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Media settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Manage media settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','media',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,68,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',69,'admin_toolbar_tools.extra_links:node.add','system.admin_content','node.add_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,3,6,9,69,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',70,'admin_toolbar_tools.extra_links:node.add.article','admin_toolbar_tools.extra_links:node.add','node.add','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:7:\"article\";}',0,4,6,9,69,70,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',71,'admin_toolbar_tools.extra_links:node.add.page','admin_toolbar_tools.extra_links:node.add','node.add','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:4:\"page\";}',0,4,6,9,69,71,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',72,'admin_toolbar_tools.extra_links:block_content_page','system.admin_content','entity.block_content.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,3,6,9,72,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',73,'admin_toolbar_tools.extra_links:add_block','admin_toolbar_tools.extra_links:block_content_page','block_content.add_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Add content block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,4,6,9,72,73,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',74,'admin_toolbar_tools.extra_links:block_content.add.basic','admin_toolbar_tools.extra_links:add_block','block_content.add_form','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:5:\"basic\";}',0,5,6,9,72,73,74,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',75,'admin_toolbar_tools.extra_links:media_page','system.admin_content','entity.media.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,3,6,9,75,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',76,'admin_toolbar_tools.extra_links:media_library','admin_toolbar_tools.extra_links:media_page','view.media_library.page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Media library\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,9,75,76,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',77,'admin_toolbar_tools.extra_links:add_media','admin_toolbar_tools.extra_links:media_page','entity.media.add_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,4,6,9,75,77,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',78,'admin_toolbar_tools.extra_links:media.add.audio','admin_toolbar_tools.extra_links:add_media','entity.media.add_form','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"audio\";}',0,5,6,9,75,77,78,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',79,'admin_toolbar_tools.extra_links:media.add.document','admin_toolbar_tools.extra_links:add_media','entity.media.add_form','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:8:\"document\";}',0,5,6,9,75,77,79,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',80,'admin_toolbar_tools.extra_links:media.add.image','admin_toolbar_tools.extra_links:add_media','entity.media.add_form','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"image\";}',0,5,6,9,75,77,80,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',81,'admin_toolbar_tools.extra_links:media.add.remote_video','admin_toolbar_tools.extra_links:add_media','entity.media.add_form','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:12:\"remote_video\";}',0,5,6,9,75,77,81,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',82,'admin_toolbar_tools.extra_links:media.add.video','admin_toolbar_tools.extra_links:add_media','entity.media.add_form','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"video\";}',0,5,6,9,75,77,82,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',83,'admin_toolbar_tools.extra_links:view.files','system.admin_content','view.files.page_1','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,9,83,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',84,'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.block_content_type.collection','entity.block_content_type.edit_form','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:5:\"basic\";}',1,4,6,11,13,84,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',85,'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsbasic','admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.block_content.field_ui_fields','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,13,84,85,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',86,'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultbasic','admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.entity_form_display.block_content.default','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,13,84,86,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',87,'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.basic','admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.entity_view_display.block_content.default','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,13,84,87,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',88,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.basic','admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.block_content_type.entity_permissions_form','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,13,84,88,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',89,'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.basic','admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.block_content_type.delete_form','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,13,84,89,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',90,'admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.comment_type.collection','entity.comment_type.edit_form','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"entity_id\";s:7:\"comment\";}',1,4,6,11,14,90,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',91,'admin_toolbar_tools.extra_links:entity.comment.field_ui_fieldscomment','admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.comment.field_ui_fields','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,14,90,91,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',92,'admin_toolbar_tools.extra_links:entity.entity_form_display.comment.defaultcomment','admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.entity_form_display.comment.default','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,14,90,92,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',93,'admin_toolbar_tools.extra_links:entity.entity_view_display.comment.default.comment','admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.entity_view_display.comment.default','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,14,90,93,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',94,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.comment.default.comment','admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.comment_type.entity_permissions_form','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,14,90,94,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',95,'admin_toolbar_tools.extra_links:entity.comment_type.delete_form.comment','admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.comment_type.delete_form','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,14,90,95,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',96,'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.contact_form.collection','entity.contact_form.edit_form','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"entity_id\";s:8:\"personal\";}',1,4,6,11,15,96,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',97,'admin_toolbar_tools.extra_links:entity.contact_message.field_ui_fieldspersonal','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.contact_message.field_ui_fields','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,15,96,97,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',98,'admin_toolbar_tools.extra_links:entity.entity_form_display.contact_message.defaultpersonal','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.entity_form_display.contact_message.default','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,15,96,98,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',99,'admin_toolbar_tools.extra_links:entity.entity_view_display.contact_message.default.personal','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.entity_view_display.contact_message.default','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,15,96,99,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',100,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.contact_message.default.personal','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.contact_form.entity_permissions_form','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,15,96,100,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',101,'admin_toolbar_tools.extra_links:entity.contact_form.delete_form.personal','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.contact_form.delete_form','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,15,96,101,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',102,'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.contact_form.collection','entity.contact_form.edit_form','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"entity_id\";s:8:\"feedback\";}',1,4,6,11,15,102,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',103,'admin_toolbar_tools.extra_links:entity.contact_message.field_ui_fieldsfeedback','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.contact_message.field_ui_fields','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,15,102,103,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',104,'admin_toolbar_tools.extra_links:entity.entity_form_display.contact_message.defaultfeedback','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.entity_form_display.contact_message.default','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,15,102,104,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',105,'admin_toolbar_tools.extra_links:entity.entity_view_display.contact_message.default.feedback','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.entity_view_display.contact_message.default','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,15,102,105,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',106,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.contact_message.default.feedback','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.contact_form.entity_permissions_form','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,15,102,106,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',107,'admin_toolbar_tools.extra_links:entity.contact_form.delete_form.feedback','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.contact_form.delete_form','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,15,102,107,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',108,'admin_toolbar_tools.extra_links:contact.form_add','entity.contact_form.collection','contact.form_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Add contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-5,_binary 'a:0:{}',0,4,6,11,15,108,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',109,'admin_toolbar_tools.extra_links:field_ui.entity_view_mode_add','entity.entity_view_mode.collection','field_ui.entity_view_mode_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Add view mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,16,17,109,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',110,'admin_toolbar_tools.extra_links:field_ui.entity_form_mode_add','entity.entity_form_mode.collection','field_ui.entity_form_mode_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Add form mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,16,18,110,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',111,'admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.media_type.collection','entity.media_type.edit_form','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"audio\";}',1,4,6,11,67,111,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',112,'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsaudio','admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.media.field_ui_fields','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,67,111,112,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',113,'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultaudio','admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.entity_form_display.media.default','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,67,111,113,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',114,'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.audio','admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.entity_view_display.media.default','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,111,114,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',115,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.audio','admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.media_type.entity_permissions_form','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,111,115,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',116,'admin_toolbar_tools.extra_links:entity.media_type.delete_form.audio','admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.media_type.delete_form','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,67,111,116,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',117,'admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.media_type.collection','entity.media_type.edit_form','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:8:\"document\";}',1,4,6,11,67,117,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',118,'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsdocument','admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.media.field_ui_fields','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,67,117,118,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',119,'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultdocument','admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.entity_form_display.media.default','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,67,117,119,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',120,'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.document','admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.entity_view_display.media.default','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,117,120,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',121,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.document','admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.media_type.entity_permissions_form','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,117,121,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',122,'admin_toolbar_tools.extra_links:entity.media_type.delete_form.document','admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.media_type.delete_form','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,67,117,122,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',123,'admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.media_type.collection','entity.media_type.edit_form','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"image\";}',1,4,6,11,67,123,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',124,'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsimage','admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.media.field_ui_fields','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,67,123,124,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',125,'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultimage','admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.entity_form_display.media.default','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,67,123,125,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',126,'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.image','admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.entity_view_display.media.default','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,123,126,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',127,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.image','admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.media_type.entity_permissions_form','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,123,127,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',128,'admin_toolbar_tools.extra_links:entity.media_type.delete_form.image','admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.media_type.delete_form','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,67,123,128,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',129,'admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.media_type.collection','entity.media_type.edit_form','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:12:\"remote_video\";}',1,4,6,11,67,129,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',130,'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsremote_video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.media.field_ui_fields','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,67,129,130,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',131,'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultremote_video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.entity_form_display.media.default','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,67,129,131,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',132,'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.remote_video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.entity_view_display.media.default','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,129,132,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',133,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.remote_video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.media_type.entity_permissions_form','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,129,133,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',134,'admin_toolbar_tools.extra_links:entity.media_type.delete_form.remote_video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.media_type.delete_form','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,67,129,134,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',135,'admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.media_type.collection','entity.media_type.edit_form','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"video\";}',1,4,6,11,67,135,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',136,'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsvideo','admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.media.field_ui_fields','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,67,135,136,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',137,'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultvideo','admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.entity_form_display.media.default','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,67,135,137,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',138,'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.entity_view_display.media.default','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,135,138,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',139,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.media_type.entity_permissions_form','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,135,139,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',140,'admin_toolbar_tools.extra_links:entity.media_type.delete_form.video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.media_type.delete_form','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,67,135,140,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',141,'admin_toolbar_tools.extra_links:media.type_add','entity.media_type.collection','entity.media_type.add_form','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Add media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-2,_binary 'a:0:{}',0,4,6,11,67,141,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',142,'admin_toolbar_tools.extra_links:entity.menu.add_form','entity.menu.collection','entity.menu.add_form','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-2,_binary 'a:0:{}',0,4,6,11,19,142,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',143,'admin_toolbar_tools.extra_links:entity.menu.edit_form.admin','entity.menu.collection','entity.menu.edit_form','menu=admin',_binary 'a:1:{s:4:\"menu\";s:5:\"admin\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:5:\"admin\";}',1,4,6,11,19,143,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',144,'admin_toolbar_tools.extra_links:entity.menu.add_link_form.admin','admin_toolbar_tools.extra_links:entity.menu.edit_form.admin','entity.menu.add_link_form','menu=admin',_binary 'a:1:{s:4:\"menu\";s:5:\"admin\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,19,143,144,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',145,'admin_toolbar_tools.extra_links:entity.menu.edit_form.footer','entity.menu.collection','entity.menu.edit_form','menu=footer',_binary 'a:1:{s:4:\"menu\";s:6:\"footer\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:6:\"footer\";}',1,4,6,11,19,145,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',146,'admin_toolbar_tools.extra_links:entity.menu.add_link_form.footer','admin_toolbar_tools.extra_links:entity.menu.edit_form.footer','entity.menu.add_link_form','menu=footer',_binary 'a:1:{s:4:\"menu\";s:6:\"footer\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,19,145,146,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',147,'admin_toolbar_tools.extra_links:entity.menu.edit_form.main','entity.menu.collection','entity.menu.edit_form','menu=main',_binary 'a:1:{s:4:\"menu\";s:4:\"main\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:4:\"main\";}',1,4,6,11,19,147,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',148,'admin_toolbar_tools.extra_links:entity.menu.add_link_form.main','admin_toolbar_tools.extra_links:entity.menu.edit_form.main','entity.menu.add_link_form','menu=main',_binary 'a:1:{s:4:\"menu\";s:4:\"main\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,19,147,148,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',149,'admin_toolbar_tools.extra_links:entity.menu.edit_form.tools','entity.menu.collection','entity.menu.edit_form','menu=tools',_binary 'a:1:{s:4:\"menu\";s:5:\"tools\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:5:\"tools\";}',1,4,6,11,19,149,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',150,'admin_toolbar_tools.extra_links:entity.menu.add_link_form.tools','admin_toolbar_tools.extra_links:entity.menu.edit_form.tools','entity.menu.add_link_form','menu=tools',_binary 'a:1:{s:4:\"menu\";s:5:\"tools\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,19,149,150,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',151,'admin_toolbar_tools.extra_links:entity.menu.edit_form.account','entity.menu.collection','entity.menu.edit_form','menu=account',_binary 'a:1:{s:4:\"menu\";s:7:\"account\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,4,_binary 'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:7:\"account\";}',1,4,6,11,19,151,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',152,'admin_toolbar_tools.extra_links:entity.menu.add_link_form.account','admin_toolbar_tools.extra_links:entity.menu.edit_form.account','entity.menu.add_link_form','menu=account',_binary 'a:1:{s:4:\"menu\";s:7:\"account\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,19,151,152,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',153,'admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.node_type.collection','entity.node_type.edit_form','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:7:\"article\";}',1,4,6,11,20,153,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',154,'admin_toolbar_tools.extra_links:entity.node.field_ui_fieldsarticle','admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.node.field_ui_fields','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,20,153,154,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',155,'admin_toolbar_tools.extra_links:entity.entity_form_display.node.defaultarticle','admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.entity_form_display.node.default','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,20,153,155,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',156,'admin_toolbar_tools.extra_links:entity.entity_view_display.node.default.article','admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.entity_view_display.node.default','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,20,153,156,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',157,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.node.default.article','admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.node_type.entity_permissions_form','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,20,153,157,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',158,'admin_toolbar_tools.extra_links:entity.node_type.delete_form.article','admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.node_type.delete_form','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,20,153,158,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',159,'admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.node_type.collection','entity.node_type.edit_form','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:4:\"page\";}',1,4,6,11,20,159,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',160,'admin_toolbar_tools.extra_links:entity.node.field_ui_fieldspage','admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.node.field_ui_fields','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,20,159,160,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',161,'admin_toolbar_tools.extra_links:entity.entity_form_display.node.defaultpage','admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.entity_form_display.node.default','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,20,159,161,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',162,'admin_toolbar_tools.extra_links:entity.entity_view_display.node.default.page','admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.entity_view_display.node.default','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,20,159,162,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',163,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.node.default.page','admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.node_type.entity_permissions_form','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,20,159,163,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',164,'admin_toolbar_tools.extra_links:entity.node_type.delete_form.page','admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.node_type.delete_form','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,20,159,164,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',165,'admin_toolbar_tools.extra_links:node.type_add','entity.node_type.collection','node.type_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Add content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-2,_binary 'a:0:{}',0,4,6,11,20,165,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',166,'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.taxonomy_vocabulary.collection','entity.taxonomy_vocabulary.overview_form','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"entity_id\";s:4:\"tags\";}',1,4,6,11,21,166,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',167,'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.edit_form.tags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.taxonomy_vocabulary.edit_form','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,21,166,167,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',168,'admin_toolbar_tools.extra_links:entity.taxonomy_term.field_ui_fieldstags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.taxonomy_term.field_ui_fields','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,21,166,168,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',169,'admin_toolbar_tools.extra_links:entity.entity_form_display.taxonomy_term.defaulttags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.entity_form_display.taxonomy_term.default','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,21,166,169,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',170,'admin_toolbar_tools.extra_links:entity.entity_view_display.taxonomy_term.default.tags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.entity_view_display.taxonomy_term.default','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,21,166,170,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',171,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.taxonomy_term.default.tags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.taxonomy_vocabulary.entity_permissions_form','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,21,166,171,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',172,'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.delete_form.tags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.taxonomy_vocabulary.delete_form','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,21,166,172,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',173,'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.add_form','entity.taxonomy_vocabulary.collection','entity.taxonomy_vocabulary.add_form','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Add vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-998,_binary 'a:0:{}',0,4,6,11,21,173,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',174,'admin_toolbar_tools.extra_links:views_ui.add','entity.view.collection','views_ui.add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add view\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-5,_binary 'a:0:{}',0,4,6,11,22,174,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',175,'admin_toolbar_tools.extra_links:views_ui.block_content','entity.view.collection','entity.view.edit_form','view=block_content',_binary 'a:1:{s:4:\"view\";s:13:\"block_content\";}','',_binary 's:14:\"Content blocks\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,175,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',176,'admin_toolbar_tools.extra_links:views_ui.comment','entity.view.collection','entity.view.edit_form','view=comment',_binary 'a:1:{s:4:\"view\";s:7:\"comment\";}','',_binary 's:8:\"Comments\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,176,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',177,'admin_toolbar_tools.extra_links:views_ui.comments_recent','entity.view.collection','entity.view.edit_form','view=comments_recent',_binary 'a:1:{s:4:\"view\";s:15:\"comments_recent\";}','',_binary 's:15:\"Recent comments\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,177,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',178,'admin_toolbar_tools.extra_links:views_ui.content','entity.view.collection','entity.view.edit_form','view=content',_binary 'a:1:{s:4:\"view\";s:7:\"content\";}','',_binary 's:7:\"Content\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,178,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',179,'admin_toolbar_tools.extra_links:views_ui.content_recent','entity.view.collection','entity.view.edit_form','view=content_recent',_binary 'a:1:{s:4:\"view\";s:14:\"content_recent\";}','',_binary 's:14:\"Recent content\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,179,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',180,'admin_toolbar_tools.extra_links:views_ui.files','entity.view.collection','entity.view.edit_form','view=files',_binary 'a:1:{s:4:\"view\";s:5:\"files\";}','',_binary 's:5:\"Files\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,180,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',181,'admin_toolbar_tools.extra_links:views_ui.frontpage','entity.view.collection','entity.view.edit_form','view=frontpage',_binary 'a:1:{s:4:\"view\";s:9:\"frontpage\";}','',_binary 's:9:\"Frontpage\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,181,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',182,'admin_toolbar_tools.extra_links:views_ui.media','entity.view.collection','entity.view.edit_form','view=media',_binary 'a:1:{s:4:\"view\";s:5:\"media\";}','',_binary 's:5:\"Media\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,182,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',183,'admin_toolbar_tools.extra_links:views_ui.media_library','entity.view.collection','entity.view.edit_form','view=media_library',_binary 'a:1:{s:4:\"view\";s:13:\"media_library\";}','',_binary 's:13:\"Media library\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,183,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',184,'admin_toolbar_tools.extra_links:views_ui.taxonomy_term','entity.view.collection','entity.view.edit_form','view=taxonomy_term',_binary 'a:1:{s:4:\"view\";s:13:\"taxonomy_term\";}','',_binary 's:13:\"Taxonomy term\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,184,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',185,'admin_toolbar_tools.extra_links:views_ui.user_admin_people','entity.view.collection','entity.view.edit_form','view=user_admin_people',_binary 'a:1:{s:4:\"view\";s:17:\"user_admin_people\";}','',_binary 's:6:\"People\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,185,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',186,'admin_toolbar_tools.extra_links:views_ui.watchdog','entity.view.collection','entity.view.edit_form','view=watchdog',_binary 'a:1:{s:4:\"view\";s:8:\"watchdog\";}','',_binary 's:8:\"Watchdog\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,186,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',187,'admin_toolbar_tools.extra_links:views_ui.who_s_new','entity.view.collection','entity.view.edit_form','view=who_s_new',_binary 'a:1:{s:4:\"view\";s:9:\"who_s_new\";}','',_binary 's:9:\"Who\'s new\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,187,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',188,'admin_toolbar_tools.extra_links:views_ui.who_s_online','entity.view.collection','entity.view.edit_form','view=who_s_online',_binary 'a:1:{s:4:\"view\";s:12:\"who_s_online\";}','',_binary 's:18:\"Who\'s online block\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,188,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',190,'admin_toolbar_tools.extra_links:update.theme_update','system.themes_page','update.theme_update','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Update\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,23,190,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',191,'admin_toolbar_tools.extra_links:system.theme_settings','system.themes_page','system.theme_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,3,6,23,191,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',192,'admin_toolbar_tools.extra_links:system.theme_settings_theme.olivero','admin_toolbar_tools.extra_links:system.theme_settings','system.theme_settings_theme','theme=olivero',_binary 'a:1:{s:5:\"theme\";s:7:\"olivero\";}','',_binary 's:7:\"Olivero\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,23,191,192,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',193,'admin_toolbar_tools.extra_links:system.theme_settings_theme.claro','admin_toolbar_tools.extra_links:system.theme_settings','system.theme_settings_theme','theme=claro',_binary 'a:1:{s:5:\"theme\";s:5:\"claro\";}','',_binary 's:5:\"Claro\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,23,191,193,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',194,'system.modules_uninstall','system.modules_list','system.modules_uninstall','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Uninstall module\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,24,194,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',196,'admin_toolbar_tools.extra_links:update.module_update','system.modules_list','update.module_update','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Update\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,24,196,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',197,'media_library.settings','system.admin_config_media','media_library.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Media Library settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"Manage Media Library settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','media_library',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,197,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',198,'admin_toolbar_tools.extra_links:config.import','config.sync','config.import_full','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Import\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,25,33,34,198,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',199,'admin_toolbar_tools.extra_links:config.export','config.sync','config.export_full','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Export\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,25,33,34,199,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',200,'admin_toolbar.settings','system.admin_config_ui','admin_toolbar.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Admin Toolbar\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"Configure the Admin Toolbar module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar',1,1,0,0,_binary 'a:0:{}',0,4,6,25,48,200,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',201,'admin_toolbar_tools.settings','system.admin_config_ui','admin_toolbar_tools.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Admin Toolbar Tools\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"Configure the Admin Toolbar Tools module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,25,48,201,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',202,'ckeditor5_plugin_pack.settings','system.admin_config_content','ckeditor5_plugin_pack.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"CKEditor 5 Plugin Pack\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure the CKEditor 5 Plugin Pack module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','ckeditor5_plugin_pack',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,202,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',203,'entity.ckeditor5_template.overview','system.admin_config_content','entity.ckeditor5_template.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"CKEditor 5 Content Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:89:\"The template feature allows you to insert predefined content structures into the document\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','ckeditor5_plugin_pack_templates',1,1,0,32,_binary 'a:0:{}',0,4,6,25,51,203,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',204,'admin_toolbar_tools.extra_links:entity.user.field_ui_fields_','entity.user.admin_form','entity.user.field_ui_fields','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,25,53,54,204,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',205,'admin_toolbar_tools.extra_links:entity.entity_form_display.user.default_','entity.user.admin_form','entity.entity_form_display.user.default','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,25,53,54,205,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',206,'admin_toolbar_tools.extra_links:entity.entity_view_display.user.default_','entity.user.admin_form','entity.entity_view_display.user.default','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,25,53,54,206,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',207,'admin_toolbar_tools.extra_links:views_ui.field_list','entity.field_storage_config.collection','views_ui.reports_fields','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Used in views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,55,59,207,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',208,'admin_toolbar_tools.extra_links:user.admin_create','entity.user.collection','user.admin_create','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,63,208,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',209,'admin_toolbar_tools.extra_links:user.admin_permissions','entity.user.collection','user.admin_permissions','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,63,209,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',210,'admin_toolbar_tools.extra_links:entity.user_role.collection','entity.user.collection','entity.user_role.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,3,6,63,210,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',211,'admin_toolbar_tools.extra_links:user.role_add','admin_toolbar_tools.extra_links:entity.user_role.collection','user.role_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-50,_binary 'a:0:{}',0,4,6,63,210,211,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',212,'admin_toolbar_tools.extra_links:entity.user_role.edit_form.anonymous','admin_toolbar_tools.extra_links:entity.user_role.collection','entity.user_role.edit_form','user_role=anonymous',_binary 'a:1:{s:9:\"user_role\";s:9:\"anonymous\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:9:\"anonymous\";}',1,4,6,63,210,212,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',213,'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.anonymous','admin_toolbar_tools.extra_links:entity.user_role.edit_form.anonymous','entity.user_role.edit_permissions_form','user_role=anonymous',_binary 'a:1:{s:9:\"user_role\";s:9:\"anonymous\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,212,213,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',214,'admin_toolbar_tools.extra_links:entity.user_role.edit_form.authenticated','admin_toolbar_tools.extra_links:entity.user_role.collection','entity.user_role.edit_form','user_role=authenticated',_binary 'a:1:{s:9:\"user_role\";s:13:\"authenticated\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:13:\"authenticated\";}',1,4,6,63,210,214,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',215,'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.authenticated','admin_toolbar_tools.extra_links:entity.user_role.edit_form.authenticated','entity.user_role.edit_permissions_form','user_role=authenticated',_binary 'a:1:{s:9:\"user_role\";s:13:\"authenticated\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,214,215,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',216,'admin_toolbar_tools.extra_links:entity.user_role.edit_form.content_editor','admin_toolbar_tools.extra_links:entity.user_role.collection','entity.user_role.edit_form','user_role=content_editor',_binary 'a:1:{s:9:\"user_role\";s:14:\"content_editor\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:14:\"content_editor\";}',1,4,6,63,210,216,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',217,'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.content_editor','admin_toolbar_tools.extra_links:entity.user_role.edit_form.content_editor','entity.user_role.edit_permissions_form','user_role=content_editor',_binary 'a:1:{s:9:\"user_role\";s:14:\"content_editor\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,216,217,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',218,'admin_toolbar_tools.extra_links:entity.user_role.delete_form.content_editor','admin_toolbar_tools.extra_links:entity.user_role.edit_form.content_editor','entity.user_role.delete_form','user_role=content_editor',_binary 'a:1:{s:9:\"user_role\";s:14:\"content_editor\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,216,218,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',219,'admin_toolbar_tools.extra_links:entity.user_role.edit_form.administrator','admin_toolbar_tools.extra_links:entity.user_role.collection','entity.user_role.edit_form','user_role=administrator',_binary 'a:1:{s:9:\"user_role\";s:13:\"administrator\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:13:\"administrator\";}',1,4,6,63,210,219,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',220,'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.administrator','admin_toolbar_tools.extra_links:entity.user_role.edit_form.administrator','entity.user_role.edit_permissions_form','user_role=administrator',_binary 'a:1:{s:9:\"user_role\";s:13:\"administrator\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,219,220,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',221,'admin_toolbar_tools.extra_links:entity.user_role.delete_form.administrator','admin_toolbar_tools.extra_links:entity.user_role.edit_form.administrator','entity.user_role.delete_form','user_role=administrator',_binary 'a:1:{s:9:\"user_role\";s:13:\"administrator\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,219,221,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',222,'admin_toolbar_tools.help','system.admin','<front>','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Tools\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-100,_binary 'a:0:{}',1,2,6,222,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',223,'system.admin_index','admin_toolbar_tools.help','system.admin_index','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Index\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-100,_binary 'a:0:{}',0,3,6,222,223,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',224,'system.run_cron','admin_toolbar_tools.help','admin_toolbar.run.cron','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Run cron\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-8,_binary 'a:0:{}',0,3,6,222,224,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',225,'system.db_update','admin_toolbar_tools.help','system.db_update','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Run updates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-6,_binary 'a:0:{}',0,3,6,222,225,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',226,'admin_toolbar_tools.flush','admin_toolbar_tools.help','admin_toolbar_tools.flush','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Flush all caches\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-9,_binary 'a:0:{}',1,3,6,222,226,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',227,'admin_toolbar_tools.cssjs','admin_toolbar_tools.flush','admin_toolbar_tools.cssjs','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Flush CSS and JavaScript\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,227,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',228,'admin_toolbar_tools.plugin','admin_toolbar_tools.flush','admin_toolbar_tools.plugin','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Flush plugins cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,228,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',229,'admin_toolbar_tools.flush_static','admin_toolbar_tools.flush','admin_toolbar_tools.flush_static','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Flush static cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,229,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',230,'admin_toolbar_tools.flush_menu','admin_toolbar_tools.flush','admin_toolbar_tools.flush_menu','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Flush routing and links cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,230,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',231,'admin_toolbar_tools.flush_twig','admin_toolbar_tools.flush','admin_toolbar_tools.flush_twig','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Flush twig cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,231,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',232,'admin_toolbar_tools.flush_rendercache','admin_toolbar_tools.flush','admin_toolbar_tools.flush_rendercache','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Flush render cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,232,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',233,'admin_toolbar_tools.theme_rebuild','admin_toolbar_tools.flush','admin_toolbar_tools.theme_rebuild','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Rebuild theme registry\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,233,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',234,'admin_toolbar_tools.extra_links:flush_views','admin_toolbar_tools.flush','admin_toolbar_tools.flush_views','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Flush views cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,234,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',235,'admin_toolbar_tools.extra_links:user.logout','admin_toolbar_tools.help','user.logout','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Logout\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,10,_binary 'a:0:{}',0,3,6,222,235,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',236,'admin_toolbar_tools.extra_links:system.theme_settings_theme.gin','admin_toolbar_tools.extra_links:system.theme_settings','system.theme_settings_theme','theme=gin',_binary 'a:1:{s:5:\"theme\";s:3:\"gin\";}','',_binary 's:3:\"Gin\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,23,191,236,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',237,'entity.paragraphs_type.collection','system.admin_structure','entity.paragraphs_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Paragraph types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Create and manage Paragraph types.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','paragraphs',1,1,0,0,_binary 'a:0:{}',1,3,6,11,237,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',238,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_accordion',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_accordion\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:13:\"ept_accordion\";}',1,4,6,11,237,238,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',239,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_accordion','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion','entity.paragraph.field_ui_fields','paragraphs_type=ept_accordion',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_accordion\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,238,239,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',240,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_accordion','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion','entity.entity_form_display.paragraph.default','paragraphs_type=ept_accordion',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_accordion\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,238,240,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',241,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_accordion','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion','entity.entity_view_display.paragraph.default','paragraphs_type=ept_accordion',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_accordion\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,238,241,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',242,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_accordion','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion','entity.paragraphs_type.delete_form','paragraphs_type=ept_accordion',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_accordion\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,238,242,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',243,'paragraphs.type_add','entity.paragraphs_type.collection','paragraphs.type_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Add paragraph type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','paragraphs',1,1,0,0,_binary 'a:0:{}',0,4,6,11,237,243,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',244,'entity_reference_revisions.delete_orphans','system.admin_config_system','entity_reference_revisions.delete_orphans','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Delete orphaned composite entities\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:90:\"Delete revisions of entities that are no longer used in Entity Reference Revisions fields.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','entity_reference_revisions',1,1,0,30,_binary 'a:0:{}',0,4,6,25,45,244,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',245,'ept_core.settings','system.admin_config_content','ept_core.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Extra Paragraph Types (EPT) settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:75:\"Breakpoints, containers width, colors and other settings for EPT paragraphs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','ept_core',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,245,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',246,'paragraphs.settings','system.admin_config_content','paragraphs.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Paragraphs settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','paragraphs',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,246,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',247,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion_section','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_accordion_section',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_accordion_section\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:21:\"ept_accordion_section\";}',1,4,6,11,237,247,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',248,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_accordion_section','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion_section','entity.paragraph.field_ui_fields','paragraphs_type=ept_accordion_section',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_accordion_section\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,247,248,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',249,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_accordion_section','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion_section','entity.entity_form_display.paragraph.default','paragraphs_type=ept_accordion_section',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_accordion_section\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,247,249,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',250,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_accordion_section','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion_section','entity.entity_view_display.paragraph.default','paragraphs_type=ept_accordion_section',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_accordion_section\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,247,250,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',251,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_accordion_section','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion_section','entity.paragraphs_type.delete_form','paragraphs_type=ept_accordion_section',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_accordion_section\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,247,251,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',252,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_basic_button','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_basic_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_basic_button\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:16:\"ept_basic_button\";}',1,4,6,11,237,252,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',253,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_basic_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_basic_button','entity.paragraph.field_ui_fields','paragraphs_type=ept_basic_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_basic_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,252,253,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',254,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_basic_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_basic_button','entity.entity_form_display.paragraph.default','paragraphs_type=ept_basic_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_basic_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,252,254,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',255,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_basic_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_basic_button','entity.entity_view_display.paragraph.default','paragraphs_type=ept_basic_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_basic_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,252,255,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',256,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_basic_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_basic_button','entity.paragraphs_type.delete_form','paragraphs_type=ept_basic_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_basic_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,252,256,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',257,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_block','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_block',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_block\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:9:\"ept_block\";}',1,4,6,11,237,257,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',258,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_block','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_block','entity.paragraph.field_ui_fields','paragraphs_type=ept_block',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_block\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,257,258,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',259,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_block','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_block','entity.entity_form_display.paragraph.default','paragraphs_type=ept_block',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_block\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,257,259,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',260,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_block','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_block','entity.entity_view_display.paragraph.default','paragraphs_type=ept_block',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_block\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,257,260,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',261,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_block','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_block','entity.paragraphs_type.delete_form','paragraphs_type=ept_block',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_block\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,257,261,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',262,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_bootstrap_button','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_bootstrap_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:20:\"ept_bootstrap_button\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:20:\"ept_bootstrap_button\";}',1,4,6,11,237,262,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',263,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_bootstrap_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_bootstrap_button','entity.paragraph.field_ui_fields','paragraphs_type=ept_bootstrap_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:20:\"ept_bootstrap_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,262,263,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',264,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_bootstrap_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_bootstrap_button','entity.entity_form_display.paragraph.default','paragraphs_type=ept_bootstrap_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:20:\"ept_bootstrap_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,262,264,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',265,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_bootstrap_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_bootstrap_button','entity.entity_view_display.paragraph.default','paragraphs_type=ept_bootstrap_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:20:\"ept_bootstrap_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,262,265,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',266,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_bootstrap_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_bootstrap_button','entity.paragraphs_type.delete_form','paragraphs_type=ept_bootstrap_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:20:\"ept_bootstrap_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,262,266,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',267,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_carousel',_binary 'a:1:{s:15:\"paragraphs_type\";s:12:\"ept_carousel\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:12:\"ept_carousel\";}',1,4,6,11,237,267,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',268,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_carousel','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel','entity.paragraph.field_ui_fields','paragraphs_type=ept_carousel',_binary 'a:1:{s:15:\"paragraphs_type\";s:12:\"ept_carousel\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,267,268,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',269,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_carousel','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel','entity.entity_form_display.paragraph.default','paragraphs_type=ept_carousel',_binary 'a:1:{s:15:\"paragraphs_type\";s:12:\"ept_carousel\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,267,269,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',270,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_carousel','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel','entity.entity_view_display.paragraph.default','paragraphs_type=ept_carousel',_binary 'a:1:{s:15:\"paragraphs_type\";s:12:\"ept_carousel\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,267,270,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',271,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_carousel','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel','entity.paragraphs_type.delete_form','paragraphs_type=ept_carousel',_binary 'a:1:{s:15:\"paragraphs_type\";s:12:\"ept_carousel\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,267,271,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',272,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel_item','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_carousel_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_carousel_item\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:17:\"ept_carousel_item\";}',1,4,6,11,237,272,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',273,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_carousel_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel_item','entity.paragraph.field_ui_fields','paragraphs_type=ept_carousel_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_carousel_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,272,273,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',274,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_carousel_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel_item','entity.entity_form_display.paragraph.default','paragraphs_type=ept_carousel_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_carousel_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,272,274,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',275,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_carousel_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel_item','entity.entity_view_display.paragraph.default','paragraphs_type=ept_carousel_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_carousel_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,272,275,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',276,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_carousel_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel_item','entity.paragraphs_type.delete_form','paragraphs_type=ept_carousel_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_carousel_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,272,276,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',277,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_columns','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_columns',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_columns\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:11:\"ept_columns\";}',1,4,6,11,237,277,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',278,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_columns','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_columns','entity.paragraph.field_ui_fields','paragraphs_type=ept_columns',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_columns\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,277,278,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',279,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_columns','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_columns','entity.entity_form_display.paragraph.default','paragraphs_type=ept_columns',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_columns\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,277,279,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',280,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_columns','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_columns','entity.entity_view_display.paragraph.default','paragraphs_type=ept_columns',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_columns\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,277,280,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',281,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_columns','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_columns','entity.paragraphs_type.delete_form','paragraphs_type=ept_columns',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_columns\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,277,281,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',282,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_countdown','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_countdown',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_countdown\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:13:\"ept_countdown\";}',1,4,6,11,237,282,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',283,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_countdown','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_countdown','entity.paragraph.field_ui_fields','paragraphs_type=ept_countdown',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_countdown\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,282,283,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',284,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_countdown','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_countdown','entity.entity_form_display.paragraph.default','paragraphs_type=ept_countdown',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_countdown\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,282,284,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',285,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_countdown','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_countdown','entity.entity_view_display.paragraph.default','paragraphs_type=ept_countdown',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_countdown\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,282,285,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',286,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_countdown','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_countdown','entity.paragraphs_type.delete_form','paragraphs_type=ept_countdown',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_countdown\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,282,286,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',287,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_counter',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_counter\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:11:\"ept_counter\";}',1,4,6,11,237,287,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',288,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_counter','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter','entity.paragraph.field_ui_fields','paragraphs_type=ept_counter',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_counter\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,287,288,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',289,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_counter','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter','entity.entity_form_display.paragraph.default','paragraphs_type=ept_counter',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_counter\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,287,289,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',290,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_counter','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter','entity.entity_view_display.paragraph.default','paragraphs_type=ept_counter',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_counter\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,287,290,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',291,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_counter','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter','entity.paragraphs_type.delete_form','paragraphs_type=ept_counter',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_counter\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,287,291,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',292,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter_item','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_counter_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_counter_item\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:16:\"ept_counter_item\";}',1,4,6,11,237,292,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',293,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_counter_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter_item','entity.paragraph.field_ui_fields','paragraphs_type=ept_counter_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_counter_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,292,293,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',294,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_counter_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter_item','entity.entity_form_display.paragraph.default','paragraphs_type=ept_counter_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_counter_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,292,294,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',295,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_counter_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter_item','entity.entity_view_display.paragraph.default','paragraphs_type=ept_counter_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_counter_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,292,295,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',296,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_counter_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter_item','entity.paragraphs_type.delete_form','paragraphs_type=ept_counter_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_counter_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,292,296,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',297,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cta','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_cta',_binary 'a:1:{s:15:\"paragraphs_type\";s:7:\"ept_cta\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:7:\"ept_cta\";}',1,4,6,11,237,297,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',298,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_cta','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cta','entity.paragraph.field_ui_fields','paragraphs_type=ept_cta',_binary 'a:1:{s:15:\"paragraphs_type\";s:7:\"ept_cta\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,297,298,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',299,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_cta','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cta','entity.entity_form_display.paragraph.default','paragraphs_type=ept_cta',_binary 'a:1:{s:15:\"paragraphs_type\";s:7:\"ept_cta\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,297,299,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',300,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_cta','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cta','entity.entity_view_display.paragraph.default','paragraphs_type=ept_cta',_binary 'a:1:{s:15:\"paragraphs_type\";s:7:\"ept_cta\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,297,300,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',301,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_cta','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cta','entity.paragraphs_type.delete_form','paragraphs_type=ept_cta',_binary 'a:1:{s:15:\"paragraphs_type\";s:7:\"ept_cta\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,297,301,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',302,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_hero','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_hero',_binary 'a:1:{s:15:\"paragraphs_type\";s:8:\"ept_hero\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:8:\"ept_hero\";}',1,4,6,11,237,302,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',303,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_hero','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_hero','entity.paragraph.field_ui_fields','paragraphs_type=ept_hero',_binary 'a:1:{s:15:\"paragraphs_type\";s:8:\"ept_hero\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,302,303,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',304,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_hero','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_hero','entity.entity_form_display.paragraph.default','paragraphs_type=ept_hero',_binary 'a:1:{s:15:\"paragraphs_type\";s:8:\"ept_hero\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,302,304,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',305,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_hero','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_hero','entity.entity_view_display.paragraph.default','paragraphs_type=ept_hero',_binary 'a:1:{s:15:\"paragraphs_type\";s:8:\"ept_hero\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,302,305,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',306,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_hero','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_hero','entity.paragraphs_type.delete_form','paragraphs_type=ept_hero',_binary 'a:1:{s:15:\"paragraphs_type\";s:8:\"ept_hero\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,302,306,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',307,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_image',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_image\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:9:\"ept_image\";}',1,4,6,11,237,307,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',308,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_image','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image','entity.paragraph.field_ui_fields','paragraphs_type=ept_image',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,307,308,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',309,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_image','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image','entity.entity_form_display.paragraph.default','paragraphs_type=ept_image',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,307,309,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',310,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_image','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image','entity.entity_view_display.paragraph.default','paragraphs_type=ept_image',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,307,310,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',311,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_image','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image','entity.paragraphs_type.delete_form','paragraphs_type=ept_image',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,307,311,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',312,'glightbox.admin_settings','system.admin_config_media','glightbox.admin_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"GLightbox settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"Configure the GLightbox settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','glightbox',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,312,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',313,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image_gallery','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_image_gallery',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_image_gallery\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:17:\"ept_image_gallery\";}',1,4,6,11,237,313,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',314,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_image_gallery','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image_gallery','entity.paragraph.field_ui_fields','paragraphs_type=ept_image_gallery',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_image_gallery\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,313,314,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',315,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_image_gallery','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image_gallery','entity.entity_form_display.paragraph.default','paragraphs_type=ept_image_gallery',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_image_gallery\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,313,315,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',316,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_image_gallery','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image_gallery','entity.entity_view_display.paragraph.default','paragraphs_type=ept_image_gallery',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_image_gallery\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,313,316,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',317,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_image_gallery','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image_gallery','entity.paragraphs_type.delete_form','paragraphs_type=ept_image_gallery',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_image_gallery\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,313,317,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',318,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_micromodal','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_micromodal',_binary 'a:1:{s:15:\"paragraphs_type\";s:14:\"ept_micromodal\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:14:\"ept_micromodal\";}',1,4,6,11,237,318,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',319,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_micromodal','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_micromodal','entity.paragraph.field_ui_fields','paragraphs_type=ept_micromodal',_binary 'a:1:{s:15:\"paragraphs_type\";s:14:\"ept_micromodal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,318,319,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',320,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_micromodal','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_micromodal','entity.entity_form_display.paragraph.default','paragraphs_type=ept_micromodal',_binary 'a:1:{s:15:\"paragraphs_type\";s:14:\"ept_micromodal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,318,320,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',321,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_micromodal','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_micromodal','entity.entity_view_display.paragraph.default','paragraphs_type=ept_micromodal',_binary 'a:1:{s:15:\"paragraphs_type\";s:14:\"ept_micromodal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,318,321,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',322,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_micromodal','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_micromodal','entity.paragraphs_type.delete_form','paragraphs_type=ept_micromodal',_binary 'a:1:{s:15:\"paragraphs_type\";s:14:\"ept_micromodal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,318,322,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',323,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_quote','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_quote',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_quote\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:9:\"ept_quote\";}',1,4,6,11,237,323,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',324,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_quote','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_quote','entity.paragraph.field_ui_fields','paragraphs_type=ept_quote',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_quote\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,323,324,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',325,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_quote','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_quote','entity.entity_form_display.paragraph.default','paragraphs_type=ept_quote',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_quote\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,323,325,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',326,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_quote','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_quote','entity.entity_view_display.paragraph.default','paragraphs_type=ept_quote',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_quote\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,323,326,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',327,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_quote','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_quote','entity.paragraphs_type.delete_form','paragraphs_type=ept_quote',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_quote\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,323,327,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',328,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_slick_slider',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_slick_slider\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:16:\"ept_slick_slider\";}',1,4,6,11,237,328,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',329,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_slick_slider','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider','entity.paragraph.field_ui_fields','paragraphs_type=ept_slick_slider',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_slick_slider\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,328,329,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',330,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_slick_slider','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider','entity.entity_form_display.paragraph.default','paragraphs_type=ept_slick_slider',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_slick_slider\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,328,330,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',331,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_slick_slider','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider','entity.entity_view_display.paragraph.default','paragraphs_type=ept_slick_slider',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_slick_slider\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,328,331,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',332,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_slick_slider','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider','entity.paragraphs_type.delete_form','paragraphs_type=ept_slick_slider',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_slick_slider\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,328,332,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',338,'admin_toolbar_tools.extra_links:paragraphs_type.collection','entity.paragraphs_type.collection','entity.paragraphs_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"All types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-999,_binary 'a:0:{}',0,4,6,11,237,338,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',346,'admin_toolbar_tools.extra_links:system.theme_settings_theme.ept_light','admin_toolbar_tools.extra_links:system.theme_settings','system.theme_settings_theme','theme=ept_light',_binary 'a:1:{s:5:\"theme\";s:9:\"ept_light\";}','',_binary 's:9:\"EPT Light\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,23,191,346,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',347,'tb_megamenu.admin','system.admin_structure','entity.tb_megamenu.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"TB Mega Menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"List of megamenu items\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','tb_megamenu',1,1,0,0,_binary 'a:0:{}',0,3,6,11,347,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('main',348,'menu_link_content:d5043c53-9961-4a60-bb2a-a37bbaaa3961','',NULL,'',_binary 'a:0:{}','https://www.drupal.org/project/ept_core',_binary 's:11:\"EPT modules\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',0,0,1,-47,_binary 'a:1:{s:9:\"entity_id\";s:1:\"1\";}',0,1,348,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('admin',350,'layout_paragraphs.label_settings','system.admin_config_content','layout_paragraphs.label_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Layout Paragraphs settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"Configure site-wide settings for Layout Paragraphs field widgets.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','layout_paragraphs',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,350,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('footer',351,'menu_link_content:9618e6db-485e-4fa0-84d3-b56e8936ef0d','',NULL,'',_binary 'a:0:{}','https://www.linkedin.com/in/ivan-abramenko/',_binary 's:8:\"LinkedIn\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,-49,_binary 'a:1:{s:9:\"entity_id\";s:1:\"3\";}',0,1,351,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('footer',352,'menu_link_content:9a831874-a895-4cc7-ac58-2de2055f7c4b','',NULL,'',_binary 'a:0:{}','https://drupalbook.org/contact',_binary 's:10:\"DrupalBook\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,-46,_binary 'a:1:{s:9:\"entity_id\";s:1:\"4\";}',0,1,352,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('footer',353,'menu_link_content:60ff628e-4af5-44f0-af2a-8bd88c057b15','',NULL,'',_binary 'a:0:{}','https://www.drupal.org/user/1079574/contact',_binary 's:10:\"Drupal.org\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,-48,_binary 'a:1:{s:9:\"entity_id\";s:1:\"5\";}',0,1,353,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('account',354,'menu_link_content:0cdaaebf-f931-4b2e-a1ed-fed2026812e5','',NULL,'',_binary 'a:0:{}','https://www.linkedin.com/in/ivan-abramenko/',_binary 's:8:\"LinkedIn\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,0,_binary 'a:1:{s:9:\"entity_id\";s:1:\"6\";}',0,1,354,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('account',355,'menu_link_content:c099779d-431c-4fb8-831c-02e395b960b7','',NULL,'',_binary 'a:0:{}','https://www.drupal.org/user/1079574/contact',_binary 's:10:\"Drupal.org\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,0,_binary 'a:1:{s:9:\"entity_id\";s:1:\"7\";}',0,1,355,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('account',356,'menu_link_content:5ddd00be-7fb0-4648-8176-b3cdf1a8fbff','',NULL,'',_binary 'a:0:{}','https://drupal.slack.com/archives/C07A942U72P',_binary 's:5:\"Slack\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,0,_binary 'a:1:{s:9:\"entity_id\";s:1:\"8\";}',0,1,356,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('footer',357,'menu_link_content:86cc3040-af4c-4f8b-901a-c9c517ae0ab6','',NULL,'',_binary 'a:0:{}','https://drupal.slack.com/archives/C07A942U72P',_binary 's:5:\"Slack\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,-47,_binary 'a:1:{s:9:\"entity_id\";s:1:\"9\";}',0,1,357,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('account',358,'menu_link_content:f7dcb4f3-cc8d-40eb-944e-073aea38aad3','',NULL,'',_binary 'a:0:{}','https://drupalbook.org/contact',_binary 's:10:\"DrupalBook\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,0,_binary 'a:1:{s:9:\"entity_id\";s:2:\"10\";}',0,1,358,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('main',359,'menu_link_content:b7aae8ff-5c43-4ae2-a08a-7fec98be2568','',NULL,'',_binary 'a:0:{}','https://www.drupal.org/project/ebt_core',_binary 's:11:\"EBT Modules\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:5:\"_self\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',0,0,0,-46,_binary 'a:1:{s:9:\"entity_id\";s:2:\"11\";}',0,1,359,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('main',360,'menu_link_content:99f46f29-6f08-4218-8291-d84b7e07ab0d','',NULL,'',_binary 'a:0:{}','https://drupalbook.org/ept/demo',_binary 's:13:\"Documentation\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,-45,_binary 'a:1:{s:9:\"entity_id\";s:2:\"12\";}',0,1,360,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('admin',361,'image_effects.settings','system.admin_config_media','image_effects.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Image Effects\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"Configure Image Effects settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','image_effects',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,361,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',362,'file_mdm.settings','system.admin_config_system','file_mdm.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"File metadata manager\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"Configure file metadata settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','file_mdm',1,1,0,0,_binary 'a:0:{}',0,4,6,25,45,362,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',363,'admin_toolbar_tools.extra_links:views_ui.what_s_new','entity.view.collection','entity.view.edit_form','view=what_s_new',_binary 'a:1:{s:4:\"view\";s:10:\"what_s_new\";}','',_binary 's:10:\"What\'s New\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,363,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('main',364,'menu_link_content:fa9e2736-9b20-41fa-9e2c-c19aad723aab','','entity.node.canonical','node=19',_binary 'a:1:{s:4:\"node\";s:2:\"19\";}','',_binary 's:12:\"Listing Page\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}','menu_link_content',1,0,0,-48,_binary 'a:1:{s:9:\"entity_id\";s:2:\"13\";}',0,1,364,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('main',365,'menu_link_content:10f330e8-9bde-4bb7-a57c-c1f39e9a02fd','','<front>','',_binary 'a:0:{}','',_binary 's:12:\"Landing Page\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}','menu_link_content',1,1,0,-49,_binary 'a:1:{s:9:\"entity_id\";s:2:\"14\";}',0,1,365,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('admin',366,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cards','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_cards',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_cards\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:9:\"ept_cards\";}',1,4,6,11,237,366,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',367,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_cards','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cards','entity.paragraph.field_ui_fields','paragraphs_type=ept_cards',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_cards\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,366,367,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',368,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_cards','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cards','entity.entity_form_display.paragraph.default','paragraphs_type=ept_cards',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_cards\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,366,368,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',369,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_cards','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cards','entity.entity_view_display.paragraph.default','paragraphs_type=ept_cards',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_cards\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,366,369,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',370,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_cards','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cards','entity.paragraphs_type.delete_form','paragraphs_type=ept_cards',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_cards\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,366,370,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',376,'entity.webform.collection','system.admin_structure','entity.webform.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Webforms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Create webforms and manage submissions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,0,_binary 'a:0:{}',1,3,6,11,376,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',377,'entity.webform.collection.item','entity.webform.collection','entity.webform.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,0,_binary 'a:0:{}',0,4,6,11,376,377,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',378,'entity.webform_submission.collection.item','entity.webform.collection','entity.webform_submission.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Submissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,20,_binary 'a:0:{}',1,4,6,11,376,378,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',379,'entity.webform_submission.collection_manage.item','entity.webform_submission.collection.item','entity.webform_submission.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Manage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,0,_binary 'a:0:{}',0,5,6,11,376,378,379,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',380,'entity.webform_submission.collection_purge.item','entity.webform_submission.collection.item','entity.webform_submission.collection_purge','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Purge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,10,_binary 'a:0:{}',0,5,6,11,376,378,380,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',381,'webform.options.item','entity.webform.collection','entity.webform_options.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,30,_binary 'a:0:{}',1,4,6,11,376,381,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',382,'webform.config.options.item','webform.options.item','entity.webform_options.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,0,_binary 'a:0:{}',0,5,6,11,376,381,382,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',383,'webform.config.item','entity.webform.collection','webform.config','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,40,_binary 'a:0:{}',1,4,6,11,376,383,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',384,'webform.config.forms.item','webform.config.item','webform.config','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,10,_binary 'a:0:{}',0,5,6,11,376,383,384,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',385,'webform.config.elements.item','webform.config.item','webform.config.elements','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Elements\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,20,_binary 'a:0:{}',0,5,6,11,376,383,385,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',386,'webform.config.submissions.item','webform.config.item','webform.config.submissions','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Submissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,40,_binary 'a:0:{}',0,5,6,11,376,383,386,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',387,'webform.config.handlers.item','webform.config.item','webform.config.handlers','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Handlers\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,50,_binary 'a:0:{}',0,5,6,11,376,383,387,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',388,'webform.config.variants.item','webform.config.item','webform.config.variants','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Variants\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,60,_binary 'a:0:{}',0,5,6,11,376,383,388,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',389,'webform.config.exporters.item','webform.config.item','webform.config.exporters','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Exporters\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,70,_binary 'a:0:{}',0,5,6,11,376,383,389,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',390,'webform.config.libraries.item','webform.config.item','webform.config.libraries','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Libraries\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,80,_binary 'a:0:{}',0,5,6,11,376,383,390,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',391,'webform.config.advanced.item','webform.config.item','webform.config.advanced','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Advanced\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,90,_binary 'a:0:{}',0,5,6,11,376,383,391,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',392,'webform.addons.item','entity.webform.collection','webform.addons','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Add-ons\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,50,_binary 'a:0:{}',0,4,6,11,376,392,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',393,'webform.help.item','entity.webform.collection','webform.help','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Help\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,60,_binary 'a:0:{}',0,4,6,11,376,393,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',394,'webform.reports_plugins','system.admin_reports','webform.reports_plugins.elements','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Webform plugins\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"Overview of plugins used by the Webform module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,0,_binary 'a:0:{}',0,3,6,55,394,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',395,'admin_toolbar_tools.extra_links:views_ui.webform_submissions','entity.view.collection','entity.view.edit_form','view=webform_submissions',_binary 'a:1:{s:4:\"view\";s:19:\"webform_submissions\";}','',_binary 's:19:\"Webform submissions\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,395,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',396,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider_item','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_slick_slider_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_slick_slider_item\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:21:\"ept_slick_slider_item\";}',1,4,6,11,237,396,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',397,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_slick_slider_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider_item','entity.paragraph.field_ui_fields','paragraphs_type=ept_slick_slider_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_slick_slider_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,396,397,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',398,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_slick_slider_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider_item','entity.entity_form_display.paragraph.default','paragraphs_type=ept_slick_slider_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_slick_slider_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,396,398,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',399,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_slick_slider_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider_item','entity.entity_view_display.paragraph.default','paragraphs_type=ept_slick_slider_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_slick_slider_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,396,399,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',400,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_slick_slider_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider_item','entity.paragraphs_type.delete_form','paragraphs_type=ept_slick_slider_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_slick_slider_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,396,400,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm');
/*!40000 ALTER TABLE `menu_tree` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node`
--

DROP TABLE IF EXISTS `node`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node` (
  `nid` int unsigned NOT NULL AUTO_INCREMENT,
  `vid` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`nid`),
  UNIQUE KEY `node_field__uuid__value` (`uuid`),
  UNIQUE KEY `node__vid` (`vid`),
  KEY `node_field__type__target_id` (`type`)
) ENGINE=InnoDB AUTO_INCREMENT=20 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node`
--

LOCK TABLES `node` WRITE;
/*!40000 ALTER TABLE `node` DISABLE KEYS */;
INSERT INTO `node` VALUES (1,45,'page','b86c7571-14d1-44a5-bd24-0d90f5afff32','en'),(2,46,'article','46723af4-3654-4768-a509-f3dcff3aa671','en'),(3,47,'article','93c7ee44-83da-4807-87bf-52938a3f8291','en'),(4,48,'article','80c0c31c-f0ba-4e94-a37c-614161120c01','en'),(5,49,'article','61fe17c0-3dbe-47c3-84d7-78764a3d1574','en'),(6,50,'article','313679dd-963a-451a-aae2-760701974bf7','en'),(7,51,'article','c23f38e0-cb81-4745-8a07-f272d2210bea','en'),(8,52,'article','193cf44c-9a28-42f9-a551-997a1cbb4c5b','en'),(9,53,'article','f906b600-2fe4-418c-bd9b-4b259a145009','en'),(10,54,'article','d9c0bdfc-bf44-4f32-891b-66a099dea642','en'),(11,55,'article','dd922eaa-0d0f-4340-826e-b6bb47e61d14','en'),(12,56,'article','b51b1456-13ba-4b7c-a734-577a143b7540','en'),(13,57,'article','0716b19b-c10a-4256-bc30-9c22f1ecae6e','en'),(14,58,'article','6d4544fa-9615-4244-8914-a3a7e2cb3e1a','en'),(15,59,'article','041b2e8e-bdad-4e00-a646-c25f1ad58dca','en'),(16,60,'article','86871467-4e91-40db-8246-eadd9d5dd805','en'),(17,61,'article','c122f46b-b6e8-477a-bb9b-5d25da9576ac','en'),(18,62,'article','b66f27fb-6a81-434b-8d07-18e39e605985','en'),(19,68,'page','7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9','en');
/*!40000 ALTER TABLE `node` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__body`
--

DROP TABLE IF EXISTS `node__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__body`
--

LOCK TABLES `node__body` WRITE;
/*!40000 ALTER TABLE `node__body` DISABLE KEYS */;
INSERT INTO `node__body` VALUES ('article',0,2,46,'en',0,'<p>Extra Paragraph Types: Video and Image Gallery module provides ability to add grid gallery with videos and images.</p>','','full_html'),('article',0,3,47,'en',0,'<p>Extra Paragraph Types: Webform module provides ability to add a paragraph with Webform.</p>','','full_html'),('article',0,4,48,'en',0,'<p>Extra Paragraph Types: Webform Popup module provides ability to add Webform in popup. The button and popup are customizable with Settings form. This module will be helpful for creating Contact Us form popup.</p>','','full_html'),('article',0,5,49,'en',0,'<p>Tested and fully functional release. EPT 1.4.x version will support Drupal 9.3+.</p>','','full_html'),('article',0,6,50,'en',0,'<p>Extra Paragraph Types: Stats module provides ability to add Numbers with Text/Icons, Description and Title with WYSIWYG editor.</p>','','full_html'),('article',0,7,51,'en',0,'<p>Extra Paragraph Types: Text module provides ability to insert existing View using Paragraphs.</p>','','full_html'),('article',0,8,52,'en',0,'<p>Extra Block Types: Views module provides ability to add an existing View as EBT Block.</p>','','full_html'),('article',0,9,53,'en',0,'<p>Templates for EPT/EBT blocks and paragraphs now can be overidden in theme template folder by using addionally \'--custom\' suffix in template name.</p>','','full_html'),('article',0,10,54,'en',0,'<p>This release contains:<br>#3418633 by saccard: Ignores customized paragraph--ept-accordion-section--default.html.twig in theme folder</p><p>Templates for EPT/EBT blocks and paragraphs now can be overidden in theme template folder by using addionally \'--custom\' suffix in template name. For example:</p><p>block--block-content--ebt-accordion--custom.html.twig<br>block--block-content--ebt-accordion.html.twig</p><p>paragraph--ept-accordion--default--custom.html.twig<br>paragraph--ept-accordion--custom.html.twig<br>paragraph--ept-accordion--default.html.twig</p>','','full_html'),('article',0,11,55,'en',0,'<p>Extra Paragraph Types: Block module provides ability to insert an existing block as EPT Paragraph.</p>','','full_html'),('article',0,12,56,'en',0,'<p>​Added a new module EBT Starterkit with EBT module generator (for Drupal 12+): drush generate ebt:module</p>','','full_html'),('article',0,13,57,'en',0,'<p>This release contains a new submodule EPT Starterkit.</p><p>EPT Starterkit module allows to generate new EPT modules (for Drush 12+):</p><p>drush generate ept:module<br>Make sure, you use ept_* prefix for machine_name (e.g. ept_tabs, ept_cards). The prefix ept_* is required for EPT block functionality.</p><p>Creating new EPT module</p><p>Start machine name with ept_* prefix, it\'s required for working all EPT modules.</p>','','full_html'),('article',0,14,58,'en',0,'<p>EBT Block module provides ability to insert any Drupal Block: Views, custom content block, programmatically created blocks.</p>','','full_html'),('article',0,15,59,'en',0,'<p>Edit Extra Block Types (EBT): Columns / Container module provides ability to insert columns with other blocks. Columns have settings for column width.</p>','','full_html'),('article',0,16,60,'en',0,'<p>Added Simple EBT settings field widget. This field widget shows only three fields Width, Spacing and Edge to Edge:<br>https://drupalbook.org/ebt/extending-ebt-settings-form</p>','','full_html'),('article',0,17,61,'en',0,'<p>This release added new settings for Background Videos, It also add support for Local Videos.</p>','','full_html'),('article',0,18,62,'en',0,'<p>This release added new settings for Background Videos, It also add support for Local Videos.</p><p>All EBT blocks have next settings for Background Videos.</p>','','full_html');
/*!40000 ALTER TABLE `node__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__field_components`
--

DROP TABLE IF EXISTS `node__field_components`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__field_components` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_components_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_components_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_components_target_id` (`field_components_target_id`),
  KEY `field_components_target_revision_id` (`field_components_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_components.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__field_components`
--

LOCK TABLES `node__field_components` WRITE;
/*!40000 ALTER TABLE `node__field_components` DISABLE KEYS */;
INSERT INTO `node__field_components` VALUES ('page',0,1,45,'en',0,1,531),('page',0,1,45,'en',1,2,532),('page',0,1,45,'en',2,6,536),('page',0,1,45,'en',3,9,539),('page',0,1,45,'en',4,10,540),('page',0,1,45,'en',5,11,541),('page',0,1,45,'en',6,30,545),('page',0,1,45,'en',7,12,546),('page',0,1,45,'en',8,23,557),('page',0,1,45,'en',9,26,560),('page',0,1,45,'en',10,33,563),('page',0,1,45,'en',11,36,567),('page',0,19,68,'en',0,40,580),('page',0,19,68,'en',1,39,581),('page',0,19,68,'en',2,38,582);
/*!40000 ALTER TABLE `node__field_components` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__field_image`
--

DROP TABLE IF EXISTS `node__field_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__field_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_image_target_id` (`field_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__field_image`
--

LOCK TABLES `node__field_image` WRITE;
/*!40000 ALTER TABLE `node__field_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `node__field_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__field_tags`
--

DROP TABLE IF EXISTS `node__field_tags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__field_tags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_tags_target_id` (`field_tags_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_tags.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__field_tags`
--

LOCK TABLES `node__field_tags` WRITE;
/*!40000 ALTER TABLE `node__field_tags` DISABLE KEYS */;
/*!40000 ALTER TABLE `node__field_tags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_access`
--

DROP TABLE IF EXISTS `node_access`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_access` (
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid this record affects.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "language".langcode of this node.',
  `fallback` tinyint unsigned NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether this record should be used as a fallback if a language condition is not provided.',
  `gid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The grant ID a user must possess in the specified realm to gain this row''s privileges on the node.',
  `realm` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The realm in which the user must possess the grant ID. Modules can define one or more realms by implementing hook_node_grants().',
  `grant_view` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can view this node.',
  `grant_update` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can edit this node.',
  `grant_delete` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can delete this node.',
  PRIMARY KEY (`nid`,`gid`,`realm`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Identifies which realm/grant pairs a user must possess in…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_access`
--

LOCK TABLES `node_access` WRITE;
/*!40000 ALTER TABLE `node_access` DISABLE KEYS */;
INSERT INTO `node_access` VALUES (0,'',1,0,'all',1,0,0);
/*!40000 ALTER TABLE `node_access` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_field_data`
--

DROP TABLE IF EXISTS `node_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_field_data` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `title` varchar(255) NOT NULL,
  `created` int NOT NULL,
  `changed` int NOT NULL,
  `promote` tinyint NOT NULL,
  `sticky` tinyint NOT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`nid`,`langcode`),
  KEY `node__id__default_langcode__langcode` (`nid`,`default_langcode`,`langcode`),
  KEY `node__vid` (`vid`),
  KEY `node_field__type__target_id` (`type`),
  KEY `node_field__uid__target_id` (`uid`),
  KEY `node_field__created` (`created`),
  KEY `node_field__changed` (`changed`),
  KEY `node__status_type` (`status`,`type`,`nid`),
  KEY `node__frontpage` (`promote`,`status`,`sticky`,`created`),
  KEY `node__title_type` (`title`(191),`type`(4))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_field_data`
--

LOCK TABLES `node_field_data` WRITE;
/*!40000 ALTER TABLE `node_field_data` DISABLE KEYS */;
INSERT INTO `node_field_data` VALUES (1,45,'page','en',1,1,'Getting Started EPT Page Buider',1728242588,1729024760,0,0,1,1),(2,46,'article','en',1,1,'New EPT Video and Image gallery module!',1665904809,1729063268,1,0,1,1),(3,47,'article','en',1,1,'New EPT Webform module!',1729063625,1729063645,1,0,1,1),(4,48,'article','en',1,1,'New EPT Webform Popup module!',1729063655,1729063666,1,0,1,1),(5,49,'article','en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.0',1697441277,1729063694,1,0,1,1),(6,50,'article','en',1,1,'New EPT Stats module!',1697441305,1729063723,1,0,1,1),(7,51,'article','en',1,1,'New EPT Views module!',1665905333,1729063749,1,0,1,1),(8,52,'article','en',1,1,'New EBT Views module!',1729063823,1729063839,1,0,1,1),(9,53,'article','en',1,1,'EBT (Extra Block Types): Core new release 1.4.16',1697441448,1729063862,1,0,1,1),(10,54,'article','en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.1',1729063871,1729063886,1,0,1,1),(11,55,'article','en',1,1,'New EPT Block module!',1729063895,1729063907,1,0,1,1),(12,56,'article','en',1,1,'EBT (Extra Block Types): Core new release 1.4.21',1665905515,1729063938,1,0,1,1),(13,57,'article','en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.3',1729063947,1729063957,1,0,1,1),(14,58,'article','en',1,1,'New EBT Block module!',1697441570,1729063985,1,0,1,1),(15,59,'article','en',1,1,'New EBT Columns / Container module!',1729063993,1729064008,1,0,1,1),(16,60,'article','en',1,1,'EBT (Extra Block Types): Core new release 1.4.22',1665905632,1729064046,1,0,1,1),(17,61,'article','en',1,1,'EBT (Extra Block Types): Core new release 1.4.24',1729064056,1729064067,1,0,1,1),(18,62,'article','en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.7',1697441675,1729064095,1,0,1,1),(19,68,'page','en',1,1,'What\'s New',1729064448,1729067292,0,0,1,1);
/*!40000 ALTER TABLE `node_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_field_revision`
--

DROP TABLE IF EXISTS `node_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_field_revision` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `title` varchar(255) DEFAULT NULL,
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `promote` tinyint DEFAULT NULL,
  `sticky` tinyint DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`,`langcode`),
  KEY `node__id__default_langcode__langcode` (`nid`,`default_langcode`,`langcode`),
  KEY `node_field__uid__target_id` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_field_revision`
--

LOCK TABLES `node_field_revision` WRITE;
/*!40000 ALTER TABLE `node_field_revision` DISABLE KEYS */;
INSERT INTO `node_field_revision` VALUES (1,1,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728242893,0,0,1,1),(1,2,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728749523,0,0,1,1),(1,3,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728751272,0,0,1,1),(1,4,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728751458,0,0,1,1),(1,5,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728762000,0,0,1,1),(1,6,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728762439,0,0,1,1),(1,7,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728762685,0,0,1,1),(1,8,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728808800,0,0,1,1),(1,9,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728809719,0,0,1,1),(1,10,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728809815,0,0,1,1),(1,11,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728809849,0,0,1,1),(1,12,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728817647,0,0,1,1),(1,13,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728819415,0,0,1,1),(1,14,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728819461,0,0,1,1),(1,15,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728819683,0,0,1,1),(1,16,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728819951,0,0,1,1),(1,17,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728820014,0,0,1,1),(1,18,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728882972,0,0,1,1),(1,19,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728883069,0,0,1,1),(1,20,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728883324,0,0,1,1),(1,21,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728883773,0,0,1,1),(1,22,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728883938,0,0,1,1),(1,23,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728884118,0,0,1,1),(1,24,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728884894,0,0,1,1),(1,25,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728885200,0,0,1,1),(1,26,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728885506,0,0,1,1),(1,27,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728885677,0,0,1,1),(1,28,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728885900,0,0,1,1),(1,29,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728888389,0,0,1,1),(1,30,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728889242,0,0,1,1),(1,31,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728889330,0,0,1,1),(1,32,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728933423,0,0,1,1),(1,33,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728933474,0,0,1,1),(1,34,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728934139,0,0,1,1),(1,35,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728934262,0,0,1,1),(1,36,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728935838,0,0,1,1),(1,37,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728936706,0,0,1,1),(1,38,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728936828,0,0,1,1),(1,39,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728936888,0,0,1,1),(1,40,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728937164,0,0,1,1),(1,41,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728937228,0,0,1,1),(1,42,'en',1,1,'Getting Started EPT Page Buider',1728242588,1729020152,0,0,1,1),(1,43,'en',1,1,'Getting Started EPT Page Buider',1728242588,1729022518,0,0,1,1),(1,44,'en',1,1,'Getting Started EPT Page Buider',1728242588,1729022935,0,0,1,1),(1,45,'en',1,1,'Getting Started EPT Page Buider',1728242588,1729024760,0,0,1,1),(2,46,'en',1,1,'New EPT Video and Image gallery module!',1665904809,1729063268,1,0,1,1),(3,47,'en',1,1,'New EPT Webform module!',1729063625,1729063645,1,0,1,1),(4,48,'en',1,1,'New EPT Webform Popup module!',1729063655,1729063666,1,0,1,1),(5,49,'en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.0',1697441277,1729063694,1,0,1,1),(6,50,'en',1,1,'New EPT Stats module!',1697441305,1729063723,1,0,1,1),(7,51,'en',1,1,'New EPT Views module!',1665905333,1729063749,1,0,1,1),(8,52,'en',1,1,'New EBT Views module!',1729063823,1729063839,1,0,1,1),(9,53,'en',1,1,'EBT (Extra Block Types): Core new release 1.4.16',1697441448,1729063862,1,0,1,1),(10,54,'en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.1',1729063871,1729063886,1,0,1,1),(11,55,'en',1,1,'New EPT Block module!',1729063895,1729063907,1,0,1,1),(12,56,'en',1,1,'EBT (Extra Block Types): Core new release 1.4.21',1665905515,1729063938,1,0,1,1),(13,57,'en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.3',1729063947,1729063957,1,0,1,1),(14,58,'en',1,1,'New EBT Block module!',1697441570,1729063985,1,0,1,1),(15,59,'en',1,1,'New EBT Columns / Container module!',1729063993,1729064008,1,0,1,1),(16,60,'en',1,1,'EBT (Extra Block Types): Core new release 1.4.22',1665905632,1729064046,1,0,1,1),(17,61,'en',1,1,'EBT (Extra Block Types): Core new release 1.4.24',1729064056,1729064067,1,0,1,1),(18,62,'en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.7',1697441675,1729064095,1,0,1,1),(19,63,'en',1,1,'What\'s New',1729064448,1729064555,0,0,1,1),(19,64,'en',1,1,'What\'s New',1729064448,1729065353,0,0,1,1),(19,65,'en',1,1,'What\'s New',1729064448,1729066913,0,0,1,1),(19,66,'en',1,1,'What\'s New',1729064448,1729066954,0,0,1,1),(19,67,'en',1,1,'What\'s New',1729064448,1729067014,0,0,1,1),(19,68,'en',1,1,'What\'s New',1729064448,1729067292,0,0,1,1);
/*!40000 ALTER TABLE `node_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision`
--

DROP TABLE IF EXISTS `node_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_timestamp` int DEFAULT NULL,
  `revision_log` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`),
  KEY `node__nid` (`nid`),
  KEY `node_field__langcode` (`langcode`),
  KEY `node_field__revision_uid__target_id` (`revision_uid`)
) ENGINE=InnoDB AUTO_INCREMENT=69 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision`
--

LOCK TABLES `node_revision` WRITE;
/*!40000 ALTER TABLE `node_revision` DISABLE KEYS */;
INSERT INTO `node_revision` VALUES (1,1,'en',1,1728242893,NULL,1),(1,2,'en',1,1728749523,NULL,1),(1,3,'en',1,1728751272,NULL,1),(1,4,'en',1,1728751458,NULL,1),(1,5,'en',1,1728762000,NULL,1),(1,6,'en',1,1728762439,NULL,1),(1,7,'en',1,1728762685,NULL,1),(1,8,'en',1,1728808800,NULL,1),(1,9,'en',1,1728809719,NULL,1),(1,10,'en',1,1728809815,NULL,1),(1,11,'en',1,1728809849,NULL,1),(1,12,'en',1,1728817647,NULL,1),(1,13,'en',1,1728819415,NULL,1),(1,14,'en',1,1728819461,NULL,1),(1,15,'en',1,1728819683,NULL,1),(1,16,'en',1,1728819951,NULL,1),(1,17,'en',1,1728820014,NULL,1),(1,18,'en',1,1728882972,NULL,1),(1,19,'en',1,1728883069,NULL,1),(1,20,'en',1,1728883324,NULL,1),(1,21,'en',1,1728883773,NULL,1),(1,22,'en',1,1728883938,NULL,1),(1,23,'en',1,1728884118,NULL,1),(1,24,'en',1,1728884894,NULL,1),(1,25,'en',1,1728885200,NULL,1),(1,26,'en',1,1728885506,NULL,1),(1,27,'en',1,1728885677,NULL,1),(1,28,'en',1,1728885900,NULL,1),(1,29,'en',1,1728888389,NULL,1),(1,30,'en',1,1728889242,NULL,1),(1,31,'en',1,1728889330,NULL,1),(1,32,'en',1,1728933423,NULL,1),(1,33,'en',1,1728933474,NULL,1),(1,34,'en',1,1728934139,NULL,1),(1,35,'en',1,1728934262,NULL,1),(1,36,'en',1,1728935838,NULL,1),(1,37,'en',1,1728936706,NULL,1),(1,38,'en',1,1728936828,NULL,1),(1,39,'en',1,1728936888,NULL,1),(1,40,'en',1,1728937164,NULL,1),(1,41,'en',1,1728937228,NULL,1),(1,42,'en',1,1729020152,NULL,1),(1,43,'en',1,1729022518,NULL,1),(1,44,'en',1,1729022935,NULL,1),(1,45,'en',1,1729024760,NULL,1),(2,46,'en',1,1729063268,NULL,1),(3,47,'en',1,1729063645,NULL,1),(4,48,'en',1,1729063666,NULL,1),(5,49,'en',1,1729063694,NULL,1),(6,50,'en',1,1729063723,NULL,1),(7,51,'en',1,1729063749,NULL,1),(8,52,'en',1,1729063839,NULL,1),(9,53,'en',1,1729063862,NULL,1),(10,54,'en',1,1729063886,NULL,1),(11,55,'en',1,1729063907,NULL,1),(12,56,'en',1,1729063938,NULL,1),(13,57,'en',1,1729063957,NULL,1),(14,58,'en',1,1729063985,NULL,1),(15,59,'en',1,1729064008,NULL,1),(16,60,'en',1,1729064046,NULL,1),(17,61,'en',1,1729064067,NULL,1),(18,62,'en',1,1729064095,NULL,1),(19,63,'en',1,1729064555,NULL,1),(19,64,'en',1,1729065353,NULL,1),(19,65,'en',1,1729066913,NULL,1),(19,66,'en',1,1729066954,NULL,1),(19,67,'en',1,1729067014,NULL,1),(19,68,'en',1,1729067292,NULL,1);
/*!40000 ALTER TABLE `node_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__body`
--

DROP TABLE IF EXISTS `node_revision__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__body`
--

LOCK TABLES `node_revision__body` WRITE;
/*!40000 ALTER TABLE `node_revision__body` DISABLE KEYS */;
INSERT INTO `node_revision__body` VALUES ('article',0,2,46,'en',0,'<p>Extra Paragraph Types: Video and Image Gallery module provides ability to add grid gallery with videos and images.</p>','','full_html'),('article',0,3,47,'en',0,'<p>Extra Paragraph Types: Webform module provides ability to add a paragraph with Webform.</p>','','full_html'),('article',0,4,48,'en',0,'<p>Extra Paragraph Types: Webform Popup module provides ability to add Webform in popup. The button and popup are customizable with Settings form. This module will be helpful for creating Contact Us form popup.</p>','','full_html'),('article',0,5,49,'en',0,'<p>Tested and fully functional release. EPT 1.4.x version will support Drupal 9.3+.</p>','','full_html'),('article',0,6,50,'en',0,'<p>Extra Paragraph Types: Stats module provides ability to add Numbers with Text/Icons, Description and Title with WYSIWYG editor.</p>','','full_html'),('article',0,7,51,'en',0,'<p>Extra Paragraph Types: Text module provides ability to insert existing View using Paragraphs.</p>','','full_html'),('article',0,8,52,'en',0,'<p>Extra Block Types: Views module provides ability to add an existing View as EBT Block.</p>','','full_html'),('article',0,9,53,'en',0,'<p>Templates for EPT/EBT blocks and paragraphs now can be overidden in theme template folder by using addionally \'--custom\' suffix in template name.</p>','','full_html'),('article',0,10,54,'en',0,'<p>This release contains:<br>#3418633 by saccard: Ignores customized paragraph--ept-accordion-section--default.html.twig in theme folder</p><p>Templates for EPT/EBT blocks and paragraphs now can be overidden in theme template folder by using addionally \'--custom\' suffix in template name. For example:</p><p>block--block-content--ebt-accordion--custom.html.twig<br>block--block-content--ebt-accordion.html.twig</p><p>paragraph--ept-accordion--default--custom.html.twig<br>paragraph--ept-accordion--custom.html.twig<br>paragraph--ept-accordion--default.html.twig</p>','','full_html'),('article',0,11,55,'en',0,'<p>Extra Paragraph Types: Block module provides ability to insert an existing block as EPT Paragraph.</p>','','full_html'),('article',0,12,56,'en',0,'<p>​Added a new module EBT Starterkit with EBT module generator (for Drupal 12+): drush generate ebt:module</p>','','full_html'),('article',0,13,57,'en',0,'<p>This release contains a new submodule EPT Starterkit.</p><p>EPT Starterkit module allows to generate new EPT modules (for Drush 12+):</p><p>drush generate ept:module<br>Make sure, you use ept_* prefix for machine_name (e.g. ept_tabs, ept_cards). The prefix ept_* is required for EPT block functionality.</p><p>Creating new EPT module</p><p>Start machine name with ept_* prefix, it\'s required for working all EPT modules.</p>','','full_html'),('article',0,14,58,'en',0,'<p>EBT Block module provides ability to insert any Drupal Block: Views, custom content block, programmatically created blocks.</p>','','full_html'),('article',0,15,59,'en',0,'<p>Edit Extra Block Types (EBT): Columns / Container module provides ability to insert columns with other blocks. Columns have settings for column width.</p>','','full_html'),('article',0,16,60,'en',0,'<p>Added Simple EBT settings field widget. This field widget shows only three fields Width, Spacing and Edge to Edge:<br>https://drupalbook.org/ebt/extending-ebt-settings-form</p>','','full_html'),('article',0,17,61,'en',0,'<p>This release added new settings for Background Videos, It also add support for Local Videos.</p>','','full_html'),('article',0,18,62,'en',0,'<p>This release added new settings for Background Videos, It also add support for Local Videos.</p><p>All EBT blocks have next settings for Background Videos.</p>','','full_html');
/*!40000 ALTER TABLE `node_revision__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__field_components`
--

DROP TABLE IF EXISTS `node_revision__field_components`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__field_components` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_components_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_components_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_components_target_id` (`field_components_target_id`),
  KEY `field_components_target_revision_id` (`field_components_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_components.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__field_components`
--

LOCK TABLES `node_revision__field_components` WRITE;
/*!40000 ALTER TABLE `node_revision__field_components` DISABLE KEYS */;
INSERT INTO `node_revision__field_components` VALUES ('page',0,1,1,'en',0,1,1),('page',0,1,2,'en',0,1,2),('page',0,1,3,'en',0,1,3),('page',0,1,4,'en',0,1,4),('page',0,1,5,'en',0,1,5),('page',0,1,6,'en',0,1,6),('page',0,1,7,'en',0,1,7),('page',0,1,8,'en',0,1,8),('page',0,1,9,'en',0,1,9),('page',0,1,9,'en',1,2,10),('page',0,1,10,'en',0,1,11),('page',0,1,10,'en',1,2,12),('page',0,1,11,'en',0,1,13),('page',0,1,11,'en',1,2,14),('page',0,1,12,'en',0,1,15),('page',0,1,12,'en',1,2,16),('page',0,1,13,'en',0,1,17),('page',0,1,13,'en',1,2,18),('page',0,1,13,'en',2,6,22),('page',0,1,14,'en',0,1,23),('page',0,1,14,'en',1,2,24),('page',0,1,14,'en',2,6,28),('page',0,1,15,'en',0,1,29),('page',0,1,15,'en',1,2,30),('page',0,1,15,'en',2,6,34),('page',0,1,16,'en',0,1,35),('page',0,1,16,'en',1,2,36),('page',0,1,16,'en',2,6,40),('page',0,1,17,'en',0,1,41),('page',0,1,17,'en',1,2,42),('page',0,1,17,'en',2,6,46),('page',0,1,18,'en',0,1,47),('page',0,1,18,'en',1,2,48),('page',0,1,18,'en',2,6,52),('page',0,1,19,'en',0,1,53),('page',0,1,19,'en',1,2,54),('page',0,1,19,'en',2,6,58),('page',0,1,20,'en',0,1,59),('page',0,1,20,'en',1,2,60),('page',0,1,20,'en',2,6,64),('page',0,1,21,'en',0,1,65),('page',0,1,21,'en',1,2,66),('page',0,1,21,'en',2,6,70),('page',0,1,21,'en',3,9,73),('page',0,1,22,'en',0,1,74),('page',0,1,22,'en',1,2,75),('page',0,1,22,'en',2,6,79),('page',0,1,22,'en',3,9,82),('page',0,1,23,'en',0,1,83),('page',0,1,23,'en',1,2,84),('page',0,1,23,'en',2,6,88),('page',0,1,23,'en',3,9,91),('page',0,1,24,'en',0,1,92),('page',0,1,24,'en',1,2,93),('page',0,1,24,'en',2,6,97),('page',0,1,24,'en',3,9,100),('page',0,1,24,'en',4,10,101),('page',0,1,25,'en',0,1,102),('page',0,1,25,'en',1,2,103),('page',0,1,25,'en',2,6,107),('page',0,1,25,'en',3,9,110),('page',0,1,25,'en',4,10,111),('page',0,1,26,'en',0,1,112),('page',0,1,26,'en',1,2,113),('page',0,1,26,'en',2,6,117),('page',0,1,26,'en',3,9,120),('page',0,1,26,'en',4,10,121),('page',0,1,27,'en',0,1,122),('page',0,1,27,'en',1,2,123),('page',0,1,27,'en',2,6,127),('page',0,1,27,'en',3,9,130),('page',0,1,27,'en',4,10,131),('page',0,1,28,'en',0,1,132),('page',0,1,28,'en',1,2,133),('page',0,1,28,'en',2,6,137),('page',0,1,28,'en',3,9,140),('page',0,1,28,'en',4,10,141),('page',0,1,29,'en',0,1,142),('page',0,1,29,'en',1,2,143),('page',0,1,29,'en',2,6,147),('page',0,1,29,'en',3,9,150),('page',0,1,29,'en',4,10,151),('page',0,1,30,'en',0,1,152),('page',0,1,30,'en',1,2,153),('page',0,1,30,'en',2,6,157),('page',0,1,30,'en',3,9,160),('page',0,1,30,'en',4,10,161),('page',0,1,30,'en',5,11,162),('page',0,1,31,'en',0,1,163),('page',0,1,31,'en',1,2,164),('page',0,1,31,'en',2,6,168),('page',0,1,31,'en',3,9,171),('page',0,1,31,'en',4,10,172),('page',0,1,31,'en',5,11,173),('page',0,1,32,'en',0,1,174),('page',0,1,32,'en',1,2,175),('page',0,1,32,'en',2,6,179),('page',0,1,32,'en',3,9,182),('page',0,1,32,'en',4,10,183),('page',0,1,32,'en',5,11,184),('page',0,1,32,'en',6,12,185),('page',0,1,33,'en',0,1,186),('page',0,1,33,'en',1,2,187),('page',0,1,33,'en',2,6,191),('page',0,1,33,'en',3,9,194),('page',0,1,33,'en',4,10,195),('page',0,1,33,'en',5,11,196),('page',0,1,33,'en',6,12,197),('page',0,1,34,'en',0,1,198),('page',0,1,34,'en',1,2,199),('page',0,1,34,'en',2,6,203),('page',0,1,34,'en',3,9,206),('page',0,1,34,'en',4,10,207),('page',0,1,34,'en',5,11,208),('page',0,1,34,'en',6,12,209),('page',0,1,34,'en',7,23,220),('page',0,1,35,'en',0,1,221),('page',0,1,35,'en',1,2,222),('page',0,1,35,'en',2,6,226),('page',0,1,35,'en',3,9,229),('page',0,1,35,'en',4,10,230),('page',0,1,35,'en',5,11,231),('page',0,1,35,'en',6,12,232),('page',0,1,35,'en',7,23,243),('page',0,1,36,'en',0,1,244),('page',0,1,36,'en',1,2,245),('page',0,1,36,'en',2,6,249),('page',0,1,36,'en',3,9,252),('page',0,1,36,'en',4,10,253),('page',0,1,36,'en',5,11,254),('page',0,1,36,'en',6,12,255),('page',0,1,36,'en',7,23,266),('page',0,1,36,'en',8,26,269),('page',0,1,37,'en',0,1,270),('page',0,1,37,'en',1,2,271),('page',0,1,37,'en',2,6,275),('page',0,1,37,'en',3,9,278),('page',0,1,37,'en',4,10,279),('page',0,1,37,'en',5,11,280),('page',0,1,37,'en',6,30,284),('page',0,1,37,'en',7,12,285),('page',0,1,37,'en',8,23,296),('page',0,1,37,'en',9,26,299),('page',0,1,38,'en',0,1,300),('page',0,1,38,'en',1,2,301),('page',0,1,38,'en',2,6,305),('page',0,1,38,'en',3,9,308),('page',0,1,38,'en',4,10,309),('page',0,1,38,'en',5,11,310),('page',0,1,38,'en',6,30,314),('page',0,1,38,'en',7,12,315),('page',0,1,38,'en',8,23,326),('page',0,1,38,'en',9,26,329),('page',0,1,39,'en',0,1,330),('page',0,1,39,'en',1,2,331),('page',0,1,39,'en',2,6,335),('page',0,1,39,'en',3,9,338),('page',0,1,39,'en',4,10,339),('page',0,1,39,'en',5,11,340),('page',0,1,39,'en',6,30,344),('page',0,1,39,'en',7,12,345),('page',0,1,39,'en',8,23,356),('page',0,1,39,'en',9,26,359),('page',0,1,40,'en',0,1,360),('page',0,1,40,'en',1,2,361),('page',0,1,40,'en',2,6,365),('page',0,1,40,'en',3,9,368),('page',0,1,40,'en',4,10,369),('page',0,1,40,'en',5,11,370),('page',0,1,40,'en',6,30,374),('page',0,1,40,'en',7,12,375),('page',0,1,40,'en',8,23,386),('page',0,1,40,'en',9,26,389),('page',0,1,40,'en',10,33,392),('page',0,1,41,'en',0,1,393),('page',0,1,41,'en',1,2,394),('page',0,1,41,'en',2,6,398),('page',0,1,41,'en',3,9,401),('page',0,1,41,'en',4,10,402),('page',0,1,41,'en',5,11,403),('page',0,1,41,'en',6,30,407),('page',0,1,41,'en',7,12,408),('page',0,1,41,'en',8,23,419),('page',0,1,41,'en',9,26,422),('page',0,1,41,'en',10,33,425),('page',0,1,42,'en',0,1,426),('page',0,1,42,'en',1,2,427),('page',0,1,42,'en',2,6,431),('page',0,1,42,'en',3,9,434),('page',0,1,42,'en',4,10,435),('page',0,1,42,'en',5,11,436),('page',0,1,42,'en',6,30,440),('page',0,1,42,'en',7,12,441),('page',0,1,42,'en',8,23,452),('page',0,1,42,'en',9,26,455),('page',0,1,42,'en',10,33,458),('page',0,1,43,'en',0,1,459),('page',0,1,43,'en',1,2,460),('page',0,1,43,'en',2,6,464),('page',0,1,43,'en',3,9,467),('page',0,1,43,'en',4,10,468),('page',0,1,43,'en',5,11,469),('page',0,1,43,'en',6,30,473),('page',0,1,43,'en',7,12,474),('page',0,1,43,'en',8,23,485),('page',0,1,43,'en',9,26,488),('page',0,1,43,'en',10,33,491),('page',0,1,43,'en',11,36,494),('page',0,1,44,'en',0,1,495),('page',0,1,44,'en',1,2,496),('page',0,1,44,'en',2,6,500),('page',0,1,44,'en',3,9,503),('page',0,1,44,'en',4,10,504),('page',0,1,44,'en',5,11,505),('page',0,1,44,'en',6,30,509),('page',0,1,44,'en',7,12,510),('page',0,1,44,'en',8,23,521),('page',0,1,44,'en',9,26,524),('page',0,1,44,'en',10,33,527),('page',0,1,44,'en',11,36,530),('page',0,1,45,'en',0,1,531),('page',0,1,45,'en',1,2,532),('page',0,1,45,'en',2,6,536),('page',0,1,45,'en',3,9,539),('page',0,1,45,'en',4,10,540),('page',0,1,45,'en',5,11,541),('page',0,1,45,'en',6,30,545),('page',0,1,45,'en',7,12,546),('page',0,1,45,'en',8,23,557),('page',0,1,45,'en',9,26,560),('page',0,1,45,'en',10,33,563),('page',0,1,45,'en',11,36,567),('page',0,19,63,'en',0,38,568),('page',0,19,64,'en',0,39,569),('page',0,19,64,'en',1,38,570),('page',0,19,65,'en',0,40,571),('page',0,19,65,'en',1,39,572),('page',0,19,65,'en',2,38,573),('page',0,19,66,'en',0,40,574),('page',0,19,66,'en',1,39,575),('page',0,19,66,'en',2,38,576),('page',0,19,67,'en',0,40,577),('page',0,19,67,'en',1,39,578),('page',0,19,67,'en',2,38,579),('page',0,19,68,'en',0,40,580),('page',0,19,68,'en',1,39,581),('page',0,19,68,'en',2,38,582);
/*!40000 ALTER TABLE `node_revision__field_components` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__field_image`
--

DROP TABLE IF EXISTS `node_revision__field_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__field_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_image_target_id` (`field_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__field_image`
--

LOCK TABLES `node_revision__field_image` WRITE;
/*!40000 ALTER TABLE `node_revision__field_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `node_revision__field_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__field_tags`
--

DROP TABLE IF EXISTS `node_revision__field_tags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__field_tags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_tags_target_id` (`field_tags_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_tags.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__field_tags`
--

LOCK TABLES `node_revision__field_tags` WRITE;
/*!40000 ALTER TABLE `node_revision__field_tags` DISABLE KEYS */;
/*!40000 ALTER TABLE `node_revision__field_tags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_accordion`
--

DROP TABLE IF EXISTS `paragraph__field_ept_accordion`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_accordion` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_accordion_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_target_id` (`field_ept_accordion_target_id`),
  KEY `field_ept_accordion_target_revision_id` (`field_ept_accordion_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_accordion.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_accordion`
--

LOCK TABLES `paragraph__field_ept_accordion` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_accordion` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_accordion` VALUES ('ept_accordion',0,36,567,'en',0,37,564),('ept_accordion',0,36,567,'en',1,34,565),('ept_accordion',0,36,567,'en',2,35,566);
/*!40000 ALTER TABLE `paragraph__field_ept_accordion` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_accordion_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_accordion_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_accordion_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_text_value` longtext NOT NULL,
  `field_ept_accordion_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_text_format` (`field_ept_accordion_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_accordion_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_accordion_text`
--

LOCK TABLES `paragraph__field_ept_accordion_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_accordion_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_accordion_text` VALUES ('ept_accordion_section',0,34,565,'en',0,'<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>','full_html'),('ept_accordion_section',0,35,566,'en',0,'<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\" target=\"_blank\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\" target=\"_blank\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\" target=\"_blank\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\" target=\"_blank\">DrupalBook</a></li></ul>','full_html'),('ept_accordion_section',0,37,564,'en',0,'<p>You can install EPT modules as usual Drupal module. Download them with composer, for example:</p><pre><code class=\"language-plaintext\">composer require drupal/ept_tabs</code></pre><p>And then install EPT module as usual.</p><p><a href=\"https://www.drupal.org/docs/develop/using-composer/manage-dependencies#adding-modules\">Download contributed modules using Composer</a></p><p>That\'s it!&nbsp;</p><p>All dependencies will be downloaded with composer automatically.</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_accordion_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_accordion_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_accordion_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_accordion_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_title_value` longtext NOT NULL,
  `field_ept_accordion_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_title_format` (`field_ept_accordion_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_accordion_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_accordion_title`
--

LOCK TABLES `paragraph__field_ept_accordion_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_accordion_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_accordion_title` VALUES ('ept_accordion_section',0,34,565,'en',0,'<p>Cool! Can I create my own EPT/EBT module?</p>','full_html'),('ept_accordion_section',0,35,566,'en',0,'<p>Send feedback or idea for EPT modules</p>','full_html'),('ept_accordion_section',0,37,564,'en',0,'<p>How to install Extra Paragraph Types (EPT) modules?</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_accordion_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_basic_button_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_basic_button_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_basic_button_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_basic_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_basic_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_basic_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_basic_button_link_uri` (`field_ept_basic_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_basic_button…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_basic_button_link`
--

LOCK TABLES `paragraph__field_ept_basic_button_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_basic_button_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_basic_button_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_block_block`
--

DROP TABLE IF EXISTS `paragraph__field_ept_block_block`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_block_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_block_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ept_block_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_block_block_plugin_id` (`field_ept_block_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_block_block.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_block_block`
--

LOCK TABLES `paragraph__field_ept_block_block` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_block_block` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_block_block` VALUES ('ept_block',0,39,581,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}');
/*!40000 ALTER TABLE `paragraph__field_ept_block_block` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_bootstrap_button_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_bootstrap_button_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_bootstrap_button_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_bootstrap_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_bootstrap_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_bootstrap_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_bootstrap_button_link_uri` (`field_ept_bootstrap_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_bootstrap_button…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_bootstrap_button_link`
--

LOCK TABLES `paragraph__field_ept_bootstrap_button_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_bootstrap_button_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_bootstrap_button_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_carousel`
--

DROP TABLE IF EXISTS `paragraph__field_ept_carousel`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_carousel` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_carousel_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_target_id` (`field_ept_carousel_target_id`),
  KEY `field_ept_carousel_target_revision_id` (`field_ept_carousel_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_carousel.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_carousel`
--

LOCK TABLES `paragraph__field_ept_carousel` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_carousel` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_carousel` VALUES ('ept_carousel',0,23,557,'en',0,13,547),('ept_carousel',0,23,557,'en',1,14,548),('ept_carousel',0,23,557,'en',2,15,549),('ept_carousel',0,23,557,'en',3,16,550),('ept_carousel',0,23,557,'en',4,17,551),('ept_carousel',0,23,557,'en',5,18,552),('ept_carousel',0,23,557,'en',6,19,553),('ept_carousel',0,23,557,'en',7,20,554),('ept_carousel',0,23,557,'en',8,21,555),('ept_carousel',0,23,557,'en',9,22,556);
/*!40000 ALTER TABLE `paragraph__field_ept_carousel` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_carousel_caption`
--

DROP TABLE IF EXISTS `paragraph__field_ept_carousel_caption`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_carousel_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_caption_value` longtext NOT NULL,
  `field_ept_carousel_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_caption_format` (`field_ept_carousel_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_carousel_caption.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_carousel_caption`
--

LOCK TABLES `paragraph__field_ept_carousel_caption` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_carousel_caption` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_carousel_caption` VALUES ('ept_carousel_item',0,13,547,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,14,548,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,15,549,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,16,550,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,17,551,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,18,552,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,19,553,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,20,554,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,21,555,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,22,556,'en',0,'<p>EPT Quote</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_carousel_caption` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_carousel_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_carousel_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_carousel_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_image_target_id` (`field_ept_carousel_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_carousel_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_carousel_image`
--

LOCK TABLES `paragraph__field_ept_carousel_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_carousel_image` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_carousel_image` VALUES ('ept_carousel_item',0,13,547,'en',0,15),('ept_carousel_item',0,14,548,'en',0,14),('ept_carousel_item',0,15,549,'en',0,13),('ept_carousel_item',0,16,550,'en',0,9),('ept_carousel_item',0,17,551,'en',0,6),('ept_carousel_item',0,18,552,'en',0,4),('ept_carousel_item',0,19,553,'en',0,7),('ept_carousel_item',0,20,554,'en',0,5),('ept_carousel_item',0,21,555,'en',0,10),('ept_carousel_item',0,22,556,'en',0,12);
/*!40000 ALTER TABLE `paragraph__field_ept_carousel_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_clickable_tile`
--

DROP TABLE IF EXISTS `paragraph__field_ept_clickable_tile`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_clickable_tile` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_clickable_tile_value` tinyint NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_clickable_tile.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_clickable_tile`
--

LOCK TABLES `paragraph__field_ept_clickable_tile` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_clickable_tile` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_clickable_tile` VALUES ('ept_tiles_item',0,3,533,'en',0,1),('ept_tiles_item',0,4,534,'en',0,0),('ept_tiles_item',0,5,535,'en',0,1);
/*!40000 ALTER TABLE `paragraph__field_ept_clickable_tile` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_columns`
--

DROP TABLE IF EXISTS `paragraph__field_ept_columns`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_columns` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_columns_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_columns_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_columns_target_id` (`field_ept_columns_target_id`),
  KEY `field_ept_columns_target_revision_id` (`field_ept_columns_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_columns.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_columns`
--

LOCK TABLES `paragraph__field_ept_columns` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_columns` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_columns` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_countdown_date`
--

DROP TABLE IF EXISTS `paragraph__field_ept_countdown_date`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_countdown_date` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_countdown_date_value` varchar(20) NOT NULL COMMENT 'The date value.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_countdown_date_value` (`field_ept_countdown_date_value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_countdown_date.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_countdown_date`
--

LOCK TABLES `paragraph__field_ept_countdown_date` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_countdown_date` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_countdown_date` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_counter_description`
--

DROP TABLE IF EXISTS `paragraph__field_ept_counter_description`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_counter_description` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_description_value` longtext NOT NULL,
  `field_ept_counter_description_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_description_format` (`field_ept_counter_description_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_counter…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_counter_description`
--

LOCK TABLES `paragraph__field_ept_counter_description` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_description` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_description` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_counter_icon`
--

DROP TABLE IF EXISTS `paragraph__field_ept_counter_icon`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_counter_icon` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_icon_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_icon_target_id` (`field_ept_counter_icon_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_counter_icon.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_counter_icon`
--

LOCK TABLES `paragraph__field_ept_counter_icon` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_icon` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_icon` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_counter_items`
--

DROP TABLE IF EXISTS `paragraph__field_ept_counter_items`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_counter_items` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_items_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_counter_items_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_items_target_id` (`field_ept_counter_items_target_id`),
  KEY `field_ept_counter_items_target_revision_id` (`field_ept_counter_items_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_counter_items.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_counter_items`
--

LOCK TABLES `paragraph__field_ept_counter_items` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_items` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_counter_items` VALUES ('ept_counter',0,26,560,'en',0,24,558),('ept_counter',0,26,560,'en',1,25,559);
/*!40000 ALTER TABLE `paragraph__field_ept_counter_items` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_counter_number`
--

DROP TABLE IF EXISTS `paragraph__field_ept_counter_number`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_counter_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_number_value` int NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_counter_number.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_counter_number`
--

LOCK TABLES `paragraph__field_ept_counter_number` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_number` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_counter_number` VALUES ('ept_counter_item',0,24,558,'en',0,25),('ept_counter_item',0,25,559,'en',0,25);
/*!40000 ALTER TABLE `paragraph__field_ept_counter_number` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_counter_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_counter_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_counter_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_title_value` longtext NOT NULL,
  `field_ept_counter_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_title_format` (`field_ept_counter_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_counter_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_counter_title`
--

LOCK TABLES `paragraph__field_ept_counter_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_counter_title` VALUES ('ept_counter_item',0,24,558,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,25,559,'en',0,'<p>EBT Modules</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_counter_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_cta_column_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_cta_column_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_cta_column_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_column_image_target_id` (`field_ept_cta_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_cta_column_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_cta_column_image`
--

LOCK TABLES `paragraph__field_ept_cta_column_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_cta_column_image` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_cta_column_image` VALUES ('ept_cta',0,11,541,'en',0,16);
/*!40000 ALTER TABLE `paragraph__field_ept_cta_column_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_cta_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_cta_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_cta_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_cta_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_cta_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_link_uri` (`field_ept_cta_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_cta_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_cta_link`
--

LOCK TABLES `paragraph__field_ept_cta_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_cta_link` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_cta_link` VALUES ('ept_cta',0,11,541,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph__field_ept_cta_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_cta_second_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_cta_second_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_cta_second_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_cta_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_cta_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_second_link_uri` (`field_ept_cta_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_cta_second_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_cta_second_link`
--

LOCK TABLES `paragraph__field_ept_cta_second_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_cta_second_link` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_cta_second_link` VALUES ('ept_cta',0,11,541,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph__field_ept_cta_second_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_gallery_item`
--

DROP TABLE IF EXISTS `paragraph__field_ept_gallery_item`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_gallery_item` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_gallery_item_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_gallery_item_target_id` (`field_ept_gallery_item_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_gallery_item.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_gallery_item`
--

LOCK TABLES `paragraph__field_ept_gallery_item` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_gallery_item` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_gallery_item` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_gallery_item_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_gallery_item_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_gallery_item_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_gallery_item_text_value` longtext NOT NULL,
  `field_ept_gallery_item_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_gallery_item_text_format` (`field_ept_gallery_item_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_gallery_item…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_gallery_item_text`
--

LOCK TABLES `paragraph__field_ept_gallery_item_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_gallery_item_text` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_gallery_item_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_hero_column_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_hero_column_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_hero_column_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_column_image_target_id` (`field_ept_hero_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_hero_column…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_hero_column_image`
--

LOCK TABLES `paragraph__field_ept_hero_column_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_hero_column_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_hero_column_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_hero_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_hero_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_hero_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_hero_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_hero_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_link_uri` (`field_ept_hero_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_hero_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_hero_link`
--

LOCK TABLES `paragraph__field_ept_hero_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_hero_link` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_hero_link` VALUES ('ept_hero',0,1,531,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph__field_ept_hero_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_hero_second_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_hero_second_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_hero_second_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_hero_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_hero_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_second_link_uri` (`field_ept_hero_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_hero_second_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_hero_second_link`
--

LOCK TABLES `paragraph__field_ept_hero_second_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_hero_second_link` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_hero_second_link` VALUES ('ept_hero',0,1,531,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph__field_ept_hero_second_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_hero_title_prefix`
--

DROP TABLE IF EXISTS `paragraph__field_ept_hero_title_prefix`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_hero_title_prefix` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_title_prefix_value` longtext NOT NULL,
  `field_ept_hero_title_prefix_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_title_prefix_format` (`field_ept_hero_title_prefix_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_hero_title…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_hero_title_prefix`
--

LOCK TABLES `paragraph__field_ept_hero_title_prefix` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_hero_title_prefix` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_hero_title_prefix` VALUES ('ept_hero',0,1,531,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,40,580,'en',0,'<p>Listing Page</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_hero_title_prefix` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_target_id` (`field_ept_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_image`
--

LOCK TABLES `paragraph__field_ept_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_image_caption`
--

DROP TABLE IF EXISTS `paragraph__field_ept_image_caption`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_image_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_caption_value` longtext NOT NULL,
  `field_ept_image_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_caption_format` (`field_ept_image_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_image_caption.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_image_caption`
--

LOCK TABLES `paragraph__field_ept_image_caption` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_image_caption` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_image_caption` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_image_gallery`
--

DROP TABLE IF EXISTS `paragraph__field_ept_image_gallery`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_image_gallery` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_gallery_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_gallery_target_id` (`field_ept_image_gallery_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_image_gallery.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_image_gallery`
--

LOCK TABLES `paragraph__field_ept_image_gallery` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_image_gallery` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_image_gallery` VALUES ('ept_image_gallery',0,10,540,'en',0,4),('ept_image_gallery',0,10,540,'en',1,5),('ept_image_gallery',0,10,540,'en',2,6),('ept_image_gallery',0,10,540,'en',3,7),('ept_image_gallery',0,10,540,'en',4,9),('ept_image_gallery',0,10,540,'en',5,10),('ept_image_gallery',0,10,540,'en',6,11),('ept_image_gallery',0,10,540,'en',7,12),('ept_image_gallery',0,10,540,'en',8,13),('ept_image_gallery',0,10,540,'en',9,14),('ept_image_gallery',0,10,540,'en',10,15);
/*!40000 ALTER TABLE `paragraph__field_ept_image_gallery` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_image_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_image_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_image_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_image_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_image_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_link_uri` (`field_ept_image_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_image_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_image_link`
--

LOCK TABLES `paragraph__field_ept_image_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_image_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_image_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_micromodal_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_micromodal_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_micromodal_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_micromodal_title_value` longtext NOT NULL,
  `field_ept_micromodal_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_micromodal_title_format` (`field_ept_micromodal_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_micromodal_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_micromodal_title`
--

LOCK TABLES `paragraph__field_ept_micromodal_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_micromodal_title` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_micromodal_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_quote_author`
--

DROP TABLE IF EXISTS `paragraph__field_ept_quote_author`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_quote_author` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_quote_author_value` longtext NOT NULL,
  `field_ept_quote_author_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_quote_author_format` (`field_ept_quote_author_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_quote_author.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_quote_author`
--

LOCK TABLES `paragraph__field_ept_quote_author` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_quote_author` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_quote_author` VALUES ('ept_quote',0,12,546,'en',0,'<p>Hockey Club</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_quote_author` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_quote_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_quote_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_quote_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_quote_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_quote_image_target_id` (`field_ept_quote_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_quote_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_quote_image`
--

LOCK TABLES `paragraph__field_ept_quote_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_quote_image` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_quote_image` VALUES ('ept_quote',0,12,546,'en',0,18);
/*!40000 ALTER TABLE `paragraph__field_ept_quote_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_settings`
--

DROP TABLE IF EXISTS `paragraph__field_ept_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_settings` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_settings_ept_settings` longblob COMMENT 'Serialized paragraph settings data',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_settings.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_settings`
--

LOCK TABLES `paragraph__field_ept_settings` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_settings` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_settings` VALUES ('ept_hero',0,1,531,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_text',0,2,532,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_tiles',0,6,536,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_stats',0,9,539,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_image_gallery',0,10,540,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_cta',0,11,541,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_quote',0,12,546,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_carousel',0,23,557,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_counter',0,26,560,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_slideshow',0,30,545,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_tabs',0,33,563,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_accordion',0,36,567,'en',0,_binary 'a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_views',0,38,582,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,581,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_hero',0,40,580,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}');
/*!40000 ALTER TABLE `paragraph__field_ept_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slick_slider`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slick_slider`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slick_slider` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_slick_slider_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_target_id` (`field_ept_slick_slider_target_id`),
  KEY `field_ept_slick_slider_target_revision_id` (`field_ept_slick_slider_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slick_slider.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slick_slider`
--

LOCK TABLES `paragraph__field_ept_slick_slider` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slick_slider_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slick_slider_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slick_slider_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_image_target_id` (`field_ept_slick_slider_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slick_slider…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slick_slider_image`
--

LOCK TABLES `paragraph__field_ept_slick_slider_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slick_slider_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slick_slider_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slick_slider_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_slick_slider_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_slick_slider_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_link_uri` (`field_ept_slick_slider_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slick_slider…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slick_slider_link`
--

LOCK TABLES `paragraph__field_ept_slick_slider_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slick_slider_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slick_slider_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slick_slider_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_text_value` longtext NOT NULL,
  `field_ept_slick_slider_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_text_format` (`field_ept_slick_slider_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slick_slider…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slick_slider_text`
--

LOCK TABLES `paragraph__field_ept_slick_slider_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_text` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slideshow`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slideshow`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slideshow` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_slideshow_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_target_id` (`field_ept_slideshow_target_id`),
  KEY `field_ept_slideshow_target_revision_id` (`field_ept_slideshow_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slideshow.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slideshow`
--

LOCK TABLES `paragraph__field_ept_slideshow` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_slideshow` VALUES ('ept_slideshow',0,30,545,'en',0,27,542),('ept_slideshow',0,30,545,'en',1,28,543),('ept_slideshow',0,30,545,'en',2,29,544);
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slideshow_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slideshow_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slideshow_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_slideshow_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_slideshow_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_link_uri` (`field_ept_slideshow_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slideshow_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slideshow_link`
--

LOCK TABLES `paragraph__field_ept_slideshow_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slideshow_slide`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slideshow_slide`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slideshow_slide` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_slide_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_slide_target_id` (`field_ept_slideshow_slide_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slideshow_slide.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slideshow_slide`
--

LOCK TABLES `paragraph__field_ept_slideshow_slide` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_slide` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_slideshow_slide` VALUES ('ept_slideshow_item',0,27,542,'en',0,20),('ept_slideshow_item',0,28,543,'en',0,21),('ept_slideshow_item',0,29,544,'en',0,22);
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_slide` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slideshow_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slideshow_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slideshow_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_text_value` longtext NOT NULL,
  `field_ept_slideshow_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_text_format` (`field_ept_slideshow_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slideshow_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slideshow_text`
--

LOCK TABLES `paragraph__field_ept_slideshow_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_slideshow_text` VALUES ('ept_slideshow_item',0,27,542,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,28,543,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,29,544,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slideshow_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slideshow_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slideshow_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_title_value` longtext NOT NULL,
  `field_ept_slideshow_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_title_format` (`field_ept_slideshow_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slideshow_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slideshow_title`
--

LOCK TABLES `paragraph__field_ept_slideshow_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_slideshow_title` VALUES ('ept_slideshow_item',0,27,542,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,28,543,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,29,544,'en',0,'<p>Settings for javascript plugins</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_stats`
--

DROP TABLE IF EXISTS `paragraph__field_ept_stats`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_stats` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_stats_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_target_id` (`field_ept_stats_target_id`),
  KEY `field_ept_stats_target_revision_id` (`field_ept_stats_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_stats.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_stats`
--

LOCK TABLES `paragraph__field_ept_stats` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_stats` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_stats` VALUES ('ept_stats',0,9,539,'en',0,7,537),('ept_stats',0,9,539,'en',1,8,538);
/*!40000 ALTER TABLE `paragraph__field_ept_stats` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_stats_item_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_stats_item_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_stats_item_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_image_target_id` (`field_ept_stats_item_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_stats_item_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_stats_item_image`
--

LOCK TABLES `paragraph__field_ept_stats_item_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_stats_item_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_stats_item_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_stats_item_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_stats_item_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_stats_item_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_link_uri` (`field_ept_stats_item_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_stats_item_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_stats_item_link`
--

LOCK TABLES `paragraph__field_ept_stats_item_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_stats_item_number`
--

DROP TABLE IF EXISTS `paragraph__field_ept_stats_item_number`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_stats_item_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_number_value` longtext NOT NULL,
  `field_ept_stats_item_number_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_number_format` (`field_ept_stats_item_number_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_stats_item…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_stats_item_number`
--

LOCK TABLES `paragraph__field_ept_stats_item_number` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_number` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_stats_item_number` VALUES ('ept_stats_item',0,7,537,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,8,538,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_number` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_stats_item_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_stats_item_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_stats_item_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_text_value` longtext NOT NULL,
  `field_ept_stats_item_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_text_format` (`field_ept_stats_item_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_stats_item_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_stats_item_text`
--

LOCK TABLES `paragraph__field_ept_stats_item_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_stats_item_text` VALUES ('ept_stats_item',0,7,537,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,8,538,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_block`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_block`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ept_tab_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_block_plugin_id` (`field_ept_tab_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_block.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_block`
--

LOCK TABLES `paragraph__field_ept_tab_block` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_block` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_block` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_content`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_content`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_content` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_content_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_content_value` (`field_ept_tab_content_value`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_content.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_content`
--

LOCK TABLES `paragraph__field_ept_tab_content` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_content` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tab_content` VALUES ('ept_tabs_item',0,31,561,'en',0,'text'),('ept_tabs_item',0,32,562,'en',0,'text');
/*!40000 ALTER TABLE `paragraph__field_ept_tab_content` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_page`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_page`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_page` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_page_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_page_target_id` (`field_ept_tab_page_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_page.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_page`
--

LOCK TABLES `paragraph__field_ept_tab_page` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_page` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_page` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_text_value` longtext NOT NULL,
  `field_ept_tab_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_text_format` (`field_ept_tab_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_text`
--

LOCK TABLES `paragraph__field_ept_tab_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tab_text` VALUES ('ept_tabs_item',0,31,561,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,562,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_tab_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_title_value` varchar(255) NOT NULL,
  `field_ept_tab_title_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_title_format` (`field_ept_tab_title_format`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_title`
--

LOCK TABLES `paragraph__field_ept_tab_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tab_title` VALUES ('ept_tabs_item',0,31,561,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,32,562,'en',0,'EBT Modules','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_tab_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_views`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_views`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_views` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_views_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tab_views_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ept_tab_views_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_views_target_id` (`field_ept_tab_views_target_id`),
  KEY `field_ept_tab_views_display_id` (`field_ept_tab_views_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_views.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_views`
--

LOCK TABLES `paragraph__field_ept_tab_views` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_views` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_views` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tabs`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tabs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tabs` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tabs_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tabs_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tabs_target_id` (`field_ept_tabs_target_id`),
  KEY `field_ept_tabs_target_revision_id` (`field_ept_tabs_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tabs.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tabs`
--

LOCK TABLES `paragraph__field_ept_tabs` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tabs` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tabs` VALUES ('ept_tabs',0,33,563,'en',0,31,561),('ept_tabs',0,33,563,'en',1,32,562);
/*!40000 ALTER TABLE `paragraph__field_ept_tabs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_text_value` longtext NOT NULL,
  `field_ept_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_text_format` (`field_ept_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_text`
--

LOCK TABLES `paragraph__field_ept_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_text` VALUES ('ept_hero',0,1,531,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_text',0,2,532,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_stats',0,9,539,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_cta',0,11,541,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_quote',0,12,546,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_hero',0,40,580,'en',0,'<p>Stay tuned!</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tiles`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tiles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tiles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tiles_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_target_id` (`field_ept_tiles_target_id`),
  KEY `field_ept_tiles_target_revision_id` (`field_ept_tiles_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tiles.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tiles`
--

LOCK TABLES `paragraph__field_ept_tiles` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tiles` VALUES ('ept_tiles',0,6,536,'en',0,3,533),('ept_tiles',0,6,536,'en',1,4,534),('ept_tiles',0,6,536,'en',2,5,535);
/*!40000 ALTER TABLE `paragraph__field_ept_tiles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tiles_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tiles_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tiles_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_image_target_id` (`field_ept_tiles_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tiles_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tiles_image`
--

LOCK TABLES `paragraph__field_ept_tiles_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tiles_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tiles_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tiles_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_tiles_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_tiles_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_link_uri` (`field_ept_tiles_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tiles_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tiles_link`
--

LOCK TABLES `paragraph__field_ept_tiles_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_link` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tiles_link` VALUES ('ept_tiles_item',0,3,533,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,5,535,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tiles_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tiles_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tiles_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_text_value` longtext NOT NULL,
  `field_ept_tiles_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_text_format` (`field_ept_tiles_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tiles_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tiles_text`
--

LOCK TABLES `paragraph__field_ept_tiles_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tiles_text` VALUES ('ept_tiles_item',0,3,533,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,4,534,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,5,535,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tiles_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tiles_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tiles_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_title_value` longtext NOT NULL,
  `field_ept_tiles_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_title_format` (`field_ept_tiles_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tiles_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tiles_title`
--

LOCK TABLES `paragraph__field_ept_tiles_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tiles_title` VALUES ('ept_tiles_item',0,3,533,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,4,534,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,5,535,'en',0,'<p>Start Creating</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_title_value` longtext NOT NULL,
  `field_ept_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_title_format` (`field_ept_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_title`
--

LOCK TABLES `paragraph__field_ept_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_title` VALUES ('ept_hero',0,1,531,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_text',0,2,532,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_tiles',0,6,536,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_stats',0,9,539,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_image_gallery',0,10,540,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_cta',0,11,541,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_quote',0,12,546,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_carousel',0,23,557,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_counter',0,26,560,'en',0,'<p>Number of modules</p>','full_html'),('ept_slideshow',0,30,545,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_tabs',0,33,563,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>','full_html'),('ept_accordion',0,36,567,'en',0,'<p>FAQ</p>','full_html'),('ept_hero',0,40,580,'en',0,'<h1>What\'s New</h1>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_video`
--

DROP TABLE IF EXISTS `paragraph__field_ept_video`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_video_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_video_target_id` (`field_ept_video_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_video.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_video`
--

LOCK TABLES `paragraph__field_ept_video` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_video` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_video` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_videos_and_images`
--

DROP TABLE IF EXISTS `paragraph__field_ept_videos_and_images`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_videos_and_images` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_videos_and_images_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_videos_and_images_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_videos_and_images_target_id` (`field_ept_videos_and_images_target_id`),
  KEY `field_ept_videos_and_images_target_revision_id` (`field_ept_videos_and_images_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_videos_and…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_videos_and_images`
--

LOCK TABLES `paragraph__field_ept_videos_and_images` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_videos_and_images` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_videos_and_images` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_views_view`
--

DROP TABLE IF EXISTS `paragraph__field_ept_views_view`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_views_view` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_views_view_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_views_view_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ept_views_view_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_views_view_target_id` (`field_ept_views_view_target_id`),
  KEY `field_ept_views_view_display_id` (`field_ept_views_view_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_views_view.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_views_view`
--

LOCK TABLES `paragraph__field_ept_views_view` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_views_view` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_views_view` VALUES ('ept_views',0,38,582,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}');
/*!40000 ALTER TABLE `paragraph__field_ept_views_view` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_webform_form`
--

DROP TABLE IF EXISTS `paragraph__field_ept_webform_form`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_webform_form` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_webform_form_target_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the webform entity.',
  `field_ept_webform_form_default_data` text COMMENT 'Default submission data.',
  `field_ept_webform_form_status` varchar(20) DEFAULT NULL COMMENT 'Flag to control whether this webform should be open, closed, or scheduled for new submissions.',
  `field_ept_webform_form_open` varchar(20) DEFAULT NULL COMMENT 'The open date/time.',
  `field_ept_webform_form_close` varchar(20) DEFAULT NULL COMMENT 'The close date/time.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_webform_form_target_id` (`field_ept_webform_form_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_webform_form.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_webform_form`
--

LOCK TABLES `paragraph__field_ept_webform_form` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_webform_form` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_webform_form` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_webform_popup_form`
--

DROP TABLE IF EXISTS `paragraph__field_ept_webform_popup_form`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_webform_popup_form` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_webform_popup_form_target_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the webform entity.',
  `field_ept_webform_popup_form_default_data` text COMMENT 'Default submission data.',
  `field_ept_webform_popup_form_status` varchar(20) DEFAULT NULL COMMENT 'Flag to control whether this webform should be open, closed, or scheduled for new submissions.',
  `field_ept_webform_popup_form_open` varchar(20) DEFAULT NULL COMMENT 'The open date/time.',
  `field_ept_webform_popup_form_close` varchar(20) DEFAULT NULL COMMENT 'The close date/time.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_webform_popup_form_target_id` (`field_ept_webform_popup_form_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_webform_popup…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_webform_popup_form`
--

LOCK TABLES `paragraph__field_ept_webform_popup_form` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_webform_popup_form` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_webform_popup_form` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_r__32204566b2`
--

DROP TABLE IF EXISTS `paragraph_r__32204566b2`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_r__32204566b2` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_bootstrap_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_bootstrap_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_bootstrap_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_bootstrap_button_link_uri` (`field_ept_bootstrap_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_r__32204566b2`
--

LOCK TABLES `paragraph_r__32204566b2` WRITE;
/*!40000 ALTER TABLE `paragraph_r__32204566b2` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_r__32204566b2` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_r__f6562160d8`
--

DROP TABLE IF EXISTS `paragraph_r__f6562160d8`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_r__f6562160d8` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_description_value` longtext NOT NULL,
  `field_ept_counter_description_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_description_format` (`field_ept_counter_description_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_r__f6562160d8`
--

LOCK TABLES `paragraph_r__f6562160d8` WRITE;
/*!40000 ALTER TABLE `paragraph_r__f6562160d8` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_r__f6562160d8` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_accordion`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_accordion`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_accordion` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_accordion_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_target_id` (`field_ept_accordion_target_id`),
  KEY `field_ept_accordion_target_revision_id` (`field_ept_accordion_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_accordion`
--

LOCK TABLES `paragraph_revision__field_ept_accordion` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_accordion` VALUES ('ept_accordion',0,36,494,'en',0,34,492),('ept_accordion',0,36,494,'en',1,35,493),('ept_accordion',0,36,530,'en',0,34,528),('ept_accordion',0,36,530,'en',1,35,529),('ept_accordion',0,36,567,'en',0,37,564),('ept_accordion',0,36,567,'en',1,34,565),('ept_accordion',0,36,567,'en',2,35,566);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_accordion_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_accordion_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_accordion_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_text_value` longtext NOT NULL,
  `field_ept_accordion_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_text_format` (`field_ept_accordion_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_accordion_text`
--

LOCK TABLES `paragraph_revision__field_ept_accordion_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_accordion_text` VALUES ('ept_accordion_section',0,34,492,'en',0,'<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>','full_html'),('ept_accordion_section',0,34,528,'en',0,'<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>','full_html'),('ept_accordion_section',0,34,565,'en',0,'<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>','full_html'),('ept_accordion_section',0,35,493,'en',0,'<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\">DrupalBook</a></li></ul>','full_html'),('ept_accordion_section',0,35,529,'en',0,'<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\" target=\"_blank\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\" target=\"_blank\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\" target=\"_blank\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\" target=\"_blank\">DrupalBook</a></li></ul>','full_html'),('ept_accordion_section',0,35,566,'en',0,'<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\" target=\"_blank\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\" target=\"_blank\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\" target=\"_blank\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\" target=\"_blank\">DrupalBook</a></li></ul>','full_html'),('ept_accordion_section',0,37,564,'en',0,'<p>You can install EPT modules as usual Drupal module. Download them with composer, for example:</p><pre><code class=\"language-plaintext\">composer require drupal/ept_tabs</code></pre><p>And then install EPT module as usual.</p><p><a href=\"https://www.drupal.org/docs/develop/using-composer/manage-dependencies#adding-modules\">Download contributed modules using Composer</a></p><p>That\'s it!&nbsp;</p><p>All dependencies will be downloaded with composer automatically.</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_accordion_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_accordion_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_accordion_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_title_value` longtext NOT NULL,
  `field_ept_accordion_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_title_format` (`field_ept_accordion_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_accordion_title`
--

LOCK TABLES `paragraph_revision__field_ept_accordion_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_accordion_title` VALUES ('ept_accordion_section',0,34,492,'en',0,'<p>Cool! Can I create my own EPT/EBT module?</p>','full_html'),('ept_accordion_section',0,34,528,'en',0,'<p>Cool! Can I create my own EPT/EBT module?</p>','full_html'),('ept_accordion_section',0,34,565,'en',0,'<p>Cool! Can I create my own EPT/EBT module?</p>','full_html'),('ept_accordion_section',0,35,493,'en',0,'<p>Send feedback or idea for EPT modules</p>','full_html'),('ept_accordion_section',0,35,529,'en',0,'<p>Send feedback or idea for EPT modules</p>','full_html'),('ept_accordion_section',0,35,566,'en',0,'<p>Send feedback or idea for EPT modules</p>','full_html'),('ept_accordion_section',0,37,564,'en',0,'<p>How to install Extra Paragraph Types (EPT) modules?</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_basic_button_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_basic_button_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_basic_button_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_basic_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_basic_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_basic_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_basic_button_link_uri` (`field_ept_basic_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_basic_button_link`
--

LOCK TABLES `paragraph_revision__field_ept_basic_button_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_basic_button_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_basic_button_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_block_block`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_block_block`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_block_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_block_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ept_block_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_block_block_plugin_id` (`field_ept_block_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_block_block`
--

LOCK TABLES `paragraph_revision__field_ept_block_block` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_block_block` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_block_block` VALUES ('ept_block',0,39,569,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}'),('ept_block',0,39,572,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}'),('ept_block',0,39,575,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}'),('ept_block',0,39,578,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}'),('ept_block',0,39,581,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_block_block` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_carousel`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_carousel`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_carousel` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_carousel_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_target_id` (`field_ept_carousel_target_id`),
  KEY `field_ept_carousel_target_revision_id` (`field_ept_carousel_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_carousel`
--

LOCK TABLES `paragraph_revision__field_ept_carousel` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_carousel` VALUES ('ept_carousel',0,23,220,'en',0,13,210),('ept_carousel',0,23,220,'en',1,14,211),('ept_carousel',0,23,220,'en',2,15,212),('ept_carousel',0,23,220,'en',3,16,213),('ept_carousel',0,23,220,'en',4,17,214),('ept_carousel',0,23,220,'en',5,18,215),('ept_carousel',0,23,220,'en',6,19,216),('ept_carousel',0,23,220,'en',7,20,217),('ept_carousel',0,23,220,'en',8,21,218),('ept_carousel',0,23,220,'en',9,22,219),('ept_carousel',0,23,243,'en',0,13,233),('ept_carousel',0,23,243,'en',1,14,234),('ept_carousel',0,23,243,'en',2,15,235),('ept_carousel',0,23,243,'en',3,16,236),('ept_carousel',0,23,243,'en',4,17,237),('ept_carousel',0,23,243,'en',5,18,238),('ept_carousel',0,23,243,'en',6,19,239),('ept_carousel',0,23,243,'en',7,20,240),('ept_carousel',0,23,243,'en',8,21,241),('ept_carousel',0,23,243,'en',9,22,242),('ept_carousel',0,23,266,'en',0,13,256),('ept_carousel',0,23,266,'en',1,14,257),('ept_carousel',0,23,266,'en',2,15,258),('ept_carousel',0,23,266,'en',3,16,259),('ept_carousel',0,23,266,'en',4,17,260),('ept_carousel',0,23,266,'en',5,18,261),('ept_carousel',0,23,266,'en',6,19,262),('ept_carousel',0,23,266,'en',7,20,263),('ept_carousel',0,23,266,'en',8,21,264),('ept_carousel',0,23,266,'en',9,22,265),('ept_carousel',0,23,296,'en',0,13,286),('ept_carousel',0,23,296,'en',1,14,287),('ept_carousel',0,23,296,'en',2,15,288),('ept_carousel',0,23,296,'en',3,16,289),('ept_carousel',0,23,296,'en',4,17,290),('ept_carousel',0,23,296,'en',5,18,291),('ept_carousel',0,23,296,'en',6,19,292),('ept_carousel',0,23,296,'en',7,20,293),('ept_carousel',0,23,296,'en',8,21,294),('ept_carousel',0,23,296,'en',9,22,295),('ept_carousel',0,23,326,'en',0,13,316),('ept_carousel',0,23,326,'en',1,14,317),('ept_carousel',0,23,326,'en',2,15,318),('ept_carousel',0,23,326,'en',3,16,319),('ept_carousel',0,23,326,'en',4,17,320),('ept_carousel',0,23,326,'en',5,18,321),('ept_carousel',0,23,326,'en',6,19,322),('ept_carousel',0,23,326,'en',7,20,323),('ept_carousel',0,23,326,'en',8,21,324),('ept_carousel',0,23,326,'en',9,22,325),('ept_carousel',0,23,356,'en',0,13,346),('ept_carousel',0,23,356,'en',1,14,347),('ept_carousel',0,23,356,'en',2,15,348),('ept_carousel',0,23,356,'en',3,16,349),('ept_carousel',0,23,356,'en',4,17,350),('ept_carousel',0,23,356,'en',5,18,351),('ept_carousel',0,23,356,'en',6,19,352),('ept_carousel',0,23,356,'en',7,20,353),('ept_carousel',0,23,356,'en',8,21,354),('ept_carousel',0,23,356,'en',9,22,355),('ept_carousel',0,23,386,'en',0,13,376),('ept_carousel',0,23,386,'en',1,14,377),('ept_carousel',0,23,386,'en',2,15,378),('ept_carousel',0,23,386,'en',3,16,379),('ept_carousel',0,23,386,'en',4,17,380),('ept_carousel',0,23,386,'en',5,18,381),('ept_carousel',0,23,386,'en',6,19,382),('ept_carousel',0,23,386,'en',7,20,383),('ept_carousel',0,23,386,'en',8,21,384),('ept_carousel',0,23,386,'en',9,22,385),('ept_carousel',0,23,419,'en',0,13,409),('ept_carousel',0,23,419,'en',1,14,410),('ept_carousel',0,23,419,'en',2,15,411),('ept_carousel',0,23,419,'en',3,16,412),('ept_carousel',0,23,419,'en',4,17,413),('ept_carousel',0,23,419,'en',5,18,414),('ept_carousel',0,23,419,'en',6,19,415),('ept_carousel',0,23,419,'en',7,20,416),('ept_carousel',0,23,419,'en',8,21,417),('ept_carousel',0,23,419,'en',9,22,418),('ept_carousel',0,23,452,'en',0,13,442),('ept_carousel',0,23,452,'en',1,14,443),('ept_carousel',0,23,452,'en',2,15,444),('ept_carousel',0,23,452,'en',3,16,445),('ept_carousel',0,23,452,'en',4,17,446),('ept_carousel',0,23,452,'en',5,18,447),('ept_carousel',0,23,452,'en',6,19,448),('ept_carousel',0,23,452,'en',7,20,449),('ept_carousel',0,23,452,'en',8,21,450),('ept_carousel',0,23,452,'en',9,22,451),('ept_carousel',0,23,485,'en',0,13,475),('ept_carousel',0,23,485,'en',1,14,476),('ept_carousel',0,23,485,'en',2,15,477),('ept_carousel',0,23,485,'en',3,16,478),('ept_carousel',0,23,485,'en',4,17,479),('ept_carousel',0,23,485,'en',5,18,480),('ept_carousel',0,23,485,'en',6,19,481),('ept_carousel',0,23,485,'en',7,20,482),('ept_carousel',0,23,485,'en',8,21,483),('ept_carousel',0,23,485,'en',9,22,484),('ept_carousel',0,23,521,'en',0,13,511),('ept_carousel',0,23,521,'en',1,14,512),('ept_carousel',0,23,521,'en',2,15,513),('ept_carousel',0,23,521,'en',3,16,514),('ept_carousel',0,23,521,'en',4,17,515),('ept_carousel',0,23,521,'en',5,18,516),('ept_carousel',0,23,521,'en',6,19,517),('ept_carousel',0,23,521,'en',7,20,518),('ept_carousel',0,23,521,'en',8,21,519),('ept_carousel',0,23,521,'en',9,22,520),('ept_carousel',0,23,557,'en',0,13,547),('ept_carousel',0,23,557,'en',1,14,548),('ept_carousel',0,23,557,'en',2,15,549),('ept_carousel',0,23,557,'en',3,16,550),('ept_carousel',0,23,557,'en',4,17,551),('ept_carousel',0,23,557,'en',5,18,552),('ept_carousel',0,23,557,'en',6,19,553),('ept_carousel',0,23,557,'en',7,20,554),('ept_carousel',0,23,557,'en',8,21,555),('ept_carousel',0,23,557,'en',9,22,556);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_carousel_caption`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_carousel_caption`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_carousel_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_caption_value` longtext NOT NULL,
  `field_ept_carousel_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_caption_format` (`field_ept_carousel_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_carousel_caption`
--

LOCK TABLES `paragraph_revision__field_ept_carousel_caption` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel_caption` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_carousel_caption` VALUES ('ept_carousel_item',0,13,210,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,233,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,256,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,286,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,316,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,346,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,376,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,409,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,442,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,475,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,511,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,547,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,14,211,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,234,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,257,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,287,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,317,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,347,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,377,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,410,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,443,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,476,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,512,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,548,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,15,212,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,235,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,258,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,288,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,318,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,348,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,378,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,411,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,444,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,477,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,513,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,549,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,16,213,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,236,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,259,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,289,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,319,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,349,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,379,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,412,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,445,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,478,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,514,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,550,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,17,214,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,237,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,260,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,290,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,320,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,350,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,380,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,413,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,446,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,479,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,515,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,551,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,18,215,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,238,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,261,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,291,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,321,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,351,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,381,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,414,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,447,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,480,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,516,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,552,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,19,216,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,239,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,262,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,292,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,322,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,352,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,382,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,415,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,448,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,481,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,517,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,553,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,20,217,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,240,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,263,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,293,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,323,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,353,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,383,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,416,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,449,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,482,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,518,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,554,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,21,218,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,241,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,264,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,294,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,324,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,354,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,384,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,417,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,450,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,483,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,519,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,555,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,22,219,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,242,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,265,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,295,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,325,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,355,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,385,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,418,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,451,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,484,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,520,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,556,'en',0,'<p>EPT Quote</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel_caption` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_carousel_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_carousel_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_carousel_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_image_target_id` (`field_ept_carousel_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_carousel_image`
--

LOCK TABLES `paragraph_revision__field_ept_carousel_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel_image` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_carousel_image` VALUES ('ept_carousel_item',0,13,210,'en',0,15),('ept_carousel_item',0,13,233,'en',0,15),('ept_carousel_item',0,13,256,'en',0,15),('ept_carousel_item',0,13,286,'en',0,15),('ept_carousel_item',0,13,316,'en',0,15),('ept_carousel_item',0,13,346,'en',0,15),('ept_carousel_item',0,13,376,'en',0,15),('ept_carousel_item',0,13,409,'en',0,15),('ept_carousel_item',0,13,442,'en',0,15),('ept_carousel_item',0,13,475,'en',0,15),('ept_carousel_item',0,13,511,'en',0,15),('ept_carousel_item',0,13,547,'en',0,15),('ept_carousel_item',0,14,211,'en',0,14),('ept_carousel_item',0,14,234,'en',0,14),('ept_carousel_item',0,14,257,'en',0,14),('ept_carousel_item',0,14,287,'en',0,14),('ept_carousel_item',0,14,317,'en',0,14),('ept_carousel_item',0,14,347,'en',0,14),('ept_carousel_item',0,14,377,'en',0,14),('ept_carousel_item',0,14,410,'en',0,14),('ept_carousel_item',0,14,443,'en',0,14),('ept_carousel_item',0,14,476,'en',0,14),('ept_carousel_item',0,14,512,'en',0,14),('ept_carousel_item',0,14,548,'en',0,14),('ept_carousel_item',0,15,212,'en',0,13),('ept_carousel_item',0,15,235,'en',0,13),('ept_carousel_item',0,15,258,'en',0,13),('ept_carousel_item',0,15,288,'en',0,13),('ept_carousel_item',0,15,318,'en',0,13),('ept_carousel_item',0,15,348,'en',0,13),('ept_carousel_item',0,15,378,'en',0,13),('ept_carousel_item',0,15,411,'en',0,13),('ept_carousel_item',0,15,444,'en',0,13),('ept_carousel_item',0,15,477,'en',0,13),('ept_carousel_item',0,15,513,'en',0,13),('ept_carousel_item',0,15,549,'en',0,13),('ept_carousel_item',0,16,213,'en',0,9),('ept_carousel_item',0,16,236,'en',0,9),('ept_carousel_item',0,16,259,'en',0,9),('ept_carousel_item',0,16,289,'en',0,9),('ept_carousel_item',0,16,319,'en',0,9),('ept_carousel_item',0,16,349,'en',0,9),('ept_carousel_item',0,16,379,'en',0,9),('ept_carousel_item',0,16,412,'en',0,9),('ept_carousel_item',0,16,445,'en',0,9),('ept_carousel_item',0,16,478,'en',0,9),('ept_carousel_item',0,16,514,'en',0,9),('ept_carousel_item',0,16,550,'en',0,9),('ept_carousel_item',0,17,214,'en',0,6),('ept_carousel_item',0,17,237,'en',0,6),('ept_carousel_item',0,17,260,'en',0,6),('ept_carousel_item',0,17,290,'en',0,6),('ept_carousel_item',0,17,320,'en',0,6),('ept_carousel_item',0,17,350,'en',0,6),('ept_carousel_item',0,17,380,'en',0,6),('ept_carousel_item',0,17,413,'en',0,6),('ept_carousel_item',0,17,446,'en',0,6),('ept_carousel_item',0,17,479,'en',0,6),('ept_carousel_item',0,17,515,'en',0,6),('ept_carousel_item',0,17,551,'en',0,6),('ept_carousel_item',0,18,215,'en',0,4),('ept_carousel_item',0,18,238,'en',0,4),('ept_carousel_item',0,18,261,'en',0,4),('ept_carousel_item',0,18,291,'en',0,4),('ept_carousel_item',0,18,321,'en',0,4),('ept_carousel_item',0,18,351,'en',0,4),('ept_carousel_item',0,18,381,'en',0,4),('ept_carousel_item',0,18,414,'en',0,4),('ept_carousel_item',0,18,447,'en',0,4),('ept_carousel_item',0,18,480,'en',0,4),('ept_carousel_item',0,18,516,'en',0,4),('ept_carousel_item',0,18,552,'en',0,4),('ept_carousel_item',0,19,216,'en',0,7),('ept_carousel_item',0,19,239,'en',0,7),('ept_carousel_item',0,19,262,'en',0,7),('ept_carousel_item',0,19,292,'en',0,7),('ept_carousel_item',0,19,322,'en',0,7),('ept_carousel_item',0,19,352,'en',0,7),('ept_carousel_item',0,19,382,'en',0,7),('ept_carousel_item',0,19,415,'en',0,7),('ept_carousel_item',0,19,448,'en',0,7),('ept_carousel_item',0,19,481,'en',0,7),('ept_carousel_item',0,19,517,'en',0,7),('ept_carousel_item',0,19,553,'en',0,7),('ept_carousel_item',0,20,217,'en',0,5),('ept_carousel_item',0,20,240,'en',0,5),('ept_carousel_item',0,20,263,'en',0,5),('ept_carousel_item',0,20,293,'en',0,5),('ept_carousel_item',0,20,323,'en',0,5),('ept_carousel_item',0,20,353,'en',0,5),('ept_carousel_item',0,20,383,'en',0,5),('ept_carousel_item',0,20,416,'en',0,5),('ept_carousel_item',0,20,449,'en',0,5),('ept_carousel_item',0,20,482,'en',0,5),('ept_carousel_item',0,20,518,'en',0,5),('ept_carousel_item',0,20,554,'en',0,5),('ept_carousel_item',0,21,218,'en',0,10),('ept_carousel_item',0,21,241,'en',0,10),('ept_carousel_item',0,21,264,'en',0,10),('ept_carousel_item',0,21,294,'en',0,10),('ept_carousel_item',0,21,324,'en',0,10),('ept_carousel_item',0,21,354,'en',0,10),('ept_carousel_item',0,21,384,'en',0,10),('ept_carousel_item',0,21,417,'en',0,10),('ept_carousel_item',0,21,450,'en',0,10),('ept_carousel_item',0,21,483,'en',0,10),('ept_carousel_item',0,21,519,'en',0,10),('ept_carousel_item',0,21,555,'en',0,10),('ept_carousel_item',0,22,219,'en',0,12),('ept_carousel_item',0,22,242,'en',0,12),('ept_carousel_item',0,22,265,'en',0,12),('ept_carousel_item',0,22,295,'en',0,12),('ept_carousel_item',0,22,325,'en',0,12),('ept_carousel_item',0,22,355,'en',0,12),('ept_carousel_item',0,22,385,'en',0,12),('ept_carousel_item',0,22,418,'en',0,12),('ept_carousel_item',0,22,451,'en',0,12),('ept_carousel_item',0,22,484,'en',0,12),('ept_carousel_item',0,22,520,'en',0,12),('ept_carousel_item',0,22,556,'en',0,12);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_clickable_tile`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_clickable_tile`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_clickable_tile` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_clickable_tile_value` tinyint NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_clickable_tile`
--

LOCK TABLES `paragraph_revision__field_ept_clickable_tile` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_clickable_tile` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_clickable_tile` VALUES ('ept_tiles_item',0,3,19,'en',0,1),('ept_tiles_item',0,3,25,'en',0,1),('ept_tiles_item',0,3,31,'en',0,1),('ept_tiles_item',0,3,37,'en',0,1),('ept_tiles_item',0,3,43,'en',0,1),('ept_tiles_item',0,3,49,'en',0,1),('ept_tiles_item',0,3,55,'en',0,1),('ept_tiles_item',0,3,61,'en',0,1),('ept_tiles_item',0,3,67,'en',0,1),('ept_tiles_item',0,3,76,'en',0,1),('ept_tiles_item',0,3,85,'en',0,1),('ept_tiles_item',0,3,94,'en',0,1),('ept_tiles_item',0,3,104,'en',0,1),('ept_tiles_item',0,3,114,'en',0,1),('ept_tiles_item',0,3,124,'en',0,1),('ept_tiles_item',0,3,134,'en',0,1),('ept_tiles_item',0,3,144,'en',0,1),('ept_tiles_item',0,3,154,'en',0,1),('ept_tiles_item',0,3,165,'en',0,1),('ept_tiles_item',0,3,176,'en',0,1),('ept_tiles_item',0,3,188,'en',0,1),('ept_tiles_item',0,3,200,'en',0,1),('ept_tiles_item',0,3,223,'en',0,1),('ept_tiles_item',0,3,246,'en',0,1),('ept_tiles_item',0,3,272,'en',0,1),('ept_tiles_item',0,3,302,'en',0,1),('ept_tiles_item',0,3,332,'en',0,1),('ept_tiles_item',0,3,362,'en',0,1),('ept_tiles_item',0,3,395,'en',0,1),('ept_tiles_item',0,3,428,'en',0,1),('ept_tiles_item',0,3,461,'en',0,1),('ept_tiles_item',0,3,497,'en',0,1),('ept_tiles_item',0,3,533,'en',0,1),('ept_tiles_item',0,4,20,'en',0,0),('ept_tiles_item',0,4,26,'en',0,0),('ept_tiles_item',0,4,32,'en',0,0),('ept_tiles_item',0,4,38,'en',0,0),('ept_tiles_item',0,4,44,'en',0,0),('ept_tiles_item',0,4,50,'en',0,0),('ept_tiles_item',0,4,56,'en',0,0),('ept_tiles_item',0,4,62,'en',0,0),('ept_tiles_item',0,4,68,'en',0,0),('ept_tiles_item',0,4,77,'en',0,0),('ept_tiles_item',0,4,86,'en',0,0),('ept_tiles_item',0,4,95,'en',0,0),('ept_tiles_item',0,4,105,'en',0,0),('ept_tiles_item',0,4,115,'en',0,0),('ept_tiles_item',0,4,125,'en',0,0),('ept_tiles_item',0,4,135,'en',0,0),('ept_tiles_item',0,4,145,'en',0,0),('ept_tiles_item',0,4,155,'en',0,0),('ept_tiles_item',0,4,166,'en',0,0),('ept_tiles_item',0,4,177,'en',0,0),('ept_tiles_item',0,4,189,'en',0,0),('ept_tiles_item',0,4,201,'en',0,0),('ept_tiles_item',0,4,224,'en',0,0),('ept_tiles_item',0,4,247,'en',0,0),('ept_tiles_item',0,4,273,'en',0,0),('ept_tiles_item',0,4,303,'en',0,0),('ept_tiles_item',0,4,333,'en',0,0),('ept_tiles_item',0,4,363,'en',0,0),('ept_tiles_item',0,4,396,'en',0,0),('ept_tiles_item',0,4,429,'en',0,0),('ept_tiles_item',0,4,462,'en',0,0),('ept_tiles_item',0,4,498,'en',0,0),('ept_tiles_item',0,4,534,'en',0,0),('ept_tiles_item',0,5,21,'en',0,1),('ept_tiles_item',0,5,27,'en',0,1),('ept_tiles_item',0,5,33,'en',0,1),('ept_tiles_item',0,5,39,'en',0,1),('ept_tiles_item',0,5,45,'en',0,1),('ept_tiles_item',0,5,51,'en',0,1),('ept_tiles_item',0,5,57,'en',0,1),('ept_tiles_item',0,5,63,'en',0,1),('ept_tiles_item',0,5,69,'en',0,1),('ept_tiles_item',0,5,78,'en',0,1),('ept_tiles_item',0,5,87,'en',0,1),('ept_tiles_item',0,5,96,'en',0,1),('ept_tiles_item',0,5,106,'en',0,1),('ept_tiles_item',0,5,116,'en',0,1),('ept_tiles_item',0,5,126,'en',0,1),('ept_tiles_item',0,5,136,'en',0,1),('ept_tiles_item',0,5,146,'en',0,1),('ept_tiles_item',0,5,156,'en',0,1),('ept_tiles_item',0,5,167,'en',0,1),('ept_tiles_item',0,5,178,'en',0,1),('ept_tiles_item',0,5,190,'en',0,1),('ept_tiles_item',0,5,202,'en',0,1),('ept_tiles_item',0,5,225,'en',0,1),('ept_tiles_item',0,5,248,'en',0,1),('ept_tiles_item',0,5,274,'en',0,1),('ept_tiles_item',0,5,304,'en',0,1),('ept_tiles_item',0,5,334,'en',0,1),('ept_tiles_item',0,5,364,'en',0,1),('ept_tiles_item',0,5,397,'en',0,1),('ept_tiles_item',0,5,430,'en',0,1),('ept_tiles_item',0,5,463,'en',0,1),('ept_tiles_item',0,5,499,'en',0,1),('ept_tiles_item',0,5,535,'en',0,1);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_clickable_tile` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_columns`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_columns`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_columns` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_columns_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_columns_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_columns_target_id` (`field_ept_columns_target_id`),
  KEY `field_ept_columns_target_revision_id` (`field_ept_columns_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_columns`
--

LOCK TABLES `paragraph_revision__field_ept_columns` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_columns` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_columns` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_countdown_date`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_countdown_date`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_countdown_date` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_countdown_date_value` varchar(20) NOT NULL COMMENT 'The date value.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_countdown_date_value` (`field_ept_countdown_date_value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_countdown_date`
--

LOCK TABLES `paragraph_revision__field_ept_countdown_date` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_countdown_date` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_countdown_date` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_counter_icon`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_counter_icon`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_counter_icon` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_icon_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_icon_target_id` (`field_ept_counter_icon_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_counter_icon`
--

LOCK TABLES `paragraph_revision__field_ept_counter_icon` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_icon` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_icon` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_counter_items`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_counter_items`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_counter_items` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_items_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_counter_items_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_items_target_id` (`field_ept_counter_items_target_id`),
  KEY `field_ept_counter_items_target_revision_id` (`field_ept_counter_items_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_counter_items`
--

LOCK TABLES `paragraph_revision__field_ept_counter_items` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_items` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_counter_items` VALUES ('ept_counter',0,26,269,'en',0,24,267),('ept_counter',0,26,269,'en',1,25,268),('ept_counter',0,26,299,'en',0,24,297),('ept_counter',0,26,299,'en',1,25,298),('ept_counter',0,26,329,'en',0,24,327),('ept_counter',0,26,329,'en',1,25,328),('ept_counter',0,26,359,'en',0,24,357),('ept_counter',0,26,359,'en',1,25,358),('ept_counter',0,26,389,'en',0,24,387),('ept_counter',0,26,389,'en',1,25,388),('ept_counter',0,26,422,'en',0,24,420),('ept_counter',0,26,422,'en',1,25,421),('ept_counter',0,26,455,'en',0,24,453),('ept_counter',0,26,455,'en',1,25,454),('ept_counter',0,26,488,'en',0,24,486),('ept_counter',0,26,488,'en',1,25,487),('ept_counter',0,26,524,'en',0,24,522),('ept_counter',0,26,524,'en',1,25,523),('ept_counter',0,26,560,'en',0,24,558),('ept_counter',0,26,560,'en',1,25,559);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_items` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_counter_number`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_counter_number`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_counter_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_number_value` int NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_counter_number`
--

LOCK TABLES `paragraph_revision__field_ept_counter_number` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_number` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_counter_number` VALUES ('ept_counter_item',0,24,267,'en',0,25),('ept_counter_item',0,24,297,'en',0,25),('ept_counter_item',0,24,327,'en',0,25),('ept_counter_item',0,24,357,'en',0,25),('ept_counter_item',0,24,387,'en',0,25),('ept_counter_item',0,24,420,'en',0,25),('ept_counter_item',0,24,453,'en',0,25),('ept_counter_item',0,24,486,'en',0,25),('ept_counter_item',0,24,522,'en',0,25),('ept_counter_item',0,24,558,'en',0,25),('ept_counter_item',0,25,268,'en',0,25),('ept_counter_item',0,25,298,'en',0,25),('ept_counter_item',0,25,328,'en',0,25),('ept_counter_item',0,25,358,'en',0,25),('ept_counter_item',0,25,388,'en',0,25),('ept_counter_item',0,25,421,'en',0,25),('ept_counter_item',0,25,454,'en',0,25),('ept_counter_item',0,25,487,'en',0,25),('ept_counter_item',0,25,523,'en',0,25),('ept_counter_item',0,25,559,'en',0,25);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_number` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_counter_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_counter_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_counter_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_title_value` longtext NOT NULL,
  `field_ept_counter_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_title_format` (`field_ept_counter_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_counter_title`
--

LOCK TABLES `paragraph_revision__field_ept_counter_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_counter_title` VALUES ('ept_counter_item',0,24,267,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,297,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,327,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,357,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,387,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,420,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,453,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,486,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,522,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,558,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,25,268,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,298,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,328,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,358,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,388,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,421,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,454,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,487,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,523,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,559,'en',0,'<p>EBT Modules</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_cta_column_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_cta_column_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_cta_column_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_column_image_target_id` (`field_ept_cta_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_cta…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_cta_column_image`
--

LOCK TABLES `paragraph_revision__field_ept_cta_column_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_column_image` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_cta_column_image` VALUES ('ept_cta',0,11,162,'en',0,16),('ept_cta',0,11,173,'en',0,16),('ept_cta',0,11,184,'en',0,16),('ept_cta',0,11,196,'en',0,16),('ept_cta',0,11,208,'en',0,16),('ept_cta',0,11,231,'en',0,16),('ept_cta',0,11,254,'en',0,16),('ept_cta',0,11,280,'en',0,16),('ept_cta',0,11,310,'en',0,16),('ept_cta',0,11,340,'en',0,16),('ept_cta',0,11,370,'en',0,16),('ept_cta',0,11,403,'en',0,16),('ept_cta',0,11,436,'en',0,16),('ept_cta',0,11,469,'en',0,16),('ept_cta',0,11,505,'en',0,16),('ept_cta',0,11,541,'en',0,16);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_column_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_cta_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_cta_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_cta_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_cta_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_cta_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_link_uri` (`field_ept_cta_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_cta…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_cta_link`
--

LOCK TABLES `paragraph_revision__field_ept_cta_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_link` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_cta_link` VALUES ('ept_cta',0,11,162,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,173,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,184,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,196,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,208,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,231,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,254,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,280,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,310,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,340,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,370,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,403,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,436,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,469,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,505,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,541,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_cta_second_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_cta_second_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_cta_second_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_cta_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_cta_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_second_link_uri` (`field_ept_cta_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_cta…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_cta_second_link`
--

LOCK TABLES `paragraph_revision__field_ept_cta_second_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_second_link` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_cta_second_link` VALUES ('ept_cta',0,11,162,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,173,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,184,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,196,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,208,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,231,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,254,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,280,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,310,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,340,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,370,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,403,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,436,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,469,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,505,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,541,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_second_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_gallery_item`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_gallery_item`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_gallery_item` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_gallery_item_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_gallery_item_target_id` (`field_ept_gallery_item_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_gallery_item`
--

LOCK TABLES `paragraph_revision__field_ept_gallery_item` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_gallery_item` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_gallery_item` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_gallery_item_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_gallery_item_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_gallery_item_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_gallery_item_text_value` longtext NOT NULL,
  `field_ept_gallery_item_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_gallery_item_text_format` (`field_ept_gallery_item_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_gallery_item_text`
--

LOCK TABLES `paragraph_revision__field_ept_gallery_item_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_gallery_item_text` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_gallery_item_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_hero_column_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_hero_column_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_hero_column_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_column_image_target_id` (`field_ept_hero_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_hero…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_hero_column_image`
--

LOCK TABLES `paragraph_revision__field_ept_hero_column_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_column_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_column_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_hero_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_hero_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_hero_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_hero_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_hero_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_link_uri` (`field_ept_hero_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_hero…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_hero_link`
--

LOCK TABLES `paragraph_revision__field_ept_hero_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_link` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_hero_link` VALUES ('ept_hero',0,1,4,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,5,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,6,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,7,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,8,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,9,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,11,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,13,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,15,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,17,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,23,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,29,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,35,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,41,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,47,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,53,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,59,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,65,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,74,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,83,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,92,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,102,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,112,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,122,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,132,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,142,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,152,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,163,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,174,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,186,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,198,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,221,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,244,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,270,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,300,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,330,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,360,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,393,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,426,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,459,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,495,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,531,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_hero_second_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_hero_second_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_hero_second_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_hero_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_hero_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_second_link_uri` (`field_ept_hero_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_hero…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_hero_second_link`
--

LOCK TABLES `paragraph_revision__field_ept_hero_second_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_second_link` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_hero_second_link` VALUES ('ept_hero',0,1,4,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,5,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,6,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,7,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,8,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,9,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,11,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,13,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,15,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,17,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,23,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,29,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,35,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,41,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,47,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,53,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,59,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,65,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,74,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,83,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,92,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,102,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,112,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,122,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,132,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,142,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,152,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,163,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,174,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,186,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,198,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,221,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,244,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,270,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,300,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,330,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,360,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,393,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,426,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,459,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,495,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,531,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_second_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_hero_title_prefix`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_hero_title_prefix`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_hero_title_prefix` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_title_prefix_value` longtext NOT NULL,
  `field_ept_hero_title_prefix_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_title_prefix_format` (`field_ept_hero_title_prefix_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_hero…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_hero_title_prefix`
--

LOCK TABLES `paragraph_revision__field_ept_hero_title_prefix` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_title_prefix` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_hero_title_prefix` VALUES ('ept_hero',0,1,1,'en',0,'<p>Demo page</p>','basic_html'),('ept_hero',0,1,2,'en',0,'<h2>EPT (Extra Block Types) Demo page</h2>','basic_html'),('ept_hero',0,1,3,'en',0,'<p>EPT (Extra Block Types) Demo page</p>','full_html'),('ept_hero',0,1,4,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,5,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,6,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,7,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,8,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,9,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,11,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,13,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,15,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,17,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,23,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,29,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,35,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,41,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,47,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,53,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,59,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,65,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,74,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,83,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,92,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,102,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,112,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,122,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,132,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,142,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,152,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,163,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,174,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,186,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,198,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,221,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,244,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,270,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,300,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,330,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,360,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,393,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,426,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,459,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,495,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,531,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,40,571,'en',0,'<p>Listing Page</p>','full_html'),('ept_hero',0,40,574,'en',0,'<p>Listing Page</p>','full_html'),('ept_hero',0,40,577,'en',0,'<p>Listing Page</p>','full_html'),('ept_hero',0,40,580,'en',0,'<p>Listing Page</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_title_prefix` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_target_id` (`field_ept_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_image`
--

LOCK TABLES `paragraph_revision__field_ept_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_image_caption`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_image_caption`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_image_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_caption_value` longtext NOT NULL,
  `field_ept_image_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_caption_format` (`field_ept_image_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_image_caption`
--

LOCK TABLES `paragraph_revision__field_ept_image_caption` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_caption` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_caption` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_image_gallery`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_image_gallery`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_image_gallery` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_gallery_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_gallery_target_id` (`field_ept_image_gallery_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_image_gallery`
--

LOCK TABLES `paragraph_revision__field_ept_image_gallery` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_gallery` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_image_gallery` VALUES ('ept_image_gallery',0,10,101,'en',0,4),('ept_image_gallery',0,10,101,'en',1,5),('ept_image_gallery',0,10,101,'en',2,6),('ept_image_gallery',0,10,111,'en',0,4),('ept_image_gallery',0,10,111,'en',1,5),('ept_image_gallery',0,10,111,'en',2,6),('ept_image_gallery',0,10,111,'en',3,7),('ept_image_gallery',0,10,121,'en',0,4),('ept_image_gallery',0,10,121,'en',1,5),('ept_image_gallery',0,10,121,'en',2,6),('ept_image_gallery',0,10,121,'en',3,7),('ept_image_gallery',0,10,131,'en',0,4),('ept_image_gallery',0,10,131,'en',1,5),('ept_image_gallery',0,10,131,'en',2,6),('ept_image_gallery',0,10,131,'en',3,7),('ept_image_gallery',0,10,141,'en',0,4),('ept_image_gallery',0,10,141,'en',1,5),('ept_image_gallery',0,10,141,'en',2,6),('ept_image_gallery',0,10,141,'en',3,7),('ept_image_gallery',0,10,141,'en',4,9),('ept_image_gallery',0,10,151,'en',0,4),('ept_image_gallery',0,10,151,'en',1,5),('ept_image_gallery',0,10,151,'en',2,6),('ept_image_gallery',0,10,151,'en',3,7),('ept_image_gallery',0,10,151,'en',4,9),('ept_image_gallery',0,10,151,'en',5,10),('ept_image_gallery',0,10,151,'en',6,11),('ept_image_gallery',0,10,151,'en',7,12),('ept_image_gallery',0,10,151,'en',8,13),('ept_image_gallery',0,10,151,'en',9,14),('ept_image_gallery',0,10,151,'en',10,15),('ept_image_gallery',0,10,161,'en',0,4),('ept_image_gallery',0,10,161,'en',1,5),('ept_image_gallery',0,10,161,'en',2,6),('ept_image_gallery',0,10,161,'en',3,7),('ept_image_gallery',0,10,161,'en',4,9),('ept_image_gallery',0,10,161,'en',5,10),('ept_image_gallery',0,10,161,'en',6,11),('ept_image_gallery',0,10,161,'en',7,12),('ept_image_gallery',0,10,161,'en',8,13),('ept_image_gallery',0,10,161,'en',9,14),('ept_image_gallery',0,10,161,'en',10,15),('ept_image_gallery',0,10,172,'en',0,4),('ept_image_gallery',0,10,172,'en',1,5),('ept_image_gallery',0,10,172,'en',2,6),('ept_image_gallery',0,10,172,'en',3,7),('ept_image_gallery',0,10,172,'en',4,9),('ept_image_gallery',0,10,172,'en',5,10),('ept_image_gallery',0,10,172,'en',6,11),('ept_image_gallery',0,10,172,'en',7,12),('ept_image_gallery',0,10,172,'en',8,13),('ept_image_gallery',0,10,172,'en',9,14),('ept_image_gallery',0,10,172,'en',10,15),('ept_image_gallery',0,10,183,'en',0,4),('ept_image_gallery',0,10,183,'en',1,5),('ept_image_gallery',0,10,183,'en',2,6),('ept_image_gallery',0,10,183,'en',3,7),('ept_image_gallery',0,10,183,'en',4,9),('ept_image_gallery',0,10,183,'en',5,10),('ept_image_gallery',0,10,183,'en',6,11),('ept_image_gallery',0,10,183,'en',7,12),('ept_image_gallery',0,10,183,'en',8,13),('ept_image_gallery',0,10,183,'en',9,14),('ept_image_gallery',0,10,183,'en',10,15),('ept_image_gallery',0,10,195,'en',0,4),('ept_image_gallery',0,10,195,'en',1,5),('ept_image_gallery',0,10,195,'en',2,6),('ept_image_gallery',0,10,195,'en',3,7),('ept_image_gallery',0,10,195,'en',4,9),('ept_image_gallery',0,10,195,'en',5,10),('ept_image_gallery',0,10,195,'en',6,11),('ept_image_gallery',0,10,195,'en',7,12),('ept_image_gallery',0,10,195,'en',8,13),('ept_image_gallery',0,10,195,'en',9,14),('ept_image_gallery',0,10,195,'en',10,15),('ept_image_gallery',0,10,207,'en',0,4),('ept_image_gallery',0,10,207,'en',1,5),('ept_image_gallery',0,10,207,'en',2,6),('ept_image_gallery',0,10,207,'en',3,7),('ept_image_gallery',0,10,207,'en',4,9),('ept_image_gallery',0,10,207,'en',5,10),('ept_image_gallery',0,10,207,'en',6,11),('ept_image_gallery',0,10,207,'en',7,12),('ept_image_gallery',0,10,207,'en',8,13),('ept_image_gallery',0,10,207,'en',9,14),('ept_image_gallery',0,10,207,'en',10,15),('ept_image_gallery',0,10,230,'en',0,4),('ept_image_gallery',0,10,230,'en',1,5),('ept_image_gallery',0,10,230,'en',2,6),('ept_image_gallery',0,10,230,'en',3,7),('ept_image_gallery',0,10,230,'en',4,9),('ept_image_gallery',0,10,230,'en',5,10),('ept_image_gallery',0,10,230,'en',6,11),('ept_image_gallery',0,10,230,'en',7,12),('ept_image_gallery',0,10,230,'en',8,13),('ept_image_gallery',0,10,230,'en',9,14),('ept_image_gallery',0,10,230,'en',10,15),('ept_image_gallery',0,10,253,'en',0,4),('ept_image_gallery',0,10,253,'en',1,5),('ept_image_gallery',0,10,253,'en',2,6),('ept_image_gallery',0,10,253,'en',3,7),('ept_image_gallery',0,10,253,'en',4,9),('ept_image_gallery',0,10,253,'en',5,10),('ept_image_gallery',0,10,253,'en',6,11),('ept_image_gallery',0,10,253,'en',7,12),('ept_image_gallery',0,10,253,'en',8,13),('ept_image_gallery',0,10,253,'en',9,14),('ept_image_gallery',0,10,253,'en',10,15),('ept_image_gallery',0,10,279,'en',0,4),('ept_image_gallery',0,10,279,'en',1,5),('ept_image_gallery',0,10,279,'en',2,6),('ept_image_gallery',0,10,279,'en',3,7),('ept_image_gallery',0,10,279,'en',4,9),('ept_image_gallery',0,10,279,'en',5,10),('ept_image_gallery',0,10,279,'en',6,11),('ept_image_gallery',0,10,279,'en',7,12),('ept_image_gallery',0,10,279,'en',8,13),('ept_image_gallery',0,10,279,'en',9,14),('ept_image_gallery',0,10,279,'en',10,15),('ept_image_gallery',0,10,309,'en',0,4),('ept_image_gallery',0,10,309,'en',1,5),('ept_image_gallery',0,10,309,'en',2,6),('ept_image_gallery',0,10,309,'en',3,7),('ept_image_gallery',0,10,309,'en',4,9),('ept_image_gallery',0,10,309,'en',5,10),('ept_image_gallery',0,10,309,'en',6,11),('ept_image_gallery',0,10,309,'en',7,12),('ept_image_gallery',0,10,309,'en',8,13),('ept_image_gallery',0,10,309,'en',9,14),('ept_image_gallery',0,10,309,'en',10,15),('ept_image_gallery',0,10,339,'en',0,4),('ept_image_gallery',0,10,339,'en',1,5),('ept_image_gallery',0,10,339,'en',2,6),('ept_image_gallery',0,10,339,'en',3,7),('ept_image_gallery',0,10,339,'en',4,9),('ept_image_gallery',0,10,339,'en',5,10),('ept_image_gallery',0,10,339,'en',6,11),('ept_image_gallery',0,10,339,'en',7,12),('ept_image_gallery',0,10,339,'en',8,13),('ept_image_gallery',0,10,339,'en',9,14),('ept_image_gallery',0,10,339,'en',10,15),('ept_image_gallery',0,10,369,'en',0,4),('ept_image_gallery',0,10,369,'en',1,5),('ept_image_gallery',0,10,369,'en',2,6),('ept_image_gallery',0,10,369,'en',3,7),('ept_image_gallery',0,10,369,'en',4,9),('ept_image_gallery',0,10,369,'en',5,10),('ept_image_gallery',0,10,369,'en',6,11),('ept_image_gallery',0,10,369,'en',7,12),('ept_image_gallery',0,10,369,'en',8,13),('ept_image_gallery',0,10,369,'en',9,14),('ept_image_gallery',0,10,369,'en',10,15),('ept_image_gallery',0,10,402,'en',0,4),('ept_image_gallery',0,10,402,'en',1,5),('ept_image_gallery',0,10,402,'en',2,6),('ept_image_gallery',0,10,402,'en',3,7),('ept_image_gallery',0,10,402,'en',4,9),('ept_image_gallery',0,10,402,'en',5,10),('ept_image_gallery',0,10,402,'en',6,11),('ept_image_gallery',0,10,402,'en',7,12),('ept_image_gallery',0,10,402,'en',8,13),('ept_image_gallery',0,10,402,'en',9,14),('ept_image_gallery',0,10,402,'en',10,15),('ept_image_gallery',0,10,435,'en',0,4),('ept_image_gallery',0,10,435,'en',1,5),('ept_image_gallery',0,10,435,'en',2,6),('ept_image_gallery',0,10,435,'en',3,7),('ept_image_gallery',0,10,435,'en',4,9),('ept_image_gallery',0,10,435,'en',5,10),('ept_image_gallery',0,10,435,'en',6,11),('ept_image_gallery',0,10,435,'en',7,12),('ept_image_gallery',0,10,435,'en',8,13),('ept_image_gallery',0,10,435,'en',9,14),('ept_image_gallery',0,10,435,'en',10,15),('ept_image_gallery',0,10,468,'en',0,4),('ept_image_gallery',0,10,468,'en',1,5),('ept_image_gallery',0,10,468,'en',2,6),('ept_image_gallery',0,10,468,'en',3,7),('ept_image_gallery',0,10,468,'en',4,9),('ept_image_gallery',0,10,468,'en',5,10),('ept_image_gallery',0,10,468,'en',6,11),('ept_image_gallery',0,10,468,'en',7,12),('ept_image_gallery',0,10,468,'en',8,13),('ept_image_gallery',0,10,468,'en',9,14),('ept_image_gallery',0,10,468,'en',10,15),('ept_image_gallery',0,10,504,'en',0,4),('ept_image_gallery',0,10,504,'en',1,5),('ept_image_gallery',0,10,504,'en',2,6),('ept_image_gallery',0,10,504,'en',3,7),('ept_image_gallery',0,10,504,'en',4,9),('ept_image_gallery',0,10,504,'en',5,10),('ept_image_gallery',0,10,504,'en',6,11),('ept_image_gallery',0,10,504,'en',7,12),('ept_image_gallery',0,10,504,'en',8,13),('ept_image_gallery',0,10,504,'en',9,14),('ept_image_gallery',0,10,504,'en',10,15),('ept_image_gallery',0,10,540,'en',0,4),('ept_image_gallery',0,10,540,'en',1,5),('ept_image_gallery',0,10,540,'en',2,6),('ept_image_gallery',0,10,540,'en',3,7),('ept_image_gallery',0,10,540,'en',4,9),('ept_image_gallery',0,10,540,'en',5,10),('ept_image_gallery',0,10,540,'en',6,11),('ept_image_gallery',0,10,540,'en',7,12),('ept_image_gallery',0,10,540,'en',8,13),('ept_image_gallery',0,10,540,'en',9,14),('ept_image_gallery',0,10,540,'en',10,15);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_gallery` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_image_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_image_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_image_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_image_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_image_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_link_uri` (`field_ept_image_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_image_link`
--

LOCK TABLES `paragraph_revision__field_ept_image_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_micromodal_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_micromodal_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_micromodal_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_micromodal_title_value` longtext NOT NULL,
  `field_ept_micromodal_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_micromodal_title_format` (`field_ept_micromodal_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_micromodal_title`
--

LOCK TABLES `paragraph_revision__field_ept_micromodal_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_micromodal_title` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_micromodal_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_quote_author`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_quote_author`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_quote_author` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_quote_author_value` longtext NOT NULL,
  `field_ept_quote_author_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_quote_author_format` (`field_ept_quote_author_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_quote_author`
--

LOCK TABLES `paragraph_revision__field_ept_quote_author` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_quote_author` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_quote_author` VALUES ('ept_quote',0,12,185,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,197,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,209,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,232,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,255,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,285,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,315,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,345,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,375,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,408,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,441,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,474,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,510,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,546,'en',0,'<p>Hockey Club</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_quote_author` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_quote_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_quote_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_quote_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_quote_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_quote_image_target_id` (`field_ept_quote_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_quote_image`
--

LOCK TABLES `paragraph_revision__field_ept_quote_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_quote_image` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_quote_image` VALUES ('ept_quote',0,12,185,'en',0,18),('ept_quote',0,12,197,'en',0,18),('ept_quote',0,12,209,'en',0,18),('ept_quote',0,12,232,'en',0,18),('ept_quote',0,12,255,'en',0,18),('ept_quote',0,12,285,'en',0,18),('ept_quote',0,12,315,'en',0,18),('ept_quote',0,12,345,'en',0,18),('ept_quote',0,12,375,'en',0,18),('ept_quote',0,12,408,'en',0,18),('ept_quote',0,12,441,'en',0,18),('ept_quote',0,12,474,'en',0,18),('ept_quote',0,12,510,'en',0,18),('ept_quote',0,12,546,'en',0,18);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_quote_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_settings`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_settings` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_settings_ept_settings` longblob COMMENT 'Serialized paragraph settings data',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_settings`
--

LOCK TABLES `paragraph_revision__field_ept_settings` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_settings` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_settings` VALUES ('ept_hero',0,1,1,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,2,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,3,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,4,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,5,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,6,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,7,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,8,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,9,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,11,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,13,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,15,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,17,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,23,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,29,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,35,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,41,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,47,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,53,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,59,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,65,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,74,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,83,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,92,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,102,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,112,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,122,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,132,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,142,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,152,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,163,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,174,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,186,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,198,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,221,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,244,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,270,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,300,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,330,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,360,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,393,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,426,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,459,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,495,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,531,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_text',0,2,10,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_text',0,2,12,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,14,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,16,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,18,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,24,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,30,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,36,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,42,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,48,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,54,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,60,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,66,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,75,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,84,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,93,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,103,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,113,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,123,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,133,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,143,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,153,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,164,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,175,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,187,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,199,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,222,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,245,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,271,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,301,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,331,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,361,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,394,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,427,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,460,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,496,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,532,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_tiles',0,6,22,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,28,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,34,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,40,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,46,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,52,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,58,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,64,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,70,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,79,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,88,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,97,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,107,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,117,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,127,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,137,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,147,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,157,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,168,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,179,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,191,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,203,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,226,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,249,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,275,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,305,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,335,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,365,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,398,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,431,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,464,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,500,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,536,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_stats',0,9,73,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:16:\"stats_in_squares\";}'),('ept_stats',0,9,82,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,91,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,100,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,110,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,120,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,130,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,140,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,150,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,160,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,171,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,182,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,194,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,206,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,229,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,252,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,278,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,308,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,338,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,368,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,401,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,434,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,467,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,503,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,539,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_image_gallery',0,10,101,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,111,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,121,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,131,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,141,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,151,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,161,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,172,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,183,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,195,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,207,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,230,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,253,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,279,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,309,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,339,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,369,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,402,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,435,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,468,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,504,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,540,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_cta',0,11,162,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,173,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,184,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,196,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,208,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,231,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,254,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,280,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,310,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,340,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,370,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,403,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,436,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,469,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,505,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,541,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_quote',0,12,185,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,197,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,209,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,232,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,255,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,285,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,315,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,345,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,375,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,408,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,441,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,474,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,510,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,546,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_carousel',0,23,220,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,243,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,266,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,296,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,326,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,356,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,386,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,419,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,452,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,485,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,521,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,557,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_counter',0,26,269,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,299,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,329,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,359,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,389,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,422,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,455,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,488,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,524,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,560,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_slideshow',0,30,284,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:0;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,314,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,344,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,374,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,407,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,440,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,473,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,509,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,545,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_tabs',0,33,392,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_tabs',0,33,425,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_tabs',0,33,458,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_tabs',0,33,491,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_tabs',0,33,527,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_tabs',0,33,563,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_accordion',0,36,494,'en',0,_binary 'a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_accordion',0,36,530,'en',0,_binary 'a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_accordion',0,36,567,'en',0,_binary 'a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_views',0,38,568,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_views',0,38,570,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_views',0,38,573,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_views',0,38,576,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_views',0,38,579,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_views',0,38,582,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,569,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,572,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,575,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,578,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,581,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_hero',0,40,571,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,40,574,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,40,577,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,40,580,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slick_slider`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slick_slider`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slick_slider` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_slick_slider_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_target_id` (`field_ept_slick_slider_target_id`),
  KEY `field_ept_slick_slider_target_revision_id` (`field_ept_slick_slider_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slick_slider`
--

LOCK TABLES `paragraph_revision__field_ept_slick_slider` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slick_slider_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slick_slider_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slick_slider_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_image_target_id` (`field_ept_slick_slider_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slick_slider_image`
--

LOCK TABLES `paragraph_revision__field_ept_slick_slider_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slick_slider_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slick_slider_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slick_slider_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_slick_slider_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_slick_slider_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_link_uri` (`field_ept_slick_slider_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slick_slider_link`
--

LOCK TABLES `paragraph_revision__field_ept_slick_slider_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slick_slider_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slick_slider_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slick_slider_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_text_value` longtext NOT NULL,
  `field_ept_slick_slider_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_text_format` (`field_ept_slick_slider_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slick_slider_text`
--

LOCK TABLES `paragraph_revision__field_ept_slick_slider_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_text` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slideshow`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slideshow`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slideshow` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_slideshow_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_target_id` (`field_ept_slideshow_target_id`),
  KEY `field_ept_slideshow_target_revision_id` (`field_ept_slideshow_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slideshow`
--

LOCK TABLES `paragraph_revision__field_ept_slideshow` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_slideshow` VALUES ('ept_slideshow',0,30,284,'en',0,27,281),('ept_slideshow',0,30,284,'en',1,28,282),('ept_slideshow',0,30,284,'en',2,29,283),('ept_slideshow',0,30,314,'en',0,27,311),('ept_slideshow',0,30,314,'en',1,28,312),('ept_slideshow',0,30,314,'en',2,29,313),('ept_slideshow',0,30,344,'en',0,27,341),('ept_slideshow',0,30,344,'en',1,28,342),('ept_slideshow',0,30,344,'en',2,29,343),('ept_slideshow',0,30,374,'en',0,27,371),('ept_slideshow',0,30,374,'en',1,28,372),('ept_slideshow',0,30,374,'en',2,29,373),('ept_slideshow',0,30,407,'en',0,27,404),('ept_slideshow',0,30,407,'en',1,28,405),('ept_slideshow',0,30,407,'en',2,29,406),('ept_slideshow',0,30,440,'en',0,27,437),('ept_slideshow',0,30,440,'en',1,28,438),('ept_slideshow',0,30,440,'en',2,29,439),('ept_slideshow',0,30,473,'en',0,27,470),('ept_slideshow',0,30,473,'en',1,28,471),('ept_slideshow',0,30,473,'en',2,29,472),('ept_slideshow',0,30,509,'en',0,27,506),('ept_slideshow',0,30,509,'en',1,28,507),('ept_slideshow',0,30,509,'en',2,29,508),('ept_slideshow',0,30,545,'en',0,27,542),('ept_slideshow',0,30,545,'en',1,28,543),('ept_slideshow',0,30,545,'en',2,29,544);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slideshow_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slideshow_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slideshow_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_slideshow_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_slideshow_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_link_uri` (`field_ept_slideshow_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slideshow_link`
--

LOCK TABLES `paragraph_revision__field_ept_slideshow_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slideshow_slide`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slideshow_slide`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slideshow_slide` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_slide_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_slide_target_id` (`field_ept_slideshow_slide_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slideshow_slide`
--

LOCK TABLES `paragraph_revision__field_ept_slideshow_slide` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_slide` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_slideshow_slide` VALUES ('ept_slideshow_item',0,27,281,'en',0,20),('ept_slideshow_item',0,27,311,'en',0,20),('ept_slideshow_item',0,27,341,'en',0,20),('ept_slideshow_item',0,27,371,'en',0,20),('ept_slideshow_item',0,27,404,'en',0,20),('ept_slideshow_item',0,27,437,'en',0,20),('ept_slideshow_item',0,27,470,'en',0,20),('ept_slideshow_item',0,27,506,'en',0,20),('ept_slideshow_item',0,27,542,'en',0,20),('ept_slideshow_item',0,28,282,'en',0,21),('ept_slideshow_item',0,28,312,'en',0,21),('ept_slideshow_item',0,28,342,'en',0,21),('ept_slideshow_item',0,28,372,'en',0,21),('ept_slideshow_item',0,28,405,'en',0,21),('ept_slideshow_item',0,28,438,'en',0,21),('ept_slideshow_item',0,28,471,'en',0,21),('ept_slideshow_item',0,28,507,'en',0,21),('ept_slideshow_item',0,28,543,'en',0,21),('ept_slideshow_item',0,29,283,'en',0,22),('ept_slideshow_item',0,29,313,'en',0,22),('ept_slideshow_item',0,29,343,'en',0,22),('ept_slideshow_item',0,29,373,'en',0,22),('ept_slideshow_item',0,29,406,'en',0,22),('ept_slideshow_item',0,29,439,'en',0,22),('ept_slideshow_item',0,29,472,'en',0,22),('ept_slideshow_item',0,29,508,'en',0,22),('ept_slideshow_item',0,29,544,'en',0,22);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_slide` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slideshow_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slideshow_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slideshow_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_text_value` longtext NOT NULL,
  `field_ept_slideshow_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_text_format` (`field_ept_slideshow_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slideshow_text`
--

LOCK TABLES `paragraph_revision__field_ept_slideshow_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_slideshow_text` VALUES ('ept_slideshow_item',0,27,281,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,311,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,341,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,371,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,404,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,437,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,470,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,506,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,542,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,28,282,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,312,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,342,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,372,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,405,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,438,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,471,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,507,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,543,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,29,283,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,313,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,343,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,373,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,406,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,439,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,472,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,508,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,544,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slideshow_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slideshow_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slideshow_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_title_value` longtext NOT NULL,
  `field_ept_slideshow_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_title_format` (`field_ept_slideshow_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slideshow_title`
--

LOCK TABLES `paragraph_revision__field_ept_slideshow_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_slideshow_title` VALUES ('ept_slideshow_item',0,27,281,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,311,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,341,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,371,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,404,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,437,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,470,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,506,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,542,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,28,282,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,312,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,342,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,372,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,405,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,438,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,471,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,507,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,543,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,29,283,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,313,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,343,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,373,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,406,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,439,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,472,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,508,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,544,'en',0,'<p>Settings for javascript plugins</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_stats`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_stats`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_stats` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_stats_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_target_id` (`field_ept_stats_target_id`),
  KEY `field_ept_stats_target_revision_id` (`field_ept_stats_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_stats`
--

LOCK TABLES `paragraph_revision__field_ept_stats` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_stats` VALUES ('ept_stats',0,9,73,'en',0,7,71),('ept_stats',0,9,73,'en',1,8,72),('ept_stats',0,9,82,'en',0,7,80),('ept_stats',0,9,82,'en',1,8,81),('ept_stats',0,9,91,'en',0,7,89),('ept_stats',0,9,91,'en',1,8,90),('ept_stats',0,9,100,'en',0,7,98),('ept_stats',0,9,100,'en',1,8,99),('ept_stats',0,9,110,'en',0,7,108),('ept_stats',0,9,110,'en',1,8,109),('ept_stats',0,9,120,'en',0,7,118),('ept_stats',0,9,120,'en',1,8,119),('ept_stats',0,9,130,'en',0,7,128),('ept_stats',0,9,130,'en',1,8,129),('ept_stats',0,9,140,'en',0,7,138),('ept_stats',0,9,140,'en',1,8,139),('ept_stats',0,9,150,'en',0,7,148),('ept_stats',0,9,150,'en',1,8,149),('ept_stats',0,9,160,'en',0,7,158),('ept_stats',0,9,160,'en',1,8,159),('ept_stats',0,9,171,'en',0,7,169),('ept_stats',0,9,171,'en',1,8,170),('ept_stats',0,9,182,'en',0,7,180),('ept_stats',0,9,182,'en',1,8,181),('ept_stats',0,9,194,'en',0,7,192),('ept_stats',0,9,194,'en',1,8,193),('ept_stats',0,9,206,'en',0,7,204),('ept_stats',0,9,206,'en',1,8,205),('ept_stats',0,9,229,'en',0,7,227),('ept_stats',0,9,229,'en',1,8,228),('ept_stats',0,9,252,'en',0,7,250),('ept_stats',0,9,252,'en',1,8,251),('ept_stats',0,9,278,'en',0,7,276),('ept_stats',0,9,278,'en',1,8,277),('ept_stats',0,9,308,'en',0,7,306),('ept_stats',0,9,308,'en',1,8,307),('ept_stats',0,9,338,'en',0,7,336),('ept_stats',0,9,338,'en',1,8,337),('ept_stats',0,9,368,'en',0,7,366),('ept_stats',0,9,368,'en',1,8,367),('ept_stats',0,9,401,'en',0,7,399),('ept_stats',0,9,401,'en',1,8,400),('ept_stats',0,9,434,'en',0,7,432),('ept_stats',0,9,434,'en',1,8,433),('ept_stats',0,9,467,'en',0,7,465),('ept_stats',0,9,467,'en',1,8,466),('ept_stats',0,9,503,'en',0,7,501),('ept_stats',0,9,503,'en',1,8,502),('ept_stats',0,9,539,'en',0,7,537),('ept_stats',0,9,539,'en',1,8,538);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_stats_item_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_stats_item_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_stats_item_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_image_target_id` (`field_ept_stats_item_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_stats_item_image`
--

LOCK TABLES `paragraph_revision__field_ept_stats_item_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_stats_item_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_stats_item_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_stats_item_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_stats_item_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_stats_item_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_link_uri` (`field_ept_stats_item_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_stats_item_link`
--

LOCK TABLES `paragraph_revision__field_ept_stats_item_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_stats_item_number`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_stats_item_number`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_stats_item_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_number_value` longtext NOT NULL,
  `field_ept_stats_item_number_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_number_format` (`field_ept_stats_item_number_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_stats_item_number`
--

LOCK TABLES `paragraph_revision__field_ept_stats_item_number` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_number` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_stats_item_number` VALUES ('ept_stats_item',0,7,71,'en',0,'<p><span style=\"background-color:rgb(255,255,255);color:rgb(34,34,34);\"><span style=\"-webkit-text-stroke-width:0px;display:inline !important;float:none;font-family:NotoSans, system-ui, sans-serif;font-size:16px;font-style:normal;font-variant-caps:normal;font-variant-ligatures:normal;font-weight:400;letter-spacing:normal;orphans:2;text-align:right;text-decoration-color:initial;text-decoration-style:initial;text-decoration-thickness:initial;text-indent:0px;text-transform:none;white-space:normal;widows:2;word-spacing:0px;\">721,320</span></span></p>','full_html'),('ept_stats_item',0,7,80,'en',0,'<p><span style=\"background-color:rgb(255,255,255);color:rgb(34,34,34);\"><span style=\"-webkit-text-stroke-width:0px;display:inline !important;float:none;font-family:NotoSans, system-ui, sans-serif;font-size:16px;font-style:normal;font-variant-caps:normal;font-variant-ligatures:normal;font-weight:400;letter-spacing:normal;orphans:2;text-align:right;text-decoration-color:initial;text-decoration-style:initial;text-decoration-thickness:initial;text-indent:0px;text-transform:none;white-space:normal;widows:2;word-spacing:0px;\">721,320</span></span></p>','full_html'),('ept_stats_item',0,7,89,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,98,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,108,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,118,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,128,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,138,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,148,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,158,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,169,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,180,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,192,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,204,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,227,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,250,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,276,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,306,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,336,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,366,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,399,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,432,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,465,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,501,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,537,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,8,72,'en',0,'<p>238,556</p>','full_html'),('ept_stats_item',0,8,81,'en',0,'<p>238,556</p>','full_html'),('ept_stats_item',0,8,90,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,99,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,109,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,119,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,129,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,139,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,149,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,159,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,170,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,181,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,193,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,205,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,228,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,251,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,277,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,307,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,337,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,367,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,400,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,433,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,466,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,502,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,538,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_number` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_stats_item_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_stats_item_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_stats_item_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_text_value` longtext NOT NULL,
  `field_ept_stats_item_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_text_format` (`field_ept_stats_item_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_stats_item_text`
--

LOCK TABLES `paragraph_revision__field_ept_stats_item_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_stats_item_text` VALUES ('ept_stats_item',0,7,71,'en',0,'<p>Websites use Drupal</p>','full_html'),('ept_stats_item',0,7,80,'en',0,'<p>Websites use Drupal</p>','full_html'),('ept_stats_item',0,7,89,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,98,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,108,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,118,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,128,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,138,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,148,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,158,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,169,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,180,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,192,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,204,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,227,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,250,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,276,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,306,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,336,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,366,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,399,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,432,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,465,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,501,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,537,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,8,72,'en',0,'<p>Usage statistics for Paragraphs module</p>','full_html'),('ept_stats_item',0,8,81,'en',0,'<p>Usage statistics for Paragraphs module</p>','full_html'),('ept_stats_item',0,8,90,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,99,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,109,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,119,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,129,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,139,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,149,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,159,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,170,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,181,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,193,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,205,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,228,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,251,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,277,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,307,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,337,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,367,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,400,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,433,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,466,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,502,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,538,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_block`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_block`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ept_tab_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_block_plugin_id` (`field_ept_tab_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_block`
--

LOCK TABLES `paragraph_revision__field_ept_tab_block` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_block` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_block` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_content`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_content`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_content` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_content_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_content_value` (`field_ept_tab_content_value`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_content`
--

LOCK TABLES `paragraph_revision__field_ept_tab_content` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_content` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tab_content` VALUES ('ept_tabs_item',0,31,390,'en',0,'text'),('ept_tabs_item',0,31,423,'en',0,'text'),('ept_tabs_item',0,31,456,'en',0,'text'),('ept_tabs_item',0,31,489,'en',0,'text'),('ept_tabs_item',0,31,525,'en',0,'text'),('ept_tabs_item',0,31,561,'en',0,'text'),('ept_tabs_item',0,32,391,'en',0,'text'),('ept_tabs_item',0,32,424,'en',0,'text'),('ept_tabs_item',0,32,457,'en',0,'text'),('ept_tabs_item',0,32,490,'en',0,'text'),('ept_tabs_item',0,32,526,'en',0,'text'),('ept_tabs_item',0,32,562,'en',0,'text');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_content` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_page`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_page`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_page` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_page_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_page_target_id` (`field_ept_tab_page_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_page`
--

LOCK TABLES `paragraph_revision__field_ept_tab_page` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_page` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_page` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_text_value` longtext NOT NULL,
  `field_ept_tab_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_text_format` (`field_ept_tab_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_text`
--

LOCK TABLES `paragraph_revision__field_ept_tab_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tab_text` VALUES ('ept_tabs_item',0,31,390,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,31,423,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,31,456,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,31,489,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,31,525,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,31,561,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,391,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,424,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,457,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,490,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,526,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,562,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_title_value` varchar(255) NOT NULL,
  `field_ept_tab_title_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_title_format` (`field_ept_tab_title_format`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_title`
--

LOCK TABLES `paragraph_revision__field_ept_tab_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tab_title` VALUES ('ept_tabs_item',0,31,390,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,31,423,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,31,456,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,31,489,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,31,525,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,31,561,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,32,391,'en',0,'EBT Modules','full_html'),('ept_tabs_item',0,32,424,'en',0,'EBT Modules','full_html'),('ept_tabs_item',0,32,457,'en',0,'EBT Modules','full_html'),('ept_tabs_item',0,32,490,'en',0,'EBT Modules','full_html'),('ept_tabs_item',0,32,526,'en',0,'EBT Modules','full_html'),('ept_tabs_item',0,32,562,'en',0,'EBT Modules','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_views`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_views`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_views` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_views_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tab_views_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ept_tab_views_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_views_target_id` (`field_ept_tab_views_target_id`),
  KEY `field_ept_tab_views_display_id` (`field_ept_tab_views_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_views`
--

LOCK TABLES `paragraph_revision__field_ept_tab_views` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_views` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_views` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tabs`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tabs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tabs` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tabs_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tabs_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tabs_target_id` (`field_ept_tabs_target_id`),
  KEY `field_ept_tabs_target_revision_id` (`field_ept_tabs_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tabs.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tabs`
--

LOCK TABLES `paragraph_revision__field_ept_tabs` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tabs` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tabs` VALUES ('ept_tabs',0,33,392,'en',0,31,390),('ept_tabs',0,33,392,'en',1,32,391),('ept_tabs',0,33,425,'en',0,31,423),('ept_tabs',0,33,425,'en',1,32,424),('ept_tabs',0,33,458,'en',0,31,456),('ept_tabs',0,33,458,'en',1,32,457),('ept_tabs',0,33,491,'en',0,31,489),('ept_tabs',0,33,491,'en',1,32,490),('ept_tabs',0,33,527,'en',0,31,525),('ept_tabs',0,33,527,'en',1,32,526),('ept_tabs',0,33,563,'en',0,31,561),('ept_tabs',0,33,563,'en',1,32,562);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tabs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_text_value` longtext NOT NULL,
  `field_ept_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_text_format` (`field_ept_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_text`
--

LOCK TABLES `paragraph_revision__field_ept_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_text` VALUES ('ept_hero',0,1,1,'en',0,'<p>Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</p>','basic_html'),('ept_hero',0,1,2,'en',0,'<p>Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</p>','basic_html'),('ept_hero',0,1,3,'en',0,'<p>Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</p>','full_html'),('ept_hero',0,1,4,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</span></p>','full_html'),('ept_hero',0,1,5,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</span></p>','full_html'),('ept_hero',0,1,6,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</span></p>','full_html'),('ept_hero',0,1,7,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</span></p>','full_html'),('ept_hero',0,1,8,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,9,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,11,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,13,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,15,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,17,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,23,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,29,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,35,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,41,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,47,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,53,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,59,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,65,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,74,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,83,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,92,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,102,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,112,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,122,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,132,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,142,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,152,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,163,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,174,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,186,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,198,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,221,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,244,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,270,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,300,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,330,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,360,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,393,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,426,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,459,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,495,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,531,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_text',0,2,10,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,12,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,14,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,16,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,18,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,24,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,30,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,36,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,42,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,48,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,54,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,60,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,66,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,75,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,84,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,93,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,103,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,113,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,123,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,133,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,143,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,153,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,164,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,175,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,187,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,199,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,222,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,245,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,271,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,301,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,331,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,361,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,394,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,427,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,460,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,496,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,532,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_stats',0,9,73,'en',0,'<p>Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</p>','full_html'),('ept_stats',0,9,82,'en',0,'<p>Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</p>','full_html'),('ept_stats',0,9,91,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,100,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,110,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,120,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,130,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,140,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,150,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,160,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,171,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,182,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,194,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,206,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,229,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,252,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,278,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,308,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,338,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,368,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,401,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,434,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,467,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,503,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,539,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_cta',0,11,162,'en',0,'<p>EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</p>','full_html'),('ept_cta',0,11,173,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,184,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,196,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,208,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,231,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,254,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,280,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,310,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,340,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,370,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,403,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,436,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,469,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,505,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,541,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_quote',0,12,185,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,197,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,209,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,232,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,255,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,285,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,315,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,345,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,375,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,408,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,441,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,474,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,510,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,546,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_hero',0,40,571,'en',0,'<p>Stay tuned!</p>','full_html'),('ept_hero',0,40,574,'en',0,'<p>Stay tuned!</p>','full_html'),('ept_hero',0,40,577,'en',0,'<p>Stay tuned!</p>','full_html'),('ept_hero',0,40,580,'en',0,'<p>Stay tuned!</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tiles`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tiles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tiles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tiles_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_target_id` (`field_ept_tiles_target_id`),
  KEY `field_ept_tiles_target_revision_id` (`field_ept_tiles_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tiles`
--

LOCK TABLES `paragraph_revision__field_ept_tiles` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tiles` VALUES ('ept_tiles',0,6,22,'en',0,3,19),('ept_tiles',0,6,22,'en',1,4,20),('ept_tiles',0,6,22,'en',2,5,21),('ept_tiles',0,6,28,'en',0,3,25),('ept_tiles',0,6,28,'en',1,4,26),('ept_tiles',0,6,28,'en',2,5,27),('ept_tiles',0,6,34,'en',0,3,31),('ept_tiles',0,6,34,'en',1,4,32),('ept_tiles',0,6,34,'en',2,5,33),('ept_tiles',0,6,40,'en',0,3,37),('ept_tiles',0,6,40,'en',1,4,38),('ept_tiles',0,6,40,'en',2,5,39),('ept_tiles',0,6,46,'en',0,3,43),('ept_tiles',0,6,46,'en',1,4,44),('ept_tiles',0,6,46,'en',2,5,45),('ept_tiles',0,6,52,'en',0,3,49),('ept_tiles',0,6,52,'en',1,4,50),('ept_tiles',0,6,52,'en',2,5,51),('ept_tiles',0,6,58,'en',0,3,55),('ept_tiles',0,6,58,'en',1,4,56),('ept_tiles',0,6,58,'en',2,5,57),('ept_tiles',0,6,64,'en',0,3,61),('ept_tiles',0,6,64,'en',1,4,62),('ept_tiles',0,6,64,'en',2,5,63),('ept_tiles',0,6,70,'en',0,3,67),('ept_tiles',0,6,70,'en',1,4,68),('ept_tiles',0,6,70,'en',2,5,69),('ept_tiles',0,6,79,'en',0,3,76),('ept_tiles',0,6,79,'en',1,4,77),('ept_tiles',0,6,79,'en',2,5,78),('ept_tiles',0,6,88,'en',0,3,85),('ept_tiles',0,6,88,'en',1,4,86),('ept_tiles',0,6,88,'en',2,5,87),('ept_tiles',0,6,97,'en',0,3,94),('ept_tiles',0,6,97,'en',1,4,95),('ept_tiles',0,6,97,'en',2,5,96),('ept_tiles',0,6,107,'en',0,3,104),('ept_tiles',0,6,107,'en',1,4,105),('ept_tiles',0,6,107,'en',2,5,106),('ept_tiles',0,6,117,'en',0,3,114),('ept_tiles',0,6,117,'en',1,4,115),('ept_tiles',0,6,117,'en',2,5,116),('ept_tiles',0,6,127,'en',0,3,124),('ept_tiles',0,6,127,'en',1,4,125),('ept_tiles',0,6,127,'en',2,5,126),('ept_tiles',0,6,137,'en',0,3,134),('ept_tiles',0,6,137,'en',1,4,135),('ept_tiles',0,6,137,'en',2,5,136),('ept_tiles',0,6,147,'en',0,3,144),('ept_tiles',0,6,147,'en',1,4,145),('ept_tiles',0,6,147,'en',2,5,146),('ept_tiles',0,6,157,'en',0,3,154),('ept_tiles',0,6,157,'en',1,4,155),('ept_tiles',0,6,157,'en',2,5,156),('ept_tiles',0,6,168,'en',0,3,165),('ept_tiles',0,6,168,'en',1,4,166),('ept_tiles',0,6,168,'en',2,5,167),('ept_tiles',0,6,179,'en',0,3,176),('ept_tiles',0,6,179,'en',1,4,177),('ept_tiles',0,6,179,'en',2,5,178),('ept_tiles',0,6,191,'en',0,3,188),('ept_tiles',0,6,191,'en',1,4,189),('ept_tiles',0,6,191,'en',2,5,190),('ept_tiles',0,6,203,'en',0,3,200),('ept_tiles',0,6,203,'en',1,4,201),('ept_tiles',0,6,203,'en',2,5,202),('ept_tiles',0,6,226,'en',0,3,223),('ept_tiles',0,6,226,'en',1,4,224),('ept_tiles',0,6,226,'en',2,5,225),('ept_tiles',0,6,249,'en',0,3,246),('ept_tiles',0,6,249,'en',1,4,247),('ept_tiles',0,6,249,'en',2,5,248),('ept_tiles',0,6,275,'en',0,3,272),('ept_tiles',0,6,275,'en',1,4,273),('ept_tiles',0,6,275,'en',2,5,274),('ept_tiles',0,6,305,'en',0,3,302),('ept_tiles',0,6,305,'en',1,4,303),('ept_tiles',0,6,305,'en',2,5,304),('ept_tiles',0,6,335,'en',0,3,332),('ept_tiles',0,6,335,'en',1,4,333),('ept_tiles',0,6,335,'en',2,5,334),('ept_tiles',0,6,365,'en',0,3,362),('ept_tiles',0,6,365,'en',1,4,363),('ept_tiles',0,6,365,'en',2,5,364),('ept_tiles',0,6,398,'en',0,3,395),('ept_tiles',0,6,398,'en',1,4,396),('ept_tiles',0,6,398,'en',2,5,397),('ept_tiles',0,6,431,'en',0,3,428),('ept_tiles',0,6,431,'en',1,4,429),('ept_tiles',0,6,431,'en',2,5,430),('ept_tiles',0,6,464,'en',0,3,461),('ept_tiles',0,6,464,'en',1,4,462),('ept_tiles',0,6,464,'en',2,5,463),('ept_tiles',0,6,500,'en',0,3,497),('ept_tiles',0,6,500,'en',1,4,498),('ept_tiles',0,6,500,'en',2,5,499),('ept_tiles',0,6,536,'en',0,3,533),('ept_tiles',0,6,536,'en',1,4,534),('ept_tiles',0,6,536,'en',2,5,535);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tiles_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tiles_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tiles_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_image_target_id` (`field_ept_tiles_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tiles_image`
--

LOCK TABLES `paragraph_revision__field_ept_tiles_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tiles_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tiles_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tiles_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_tiles_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_tiles_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_link_uri` (`field_ept_tiles_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tiles_link`
--

LOCK TABLES `paragraph_revision__field_ept_tiles_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_link` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tiles_link` VALUES ('ept_tiles_item',0,3,19,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,25,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,31,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,37,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,43,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,49,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,55,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,61,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,67,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,76,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,85,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,94,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,104,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,114,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,124,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,134,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,144,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,154,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,165,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,176,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,188,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,200,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,223,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,246,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,272,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,302,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,332,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,362,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,395,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,428,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,461,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,497,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,533,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,5,21,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,27,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,33,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,39,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,45,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,51,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,57,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,63,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,69,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,78,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,87,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,96,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,106,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,116,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,126,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,136,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,146,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,156,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,167,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,178,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,190,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,202,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,225,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,248,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,274,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,304,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,334,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,364,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,397,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,430,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,463,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,499,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,535,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tiles_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tiles_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tiles_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_text_value` longtext NOT NULL,
  `field_ept_tiles_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_text_format` (`field_ept_tiles_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tiles_text`
--

LOCK TABLES `paragraph_revision__field_ept_tiles_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tiles_text` VALUES ('ept_tiles_item',0,3,19,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,25,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,31,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,37,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,43,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,49,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,55,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,61,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,67,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,76,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,85,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,94,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,104,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,114,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,124,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,134,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,144,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,154,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,165,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,176,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,188,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,200,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,223,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,246,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,272,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,302,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,332,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,362,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,395,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,428,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,461,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,497,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,533,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,4,20,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,26,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,32,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,38,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,44,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,50,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,56,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,62,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,68,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,77,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,86,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,95,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,105,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,115,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,125,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,135,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,145,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,155,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,166,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,177,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,189,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,201,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,224,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,247,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,273,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,303,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,333,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,363,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,396,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,429,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,462,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,498,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,534,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,5,21,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,27,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,33,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,39,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,45,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,51,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,57,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,63,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,69,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,78,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,87,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,96,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,106,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,116,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,126,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,136,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,146,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,156,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,167,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,178,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,190,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,202,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,225,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,248,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,274,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,304,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,334,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,364,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,397,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,430,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,463,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,499,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,535,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tiles_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tiles_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tiles_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_title_value` longtext NOT NULL,
  `field_ept_tiles_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_title_format` (`field_ept_tiles_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tiles_title`
--

LOCK TABLES `paragraph_revision__field_ept_tiles_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tiles_title` VALUES ('ept_tiles_item',0,3,19,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,25,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,31,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,37,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,43,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,49,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,55,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,61,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,67,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,76,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,85,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,94,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,104,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,114,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,124,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,134,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,144,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,154,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,165,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,176,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,188,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,200,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,223,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,246,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,272,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,302,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,332,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,362,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,395,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,428,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,461,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,497,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,533,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,4,20,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,26,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,32,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,38,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,44,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,50,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,56,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,62,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,68,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,77,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,86,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,95,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,105,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,115,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,125,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,135,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,145,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,155,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,166,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,177,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,189,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,201,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,224,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,247,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,273,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,303,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,333,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,363,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,396,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,429,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,462,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,498,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,534,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,5,21,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,27,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,33,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,39,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,45,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,51,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,57,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,63,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,69,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,78,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,87,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,96,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,106,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,116,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,126,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,136,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,146,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,156,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,167,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,178,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,190,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,202,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,225,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,248,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,274,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,304,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,334,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,364,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,397,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,430,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,463,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,499,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,535,'en',0,'<p>Start Creating</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_title_value` longtext NOT NULL,
  `field_ept_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_title_format` (`field_ept_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_title`
--

LOCK TABLES `paragraph_revision__field_ept_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_title` VALUES ('ept_hero',0,1,1,'en',0,'<p>EPT Page Builder - Getting Started</p>','basic_html'),('ept_hero',0,1,2,'en',0,'<p>EPT Page Builder - Getting Started</p>','basic_html'),('ept_hero',0,1,3,'en',0,'<p>EPT Page Builder - Getting Started</p>','full_html'),('ept_hero',0,1,4,'en',0,'<h1><span style=\"color:hsl(0, 0%, 100%);\">EPT (Extra Paragraph Types) Page Builder</span></h1>','full_html'),('ept_hero',0,1,5,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">EPT (Extra Paragraph Types) Page Builder</span></h1>','full_html'),('ept_hero',0,1,6,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">EPT (Extra Paragraph Types) Page Builder</span></h1>','full_html'),('ept_hero',0,1,7,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">EPT (Extra Paragraph Types) Page Builder</span></h1>','full_html'),('ept_hero',0,1,8,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,9,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,11,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,13,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,15,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,17,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,23,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,29,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,35,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,41,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,47,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,53,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,59,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,65,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,74,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,83,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,92,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,102,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,112,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,122,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,132,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,142,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,152,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,163,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,174,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,186,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,198,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,221,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,244,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,270,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,300,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,330,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,360,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,393,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,426,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,459,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,495,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,531,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_text',0,2,10,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,12,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,14,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,16,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,18,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,24,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,30,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,36,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,42,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,48,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,54,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,60,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,66,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,75,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,84,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,93,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,103,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,113,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,123,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,133,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,143,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,153,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,164,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,175,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,187,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,199,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,222,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,245,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,271,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,301,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,331,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,361,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,394,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,427,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,460,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,496,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,532,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_tiles',0,6,52,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,58,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,64,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,70,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,79,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,88,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,97,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,107,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,117,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,127,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,137,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,147,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,157,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,168,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,179,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,191,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,203,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,226,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,249,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,275,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,305,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,335,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,365,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,398,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,431,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,464,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,500,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,536,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_stats',0,9,73,'en',0,'<p>What Are Drupal Paragraphs?</p>','full_html'),('ept_stats',0,9,82,'en',0,'<p>What Are Drupal Paragraphs?</p>','full_html'),('ept_stats',0,9,91,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,100,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,110,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,120,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,130,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,140,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,150,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,160,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,171,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,182,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,194,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,206,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,229,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,252,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,278,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,308,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,338,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,368,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,401,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,434,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,467,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,503,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,539,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_image_gallery',0,10,101,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,111,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,121,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,131,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,141,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,151,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,161,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,172,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,183,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,195,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,207,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,230,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,253,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,279,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,309,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,339,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,369,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,402,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,435,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,468,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,504,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,540,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_cta',0,11,162,'en',0,'<p>EPT modules uses GLightbox for Image/Video in popups</p>','full_html'),('ept_cta',0,11,173,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,184,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,196,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,208,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,231,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,254,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,280,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,310,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,340,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,370,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,403,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,436,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,469,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,505,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,541,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_quote',0,12,185,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,197,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,209,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,232,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,255,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,285,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,315,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,345,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,375,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,408,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,441,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,474,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,510,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,546,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_carousel',0,23,220,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,243,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,266,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,296,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,326,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,356,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,386,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,419,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,452,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,485,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,521,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,557,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_counter',0,26,269,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,299,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,329,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,359,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,389,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,422,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,455,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,488,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,524,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,560,'en',0,'<p>Number of modules</p>','full_html'),('ept_slideshow',0,30,284,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,314,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,344,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,374,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,407,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,440,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,473,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,509,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,545,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_tabs',0,33,392,'en',0,'<p>List of all Extra Paragraph Types (EPT) and Extra Block Types (EBT)&nbsp;</p>','full_html'),('ept_tabs',0,33,425,'en',0,'<p>List of all Extra Paragraph Types (EPT) and Extra Block Types (EBT)&nbsp;</p>','full_html'),('ept_tabs',0,33,458,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>','full_html'),('ept_tabs',0,33,491,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>','full_html'),('ept_tabs',0,33,527,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>','full_html'),('ept_tabs',0,33,563,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>','full_html'),('ept_accordion',0,36,494,'en',0,'<p>FAQ</p>','full_html'),('ept_accordion',0,36,530,'en',0,'<p>FAQ</p>','full_html'),('ept_accordion',0,36,567,'en',0,'<p>FAQ</p>','full_html'),('ept_hero',0,40,571,'en',0,'<p>What\'s New</p>','full_html'),('ept_hero',0,40,574,'en',0,'<p>What\'s New</p>','full_html'),('ept_hero',0,40,577,'en',0,'<h1>What\'s New</h1>','full_html'),('ept_hero',0,40,580,'en',0,'<h1>What\'s New</h1>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_video`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_video`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_video_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_video_target_id` (`field_ept_video_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_video`
--

LOCK TABLES `paragraph_revision__field_ept_video` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_video` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_video` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_videos_and_images`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_videos_and_images`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_videos_and_images` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_videos_and_images_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_videos_and_images_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_videos_and_images_target_id` (`field_ept_videos_and_images_target_id`),
  KEY `field_ept_videos_and_images_target_revision_id` (`field_ept_videos_and_images_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_videos_and_images`
--

LOCK TABLES `paragraph_revision__field_ept_videos_and_images` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_videos_and_images` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_videos_and_images` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_views_view`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_views_view`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_views_view` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_views_view_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_views_view_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ept_views_view_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_views_view_target_id` (`field_ept_views_view_target_id`),
  KEY `field_ept_views_view_display_id` (`field_ept_views_view_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_views_view`
--

LOCK TABLES `paragraph_revision__field_ept_views_view` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_views_view` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_views_view` VALUES ('ept_views',0,38,568,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}'),('ept_views',0,38,570,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}'),('ept_views',0,38,573,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}'),('ept_views',0,38,576,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}'),('ept_views',0,38,579,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}'),('ept_views',0,38,582,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_views_view` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_webform_form`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_webform_form`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_webform_form` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_webform_form_target_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the webform entity.',
  `field_ept_webform_form_default_data` text COMMENT 'Default submission data.',
  `field_ept_webform_form_status` varchar(20) DEFAULT NULL COMMENT 'Flag to control whether this webform should be open, closed, or scheduled for new submissions.',
  `field_ept_webform_form_open` varchar(20) DEFAULT NULL COMMENT 'The open date/time.',
  `field_ept_webform_form_close` varchar(20) DEFAULT NULL COMMENT 'The close date/time.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_webform_form_target_id` (`field_ept_webform_form_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_webform_form`
--

LOCK TABLES `paragraph_revision__field_ept_webform_form` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_webform_form` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_webform_form` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_webform_popup_form`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_webform_popup_form`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_webform_popup_form` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_webform_popup_form_target_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the webform entity.',
  `field_ept_webform_popup_form_default_data` text COMMENT 'Default submission data.',
  `field_ept_webform_popup_form_status` varchar(20) DEFAULT NULL COMMENT 'Flag to control whether this webform should be open, closed, or scheduled for new submissions.',
  `field_ept_webform_popup_form_open` varchar(20) DEFAULT NULL COMMENT 'The open date/time.',
  `field_ept_webform_popup_form_close` varchar(20) DEFAULT NULL COMMENT 'The close date/time.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_webform_popup_form_target_id` (`field_ept_webform_popup_form_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_webform_popup_form`
--

LOCK TABLES `paragraph_revision__field_ept_webform_popup_form` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_webform_popup_form` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_webform_popup_form` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraphs_item`
--

DROP TABLE IF EXISTS `paragraphs_item`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraphs_item` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `paragraph_field__uuid__value` (`uuid`),
  UNIQUE KEY `paragraph__revision_id` (`revision_id`),
  KEY `paragraph_field__type__target_id` (`type`)
) ENGINE=InnoDB AUTO_INCREMENT=41 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for paragraph entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraphs_item`
--

LOCK TABLES `paragraphs_item` WRITE;
/*!40000 ALTER TABLE `paragraphs_item` DISABLE KEYS */;
INSERT INTO `paragraphs_item` VALUES (1,531,'ept_hero','088e8f36-aa92-4779-a6f3-20855a3bee73','en'),(2,532,'ept_text','be1571de-b029-444e-be82-de9318b229ad','en'),(3,533,'ept_tiles_item','34bcf35b-46b1-40fe-945d-8fb70d8699b6','en'),(4,534,'ept_tiles_item','ca1814e1-24d2-4312-87ce-300646c90af5','en'),(5,535,'ept_tiles_item','41b512ea-5da1-4d79-8932-848dd65fbede','en'),(6,536,'ept_tiles','f427a33f-64f8-4506-99c7-a8605b1df563','en'),(7,537,'ept_stats_item','26311542-79cb-4dbd-afae-5eaaa37c8c3e','en'),(8,538,'ept_stats_item','13a0b97c-311e-4742-821b-d4d27041731f','en'),(9,539,'ept_stats','926f3603-0a5c-4fc3-9d32-eddfeb355833','en'),(10,540,'ept_image_gallery','c2140955-0941-4cea-a839-676831aacf2d','en'),(11,541,'ept_cta','df2b4021-56a6-496c-a770-df39af537eee','en'),(12,546,'ept_quote','7926a1d4-73de-4662-af2c-f956f44efc2a','en'),(13,547,'ept_carousel_item','28a6aa54-d81c-41d1-8295-fe11ca28099a','en'),(14,548,'ept_carousel_item','a4eac7aa-822e-4fa3-9455-c1bb581a624f','en'),(15,549,'ept_carousel_item','d1b58918-ffa2-4bce-bfbc-c9deb44b5867','en'),(16,550,'ept_carousel_item','468f6ab7-7312-46ae-bcf6-ef603e838f68','en'),(17,551,'ept_carousel_item','8b37f259-e19c-4f81-822b-4ab3f83ede48','en'),(18,552,'ept_carousel_item','b4ee429d-8ae5-494d-8349-f1d7bc895fac','en'),(19,553,'ept_carousel_item','e1a17a42-8975-45f0-ad79-d1e16708218e','en'),(20,554,'ept_carousel_item','290eb5f2-3408-46ba-9d87-618c1395cd44','en'),(21,555,'ept_carousel_item','7e05ae91-dba8-4b5b-8a2e-3bf8b09bf8cf','en'),(22,556,'ept_carousel_item','eeac7ad1-b0a3-4898-a4e2-4e0aadfa2e09','en'),(23,557,'ept_carousel','9d2e5c79-3f95-4416-adba-4ad4ae7683d3','en'),(24,558,'ept_counter_item','b7e52e90-6342-4ad9-9dc2-55f13a47c86b','en'),(25,559,'ept_counter_item','ce5d0752-e11c-4fcb-9b52-46d8c45b4a74','en'),(26,560,'ept_counter','face81f9-5400-406b-a64c-0c7717518193','en'),(27,542,'ept_slideshow_item','99c07029-1a55-4c8b-9253-35a63ab6dfb4','en'),(28,543,'ept_slideshow_item','3c06beb1-0396-43fd-9447-84df05591b3f','en'),(29,544,'ept_slideshow_item','73569f80-2633-4a12-9cfb-720de0540f8c','en'),(30,545,'ept_slideshow','ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b','en'),(31,561,'ept_tabs_item','03e1362a-b7df-4469-b71d-5195bdeb4904','en'),(32,562,'ept_tabs_item','3747fc91-691d-4dac-a4df-e51cf0a0d5a1','en'),(33,563,'ept_tabs','bc10cacf-328a-491e-9ba0-4d72f49bdd4c','en'),(34,565,'ept_accordion_section','37923327-88d4-4fe3-84e9-3d4b9eef2c3e','en'),(35,566,'ept_accordion_section','05578525-caa1-4526-aa56-56d6d3e9b6fc','en'),(36,567,'ept_accordion','c1d65509-37e9-4ef2-9c23-fbd78fe17204','en'),(37,564,'ept_accordion_section','c2fdfa00-3d9e-4e59-89a0-05f5ebf0ed9a','en'),(38,582,'ept_views','27496e1b-7e55-4ef1-a324-6a0afdd5dce4','en'),(39,581,'ept_block','6e8df8b3-0097-4c28-a044-a1ffc40d37ea','en'),(40,580,'ept_hero','93872b1e-0586-4e38-b8a5-5edca3c418e7','en');
/*!40000 ALTER TABLE `paragraphs_item` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraphs_item_field_data`
--

DROP TABLE IF EXISTS `paragraphs_item_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraphs_item_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `parent_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `behavior_settings` longtext,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `paragraph__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `paragraph__revision_id` (`revision_id`),
  KEY `paragraph_field__type__target_id` (`type`),
  KEY `paragraph__status_type` (`status`,`type`,`id`),
  KEY `paragraphs__parent_fields` (`parent_type`,`parent_id`,`parent_field_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for paragraph entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraphs_item_field_data`
--

LOCK TABLES `paragraphs_item_field_data` WRITE;
/*!40000 ALTER TABLE `paragraphs_item_field_data` DISABLE KEYS */;
INSERT INTO `paragraphs_item_field_data` VALUES (1,531,'ept_hero','en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,532,'ept_text','en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,533,'ept_tiles_item','en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,534,'ept_tiles_item','en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,535,'ept_tiles_item','en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,536,'ept_tiles','en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,537,'ept_stats_item','en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,538,'ept_stats_item','en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,539,'ept_stats','en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,540,'ept_image_gallery','en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,541,'ept_cta','en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,546,'ept_quote','en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,547,'ept_carousel_item','en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,548,'ept_carousel_item','en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,549,'ept_carousel_item','en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,550,'ept_carousel_item','en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,551,'ept_carousel_item','en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,552,'ept_carousel_item','en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,553,'ept_carousel_item','en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,554,'ept_carousel_item','en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,555,'ept_carousel_item','en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,556,'ept_carousel_item','en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,557,'ept_carousel','en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,558,'ept_counter_item','en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,559,'ept_counter_item','en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,560,'ept_counter','en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,542,'ept_slideshow_item','en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,543,'ept_slideshow_item','en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,544,'ept_slideshow_item','en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,545,'ept_slideshow','en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,561,'ept_tabs_item','en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,562,'ept_tabs_item','en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,563,'ept_tabs','en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(34,565,'ept_accordion_section','en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,NULL),(35,566,'ept_accordion_section','en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,NULL),(36,567,'ept_accordion','en',1,1729022156,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(37,564,'ept_accordion_section','en',1,1729024475,'36','paragraph','field_ept_accordion','a:0:{}',1,1),(38,582,'ept_views','en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(39,581,'ept_block','en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(40,580,'ept_hero','en',1,1729066868,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL);
/*!40000 ALTER TABLE `paragraphs_item_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraphs_item_revision`
--

DROP TABLE IF EXISTS `paragraphs_item_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraphs_item_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `paragraph__id` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=583 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for paragraph entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraphs_item_revision`
--

LOCK TABLES `paragraphs_item_revision` WRITE;
/*!40000 ALTER TABLE `paragraphs_item_revision` DISABLE KEYS */;
INSERT INTO `paragraphs_item_revision` VALUES (1,1,'en',1),(1,2,'en',1),(1,3,'en',1),(1,4,'en',1),(1,5,'en',1),(1,6,'en',1),(1,7,'en',1),(1,8,'en',1),(1,9,'en',1),(2,10,'en',1),(1,11,'en',1),(2,12,'en',1),(1,13,'en',1),(2,14,'en',1),(1,15,'en',1),(2,16,'en',1),(1,17,'en',1),(2,18,'en',1),(3,19,'en',1),(4,20,'en',1),(5,21,'en',1),(6,22,'en',1),(1,23,'en',1),(2,24,'en',1),(3,25,'en',1),(4,26,'en',1),(5,27,'en',1),(6,28,'en',1),(1,29,'en',1),(2,30,'en',1),(3,31,'en',1),(4,32,'en',1),(5,33,'en',1),(6,34,'en',1),(1,35,'en',1),(2,36,'en',1),(3,37,'en',1),(4,38,'en',1),(5,39,'en',1),(6,40,'en',1),(1,41,'en',1),(2,42,'en',1),(3,43,'en',1),(4,44,'en',1),(5,45,'en',1),(6,46,'en',1),(1,47,'en',1),(2,48,'en',1),(3,49,'en',1),(4,50,'en',1),(5,51,'en',1),(6,52,'en',1),(1,53,'en',1),(2,54,'en',1),(3,55,'en',1),(4,56,'en',1),(5,57,'en',1),(6,58,'en',1),(1,59,'en',1),(2,60,'en',1),(3,61,'en',1),(4,62,'en',1),(5,63,'en',1),(6,64,'en',1),(1,65,'en',1),(2,66,'en',1),(3,67,'en',1),(4,68,'en',1),(5,69,'en',1),(6,70,'en',1),(7,71,'en',1),(8,72,'en',1),(9,73,'en',1),(1,74,'en',1),(2,75,'en',1),(3,76,'en',1),(4,77,'en',1),(5,78,'en',1),(6,79,'en',1),(7,80,'en',1),(8,81,'en',1),(9,82,'en',1),(1,83,'en',1),(2,84,'en',1),(3,85,'en',1),(4,86,'en',1),(5,87,'en',1),(6,88,'en',1),(7,89,'en',1),(8,90,'en',1),(9,91,'en',1),(1,92,'en',1),(2,93,'en',1),(3,94,'en',1),(4,95,'en',1),(5,96,'en',1),(6,97,'en',1),(7,98,'en',1),(8,99,'en',1),(9,100,'en',1),(10,101,'en',1),(1,102,'en',1),(2,103,'en',1),(3,104,'en',1),(4,105,'en',1),(5,106,'en',1),(6,107,'en',1),(7,108,'en',1),(8,109,'en',1),(9,110,'en',1),(10,111,'en',1),(1,112,'en',1),(2,113,'en',1),(3,114,'en',1),(4,115,'en',1),(5,116,'en',1),(6,117,'en',1),(7,118,'en',1),(8,119,'en',1),(9,120,'en',1),(10,121,'en',1),(1,122,'en',1),(2,123,'en',1),(3,124,'en',1),(4,125,'en',1),(5,126,'en',1),(6,127,'en',1),(7,128,'en',1),(8,129,'en',1),(9,130,'en',1),(10,131,'en',1),(1,132,'en',1),(2,133,'en',1),(3,134,'en',1),(4,135,'en',1),(5,136,'en',1),(6,137,'en',1),(7,138,'en',1),(8,139,'en',1),(9,140,'en',1),(10,141,'en',1),(1,142,'en',1),(2,143,'en',1),(3,144,'en',1),(4,145,'en',1),(5,146,'en',1),(6,147,'en',1),(7,148,'en',1),(8,149,'en',1),(9,150,'en',1),(10,151,'en',1),(1,152,'en',1),(2,153,'en',1),(3,154,'en',1),(4,155,'en',1),(5,156,'en',1),(6,157,'en',1),(7,158,'en',1),(8,159,'en',1),(9,160,'en',1),(10,161,'en',1),(11,162,'en',1),(1,163,'en',1),(2,164,'en',1),(3,165,'en',1),(4,166,'en',1),(5,167,'en',1),(6,168,'en',1),(7,169,'en',1),(8,170,'en',1),(9,171,'en',1),(10,172,'en',1),(11,173,'en',1),(1,174,'en',1),(2,175,'en',1),(3,176,'en',1),(4,177,'en',1),(5,178,'en',1),(6,179,'en',1),(7,180,'en',1),(8,181,'en',1),(9,182,'en',1),(10,183,'en',1),(11,184,'en',1),(12,185,'en',1),(1,186,'en',1),(2,187,'en',1),(3,188,'en',1),(4,189,'en',1),(5,190,'en',1),(6,191,'en',1),(7,192,'en',1),(8,193,'en',1),(9,194,'en',1),(10,195,'en',1),(11,196,'en',1),(12,197,'en',1),(1,198,'en',1),(2,199,'en',1),(3,200,'en',1),(4,201,'en',1),(5,202,'en',1),(6,203,'en',1),(7,204,'en',1),(8,205,'en',1),(9,206,'en',1),(10,207,'en',1),(11,208,'en',1),(12,209,'en',1),(13,210,'en',1),(14,211,'en',1),(15,212,'en',1),(16,213,'en',1),(17,214,'en',1),(18,215,'en',1),(19,216,'en',1),(20,217,'en',1),(21,218,'en',1),(22,219,'en',1),(23,220,'en',1),(1,221,'en',1),(2,222,'en',1),(3,223,'en',1),(4,224,'en',1),(5,225,'en',1),(6,226,'en',1),(7,227,'en',1),(8,228,'en',1),(9,229,'en',1),(10,230,'en',1),(11,231,'en',1),(12,232,'en',1),(13,233,'en',1),(14,234,'en',1),(15,235,'en',1),(16,236,'en',1),(17,237,'en',1),(18,238,'en',1),(19,239,'en',1),(20,240,'en',1),(21,241,'en',1),(22,242,'en',1),(23,243,'en',1),(1,244,'en',1),(2,245,'en',1),(3,246,'en',1),(4,247,'en',1),(5,248,'en',1),(6,249,'en',1),(7,250,'en',1),(8,251,'en',1),(9,252,'en',1),(10,253,'en',1),(11,254,'en',1),(12,255,'en',1),(13,256,'en',1),(14,257,'en',1),(15,258,'en',1),(16,259,'en',1),(17,260,'en',1),(18,261,'en',1),(19,262,'en',1),(20,263,'en',1),(21,264,'en',1),(22,265,'en',1),(23,266,'en',1),(24,267,'en',1),(25,268,'en',1),(26,269,'en',1),(1,270,'en',1),(2,271,'en',1),(3,272,'en',1),(4,273,'en',1),(5,274,'en',1),(6,275,'en',1),(7,276,'en',1),(8,277,'en',1),(9,278,'en',1),(10,279,'en',1),(11,280,'en',1),(27,281,'en',1),(28,282,'en',1),(29,283,'en',1),(30,284,'en',1),(12,285,'en',1),(13,286,'en',1),(14,287,'en',1),(15,288,'en',1),(16,289,'en',1),(17,290,'en',1),(18,291,'en',1),(19,292,'en',1),(20,293,'en',1),(21,294,'en',1),(22,295,'en',1),(23,296,'en',1),(24,297,'en',1),(25,298,'en',1),(26,299,'en',1),(1,300,'en',1),(2,301,'en',1),(3,302,'en',1),(4,303,'en',1),(5,304,'en',1),(6,305,'en',1),(7,306,'en',1),(8,307,'en',1),(9,308,'en',1),(10,309,'en',1),(11,310,'en',1),(27,311,'en',1),(28,312,'en',1),(29,313,'en',1),(30,314,'en',1),(12,315,'en',1),(13,316,'en',1),(14,317,'en',1),(15,318,'en',1),(16,319,'en',1),(17,320,'en',1),(18,321,'en',1),(19,322,'en',1),(20,323,'en',1),(21,324,'en',1),(22,325,'en',1),(23,326,'en',1),(24,327,'en',1),(25,328,'en',1),(26,329,'en',1),(1,330,'en',1),(2,331,'en',1),(3,332,'en',1),(4,333,'en',1),(5,334,'en',1),(6,335,'en',1),(7,336,'en',1),(8,337,'en',1),(9,338,'en',1),(10,339,'en',1),(11,340,'en',1),(27,341,'en',1),(28,342,'en',1),(29,343,'en',1),(30,344,'en',1),(12,345,'en',1),(13,346,'en',1),(14,347,'en',1),(15,348,'en',1),(16,349,'en',1),(17,350,'en',1),(18,351,'en',1),(19,352,'en',1),(20,353,'en',1),(21,354,'en',1),(22,355,'en',1),(23,356,'en',1),(24,357,'en',1),(25,358,'en',1),(26,359,'en',1),(1,360,'en',1),(2,361,'en',1),(3,362,'en',1),(4,363,'en',1),(5,364,'en',1),(6,365,'en',1),(7,366,'en',1),(8,367,'en',1),(9,368,'en',1),(10,369,'en',1),(11,370,'en',1),(27,371,'en',1),(28,372,'en',1),(29,373,'en',1),(30,374,'en',1),(12,375,'en',1),(13,376,'en',1),(14,377,'en',1),(15,378,'en',1),(16,379,'en',1),(17,380,'en',1),(18,381,'en',1),(19,382,'en',1),(20,383,'en',1),(21,384,'en',1),(22,385,'en',1),(23,386,'en',1),(24,387,'en',1),(25,388,'en',1),(26,389,'en',1),(31,390,'en',1),(32,391,'en',1),(33,392,'en',1),(1,393,'en',1),(2,394,'en',1),(3,395,'en',1),(4,396,'en',1),(5,397,'en',1),(6,398,'en',1),(7,399,'en',1),(8,400,'en',1),(9,401,'en',1),(10,402,'en',1),(11,403,'en',1),(27,404,'en',1),(28,405,'en',1),(29,406,'en',1),(30,407,'en',1),(12,408,'en',1),(13,409,'en',1),(14,410,'en',1),(15,411,'en',1),(16,412,'en',1),(17,413,'en',1),(18,414,'en',1),(19,415,'en',1),(20,416,'en',1),(21,417,'en',1),(22,418,'en',1),(23,419,'en',1),(24,420,'en',1),(25,421,'en',1),(26,422,'en',1),(31,423,'en',1),(32,424,'en',1),(33,425,'en',1),(1,426,'en',1),(2,427,'en',1),(3,428,'en',1),(4,429,'en',1),(5,430,'en',1),(6,431,'en',1),(7,432,'en',1),(8,433,'en',1),(9,434,'en',1),(10,435,'en',1),(11,436,'en',1),(27,437,'en',1),(28,438,'en',1),(29,439,'en',1),(30,440,'en',1),(12,441,'en',1),(13,442,'en',1),(14,443,'en',1),(15,444,'en',1),(16,445,'en',1),(17,446,'en',1),(18,447,'en',1),(19,448,'en',1),(20,449,'en',1),(21,450,'en',1),(22,451,'en',1),(23,452,'en',1),(24,453,'en',1),(25,454,'en',1),(26,455,'en',1),(31,456,'en',1),(32,457,'en',1),(33,458,'en',1),(1,459,'en',1),(2,460,'en',1),(3,461,'en',1),(4,462,'en',1),(5,463,'en',1),(6,464,'en',1),(7,465,'en',1),(8,466,'en',1),(9,467,'en',1),(10,468,'en',1),(11,469,'en',1),(27,470,'en',1),(28,471,'en',1),(29,472,'en',1),(30,473,'en',1),(12,474,'en',1),(13,475,'en',1),(14,476,'en',1),(15,477,'en',1),(16,478,'en',1),(17,479,'en',1),(18,480,'en',1),(19,481,'en',1),(20,482,'en',1),(21,483,'en',1),(22,484,'en',1),(23,485,'en',1),(24,486,'en',1),(25,487,'en',1),(26,488,'en',1),(31,489,'en',1),(32,490,'en',1),(33,491,'en',1),(34,492,'en',1),(35,493,'en',1),(36,494,'en',1),(1,495,'en',1),(2,496,'en',1),(3,497,'en',1),(4,498,'en',1),(5,499,'en',1),(6,500,'en',1),(7,501,'en',1),(8,502,'en',1),(9,503,'en',1),(10,504,'en',1),(11,505,'en',1),(27,506,'en',1),(28,507,'en',1),(29,508,'en',1),(30,509,'en',1),(12,510,'en',1),(13,511,'en',1),(14,512,'en',1),(15,513,'en',1),(16,514,'en',1),(17,515,'en',1),(18,516,'en',1),(19,517,'en',1),(20,518,'en',1),(21,519,'en',1),(22,520,'en',1),(23,521,'en',1),(24,522,'en',1),(25,523,'en',1),(26,524,'en',1),(31,525,'en',1),(32,526,'en',1),(33,527,'en',1),(34,528,'en',1),(35,529,'en',1),(36,530,'en',1),(1,531,'en',1),(2,532,'en',1),(3,533,'en',1),(4,534,'en',1),(5,535,'en',1),(6,536,'en',1),(7,537,'en',1),(8,538,'en',1),(9,539,'en',1),(10,540,'en',1),(11,541,'en',1),(27,542,'en',1),(28,543,'en',1),(29,544,'en',1),(30,545,'en',1),(12,546,'en',1),(13,547,'en',1),(14,548,'en',1),(15,549,'en',1),(16,550,'en',1),(17,551,'en',1),(18,552,'en',1),(19,553,'en',1),(20,554,'en',1),(21,555,'en',1),(22,556,'en',1),(23,557,'en',1),(24,558,'en',1),(25,559,'en',1),(26,560,'en',1),(31,561,'en',1),(32,562,'en',1),(33,563,'en',1),(37,564,'en',1),(34,565,'en',1),(35,566,'en',1),(36,567,'en',1),(38,568,'en',1),(39,569,'en',1),(38,570,'en',1),(40,571,'en',1),(39,572,'en',1),(38,573,'en',1),(40,574,'en',1),(39,575,'en',1),(38,576,'en',1),(40,577,'en',1),(39,578,'en',1),(38,579,'en',1),(40,580,'en',1),(39,581,'en',1),(38,582,'en',1);
/*!40000 ALTER TABLE `paragraphs_item_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraphs_item_revision_field_data`
--

DROP TABLE IF EXISTS `paragraphs_item_revision_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraphs_item_revision_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `parent_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `behavior_settings` longtext,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `paragraph__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `paragraphs__parent_fields` (`parent_type`,`parent_id`,`parent_field_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for paragraph entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraphs_item_revision_field_data`
--

LOCK TABLES `paragraphs_item_revision_field_data` WRITE;
/*!40000 ALTER TABLE `paragraphs_item_revision_field_data` DISABLE KEYS */;
INSERT INTO `paragraphs_item_revision_field_data` VALUES (1,1,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,2,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,3,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,4,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,5,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,6,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,7,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,8,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,9,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(2,10,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,11,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,12,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,13,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(2,14,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,15,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(2,16,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,17,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,18,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,19,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,1),(4,20,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,1),(5,21,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,1),(6,22,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,23,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,24,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,25,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,26,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,27,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,28,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,29,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,30,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,31,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,32,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,33,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,34,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,35,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,36,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,37,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,38,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,39,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,40,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,41,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,42,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,43,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,44,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,45,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,46,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,47,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,48,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,49,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,50,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,51,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,52,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,53,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,54,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,55,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,56,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,57,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,58,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,59,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,60,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,61,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,62,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,63,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,64,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,65,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,66,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,67,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,68,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,69,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,70,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,71,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,1),(8,72,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,1),(9,73,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,74,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,75,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,76,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,77,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,78,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,79,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,80,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,81,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,82,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,83,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,84,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,85,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,86,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,87,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,88,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,89,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,1),(8,90,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,1),(9,91,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,92,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,93,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,94,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,95,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,96,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,97,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,98,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,99,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,100,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,101,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,102,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,103,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,104,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,105,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,106,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,107,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,108,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,109,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,110,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,111,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,112,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,113,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,114,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,115,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,116,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,117,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,118,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,119,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,120,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,121,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,122,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,123,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,124,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,125,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,126,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,127,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(7,128,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,129,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,130,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,131,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,132,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,133,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,134,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,135,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,136,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,137,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,138,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,139,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,140,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,141,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,142,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,143,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,144,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,145,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,146,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,147,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,148,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,149,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,150,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,151,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,152,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,153,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,154,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,155,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,156,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,157,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,158,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,159,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,160,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,161,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,162,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,163,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,164,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,165,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,166,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,167,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,168,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,169,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,170,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,171,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,172,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,173,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,174,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,175,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,176,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,177,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,178,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,179,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,180,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,181,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,182,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,183,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,184,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,185,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,186,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,187,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,188,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,189,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,190,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,191,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,192,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,193,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,194,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,195,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,196,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,197,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,198,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,199,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,200,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,201,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,202,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,203,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,204,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,205,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,206,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,207,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,208,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,209,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,210,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(14,211,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(15,212,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(16,213,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(17,214,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(18,215,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(19,216,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(20,217,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(21,218,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(22,219,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(23,220,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,221,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,222,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,223,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,224,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,225,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,226,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,227,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,228,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,229,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,230,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,231,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,232,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,233,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,234,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,235,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,236,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,237,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,238,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,239,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,240,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,241,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,242,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,243,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,244,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,245,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,246,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,247,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,248,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,249,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,250,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,251,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,252,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,253,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,254,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,255,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,256,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,257,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,258,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,259,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,260,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,261,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,262,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,263,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,264,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,265,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,266,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,267,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,1),(25,268,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,1),(26,269,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,270,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,271,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,272,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,273,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,274,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,275,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,276,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,277,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,278,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,279,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,280,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,281,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,1),(28,282,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,1),(29,283,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,1),(30,284,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(12,285,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,286,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,287,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,288,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,289,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,290,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,291,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,292,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,293,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,294,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,295,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,296,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,297,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,298,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,299,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,300,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,301,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,302,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,303,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,304,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,305,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,306,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,307,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,308,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,309,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,310,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,311,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,312,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,313,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,314,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(12,315,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,316,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,317,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,318,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,319,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,320,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,321,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,322,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,323,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,324,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,325,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,326,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,327,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,328,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,329,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,330,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,331,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,332,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,333,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,334,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,335,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,336,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,337,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,338,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,339,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,340,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,341,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,342,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,343,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,344,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(12,345,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,346,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,347,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,348,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,349,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,350,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,351,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,352,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,353,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,354,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,355,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,356,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,357,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,358,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,359,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,360,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,361,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,362,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,363,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,364,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,365,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,366,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,367,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,368,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,369,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,370,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,371,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,372,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,373,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,374,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,375,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,376,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,377,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,378,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,379,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,380,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,381,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,382,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,383,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,384,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,385,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,386,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,387,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,388,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,389,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,390,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,1),(32,391,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,1),(33,392,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,393,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,394,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,395,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,396,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,397,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,398,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,399,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,400,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,401,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,402,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,403,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,404,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,405,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,406,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,407,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,408,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,409,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,410,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,411,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,412,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,413,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,414,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,415,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,416,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,417,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,418,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,419,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,420,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,421,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,422,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,423,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,424,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,425,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,426,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,427,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,428,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,429,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,430,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,431,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,432,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,433,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,434,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,435,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,436,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,437,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,438,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,439,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,440,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,441,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,442,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,443,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,444,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,445,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,446,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,447,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,448,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,449,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,450,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,451,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,452,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,453,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,454,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,455,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,456,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,457,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,458,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,459,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,460,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,461,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,462,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,463,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,464,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,465,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,466,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,467,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,468,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,469,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,470,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,471,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,472,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,473,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,474,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,475,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,476,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,477,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,478,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,479,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,480,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,481,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,482,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,483,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,484,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,485,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,486,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,487,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,488,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,489,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,490,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,491,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(34,492,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,1),(35,493,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,1),(36,494,'en',1,1729022156,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,495,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,496,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,497,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,498,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,499,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,500,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,501,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,502,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,503,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,504,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,505,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,506,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,507,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,508,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,509,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,510,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,511,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,512,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,513,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,514,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,515,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,516,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,517,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,518,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,519,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,520,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,521,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,522,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,523,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,524,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,525,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,526,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,527,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(34,528,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,NULL),(35,529,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,1),(36,530,'en',1,1729022156,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,531,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,532,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,533,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,534,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,535,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,536,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,537,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,538,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,539,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,540,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,541,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,542,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,543,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,544,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,545,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,546,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,547,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,548,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,549,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,550,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,551,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,552,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,553,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,554,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,555,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,556,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,557,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,558,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,559,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,560,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,561,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,562,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,563,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(37,564,'en',1,1729024475,'36','paragraph','field_ept_accordion','a:0:{}',1,1),(34,565,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,NULL),(35,566,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,NULL),(36,567,'en',1,1729022156,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(38,568,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(39,569,'en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(38,570,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(40,571,'en',1,1729066868,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(39,572,'en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(38,573,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(40,574,'en',1,1729066868,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(39,575,'en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(38,576,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(40,577,'en',1,1729066868,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(39,578,'en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(38,579,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(40,580,'en',1,1729066868,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(39,581,'en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(38,582,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL);
/*!40000 ALTER TABLE `paragraphs_item_revision_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `path_alias`
--

DROP TABLE IF EXISTS `path_alias`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `path_alias` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` varchar(255) DEFAULT NULL,
  `alias` varchar(255) DEFAULT NULL,
  `status` tinyint NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `path_alias_field__uuid__value` (`uuid`),
  UNIQUE KEY `path_alias__revision_id` (`revision_id`),
  KEY `path_alias__alias_langcode_id_status` (`alias`(191),`langcode`,`id`,`status`),
  KEY `path_alias__path_langcode_id_status` (`path`(191),`langcode`,`id`,`status`)
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for path_alias entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `path_alias`
--

LOCK TABLES `path_alias` WRITE;
/*!40000 ALTER TABLE `path_alias` DISABLE KEYS */;
INSERT INTO `path_alias` VALUES (1,1,'88aa9d05-9cea-4b1c-a0a8-c3feb0fe14d0','en','/node/19','/whats-new',1),(2,2,'6ab4330c-fbec-4313-964d-0ef124a1fe01','en','/webform/contact','/form/contact',1),(3,3,'2a952dd5-32d0-4e55-8666-ff02abc91c34','und','/webform/contact','/form/contact',1),(4,4,'cc28f0ab-3131-4dbc-8cbf-ddddcd4d8784','en','/webform/contact/confirmation','/form/contact/confirmation',1),(5,5,'108c2392-d93c-46e0-9a14-070babe1cc1d','und','/webform/contact/confirmation','/form/contact/confirmation',1),(6,6,'50e0f3b0-2731-4445-bf16-f2787e65046c','en','/webform/contact/submissions','/form/contact/submissions',1),(7,7,'dbdf89b9-c1c7-41dc-bb9c-7d5bf8c25b55','und','/webform/contact/submissions','/form/contact/submissions',1),(8,8,'d000da72-7c96-4a08-8d56-4f9dfa4f82ff','en','/webform/contact/drafts','/form/contact/drafts',1),(9,9,'2f95460a-012d-4fad-b9cc-082a4c06c4a2','und','/webform/contact/drafts','/form/contact/drafts',1);
/*!40000 ALTER TABLE `path_alias` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `path_alias_revision`
--

DROP TABLE IF EXISTS `path_alias_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `path_alias_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` varchar(255) DEFAULT NULL,
  `alias` varchar(255) DEFAULT NULL,
  `status` tinyint NOT NULL,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `path_alias__id` (`id`),
  KEY `path_alias_revision__alias_langcode_id_status` (`alias`(191),`langcode`,`id`,`status`),
  KEY `path_alias_revision__path_langcode_id_status` (`path`(191),`langcode`,`id`,`status`)
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for path_alias entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `path_alias_revision`
--

LOCK TABLES `path_alias_revision` WRITE;
/*!40000 ALTER TABLE `path_alias_revision` DISABLE KEYS */;
INSERT INTO `path_alias_revision` VALUES (1,1,'en','/node/19','/whats-new',1,1),(2,2,'en','/webform/contact','/form/contact',1,1),(3,3,'und','/webform/contact','/form/contact',1,1),(4,4,'en','/webform/contact/confirmation','/form/contact/confirmation',1,1),(5,5,'und','/webform/contact/confirmation','/form/contact/confirmation',1,1),(6,6,'en','/webform/contact/submissions','/form/contact/submissions',1,1),(7,7,'und','/webform/contact/submissions','/form/contact/submissions',1,1),(8,8,'en','/webform/contact/drafts','/form/contact/drafts',1,1),(9,9,'und','/webform/contact/drafts','/form/contact/drafts',1,1);
/*!40000 ALTER TABLE `path_alias_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `queue`
--

DROP TABLE IF EXISTS `queue`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `queue` (
  `item_id` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique item ID.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The queue name.',
  `data` longblob COMMENT 'The arbitrary data for the item.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp when the claim lease expires on the item.',
  `created` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp when the item was created.',
  PRIMARY KEY (`item_id`),
  KEY `name_created` (`name`,`created`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB AUTO_INCREMENT=592 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores items in queues.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `queue`
--

LOCK TABLES `queue` WRITE;
/*!40000 ALTER TABLE `queue` DISABLE KEYS */;
INSERT INTO `queue` VALUES (576,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:6:\"drupal\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Announcements\";s:7:\"version\";s:6:\"11.1.0\";s:7:\"package\";s:4:\"Core\";s:7:\"project\";s:6:\"drupal\";s:16:\"_info_file_ctime\";i:1735498473;s:9:\"datestamp\";i:0;}s:9:\"datestamp\";i:0;s:8:\"includes\";a:43:{s:18:\"announcements_feed\";s:13:\"Announcements\";s:14:\"automated_cron\";s:14:\"Automated Cron\";s:8:\"big_pipe\";s:7:\"BigPipe\";s:5:\"block\";s:5:\"Block\";s:13:\"block_content\";s:13:\"Block Content\";s:10:\"breakpoint\";s:10:\"Breakpoint\";s:9:\"ckeditor5\";s:10:\"CKEditor 5\";s:7:\"comment\";s:7:\"Comment\";s:6:\"config\";s:21:\"Configuration Manager\";s:7:\"contact\";s:7:\"Contact\";s:10:\"contextual\";s:16:\"Contextual Links\";s:8:\"datetime\";s:8:\"Datetime\";s:5:\"dblog\";s:16:\"Database Logging\";s:18:\"dynamic_page_cache\";s:27:\"Internal Dynamic Page Cache\";s:6:\"editor\";s:11:\"Text Editor\";s:5:\"field\";s:5:\"Field\";s:8:\"field_ui\";s:8:\"Field UI\";s:4:\"file\";s:4:\"File\";s:6:\"filter\";s:6:\"Filter\";s:4:\"help\";s:4:\"Help\";s:7:\"history\";s:7:\"History\";s:5:\"image\";s:5:\"Image\";s:16:\"layout_discovery\";s:16:\"Layout Discovery\";s:4:\"link\";s:4:\"Link\";s:5:\"media\";s:5:\"Media\";s:13:\"media_library\";s:13:\"Media Library\";s:17:\"menu_link_content\";s:17:\"Custom Menu Links\";s:7:\"menu_ui\";s:7:\"Menu UI\";s:4:\"node\";s:4:\"Node\";s:7:\"options\";s:7:\"Options\";s:10:\"page_cache\";s:19:\"Internal Page Cache\";s:4:\"path\";s:4:\"Path\";s:10:\"path_alias\";s:10:\"Path alias\";s:6:\"search\";s:6:\"Search\";s:8:\"shortcut\";s:8:\"Shortcut\";s:6:\"system\";s:6:\"System\";s:8:\"taxonomy\";s:8:\"Taxonomy\";s:4:\"text\";s:4:\"Text\";s:7:\"toolbar\";s:7:\"Toolbar\";s:6:\"update\";s:14:\"Update Manager\";s:4:\"user\";s:4:\"User\";s:5:\"views\";s:5:\"Views\";s:8:\"views_ui\";s:8:\"Views UI\";}s:12:\"project_type\";s:4:\"core\";s:14:\"project_status\";b:1;}',0,1735499397),(577,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:13:\"admin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Admin Toolbar\";s:7:\"package\";s:14:\"Administration\";s:7:\"version\";s:5:\"3.5.1\";s:7:\"project\";s:13:\"admin_toolbar\";s:9:\"datestamp\";i:1730409975;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1730409975;s:8:\"includes\";a:2:{s:13:\"admin_toolbar\";s:13:\"Admin Toolbar\";s:19:\"admin_toolbar_tools\";s:25:\"Admin Toolbar Extra Tools\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(578,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.2.4\";s:7:\"project\";s:21:\"ckeditor5_plugin_pack\";s:9:\"datestamp\";i:1734514951;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734514951;s:8:\"includes\";a:12:{s:21:\"ckeditor5_plugin_pack\";s:22:\"CKEditor 5 Plugin Pack\";s:32:\"ckeditor5_plugin_pack_auto_image\";s:21:\"CKEditor 5 Auto Image\";s:38:\"ckeditor5_plugin_pack_find_and_replace\";s:27:\"CKEditor 5 Find And Replace\";s:26:\"ckeditor5_plugin_pack_font\";s:23:\"CKEditor 5 Font Plugins\";s:31:\"ckeditor5_plugin_pack_highlight\";s:20:\"CKEditor 5 Highlight\";s:34:\"ckeditor5_plugin_pack_indent_block\";s:28:\"CKEditor 5 Block Indentation\";s:37:\"ckeditor5_plugin_pack_link_attributes\";s:26:\"CKEditor 5 Link Attributes\";s:32:\"ckeditor5_plugin_pack_page_break\";s:21:\"CKEditor 5 Page Break\";s:32:\"ckeditor5_plugin_pack_select_all\";s:21:\"CKEditor 5 Select All\";s:31:\"ckeditor5_plugin_pack_templates\";s:20:\"CKEditor 5 Templates\";s:41:\"ckeditor5_plugin_pack_text_transformation\";s:30:\"CKEditor 5 Text Transformation\";s:40:\"ckeditor5_plugin_pack_todo_document_list\";s:21:\"CKEditor 5 To-do List\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(579,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:26:\"ckeditor5_premium_features\";s:4:\"info\";a:6:{s:4:\"name\";s:27:\"CKEditor 5 Full-screen Mode\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.3.5\";s:7:\"project\";s:26:\"ckeditor5_premium_features\";s:9:\"datestamp\";i:1734513731;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1734513731;s:8:\"includes\";a:1:{s:37:\"ckeditor5_premium_features_fullscreen\";s:27:\"CKEditor 5 Full-screen Mode\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(580,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:12:\"ept_carousel\";s:4:\"info\";a:6:{s:4:\"name\";s:37:\"Extra Paragraph Types (EPT): Carousel\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:12:\"ept_carousel\";s:9:\"datestamp\";i:1734284534;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1734284534;s:8:\"includes\";a:1:{s:12:\"ept_carousel\";s:37:\"Extra Paragraph Types (EPT): Carousel\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(581,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:8:\"ept_hero\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Hero\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:8:\"ept_hero\";s:9:\"datestamp\";i:1733145602;s:16:\"_info_file_ctime\";i:1735498428;}s:9:\"datestamp\";i:1733145602;s:8:\"includes\";a:1:{s:8:\"ept_hero\";s:33:\"Extra Paragraph Types (EPT): Hero\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(582,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:8:\"ept_tabs\";s:4:\"info\";a:6:{s:4:\"name\";s:33:\"Extra Paragraph Types (EPT): Tabs\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.5\";s:7:\"project\";s:8:\"ept_tabs\";s:9:\"datestamp\";i:1735472536;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1735472536;s:8:\"includes\";a:1:{s:8:\"ept_tabs\";s:33:\"Extra Paragraph Types (EPT): Tabs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(583,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:11:\"ept_webform\";s:4:\"info\";a:6:{s:4:\"name\";s:36:\"Extra Paragraph Types (EPT): Webform\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.2\";s:7:\"project\";s:11:\"ept_webform\";s:9:\"datestamp\";i:1721384667;s:16:\"_info_file_ctime\";i:1735492408;}s:9:\"datestamp\";i:1721384667;s:8:\"includes\";a:1:{s:11:\"ept_webform\";s:36:\"Extra Paragraph Types (EPT): Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(584,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:17:\"ept_webform_popup\";s:4:\"info\";a:6:{s:4:\"name\";s:42:\"Extra Paragraph Types (EPT): Webform Popup\";s:7:\"package\";s:21:\"Extra Paragraph Types\";s:7:\"version\";s:5:\"1.4.3\";s:7:\"project\";s:17:\"ept_webform_popup\";s:9:\"datestamp\";i:1721384667;s:16:\"_info_file_ctime\";i:1735492408;}s:9:\"datestamp\";i:1721384667;s:8:\"includes\";a:1:{s:17:\"ept_webform_popup\";s:42:\"Extra Paragraph Types (EPT): Webform Popup\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(585,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:11:\"gin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Gin Toolbar\";s:7:\"version\";s:7:\"8.x-1.0\";s:7:\"project\";s:11:\"gin_toolbar\";s:9:\"datestamp\";i:1734698812;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734698812;s:8:\"includes\";a:1:{s:11:\"gin_toolbar\";s:11:\"Gin Toolbar\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(586,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:9:\"glightbox\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"GLightbox\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:6:\"1.0.13\";s:7:\"project\";s:9:\"glightbox\";s:9:\"datestamp\";i:1734093965;s:16:\"_info_file_ctime\";i:1735498429;}s:9:\"datestamp\";i:1734093965;s:8:\"includes\";a:1:{s:9:\"glightbox\";s:9:\"GLightbox\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(587,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:21:\"glightbox_media_video\";s:4:\"info\";a:6:{s:4:\"name\";s:21:\"GLightbox Media Video\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"1.0.3\";s:7:\"project\";s:21:\"glightbox_media_video\";s:9:\"datestamp\";i:1734297827;s:16:\"_info_file_ctime\";i:1735498430;}s:9:\"datestamp\";i:1734297827;s:8:\"includes\";a:1:{s:21:\"glightbox_media_video\";s:21:\"GLightbox Media Video\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(588,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:13:\"image_effects\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Image Effects\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"4.0.0\";s:7:\"project\";s:13:\"image_effects\";s:9:\"datestamp\";i:1733831440;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1733831440;s:8:\"includes\";a:1:{s:13:\"image_effects\";s:13:\"Image Effects\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(589,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:17:\"layout_paragraphs\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Layout Paragraphs\";s:7:\"package\";s:10:\"Paragraphs\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:17:\"layout_paragraphs\";s:9:\"datestamp\";i:1732724680;s:16:\"_info_file_ctime\";i:1735498433;}s:9:\"datestamp\";i:1732724680;s:8:\"includes\";a:1:{s:17:\"layout_paragraphs\";s:17:\"Layout Paragraphs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(590,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:7:\"webform\";s:4:\"info\";a:6:{s:4:\"name\";s:7:\"Webform\";s:7:\"package\";s:7:\"Webform\";s:7:\"version\";s:12:\"6.3.0-alpha3\";s:7:\"project\";s:7:\"webform\";s:9:\"datestamp\";i:1733851313;s:16:\"_info_file_ctime\";i:1735492412;}s:9:\"datestamp\";i:1733851313;s:8:\"includes\";a:1:{s:7:\"webform\";s:7:\"Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1735499397),(591,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:3:\"gin\";s:4:\"info\";a:5:{s:4:\"name\";s:3:\"Gin\";s:7:\"version\";s:7:\"8.x-3.0\";s:7:\"project\";s:3:\"gin\";s:9:\"datestamp\";i:1734696851;s:16:\"_info_file_ctime\";i:1735498436;}s:9:\"datestamp\";i:1734696851;s:8:\"includes\";a:1:{s:3:\"gin\";s:3:\"Gin\";}s:12:\"project_type\";s:5:\"theme\";s:14:\"project_status\";b:1;}',0,1735499397);
/*!40000 ALTER TABLE `queue` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `router`
--

DROP TABLE IF EXISTS `router`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `router` (
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Machine name of this route',
  `path` varchar(255) NOT NULL DEFAULT '' COMMENT 'The path for this URI',
  `pattern_outline` varchar(255) NOT NULL DEFAULT '' COMMENT 'The pattern',
  `fit` int NOT NULL DEFAULT '0' COMMENT 'A numeric representation of how specific the path is.',
  `route` longblob COMMENT 'A serialized Route object',
  `number_parts` smallint NOT NULL DEFAULT '0' COMMENT 'Number of parts in this router path.',
  PRIMARY KEY (`name`),
  KEY `pattern_outline_parts` (`pattern_outline`(191),`number_parts`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maps paths to various callbacks (access, page and title)';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `router`
--

LOCK TABLES `router` WRITE;
/*!40000 ALTER TABLE `router` DISABLE KEYS */;
INSERT INTO `router` VALUES ('<button>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('<current>','/<current>','/<current>',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/<current>\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:0:{}s:7:\"options\";a:2:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/\\<current\\>$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/<current>\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:10:\"/<current>\";s:8:\"numParts\";i:1;}}',1),('<front>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:6:\"_title\";s:4:\"Home\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('<nolink>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('<none>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('admin_toolbar.run.cron','/run-cron','/run-cron',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:9:\"/run-cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:65:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::runCron\";s:6:\"_title\";s:8:\"Run cron\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/run\\-cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/run-cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:9:\"/run-cron\";s:8:\"numParts\";i:1;}}',1),('admin_toolbar.settings','/admin/config/user-interface/admin-toolbar','/admin/config/user-interface/admin-toolbar',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/user-interface/admin-toolbar\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\admin_toolbar\\Form\\AdminToolbarSettingsForm\";s:6:\"_title\";s:22:\"Admin Toolbar settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/config/user\\-interface/admin\\-toolbar$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/admin-toolbar\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:42:\"/admin/config/user-interface/admin-toolbar\";s:8:\"numParts\";i:4;}}',4),('admin_toolbar_tools.cssjs','/admin/flush/cssjs','/admin/flush/cssjs',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/admin/flush/cssjs\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushJsCss\";s:6:\"_title\";s:24:\"Flush CSS and JavaScript\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/admin/flush/cssjs$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/admin/flush/cssjs\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/admin/flush/cssjs\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.flush','/admin/flush','/admin/flush',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/admin/flush\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:66:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushAll\";s:6:\"_title\";s:16:\"Flush all caches\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/admin/flush$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/admin/flush\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/admin/flush\";s:8:\"numParts\";i:2;}}',2),('admin_toolbar_tools.flush_menu','/admin/flush/menu','/admin/flush/menu',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/admin/flush/menu\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:67:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushMenu\";s:6:\"_title\";s:4:\"Menu\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/admin/flush/menu$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/flush/menu\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/admin/flush/menu\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.flush_rendercache','/admin/flush/rendercache','/admin/flush/rendercache',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/flush/rendercache\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:69:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::cacheRender\";s:6:\"_title\";s:12:\"Render cache\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/flush/rendercache$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/flush/rendercache\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/flush/rendercache\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.flush_static','/admin/flush/static-caches','/admin/flush/static-caches',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/flush/static-caches\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:69:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushStatic\";s:6:\"_title\";s:13:\"Static caches\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/flush/static\\-caches$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/flush/static-caches\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/admin/flush/static-caches\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.flush_twig','/admin/flush/twig','/admin/flush/twig',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/admin/flush/twig\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:67:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushTwig\";s:6:\"_title\";s:4:\"Twig\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/admin/flush/twig$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/flush/twig\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/admin/flush/twig\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.flush_views','/admin/flush/views','/admin/flush/views',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/admin/flush/views\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushViews\";s:6:\"_title\";s:5:\"Views\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/admin/flush/views$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/admin/flush/views\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/admin/flush/views\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.plugin','/admin/flush/plugin','/admin/flush/plugin',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/flush/plugin\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:70:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushPlugins\";s:6:\"_title\";s:6:\"Plugin\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/flush/plugin$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/flush/plugin\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/flush/plugin\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.settings','/admin/config/user-interface/admin-toolbar-tools','/admin/config/user-interface/admin-toolbar-tools',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/config/user-interface/admin-toolbar-tools\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:62:\"\\Drupal\\admin_toolbar_tools\\Form\\AdminToolbarToolsSettingsForm\";s:6:\"_title\";s:28:\"Admin Toolbar Tools settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/user\\-interface/admin\\-toolbar\\-tools$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/admin/config/user-interface/admin-toolbar-tools\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:48:\"/admin/config/user-interface/admin-toolbar-tools\";s:8:\"numParts\";i:4;}}',4),('admin_toolbar_tools.theme_rebuild','/admin/flush/theme_rebuild','/admin/flush/theme_rebuild',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/flush/theme_rebuild\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:70:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::themeRebuild\";s:6:\"_title\";s:13:\"Theme Rebuild\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/flush/theme_rebuild$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/flush/theme_rebuild\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/admin/flush/theme_rebuild\";s:8:\"numParts\";i:3;}}',3),('announcements_feed.announcement','/admin/announcements_feed','/admin/announcements_feed',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/announcements_feed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:74:\"\\Drupal\\announcements_feed\\Controller\\AnnounceController::getAnnouncements\";s:6:\"_title\";s:23:\"Community announcements\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"access announcements\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/announcements_feed$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/announcements_feed\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:25:\"/admin/announcements_feed\";s:8:\"numParts\";i:2;}}',2),('big_pipe.nojs','/big_pipe/no-js','/big_pipe/no-js',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:15:\"/big_pipe/no-js\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\big_pipe\\Controller\\BigPipeController:setNoJsCookie\";s:6:\"_title\";s:19:\"BigPipe no-JS check\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:23:\"{^/big_pipe/no\\-js$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/big_pipe/no-js\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:15:\"/big_pipe/no-js\";s:8:\"numParts\";i:2;}}',2),('block.admin_add','/admin/structure/block/add/{plugin_id}/{theme}','/admin/structure/block/add/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/block/add/{plugin_id}/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:66:\"\\Drupal\\block\\Controller\\BlockAddController::blockAddConfigureForm\";s:5:\"theme\";N;s:6:\"_title\";s:15:\"Configure block\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"plugin_id\";i:1;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/block/add/(?P<plugin_id>[^/]++)(?:/(?P<theme>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"plugin_id\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/block/add\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"plugin_id\";i:1;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/structure/block/add/%\";s:8:\"numParts\";i:6;}}',6),('block.admin_demo','/admin/structure/block/demo/{theme}','/admin/structure/block/demo/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/block/demo/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:46:\"\\Drupal\\block\\Controller\\BlockController::demo\";s:15:\"_title_callback\";s:21:\"theme_handler:getName\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/block/demo/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/block/demo\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/block/demo/%\";s:8:\"numParts\";i:5;}}',5),('block.admin_display','/admin/structure/block','/admin/structure/block',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:53:\"\\Drupal\\block\\Controller\\BlockListController::listing\";s:6:\"_title\";s:12:\"Block layout\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/block\";s:8:\"numParts\";i:3;}}',3),('block.admin_display_theme','/admin/structure/block/list/{theme}','/admin/structure/block/list/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/block/list/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:53:\"\\Drupal\\block\\Controller\\BlockListController::listing\";s:6:\"_title\";s:12:\"Block layout\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/block/list/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/block/list\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/block/list/%\";s:8:\"numParts\";i:5;}}',5),('block.admin_library','/admin/structure/block/library/{theme}','/admin/structure/block/library/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/structure/block/library/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\block\\Controller\\BlockLibraryController::listBlocks\";s:6:\"_title\";s:11:\"Place block\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/structure/block/library/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/block/library\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:32:\"/admin/structure/block/library/%\";s:8:\"numParts\";i:5;}}',5),('block.category_autocomplete','/block-category/autocomplete','/block-category/autocomplete',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/block-category/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:69:\"\\Drupal\\block\\Controller\\CategoryAutocompleteController::autocomplete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/block\\-category/autocomplete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/block-category/autocomplete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:28:\"/block-category/autocomplete\";s:8:\"numParts\";i:2;}}',2),('block_content.add_form','/block/add/{block_content_type}','/block/add/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/block/add/{block_content_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\block_content\\Controller\\BlockContentController::addForm\";s:15:\"_title_callback\";s:72:\"\\Drupal\\block_content\\Controller\\BlockContentController::getAddFormTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:34:\"block_content:{block_content_type}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/block/add/(?P<block_content_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/block/add\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:12:\"/block/add/%\";s:8:\"numParts\";i:3;}}',3),('block_content.add_page','/block/add','/block/add',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/block/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\block_content\\Controller\\BlockContentController::add\";s:6:\"_title\";s:17:\"Add content block\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:13:\"block_content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/block/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/block/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/block/add\";s:8:\"numParts\";i:2;}}',2),('block_content.type_add','/admin/structure/block-content/add','/admin/structure/block-content/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/block-content/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"block_content_type.add\";s:6:\"_title\";s:3:\"Add\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:18:\"block_content_type\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/structure/block\\-content/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/structure/block-content/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/structure/block-content/add\";s:8:\"numParts\";i:4;}}',4),('ckeditor5.media_entity_metadata','/ckeditor5/{editor}/media-entity-metadata','/ckeditor5/%/media-entity-metadata',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/ckeditor5/{editor}/media-entity-metadata\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:74:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5MediaController::mediaEntityMetadata\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:10:\"editor.use\";s:14:\"_custom_access\";s:61:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5MediaController::access\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:3:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";i:2;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/ckeditor5/(?P<editor>[^/]++)/media\\-entity\\-metadata$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/media-entity-metadata\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/ckeditor5\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:34:\"/ckeditor5/%/media-entity-metadata\";s:8:\"numParts\";i:3;}}',3),('ckeditor5.upload_image','/ckeditor5/upload-image/{editor}','/ckeditor5/upload-image/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/ckeditor5/upload-image/{editor}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:61:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5ImageController::upload\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:10:\"editor.use\";s:14:\"_custom_access\";s:79:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5ImageController::imageUploadEnabledAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:3:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";i:2;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/ckeditor5/upload\\-image/(?P<editor>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/ckeditor5/upload-image\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:25:\"/ckeditor5/upload-image/%\";s:8:\"numParts\";i:3;}}',3),('ckeditor5_plugin_pack.settings','/admin/config/ckeditor5-plugin-pack','/admin/config/ckeditor5-plugin-pack',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/config/ckeditor5-plugin-pack\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"\\Drupal\\ckeditor5_plugin_pack\\Form\\SettingsForm\";s:6:\"_title\";s:31:\"CKEditor 5 Plugin Pack settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/ckeditor5\\-plugin\\-pack$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/ckeditor5-plugin-pack\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:35:\"/admin/config/ckeditor5-plugin-pack\";s:8:\"numParts\";i:3;}}',3),('comment.admin','/admin/content/comment','/admin/content/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/content/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:14:\"page_published\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/content/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/content/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/content/comment\";s:8:\"numParts\";i:3;}}',3),('comment.admin_approval','/admin/content/comment/approval','/admin/content/comment/approval',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/content/comment/approval\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:15:\"page_unapproved\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/content/comment/approval$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/content/comment/approval\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/content/comment/approval\";s:8:\"numParts\";i:4;}}',4),('comment.approve','/comment/{comment}/approve','/comment/%/approve',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/comment/{comment}/approve\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:7:\"Approve\";s:11:\"_controller\";s:60:\"\\Drupal\\comment\\Controller\\CommentController::commentApprove\";s:11:\"entity_type\";s:7:\"comment\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:15:\"comment.approve\";s:11:\"_csrf_token\";s:4:\"TRUE\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/comment/(?P<comment>\\d+)/approve$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/approve\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:18:\"/comment/%/approve\";s:8:\"numParts\";i:3;}}',3),('comment.multiple_delete_confirm','/admin/content/comment/delete','/admin/content/comment/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/content/comment/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:6:\"Delete\";s:5:\"_form\";s:42:\"\\Drupal\\comment\\Form\\ConfirmDeleteMultiple\";s:14:\"entity_type_id\";s:7:\"comment\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:7:\"comment\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/content/comment/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/content/comment/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/content/comment/delete\";s:8:\"numParts\";i:4;}}',4),('comment.new_comments_node_links','/comments/render_new_comments_node_links','/comments/render_new_comments_node_links',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/comments/render_new_comments_node_links\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\comment\\Controller\\CommentController::renderNewCommentsNodeLinks\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/comments/render_new_comments_node_links$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/comments/render_new_comments_node_links\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:40:\"/comments/render_new_comments_node_links\";s:8:\"numParts\";i:2;}}',2),('comment.node_redirect','/comment/{node}/reply','/comment/%/reply',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/comment/{node}/reply\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\comment\\Controller\\CommentController::redirectNode\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:9:\"node.view\";s:20:\"_module_dependencies\";s:4:\"node\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/comment/(?P<node>\\d+)/reply$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reply\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:16:\"/comment/%/reply\";s:8:\"numParts\";i:3;}}',3),('comment.reply','/comment/reply/{entity_type}/{entity}/{field_name}/{pid}','/comment/reply/%/%/%',24,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/comment/reply/{entity_type}/{entity}/{field_name}/{pid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:58:\"\\Drupal\\comment\\Controller\\CommentController::getReplyForm\";s:6:\"_title\";s:15:\"Add new comment\";s:3:\"pid\";N;}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:61:\"\\Drupal\\comment\\Controller\\CommentController::replyFormAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:{entity_type}\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:11:\"entity_type\";i:1;s:6:\"entity\";i:2;s:10:\"field_name\";i:3;s:3:\"pid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/comment/reply/(?P<entity_type>[^/]++)/(?P<entity>[^/]++)/(?P<field_name>[^/]++)(?:/(?P<pid>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"pid\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/comment/reply\";}}s:9:\"path_vars\";a:4:{i:0;s:11:\"entity_type\";i:1;s:6:\"entity\";i:2;s:10:\"field_name\";i:3;s:3:\"pid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:24;s:14:\"patternOutline\";s:20:\"/comment/reply/%/%/%\";s:8:\"numParts\";i:6;}}',6),('config.diff','/admin/config/development/configuration/sync/diff/{source_name}/{target_name}','/admin/config/development/configuration/sync/diff/%',126,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/config/development/configuration/sync/diff/{source_name}/{target_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\config\\Controller\\ConfigController::diff\";s:11:\"target_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"source_name\";i:1;s:11:\"target_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/config/development/configuration/sync/diff/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:49:\"/admin/config/development/configuration/sync/diff\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"source_name\";i:1;s:11:\"target_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/sync/diff/%\";s:8:\"numParts\";i:8;}}',8),('config.diff_collection','/admin/config/development/configuration/sync/diff_collection/{collection}/{source_name}/{target_name}','/admin/config/development/configuration/sync/diff_collection/%/%',252,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:101:\"/admin/config/development/configuration/sync/diff_collection/{collection}/{source_name}/{target_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\config\\Controller\\ConfigController::diff\";s:11:\"target_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"collection\";i:1;s:11:\"source_name\";i:2;s:11:\"target_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:143:\"{^/admin/config/development/configuration/sync/diff_collection/(?P<collection>[^/]++)/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"collection\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:60:\"/admin/config/development/configuration/sync/diff_collection\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"collection\";i:1;s:11:\"source_name\";i:2;s:11:\"target_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:252;s:14:\"patternOutline\";s:64:\"/admin/config/development/configuration/sync/diff_collection/%/%\";s:8:\"numParts\";i:9;}}',9),('config.export_download','/admin/config/development/configuration/full/export-download','/admin/config/development/configuration/full/export-download',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/development/configuration/full/export-download\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\config\\Controller\\ConfigController::downloadExport\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/development/configuration/full/export\\-download$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:60:\"/admin/config/development/configuration/full/export-download\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:60:\"/admin/config/development/configuration/full/export-download\";s:8:\"numParts\";i:6;}}',6),('config.export_full','/admin/config/development/configuration/full/export','/admin/config/development/configuration/full/export',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/development/configuration/full/export\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\config\\Form\\ConfigExportForm\";s:6:\"_title\";s:6:\"Export\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/development/configuration/full/export$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/development/configuration/full/export\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/full/export\";s:8:\"numParts\";i:6;}}',6),('config.export_single','/admin/config/development/configuration/single/export/{config_type}/{config_name}','/admin/config/development/configuration/single/export',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/config/development/configuration/single/export/{config_type}/{config_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:13:\"Single export\";s:5:\"_form\";s:42:\"\\Drupal\\config\\Form\\ConfigSingleExportForm\";s:11:\"config_type\";N;s:11:\"config_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"config_type\";i:1;s:11:\"config_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:118:\"{^/admin/config/development/configuration/single/export(?:/(?P<config_type>[^/]++)(?:/(?P<config_name>[^/]++))?)?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"config_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"config_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:53:\"/admin/config/development/configuration/single/export\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"config_type\";i:1;s:11:\"config_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:53:\"/admin/config/development/configuration/single/export\";s:8:\"numParts\";i:8;}}',8),('config.import_full','/admin/config/development/configuration/full/import','/admin/config/development/configuration/full/import',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/development/configuration/full/import\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\config\\Form\\ConfigImportForm\";s:6:\"_title\";s:6:\"Import\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"import configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/development/configuration/full/import$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/development/configuration/full/import\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/full/import\";s:8:\"numParts\";i:6;}}',6),('config.import_single','/admin/config/development/configuration/single/import','/admin/config/development/configuration/single/import',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/development/configuration/single/import\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:13:\"Single import\";s:5:\"_form\";s:42:\"\\Drupal\\config\\Form\\ConfigSingleImportForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"import configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/admin/config/development/configuration/single/import$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:53:\"/admin/config/development/configuration/single/import\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:53:\"/admin/config/development/configuration/single/import\";s:8:\"numParts\";i:6;}}',6),('config.sync','/admin/config/development/configuration','/admin/config/development/configuration',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/config/development/configuration\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:30:\"\\Drupal\\config\\Form\\ConfigSync\";s:6:\"_title\";s:11:\"Synchronize\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/config/development/configuration$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/development/configuration\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/config/development/configuration\";s:8:\"numParts\";i:4;}}',4),('contact.form_add','/admin/structure/contact/add','/admin/structure/contact/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/structure/contact/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"contact_form.add\";s:6:\"_title\";s:16:\"Add contact form\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer contact forms\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/structure/contact/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/contact/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/structure/contact/add\";s:8:\"numParts\";i:4;}}',4),('contact.site_page','/contact','/contact',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:8:\"/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:61:\"\\Drupal\\contact\\Controller\\ContactController::contactSitePage\";s:12:\"contact_form\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"access site-wide contact form\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:15:\"{^/contact$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:8:\"/contact\";s:8:\"numParts\";i:1;}}',1),('contextual.render','/contextual/render','/contextual/render',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/contextual/render\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\contextual\\ContextualController::render\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"access contextual links\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/contextual/render$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/contextual/render\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:18:\"/contextual/render\";s:8:\"numParts\";i:2;}}',2),('dblog.access_denied','/admin/reports/access-denied','/admin/reports/access-denied',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/access-denied\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:26:\"Top \'access denied\' errors\";s:11:\"_controller\";s:56:\"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages\";s:4:\"type\";s:13:\"access denied\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/access\\-denied$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/access-denied\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/reports/access-denied\";s:8:\"numParts\";i:3;}}',3),('dblog.confirm','/admin/reports/dblog/confirm','/admin/reports/dblog/confirm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/dblog/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\dblog\\Form\\DblogClearLogConfirmForm\";s:6:\"_title\";s:34:\"Confirm delete recent log messages\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/reports/dblog/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/dblog/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/reports/dblog/confirm\";s:8:\"numParts\";i:4;}}',4),('dblog.event','/admin/reports/dblog/event/{event_id}','/admin/reports/dblog/event/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/reports/dblog/event/{event_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\dblog\\Controller\\DbLogController::eventDetails\";s:6:\"_title\";s:7:\"Details\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"event_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/reports/dblog/event/(?P<event_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"event_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/reports/dblog/event\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"event_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/reports/dblog/event/%\";s:8:\"numParts\";i:5;}}',5),('dblog.overview','/admin/reports/dblog','/admin/reports/dblog',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/reports/dblog\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"watchdog\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/reports/dblog$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/reports/dblog\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/reports/dblog\";s:8:\"numParts\";i:3;}}',3),('dblog.page_not_found','/admin/reports/page-not-found','/admin/reports/page-not-found',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/page-not-found\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:27:\"Top \'page not found\' errors\";s:11:\"_controller\";s:56:\"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages\";s:4:\"type\";s:14:\"page not found\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/page\\-not\\-found$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/page-not-found\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:29:\"/admin/reports/page-not-found\";s:8:\"numParts\";i:3;}}',3),('editor.filter_xss','/editor/filter_xss/{filter_format}','/editor/filter_xss/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/editor/filter_xss/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:42:\"\\Drupal\\editor\\EditorController::filterXss\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"filter_format.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/editor/filter_xss/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/editor/filter_xss\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:20:\"/editor/filter_xss/%\";s:8:\"numParts\";i:3;}}',3),('entity.block.delete_form','/admin/structure/block/manage/{block}/delete','/admin/structure/block/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/block/manage/{block}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"block.delete\";s:6:\"_title\";s:12:\"Remove block\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/block/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.block.disable','/admin/structure/block/manage/{block}/disable','/admin/structure/block/manage/%/disable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/block/manage/{block}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\block\\Controller\\BlockController::performOperation\";s:2:\"op\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:13:\"block.disable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/block/manage/%/disable\";s:8:\"numParts\";i:6;}}',6),('entity.block.edit_form','/admin/structure/block/manage/{block}','/admin/structure/block/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/structure/block/manage/{block}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"block.default\";s:6:\"_title\";s:15:\"Configure block\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"block.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/structure/block/manage/(?P<block>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/block/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.block.enable','/admin/structure/block/manage/{block}/enable','/admin/structure/block/manage/%/enable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/block/manage/{block}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\block\\Controller\\BlockController::performOperation\";s:2:\"op\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"block.enable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/block/manage/%/enable\";s:8:\"numParts\";i:6;}}',6),('entity.block_content.canonical','/admin/content/block/{block_content}','/admin/content/block/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/content/block/{block_content}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"block_content.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/content/block/(?P<block_content>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/admin/content/block/%\";s:8:\"numParts\";i:4;}}',4),('entity.block_content.collection','/admin/content/block','/admin/content/block',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"block_content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"access block library\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/block\";s:8:\"numParts\";i:3;}}',3),('entity.block_content.delete_form','/admin/content/block/{block_content}/delete','/admin/content/block/%/delete',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/content/block/{block_content}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"block_content.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.delete\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/admin/content/block/(?P<block_content>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:29:\"/admin/content/block/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.block_content.edit_form','/admin/content/block/{block_content}','/admin/content/block/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/content/block/{block_content}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:18:\"block_content.edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/content/block/(?P<block_content>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/admin/content/block/%\";s:8:\"numParts\";i:4;}}',4),('entity.block_content.field_ui_fields','/admin/structure/block-content/manage/{block_content_type}/fields','/admin/structure/block-content/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/block-content/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.block_content.revision_delete_form','/admin/content/block/{block_content}/revision/{block_content_revision}/delete','/admin/content/block/%/revision/%/delete',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"block_content.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:38:\"block_content_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"block_content_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:block_content\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/content/block/(?P<block_content>[^/]++)/revision/(?P<block_content_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"block_content_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:40:\"/admin/content/block/%/revision/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.block_content.revision_revert_form','/admin/content/block/{block_content}/revision/{block_content_revision}/revert','/admin/content/block/%/revision/%/revert',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"block_content.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"block_content_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"block_content_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:block_content\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/content/block/(?P<block_content>[^/]++)/revision/(?P<block_content_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"block_content_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:40:\"/admin/content/block/%/revision/%/revert\";s:8:\"numParts\";i:7;}}',7),('entity.block_content.version_history','/admin/content/block/{block_content}/revisions','/admin/content/block/%/revisions',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/content/block/{block_content}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:32:\"block_content.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:13:\"block_content\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/content/block/(?P<block_content>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:32:\"/admin/content/block/%/revisions\";s:8:\"numParts\";i:5;}}',5),('entity.block_content_type.collection','/admin/structure/block-content','/admin/structure/block-content',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/structure/block-content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:18:\"block_content_type\";s:6:\"_title\";s:11:\"Block types\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer block types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/block\\-content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/block-content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/admin/structure/block-content\";s:8:\"numParts\";i:3;}}',3),('entity.block_content_type.delete_form','/admin/structure/block-content/manage/{block_content_type}/delete','/admin/structure/block-content/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"block_content_type.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"block_content_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/block-content/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.block_content_type.edit_form','/admin/structure/block-content/manage/{block_content_type}','/admin/structure/block-content/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/block-content/manage/{block_content_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"block_content_type.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"block_content_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:39:\"/admin/structure/block-content/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.block_content_type.entity_permissions_form','/admin/structure/block-content/manage/{block_content_type}/permissions','/admin/structure/block-content/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/block-content/manage/{block_content_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:13:\"block_content\";s:18:\"bundle_entity_type\";s:18:\"block_content_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:3:{s:4:\"type\";s:25:\"entity:block_content_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:51:\"/admin/structure/block-content/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.ckeditor5_template.add_form','/admin/config/ckeditor5-templates/content-templates/add','/admin/config/ckeditor5-templates/content-templates/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"ckeditor5_template.add\";s:6:\"_title\";s:24:\"Add a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:8:\"numParts\";i:5;}}',5),('entity.ckeditor5_template.collection','/admin/config/ckeditor5-templates/content-templates','/admin/config/ckeditor5-templates/content-templates',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:18:\"ckeditor5_template\";s:6:\"_title\";s:41:\"CKEditor5 Content Templates Configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/admin/config/ckeditor5\\-templates/content\\-templates$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:8:\"numParts\";i:4;}}',4),('entity.ckeditor5_template.delete_form','/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/delete','/admin/config/ckeditor5-templates/content-templates/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"ckeditor5_template.delete\";s:6:\"_title\";s:27:\"Delete a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:60:\"/admin/config/ckeditor5-templates/content-templates/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.ckeditor5_template.edit_form','/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}','/admin/config/ckeditor5-templates/content-templates/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"ckeditor5_template.edit\";s:6:\"_title\";s:25:\"Edit a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:91:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:53:\"/admin/config/ckeditor5-templates/content-templates/%\";s:8:\"numParts\";i:5;}}',5),('entity.comment.canonical','/comment/{comment}','/comment/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/comment/{comment}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:67:\"\\Drupal\\comment\\Controller\\CommentController::commentPermalinkTitle\";s:11:\"_controller\";s:62:\"\\Drupal\\comment\\Controller\\CommentController::commentPermalink\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"comment.view\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/comment/(?P<comment>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/comment/%\";s:8:\"numParts\";i:2;}}',2),('entity.comment.delete_form','/comment/{comment}/delete','/comment/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/comment/{comment}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:6:\"Delete\";s:12:\"_entity_form\";s:14:\"comment.delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"comment.delete\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/comment/(?P<comment>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/comment/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.comment.delete_multiple_form','/admin/content/comment/delete','/admin/content/comment/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/content/comment/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:6:\"Delete\";s:5:\"_form\";s:42:\"\\Drupal\\comment\\Form\\ConfirmDeleteMultiple\";s:14:\"entity_type_id\";s:7:\"comment\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:7:\"comment\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/content/comment/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/content/comment/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/content/comment/delete\";s:8:\"numParts\";i:4;}}',4),('entity.comment.edit_form','/comment/{comment}/edit','/comment/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/comment/{comment}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:4:\"Edit\";s:12:\"_entity_form\";s:15:\"comment.default\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"comment.update\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/comment/(?P<comment>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/comment/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.comment.field_ui_fields','/admin/structure/comment/manage/{comment_type}/fields','/admin/structure/comment/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/comment/manage/{comment_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/comment/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.comment_type.add_form','/admin/structure/comment/types/add','/admin/structure/comment/types/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/comment/types/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"comment_type.add\";s:6:\"_title\";s:16:\"Add comment type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer comment types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/structure/comment/types/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/structure/comment/types/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/structure/comment/types/add\";s:8:\"numParts\";i:5;}}',5),('entity.comment_type.collection','/admin/structure/comment','/admin/structure/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/structure/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"comment_type\";s:6:\"_title\";s:13:\"Comment types\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer comment types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/structure/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/structure/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/structure/comment\";s:8:\"numParts\";i:3;}}',3),('entity.comment_type.delete_form','/admin/structure/comment/manage/{comment_type}/delete','/admin/structure/comment/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/comment/manage/{comment_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"comment_type.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"comment_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/comment/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.comment_type.edit_form','/admin/structure/comment/manage/{comment_type}','/admin/structure/comment/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/comment/manage/{comment_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"comment_type.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"comment_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/structure/comment/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.comment_type.entity_permissions_form','/admin/structure/comment/manage/{comment_type}/permissions','/admin/structure/comment/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/comment/manage/{comment_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:7:\"comment\";s:18:\"bundle_entity_type\";s:12:\"comment_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:3:{s:4:\"type\";s:19:\"entity:comment_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:45:\"/admin/structure/comment/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.contact_form.canonical','/contact/{contact_form}','/contact/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/contact/{contact_form}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:61:\"\\Drupal\\contact\\Controller\\ContactController::contactSitePage\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"contact_form.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/contact/(?P<contact_form>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/contact/%\";s:8:\"numParts\";i:2;}}',2),('entity.contact_form.collection','/admin/structure/contact','/admin/structure/contact',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/structure/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"contact_form\";s:6:\"_title\";s:13:\"Contact forms\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer contact forms\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/structure/contact$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/structure/contact\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/structure/contact\";s:8:\"numParts\";i:3;}}',3),('entity.contact_form.delete_form','/admin/structure/contact/manage/{contact_form}/delete','/admin/structure/contact/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/contact/manage/{contact_form}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"contact_form.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"contact_form.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/contact/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.contact_form.edit_form','/admin/structure/contact/manage/{contact_form}','/admin/structure/contact/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/contact/manage/{contact_form}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"contact_form.edit\";s:6:\"_title\";s:17:\"Edit contact form\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"contact_form.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/structure/contact/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.contact_form.entity_permissions_form','/admin/structure/contact/manage/{contact_form}/permissions','/admin/structure/contact/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/contact/manage/{contact_form}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:18:\"bundle_entity_type\";s:12:\"contact_form\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:3:{s:4:\"type\";s:19:\"entity:contact_form\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:45:\"/admin/structure/contact/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.contact_message.field_ui_fields','/admin/structure/contact/manage/{contact_form}/fields','/admin/structure/contact/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/contact/manage/{contact_form}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/contact/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.date_format.collection','/admin/config/regional/date-time','/admin/config/regional/date-time',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/regional/date-time\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"date_format\";s:6:\"_title\";s:21:\"Date and time formats\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/regional/date\\-time$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/regional/date-time\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/regional/date-time\";s:8:\"numParts\";i:4;}}',4),('entity.date_format.delete_form','/admin/config/regional/date-time/formats/manage/{date_format}/delete','/admin/config/regional/date-time/formats/manage/%/delete',253,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/regional/date-time/formats/manage/{date_format}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"date_format.delete\";s:6:\"_title\";s:18:\"Delete date format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"date_format.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"date_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"date_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:253;s:14:\"patternOutline\";s:56:\"/admin/config/regional/date-time/formats/manage/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.date_format.edit_form','/admin/config/regional/date-time/formats/manage/{date_format}','/admin/config/regional/date-time/formats/manage/%',126,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/config/regional/date-time/formats/manage/{date_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"date_format.edit\";s:6:\"_title\";s:16:\"Edit date format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"date_format.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"date_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"date_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:49:\"/admin/config/regional/date-time/formats/manage/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.block_content.default','/admin/structure/block-content/manage/{block_content_type}/form-display','/admin/structure/block-content/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/block-content/manage/{block_content_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:52:\"/admin/structure/block-content/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.block_content.form_mode','/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}','/admin/structure/block-content/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:54:\"/admin/structure/block-content/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.comment.default','/admin/structure/comment/manage/{comment_type}/form-display','/admin/structure/comment/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/comment/manage/{comment_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/comment/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.comment.form_mode','/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}','/admin/structure/comment/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/comment/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.contact_message.default','/admin/structure/contact/manage/{contact_form}/form-display','/admin/structure/contact/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/contact/manage/{contact_form}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/contact/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.contact_message.form_mode','/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}','/admin/structure/contact/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/contact/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.media.default','/admin/structure/media/manage/{media_type}/form-display','/admin/structure/media/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/media/manage/{media_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/media/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.media.form_mode','/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}','/admin/structure/media/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:46:\"/admin/structure/media/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.node.default','/admin/structure/types/manage/{node_type}/form-display','/admin/structure/types/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/types/manage/{node_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/types/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.node.form_mode','/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}','/admin/structure/types/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:46:\"/admin/structure/types/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.paragraph.default','/admin/structure/paragraphs_type/{paragraphs_type}/form-display','/admin/structure/paragraphs_type/%/form-display',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:47:\"/admin/structure/paragraphs_type/%/form-display\";s:8:\"numParts\";i:5;}}',5),('entity.entity_form_display.paragraph.form_mode','/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}','/admin/structure/paragraphs_type/%/form-display/%',58,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:58;s:14:\"patternOutline\";s:49:\"/admin/structure/paragraphs_type/%/form-display/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.taxonomy_term.default','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display','/admin/structure/taxonomy/manage/%/overview/form-display',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/taxonomy/manage/%/overview/form-display\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.taxonomy_term.form_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}','/admin/structure/taxonomy/manage/%/overview/form-display/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:58:\"/admin/structure/taxonomy/manage/%/overview/form-display/%\";s:8:\"numParts\";i:8;}}',8),('entity.entity_form_display.user.default','/admin/config/people/accounts/form-display','/admin/config/people/accounts/form-display',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/people/accounts/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer user form display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/config/people/accounts/form\\-display$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:42:\"/admin/config/people/accounts/form-display\";s:8:\"numParts\";i:5;}}',5),('entity.entity_form_display.user.form_mode','/admin/config/people/accounts/form-display/{form_mode_name}','/admin/config/people/accounts/form-display/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/people/accounts/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer user form display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/people/accounts/form-display/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_mode.add_form','/admin/structure/display-modes/form/add/{entity_type_id}','/admin/structure/display-modes/form/add/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/display-modes/form/add/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"entity_form_mode.add\";s:6:\"_title\";s:13:\"Add form mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/display\\-modes/form/add/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/form/add\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/structure/display-modes/form/add/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_mode.collection','/admin/structure/display-modes/form','/admin/structure/display-modes/form',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/display-modes/form\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"entity_form_mode\";s:6:\"_title\";s:10:\"Form modes\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/display\\-modes/form$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/structure/display-modes/form\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/structure/display-modes/form\";s:8:\"numParts\";i:4;}}',4),('entity.entity_form_mode.delete_form','/admin/structure/display-modes/form/manage/{entity_form_mode}/delete','/admin/structure/display-modes/form/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/display-modes/form/manage/{entity_form_mode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"entity_form_mode.delete\";s:6:\"_title\";s:16:\"Delete form mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_form_mode.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/structure/display-modes/form/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_mode.edit_form','/admin/structure/display-modes/form/manage/{entity_form_mode}','/admin/structure/display-modes/form/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/display-modes/form/manage/{entity_form_mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"entity_form_mode.edit\";s:6:\"_title\";s:14:\"Edit form mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_form_mode.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/structure/display-modes/form/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.block_content.default','/admin/structure/block-content/manage/{block_content_type}/display','/admin/structure/block-content/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/block-content/manage/{block_content_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:47:\"/admin/structure/block-content/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.block_content.view_mode','/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}','/admin/structure/block-content/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:49:\"/admin/structure/block-content/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.comment.default','/admin/structure/comment/manage/{comment_type}/display','/admin/structure/comment/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/comment/manage/{comment_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/comment/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.comment.view_mode','/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}','/admin/structure/comment/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:43:\"/admin/structure/comment/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.contact_message.default','/admin/structure/contact/manage/{contact_form}/display','/admin/structure/contact/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/contact/manage/{contact_form}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/contact/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.contact_message.view_mode','/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}','/admin/structure/contact/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:43:\"/admin/structure/contact/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.media.default','/admin/structure/media/manage/{media_type}/display','/admin/structure/media/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/media/manage/{media_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/media/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.media.view_mode','/admin/structure/media/manage/{media_type}/display/{view_mode_name}','/admin/structure/media/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:41:\"/admin/structure/media/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.node.default','/admin/structure/types/manage/{node_type}/display','/admin/structure/types/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/types/manage/{node_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/types/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.node.view_mode','/admin/structure/types/manage/{node_type}/display/{view_mode_name}','/admin/structure/types/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:41:\"/admin/structure/types/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.paragraph.default','/admin/structure/paragraphs_type/{paragraphs_type}/display','/admin/structure/paragraphs_type/%/display',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/paragraphs_type/{paragraphs_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:42:\"/admin/structure/paragraphs_type/%/display\";s:8:\"numParts\";i:5;}}',5),('entity.entity_view_display.paragraph.view_mode','/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}','/admin/structure/paragraphs_type/%/display/%',58,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:58;s:14:\"patternOutline\";s:44:\"/admin/structure/paragraphs_type/%/display/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.taxonomy_term.default','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display','/admin/structure/taxonomy/manage/%/overview/display',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/taxonomy/manage/%/overview/display\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.taxonomy_term.view_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}','/admin/structure/taxonomy/manage/%/overview/display/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:53:\"/admin/structure/taxonomy/manage/%/overview/display/%\";s:8:\"numParts\";i:8;}}',8),('entity.entity_view_display.user.default','/admin/config/people/accounts/display','/admin/config/people/accounts/display',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/people/accounts/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/people/accounts/display$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/people/accounts/display\";s:8:\"numParts\";i:5;}}',5),('entity.entity_view_display.user.view_mode','/admin/config/people/accounts/display/{view_mode_name}','/admin/config/people/accounts/display/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/people/accounts/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:39:\"/admin/config/people/accounts/display/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_mode.add_form','/admin/structure/display-modes/view/add/{entity_type_id}','/admin/structure/display-modes/view/add/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/display-modes/view/add/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"entity_view_mode.add\";s:6:\"_title\";s:13:\"Add view mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/display\\-modes/view/add/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/view/add\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/structure/display-modes/view/add/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_mode.collection','/admin/structure/display-modes/view','/admin/structure/display-modes/view',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/display-modes/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"entity_view_mode\";s:6:\"_title\";s:10:\"View modes\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/display\\-modes/view$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/structure/display-modes/view\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/structure/display-modes/view\";s:8:\"numParts\";i:4;}}',4),('entity.entity_view_mode.delete_form','/admin/structure/display-modes/view/manage/{entity_view_mode}/delete','/admin/structure/display-modes/view/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/display-modes/view/manage/{entity_view_mode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"entity_view_mode.delete\";s:6:\"_title\";s:16:\"Delete view mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_view_mode.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/structure/display-modes/view/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_mode.edit_form','/admin/structure/display-modes/view/manage/{entity_view_mode}','/admin/structure/display-modes/view/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/display-modes/view/manage/{entity_view_mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"entity_view_mode.edit\";s:6:\"_title\";s:14:\"Edit view mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_view_mode.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/structure/display-modes/view/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.field_config.block_content_field_delete_form','/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/delete','/admin/structure/block-content/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/block-content/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.block_content_field_edit_form','/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}','/admin/structure/block-content/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/block-content/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.comment_field_delete_form','/admin/structure/comment/manage/{comment_type}/fields/{field_config}/delete','/admin/structure/comment/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/comment/manage/{comment_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/comment/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.comment_field_edit_form','/admin/structure/comment/manage/{comment_type}/fields/{field_config}','/admin/structure/comment/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/comment/manage/{comment_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:42:\"/admin/structure/comment/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.contact_message_field_delete_form','/admin/structure/contact/manage/{contact_form}/fields/{field_config}/delete','/admin/structure/contact/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/contact/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.contact_message_field_edit_form','/admin/structure/contact/manage/{contact_form}/fields/{field_config}','/admin/structure/contact/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:42:\"/admin/structure/contact/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.media_field_delete_form','/admin/structure/media/manage/{media_type}/fields/{field_config}/delete','/admin/structure/media/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/media/manage/{media_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/media/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.media_field_edit_form','/admin/structure/media/manage/{media_type}/fields/{field_config}','/admin/structure/media/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/media/manage/{media_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:91:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:40:\"/admin/structure/media/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.node_field_delete_form','/admin/structure/types/manage/{node_type}/fields/{field_config}/delete','/admin/structure/types/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/types/manage/{node_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:97:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/types/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.node_field_edit_form','/admin/structure/types/manage/{node_type}/fields/{field_config}','/admin/structure/types/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/types/manage/{node_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:40:\"/admin/structure/types/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.paragraph_field_delete_form','/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}/delete','/admin/structure/paragraphs_type/%/fields/%/delete',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:50:\"/admin/structure/paragraphs_type/%/fields/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.paragraph_field_edit_form','/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}','/admin/structure/paragraphs_type/%/fields/%',58,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:58;s:14:\"patternOutline\";s:43:\"/admin/structure/paragraphs_type/%/fields/%\";s:8:\"numParts\";i:6;}}',6),('entity.field_config.taxonomy_term_field_delete_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/delete','/admin/structure/taxonomy/manage/%/overview/fields/%/delete',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:119:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:59:\"/admin/structure/taxonomy/manage/%/overview/fields/%/delete\";s:8:\"numParts\";i:9;}}',9),('entity.field_config.taxonomy_term_field_edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}','/admin/structure/taxonomy/manage/%/overview/fields/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:52:\"/admin/structure/taxonomy/manage/%/overview/fields/%\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.user_field_delete_form','/admin/config/people/accounts/fields/{field_config}/delete','/admin/config/people/accounts/fields/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/config/people/accounts/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:45:\"/admin/config/people/accounts/fields/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.user_field_edit_form','/admin/config/people/accounts/fields/{field_config}','/admin/config/people/accounts/fields/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/people/accounts/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/people/accounts/fields/%\";s:8:\"numParts\";i:6;}}',6),('entity.field_storage_config.collection','/admin/reports/fields','/admin/reports/fields',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/reports/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:20:\"field_storage_config\";s:6:\"_title\";s:10:\"Field list\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/reports/fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/reports/fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/reports/fields\";s:8:\"numParts\";i:3;}}',3),('entity.file.delete_form','/file/{file}/delete','/file/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/file/{file}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"file.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:4:\"file\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"file.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"file\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"file\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/file/(?P<file>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"file\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/file\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"file\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/file/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.filter_format.disable','/admin/config/content/formats/manage/{filter_format}/disable','/admin/config/content/formats/manage/%/disable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/content/formats/manage/{filter_format}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"filter_format.disable\";s:6:\"_title\";s:19:\"Disable text format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:21:\"filter_format.disable\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/content/formats/manage/%/disable\";s:8:\"numParts\";i:7;}}',7),('entity.filter_format.edit_form','/admin/config/content/formats/manage/{filter_format}','/admin/config/content/formats/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/content/formats/manage/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"filter_format.edit\";s:15:\"_title_callback\";s:52:\"\\Drupal\\filter\\Controller\\FilterController::getLabel\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:20:\"filter_format.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/content/formats/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.filter_format.enable','/admin/config/content/formats/manage/{filter_format}/enable','/admin/config/content/formats/manage/%/enable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/content/formats/manage/{filter_format}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"filter_format.enable\";s:6:\"_title\";s:18:\"Enable text format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:20:\"filter_format.enable\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:45:\"/admin/config/content/formats/manage/%/enable\";s:8:\"numParts\";i:7;}}',7),('entity.image_style.collection','/admin/config/media/image-styles','/admin/config/media/image-styles',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/media/image-styles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"image_style\";s:6:\"_title\";s:12:\"Image styles\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/media/image\\-styles$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/media/image-styles\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/media/image-styles\";s:8:\"numParts\";i:4;}}',4),('entity.image_style.delete_form','/admin/config/media/image-styles/manage/{image_style}/delete','/admin/config/media/image-styles/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/media/image-styles/manage/{image_style}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"image_style.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"image_style.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:48:\"/admin/config/media/image-styles/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.image_style.edit_form','/admin/config/media/image-styles/manage/{image_style}','/admin/config/media/image-styles/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/media/image-styles/manage/{image_style}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"image_style.edit\";s:6:\"_title\";s:10:\"Edit style\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/config/media/image-styles/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.image_style.flush_form','/admin/config/media/image-styles/manage/{image_style}/flush','/admin/config/media/image-styles/manage/%/flush',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/media/image-styles/manage/{image_style}/flush\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"image_style.flush\";s:6:\"_title\";s:5:\"Flush\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/flush$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/flush\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:47:\"/admin/config/media/image-styles/manage/%/flush\";s:8:\"numParts\";i:7;}}',7),('entity.media.add_form','/media/add/{media_type}','/media/add/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/media/add/{media_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:9:\"media.add\";s:14:\"entity_type_id\";s:5:\"media\";s:15:\"_title_callback\";s:62:\"Drupal\\Core\\Entity\\Controller\\EntityController::addBundleTitle\";s:16:\"bundle_parameter\";s:10:\"media_type\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:18:\"media:{media_type}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:3:{s:4:\"type\";s:17:\"entity:media_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/media/add/(?P<media_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/media/add\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:12:\"/media/add/%\";s:8:\"numParts\";i:3;}}',3),('entity.media.add_page','/media/add','/media/add',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/media/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:55:\"Drupal\\Core\\Entity\\Controller\\EntityController::addPage\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";s:14:\"entity_type_id\";s:5:\"media\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:5:\"media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/media/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/media/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/media/add\";s:8:\"numParts\";i:2;}}',2),('entity.media.canonical','/media/{media}/edit','/media/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/media/{media}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:10:\"media.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"media.update\";s:5:\"media\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/media/(?P<media>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:13:\"/media/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.media.collection','/admin/content/media','/admin/content/media',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"media\";s:10:\"display_id\";s:15:\"media_page_list\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access media overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/media\";s:8:\"numParts\";i:3;}}',3),('entity.media.delete_form','/media/{media}/delete','/media/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/media/{media}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"media.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"media.delete\";s:5:\"media\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/media/(?P<media>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/media/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.media.delete_multiple_form','/media/delete','/media/delete',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/media/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"Drupal\\Core\\Entity\\Form\\DeleteMultipleForm\";s:14:\"entity_type_id\";s:5:\"media\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:5:\"media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/media/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/media/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/media/delete\";s:8:\"numParts\";i:2;}}',2),('entity.media.edit_form','/media/{media}/edit','/media/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/media/{media}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:10:\"media.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"media.update\";s:5:\"media\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/media/(?P<media>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:13:\"/media/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.media.field_ui_fields','/admin/structure/media/manage/{media_type}/fields','/admin/structure/media/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/media/manage/{media_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/media/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.media.revision','/media/{media}/revisions/{media_revision}/view','/media/%/revisions/%/view',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/media/{media}/revisions/{media_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController\";s:15:\"_title_callback\";s:65:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:28:\"media_revision.view revision\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:14:\"media_revision\";a:2:{s:4:\"type\";s:21:\"entity_revision:media\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/media/(?P<media>[^/]++)/revisions/(?P<media_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"media_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:25:\"/media/%/revisions/%/view\";s:8:\"numParts\";i:5;}}',5),('entity.media.revision_delete_form','/media/{media}/revision/{media_revision}/delete','/media/%/revision/%/delete',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/media/{media}/revision/{media_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"media.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:30:\"media_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:14:\"media_revision\";a:2:{s:4:\"type\";s:21:\"entity_revision:media\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/media/(?P<media>[^/]++)/revision/(?P<media_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"media_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/media/%/revision/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.media.revision_revert_form','/media/{media}/revision/{media_revision}/revert','/media/%/revision/%/revert',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/media/{media}/revision/{media_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"media.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:21:\"media_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:14:\"media_revision\";a:2:{s:4:\"type\";s:21:\"entity_revision:media\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/media/(?P<media>[^/]++)/revision/(?P<media_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"media_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/media/%/revision/%/revert\";s:8:\"numParts\";i:5;}}',5),('entity.media.version_history','/media/{media}/revisions','/media/%/revisions',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/media/{media}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"media.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:5:\"media\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/media/(?P<media>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:18:\"/media/%/revisions\";s:8:\"numParts\";i:3;}}',3),('entity.media_type.add_form','/admin/structure/media/add','/admin/structure/media/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/media/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:14:\"media_type.add\";s:14:\"entity_type_id\";s:10:\"media_type\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:10:\"media_type\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/media/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/media/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/media/add\";s:8:\"numParts\";i:4;}}',4),('entity.media_type.collection','/admin/structure/media','/admin/structure/media',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:10:\"media_type\";s:6:\"_title\";s:11:\"Media types\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer media types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/media\";s:8:\"numParts\";i:3;}}',3),('entity.media_type.delete_form','/admin/structure/media/manage/{media_type}/delete','/admin/structure/media/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/media/manage/{media_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"media_type.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"media_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/media/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.media_type.edit_form','/admin/structure/media/manage/{media_type}','/admin/structure/media/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/media/manage/{media_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"media_type.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"media_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/media/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.media_type.entity_permissions_form','/admin/structure/media/manage/{media_type}/permissions','/admin/structure/media/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/media/manage/{media_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:5:\"media\";s:18:\"bundle_entity_type\";s:10:\"media_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:10:\"media_type\";a:3:{s:4:\"type\";s:17:\"entity:media_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/media/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.menu.add_form','/admin/structure/menu/add','/admin/structure/menu/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/structure/menu/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:8:\"menu.add\";s:6:\"_title\";s:8:\"Add menu\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/structure/menu/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/structure/menu/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/structure/menu/add\";s:8:\"numParts\";i:4;}}',4),('entity.menu.add_link_form','/admin/structure/menu/manage/{menu}/add','/admin/structure/menu/manage/%/add',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/menu/manage/{menu}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\menu_link_content\\Controller\\MenuController::addLink\";s:6:\"_title\";s:13:\"Add menu link\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:17:\"menu_link_content\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/menu/manage/%/add\";s:8:\"numParts\";i:6;}}',6),('entity.menu.collection','/admin/structure/menu','/admin/structure/menu',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/structure/menu\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:4:\"menu\";s:6:\"_title\";s:5:\"Menus\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/structure/menu$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/structure/menu\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/structure/menu\";s:8:\"numParts\";i:3;}}',3),('entity.menu.delete_form','/admin/structure/menu/manage/{menu}/delete','/admin/structure/menu/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/menu/manage/{menu}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"menu.delete\";s:6:\"_title\";s:11:\"Delete menu\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"menu.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/menu/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.menu.edit_form','/admin/structure/menu/manage/{menu}','/admin/structure/menu/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/menu/manage/{menu}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:9:\"menu.edit\";s:15:\"_title_callback\";s:52:\"\\Drupal\\menu_ui\\Controller\\MenuController::menuTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"menu.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:30:\"/admin/structure/menu/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.menu_link_content.canonical','/admin/structure/menu/item/{menu_link_content}/edit','/admin/structure/menu/item/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"menu_link_content.default\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/item/%/edit\";s:8:\"numParts\";i:6;}}',6),('entity.menu_link_content.delete_form','/admin/structure/menu/item/{menu_link_content}/delete','/admin/structure/menu/item/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/menu/item/{menu_link_content}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"menu_link_content.delete\";s:6:\"_title\";s:16:\"Delete menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:35:\"/admin/structure/menu/item/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.menu_link_content.edit_form','/admin/structure/menu/item/{menu_link_content}/edit','/admin/structure/menu/item/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"menu_link_content.default\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/item/%/edit\";s:8:\"numParts\";i:6;}}',6),('entity.node.canonical','/node/{node}','/node/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/node/{node}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\node\\Controller\\NodeViewController::view\";s:15:\"_title_callback\";s:49:\"\\Drupal\\node\\Controller\\NodeViewController::title\";}s:12:\"requirements\";a:2:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"node.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/node/(?P<node>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/node/%\";s:8:\"numParts\";i:2;}}',2),('entity.node.delete_form','/node/{node}/delete','/node/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/node/{node}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"node.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"node.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/node/(?P<node>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/node/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.node.delete_multiple_form','/admin/content/node/delete','/admin/content/node/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/content/node/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\node\\Form\\DeleteMultiple\";s:14:\"entity_type_id\";s:4:\"node\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:4:\"node\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/node/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/node/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/content/node/delete\";s:8:\"numParts\";i:4;}}',4),('entity.node.edit_form','/node/{node}/edit','/node/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/node/{node}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:9:\"node.edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"node.update\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/node/(?P<node>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:12:\"/node/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.node.field_ui_fields','/admin/structure/types/manage/{node_type}/fields','/admin/structure/types/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/types/manage/{node_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/types/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.node.preview','/node/preview/{node_preview}/{view_mode_id}','/node/preview/%/%',12,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/node/preview/{node_preview}/{view_mode_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:51:\"\\Drupal\\node\\Controller\\NodePreviewController::view\";s:15:\"_title_callback\";s:52:\"\\Drupal\\node\\Controller\\NodePreviewController::title\";}s:12:\"requirements\";a:1:{s:20:\"_node_preview_access\";s:14:\"{node_preview}\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"node_preview\";a:2:{s:4:\"type\";s:12:\"node_preview\";s:9:\"converter\";s:42:\"drupal.proxy_original_service.node_preview\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:25:\"access_check.node.preview\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"node_preview\";i:1;s:12:\"view_mode_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/node/preview/(?P<node_preview>[^/]++)/(?P<view_mode_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"view_mode_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"node_preview\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/node/preview\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"node_preview\";i:1;s:12:\"view_mode_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:12;s:14:\"patternOutline\";s:17:\"/node/preview/%/%\";s:8:\"numParts\";i:4;}}',4),('entity.node.revision','/node/{node}/revisions/{node_revision}/view','/node/%/revisions/%/view',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/node/{node}/revisions/{node_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\node\\Controller\\NodeController::revisionShow\";s:15:\"_title_callback\";s:57:\"\\Drupal\\node\\Controller\\NodeController::revisionPageTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"node_revision.view revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:24:\"/node/%/revisions/%/view\";s:8:\"numParts\";i:5;}}',5),('entity.node.version_history','/node/{node}/revisions','/node/%/revisions',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/node/{node}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:9:\"Revisions\";s:11:\"_controller\";s:56:\"\\Drupal\\node\\Controller\\NodeController::revisionOverview\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:23:\"node.view all revisions\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/node/(?P<node>\\d+)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/node/%/revisions\";s:8:\"numParts\";i:3;}}',3),('entity.node_type.collection','/admin/structure/types','/admin/structure/types',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/types\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:9:\"node_type\";s:6:\"_title\";s:13:\"Content types\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/types$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/types\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/types\";s:8:\"numParts\";i:3;}}',3),('entity.node_type.delete_form','/admin/structure/types/manage/{node_type}/delete','/admin/structure/types/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/types/manage/{node_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"node_type.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"node_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/types/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.node_type.edit_form','/admin/structure/types/manage/{node_type}','/admin/structure/types/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/types/manage/{node_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"node_type.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/types/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.node_type.entity_permissions_form','/admin/structure/types/manage/{node_type}/permissions','/admin/structure/types/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/types/manage/{node_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:4:\"node\";s:18:\"bundle_entity_type\";s:9:\"node_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:3:{s:4:\"type\";s:16:\"entity:node_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/types/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.paragraph.field_ui_fields','/admin/structure/paragraphs_type/{paragraphs_type}/fields','/admin/structure/paragraphs_type/%/fields',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:41:\"/admin/structure/paragraphs_type/%/fields\";s:8:\"numParts\";i:5;}}',5),('entity.paragraphs_type.collection','/admin/structure/paragraphs_type','/admin/structure/paragraphs_type',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/structure/paragraphs_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:15:\"paragraphs_type\";s:6:\"_title\";s:16:\"Paragraphs types\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/structure/paragraphs_type$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:32:\"/admin/structure/paragraphs_type\";s:8:\"numParts\";i:3;}}',3),('entity.paragraphs_type.delete_form','/admin/structure/paragraphs_type/{paragraphs_type}/delete','/admin/structure/paragraphs_type/%/delete',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/paragraphs_type/{paragraphs_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"paragraphs_type.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:41:\"/admin/structure/paragraphs_type/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.paragraphs_type.edit_form','/admin/structure/paragraphs_type/{paragraphs_type}','/admin/structure/paragraphs_type/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/paragraphs_type/{paragraphs_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:20:\"paragraphs_type.edit\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/admin/structure/paragraphs_type/%\";s:8:\"numParts\";i:4;}}',4),('entity.path_alias.add_form','/admin/config/search/path/add','/admin/config/search/path/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/search/path/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:18:\"path_alias.default\";s:14:\"entity_type_id\";s:10:\"path_alias\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:10:\"path_alias\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/search/path/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/search/path/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:29:\"/admin/config/search/path/add\";s:8:\"numParts\";i:5;}}',5),('entity.path_alias.collection','/admin/config/search/path','/admin/config/search/path',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/search/path\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:10:\"path_alias\";s:6:\"_title\";s:11:\"URL aliases\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer url aliases\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/search/path$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/search/path\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/config/search/path\";s:8:\"numParts\";i:4;}}',4),('entity.path_alias.delete_form','/admin/config/search/path/delete/{path_alias}','/admin/config/search/path/delete/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/search/path/delete/{path_alias}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"path_alias.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"path_alias.delete\";s:10:\"path_alias\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"path_alias\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"path_alias\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/config/search/path/delete/(?P<path_alias>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:10:\"path_alias\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/search/path/delete\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"path_alias\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:34:\"/admin/config/search/path/delete/%\";s:8:\"numParts\";i:6;}}',6),('entity.path_alias.edit_form','/admin/config/search/path/edit/{path_alias}','/admin/config/search/path/edit/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/config/search/path/edit/{path_alias}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"path_alias.default\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"path_alias.update\";s:10:\"path_alias\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"path_alias\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"path_alias\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/admin/config/search/path/edit/(?P<path_alias>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:10:\"path_alias\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/search/path/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"path_alias\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:32:\"/admin/config/search/path/edit/%\";s:8:\"numParts\";i:6;}}',6),('entity.shortcut.canonical','/admin/config/user-interface/shortcut/link/{shortcut}','/admin/config/user-interface/shortcut/link/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut.default\";s:6:\"_title\";s:4:\"Edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/user-interface/shortcut/link/%\";s:8:\"numParts\";i:6;}}',6),('entity.shortcut.delete_form','/admin/config/user-interface/shortcut/link/{shortcut}/delete','/admin/config/user-interface/shortcut/link/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"shortcut.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.delete\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/config/user-interface/shortcut/link/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut.edit_form','/admin/config/user-interface/shortcut/link/{shortcut}','/admin/config/user-interface/shortcut/link/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut.default\";s:6:\"_title\";s:4:\"Edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/user-interface/shortcut/link/%\";s:8:\"numParts\";i:6;}}',6),('entity.shortcut.link_delete_inline','/admin/config/user-interface/shortcut/link/{shortcut}/delete-inline','/admin/config/user-interface/shortcut/link/%/delete-inline',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete-inline\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\shortcut\\Controller\\ShortcutController::deleteShortcutLinkInline\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:15:\"shortcut.delete\";s:11:\"_csrf_token\";s:4:\"TRUE\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/delete\\-inline$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/delete-inline\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:58:\"/admin/config/user-interface/shortcut/link/%/delete-inline\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut_set.collection','/admin/config/user-interface/shortcut','/admin/config/user-interface/shortcut',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/user-interface/shortcut\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"shortcut_set\";s:6:\"_title\";s:9:\"Shortcuts\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer shortcuts\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/user\\-interface/shortcut$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/user-interface/shortcut\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/user-interface/shortcut\";s:8:\"numParts\";i:4;}}',4),('entity.shortcut_set.customize_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize','/admin/config/user-interface/shortcut/manage/%/customize',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"shortcut_set.customize\";s:6:\"_title\";s:10:\"List links\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/customize$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/customize\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:56:\"/admin/config/user-interface/shortcut/manage/%/customize\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut_set.delete_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete','/admin/config/user-interface/shortcut/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"shortcut_set.delete\";s:6:\"_title\";s:19:\"Delete shortcut set\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:53:\"/admin/config/user-interface/shortcut/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut_set.edit_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}','/admin/config/user-interface/shortcut/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"shortcut_set.edit\";s:6:\"_title\";s:17:\"Edit shortcut set\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:46:\"/admin/config/user-interface/shortcut/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.add_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/add','/admin/structure/taxonomy/manage/%/add',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\taxonomy\\Controller\\TaxonomyController::addForm\";s:6:\"_title\";s:8:\"Add term\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:35:\"taxonomy_term:{taxonomy_vocabulary}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/taxonomy/manage/%/add\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.canonical','/taxonomy/term/{taxonomy_term}','/taxonomy/term/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/taxonomy/term/{taxonomy_term}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:57:\"\\Drupal\\taxonomy\\Controller\\TaxonomyController::termTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:13:\"taxonomy_term\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/taxonomy/term/%\";s:8:\"numParts\";i:3;}}',3),('entity.taxonomy_term.delete_form','/taxonomy/term/{taxonomy_term}/delete','/taxonomy/term/%/delete',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/taxonomy/term/{taxonomy_term}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"taxonomy_term.delete\";s:6:\"_title\";s:11:\"Delete term\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"taxonomy_term.delete\";s:13:\"taxonomy_term\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:23:\"/taxonomy/term/%/delete\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_term.edit_form','/taxonomy/term/{taxonomy_term}/edit','/taxonomy/term/%/edit',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/taxonomy/term/{taxonomy_term}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"taxonomy_term.default\";s:6:\"_title\";s:9:\"Edit term\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"taxonomy_term.update\";s:13:\"taxonomy_term\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:21:\"/taxonomy/term/%/edit\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_term.field_ui_fields','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields','/admin/structure/taxonomy/manage/%/overview/fields',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/taxonomy/manage/%/overview/fields\";s:8:\"numParts\";i:7;}}',7),('entity.taxonomy_term.revision','/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view','/taxonomy/term/%/revision/%/view',53,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController\";s:15:\"_title_callback\";s:65:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:36:\"taxonomy_term_revision.view revision\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:96:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:32:\"/taxonomy/term/%/revision/%/view\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.revision_delete_form','/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete','/taxonomy/term/%/revision/%/delete',53,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"taxonomy_term.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:38:\"taxonomy_term_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:34:\"/taxonomy/term/%/revision/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.revision_revert_form','/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert','/taxonomy/term/%/revision/%/revert',53,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"taxonomy_term.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"taxonomy_term_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:34:\"/taxonomy/term/%/revision/%/revert\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.version_history','/taxonomy/term/{taxonomy_term}/revisions','/taxonomy/term/%/revisions',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/taxonomy/term/{taxonomy_term}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:32:\"taxonomy_term.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:26:\"/taxonomy/term/%/revisions\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_vocabulary.add_form','/admin/structure/taxonomy/add','/admin/structure/taxonomy/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/taxonomy/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:27:\"taxonomy_vocabulary.default\";s:14:\"entity_type_id\";s:19:\"taxonomy_vocabulary\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:19:\"taxonomy_vocabulary\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/taxonomy/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/taxonomy/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/taxonomy/add\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_vocabulary.collection','/admin/structure/taxonomy','/admin/structure/taxonomy',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/structure/taxonomy\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:19:\"taxonomy_vocabulary\";s:6:\"_title\";s:8:\"Taxonomy\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:44:\"administer taxonomy+access taxonomy overview\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/structure/taxonomy$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/structure/taxonomy\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/structure/taxonomy\";s:8:\"numParts\";i:3;}}',3),('entity.taxonomy_vocabulary.delete_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete','/admin/structure/taxonomy/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:26:\"taxonomy_vocabulary.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:26:\"taxonomy_vocabulary.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/taxonomy/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_vocabulary.edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}','/admin/structure/taxonomy/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:27:\"taxonomy_vocabulary.default\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:26:\"taxonomy_vocabulary.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:34:\"/admin/structure/taxonomy/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.taxonomy_vocabulary.entity_permissions_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions','/admin/structure/taxonomy/manage/%/overview/permissions',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:18:\"bundle_entity_type\";s:19:\"taxonomy_vocabulary\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/overview/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:55:\"/admin/structure/taxonomy/manage/%/overview/permissions\";s:8:\"numParts\";i:7;}}',7),('entity.taxonomy_vocabulary.overview_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview','/admin/structure/taxonomy/manage/%/overview',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:5:\"_form\";s:34:\"Drupal\\taxonomy\\Form\\OverviewTerms\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:44:\"taxonomy_vocabulary.access taxonomy overview\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:21:\"with_config_overrides\";b:1;s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/overview\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/taxonomy/manage/%/overview\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_vocabulary.reset_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset','/admin/structure/taxonomy/manage/%/reset',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"taxonomy_vocabulary.reset\";s:6:\"_title\";s:5:\"Reset\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:37:\"taxonomy_vocabulary.reset all weights\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:21:\"with_config_overrides\";b:1;s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/reset$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reset\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/taxonomy/manage/%/reset\";s:8:\"numParts\";i:6;}}',6),('entity.tb_megamenu.add_form','/admin/structure/tb-megamenu/add','/admin/structure/tb-megamenu/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/structure/tb-megamenu/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"tb_megamenu.add\";s:6:\"_title\";s:15:\"Add a Mega Menu\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer tb_megamenu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/structure/tb\\-megamenu/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/tb-megamenu/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/structure/tb-megamenu/add\";s:8:\"numParts\";i:4;}}',4),('entity.tb_megamenu.collection','/admin/structure/tb-megamenu','/admin/structure/tb-megamenu',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/structure/tb-megamenu\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"tb_megamenu\";s:6:\"_title\";s:12:\"TB Mega Menu\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer tb_megamenu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/tb\\-megamenu$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/tb-megamenu\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/structure/tb-megamenu\";s:8:\"numParts\";i:3;}}',3),('entity.tb_megamenu.delete_form','/admin/structure/tb-megamenu/{tb_megamenu}/delete','/admin/structure/tb-megamenu/%/delete',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/tb-megamenu/{tb_megamenu}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"tb_megamenu.delete\";s:6:\"_title\";s:16:\"Delete Mega Menu\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:22:\"administer tb_megamenu\";s:11:\"tb_megamenu\";s:14:\"[a-zA-Z0-9_-]+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"tb_megamenu\";a:2:{s:4:\"type\";s:18:\"entity:tb_megamenu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/tb\\-megamenu/(?P<tb_megamenu>[a-zA-Z0-9_-]+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:14:\"[a-zA-Z0-9_-]+\";i:3;s:11:\"tb_megamenu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/tb-megamenu\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:37:\"/admin/structure/tb-megamenu/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.tb_megamenu.edit_form','/admin/structure/tb-megamenu/{tb_megamenu}','/admin/structure/tb-megamenu/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/tb-megamenu/{tb_megamenu}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:19:\"Config TB Mega Menu\";s:11:\"_controller\";s:72:\"\\Drupal\\tb_megamenu\\Controller\\TBMegaMenuAdminController::configMegaMenu\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:22:\"administer tb_megamenu\";s:11:\"tb_megamenu\";s:14:\"[a-zA-Z0-9_-]+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"tb_megamenu\";a:2:{s:4:\"type\";s:18:\"entity:tb_megamenu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/tb\\-megamenu/(?P<tb_megamenu>[a-zA-Z0-9_-]+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:14:\"[a-zA-Z0-9_-]+\";i:3;s:11:\"tb_megamenu\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/tb-megamenu\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:30:\"/admin/structure/tb-megamenu/%\";s:8:\"numParts\";i:4;}}',4),('entity.user.admin_form','/admin/config/people/accounts','/admin/config/people/accounts',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/people/accounts\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\user\\AccountSettingsForm\";s:6:\"_title\";s:16:\"Account settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer account settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/people/accounts$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/people/accounts\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/people/accounts\";s:8:\"numParts\";i:4;}}',4),('entity.user.cancel_form','/user/{user}/cancel','/user/%/cancel',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/user/{user}/cancel\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:14:\"Cancel account\";s:12:\"_entity_form\";s:11:\"user.cancel\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"user.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/user/(?P<user>\\d+)/cancel$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/cancel\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/user/%/cancel\";s:8:\"numParts\";i:3;}}',3),('entity.user.canonical','/user/{user}','/user/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/{user}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_view\";s:9:\"user.full\";s:15:\"_title_callback\";s:48:\"Drupal\\user\\Controller\\UserController::userTitle\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"user.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/user/(?P<user>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/user/%\";s:8:\"numParts\";i:2;}}',2),('entity.user.collection','/admin/people','/admin/people',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:17:\"user_admin_people\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:16:\"administer users\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/people\";s:8:\"numParts\";i:2;}}',2),('entity.user.contact_form','/user/{user}/contact','/user/%/contact',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/user/{user}/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:65:\"\\Drupal\\contact\\Controller\\ContactController::contactPersonalPage\";}s:12:\"requirements\";a:2:{s:28:\"_access_contact_personal_tab\";s:4:\"TRUE\";s:4:\"user\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:29:\"access_check.contact_personal\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/user/(?P<user>\\d+)/contact$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/user/%/contact\";s:8:\"numParts\";i:3;}}',3),('entity.user.edit_form','/user/{user}/edit','/user/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/user/{user}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"user.default\";s:15:\"_title_callback\";s:48:\"Drupal\\user\\Controller\\UserController::userTitle\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"user.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/user/(?P<user>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:12:\"/user/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.user.field_ui_fields','/admin/config/people/accounts/fields','/admin/config/people/accounts/fields',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/config/people/accounts/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/config/people/accounts/fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:36:\"/admin/config/people/accounts/fields\";s:8:\"numParts\";i:5;}}',5),('entity.user_role.collection','/admin/people/roles','/admin/people/roles',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/people/roles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:9:\"user_role\";s:6:\"_title\";s:5:\"Roles\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/people/roles$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/people/roles\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/people/roles\";s:8:\"numParts\";i:3;}}',3),('entity.user_role.delete_form','/admin/people/roles/manage/{user_role}/delete','/admin/people/roles/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/people/roles/manage/{user_role}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"user_role.delete\";s:6:\"_title\";s:11:\"Delete role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:35:\"/admin/people/roles/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.user_role.edit_form','/admin/people/roles/manage/{user_role}','/admin/people/roles/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/people/roles/manage/{user_role}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"user_role.default\";s:6:\"_title\";s:9:\"Edit role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/people/roles/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.user_role.edit_permissions_form','/admin/people/permissions/{user_role}','/admin/people/permissions/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/people/permissions/{user_role}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:49:\"\\Drupal\\user\\Form\\UserPermissionsRoleSpecificForm\";s:6:\"_title\";s:9:\"Edit role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/people/permissions/(?P<user_role>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/people/permissions\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:27:\"/admin/people/permissions/%\";s:8:\"numParts\";i:4;}}',4),('entity.view.break_lock_form','/admin/structure/views/view/{view}/break-lock','/admin/structure/views/view/%/break-lock',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/views/view/{view}/break-lock\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"view.break_lock\";s:6:\"_title\";s:10:\"Break lock\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:15:\"view.break-lock\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/views/view/(?P<view>[^/]++)/break\\-lock$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/break-lock\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/views/view/%/break-lock\";s:8:\"numParts\";i:6;}}',6),('entity.view.collection','/admin/structure/views','/admin/structure/views',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/views\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:4:\"view\";s:6:\"_title\";s:5:\"Views\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/views$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/views\";s:8:\"numParts\";i:3;}}',3),('entity.view.delete_form','/admin/structure/views/view/{view}/delete','/admin/structure/views/view/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/views/view/{view}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"view.delete\";s:6:\"_title\";s:11:\"Delete view\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/views/view/(?P<view>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:36:\"/admin/structure/views/view/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.view.disable','/admin/structure/views/view/{view}/disable','/admin/structure/views/view/%/disable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/views/view/{view}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::ajaxOperation\";s:2:\"op\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"view.disable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/views/view/(?P<view>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/views/view/%/disable\";s:8:\"numParts\";i:6;}}',6),('entity.view.duplicate_form','/admin/structure/views/view/{view}/duplicate','/admin/structure/views/view/%/duplicate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/views/view/{view}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"view.duplicate\";s:6:\"_title\";s:14:\"Duplicate view\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"view.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/views/view/(?P<view>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/views/view/%/duplicate\";s:8:\"numParts\";i:6;}}',6),('entity.view.edit_display_form','/admin/structure/views/view/{view}/edit/{display_id}','/admin/structure/views/view/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/structure/views/view/{view}/edit/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::edit\";s:10:\"display_id\";N;}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/views/view/(?P<view>[^/]++)/edit(?:/(?P<display_id>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/views/view/%/edit\";s:8:\"numParts\";i:7;}}',7),('entity.view.edit_form','/admin/structure/views/view/{view}','/admin/structure/views/view/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/views/view/{view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::edit\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/structure/views/view/(?P<view>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/views/view/%\";s:8:\"numParts\";i:5;}}',5),('entity.view.enable','/admin/structure/views/view/{view}/enable','/admin/structure/views/view/%/enable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/views/view/{view}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::ajaxOperation\";s:2:\"op\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.enable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/views/view/(?P<view>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:36:\"/admin/structure/views/view/%/enable\";s:8:\"numParts\";i:6;}}',6),('entity.view.preview_form','/admin/structure/views/view/{view}/preview/{display_id}','/admin/structure/views/view/%/preview',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/views/view/{view}/preview/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"view.preview\";s:10:\"display_id\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/views/view/(?P<view>[^/]++)/preview(?:/(?P<display_id>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/preview\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/views/view/%/preview\";s:8:\"numParts\";i:7;}}',7),('entity.webform.access_denied','/webform/{webform}/access-denied','/webform/%/access-denied',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/webform/{webform}/access-denied\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::accessDenied\";s:15:\"_title_callback\";s:69:\"\\Drupal\\webform\\Controller\\WebformEntityController::accessDeniedTitle\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/webform/(?P<webform>[^/]++)/access\\-denied$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/access-denied\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:24:\"/webform/%/access-denied\";s:8:\"numParts\";i:3;}}',3),('entity.webform.add_form','/admin/structure/webform/add','/admin/structure/webform/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/structure/webform/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"webform.add\";s:6:\"_title\";s:11:\"Add webform\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:7:\"webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/structure/webform/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/webform/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/structure/webform/add\";s:8:\"numParts\";i:4;}}',4),('entity.webform.assets.css','/webform/css/{webform}/custom.css','/webform/css/%/custom.css',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/webform/css/{webform}/custom.css\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:55:\"\\Drupal\\webform\\Controller\\WebformEntityController::css\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/webform/css/(?P<webform>[^/]++)/custom\\.css$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/custom.css\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/webform/css\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:25:\"/webform/css/%/custom.css\";s:8:\"numParts\";i:4;}}',4),('entity.webform.assets.javascript','/webform/javascript/{webform}/custom.js','/webform/javascript/%/custom.js',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/webform/javascript/{webform}/custom.js\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\webform\\Controller\\WebformEntityController::javascript\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/webform/javascript/(?P<webform>[^/]++)/custom\\.js$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/custom.js\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/javascript\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:31:\"/webform/javascript/%/custom.js\";s:8:\"numParts\";i:4;}}',4),('entity.webform.autocomplete','/admin/structure/webform/autocomplete','/admin/structure/webform/autocomplete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/structure/webform/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::autocomplete\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkOverviewAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/structure/webform/autocomplete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/webform/autocomplete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/structure/webform/autocomplete\";s:8:\"numParts\";i:4;}}',4),('entity.webform.autocomplete.archived','/admin/structure/webform/autocomplete/archived','/admin/structure/webform/autocomplete/archived',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/webform/autocomplete/archived\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::autocomplete\";s:8:\"archived\";b:1;}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkOverviewAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/admin/structure/webform/autocomplete/archived$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/structure/webform/autocomplete/archived\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/autocomplete/archived\";s:8:\"numParts\";i:5;}}',5),('entity.webform.canonical','/webform/{webform}','/webform/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/webform/{webform}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\webform\\Controller\\WebformEntityController::addForm\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform.submission_page\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/webform/(?P<webform>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/webform/%\";s:8:\"numParts\";i:2;}}',2),('entity.webform.collection','/admin/structure/webform','/admin/structure/webform',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/structure/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:7:\"webform\";s:6:\"_title\";s:8:\"Webforms\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkOverviewAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/structure/webform$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/structure/webform\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/structure/webform\";s:8:\"numParts\";i:3;}}',3),('entity.webform.confirmation','/webform/{webform}/confirmation','/webform/%/confirmation',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/webform/{webform}/confirmation\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::confirmation\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/webform/(?P<webform>[^/]++)/confirmation$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/confirmation\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:23:\"/webform/%/confirmation\";s:8:\"numParts\";i:3;}}',3),('entity.webform.delete_form','/admin/structure/webform/manage/{webform}/delete','/admin/structure/webform/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"webform.delete\";s:6:\"_title\";s:14:\"Delete webform\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.webform.duplicate_form','/admin/structure/webform/manage/{webform}/duplicate','/admin/structure/webform/manage/%/duplicate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/webform/manage/{webform}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"webform.duplicate\";s:6:\"_title\";s:17:\"Duplicate webform\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"webform.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/manage/%/duplicate\";s:8:\"numParts\";i:6;}}',6),('entity.webform.edit_form','/admin/structure/webform/manage/{webform}','/admin/structure/webform/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/webform/manage/{webform}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"webform.edit\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/structure/webform/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.webform.export_form','/admin/structure/webform/manage/{webform}/export','/admin/structure/webform/manage/%/export',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/export\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"webform.export\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/export$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/export\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/export\";s:8:\"numParts\";i:6;}}',6),('entity.webform.handler','/admin/structure/webform/manage/{webform}/handlers/add','/admin/structure/webform/manage/%/handlers/add',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/webform/manage/{webform}/handlers/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:71:\"\\Drupal\\webform\\Controller\\WebformPluginHandlerController::listHandlers\";s:6:\"_title\";s:16:\"Select a handler\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:63:\"\\Drupal\\webform\\Access\\WebformHandlerAccess::checkHandlerAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/handlers/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/manage/%/handlers/add\";s:8:\"numParts\";i:7;}}',7),('entity.webform.handler.add_email','/admin/structure/webform/manage/{webform}/handlers/add/email','/admin/structure/webform/manage/%/handlers/add/email',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/webform/manage/{webform}/handlers/add/email\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:42:\"\\Drupal\\webform\\Form\\WebformHandlerAddForm\";s:6:\"_title\";s:9:\"Add email\";s:15:\"webform_handler\";s:5:\"email\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:63:\"\\Drupal\\webform\\Access\\WebformHandlerAccess::checkHandlerAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/add/email$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/handlers/add/email\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/handlers/add/email\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.add_form','/admin/structure/webform/manage/{webform}/handlers/add/{webform_handler}','/admin/structure/webform/manage/%/handlers/add/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/webform/manage/{webform}/handlers/add/{webform_handler}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\webform\\Form\\WebformHandlerAddForm\";s:6:\"_title\";s:19:\"Add webform handler\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:63:\"\\Drupal\\webform\\Access\\WebformHandlerAccess::checkHandlerAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/add/(?P<webform_handler>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/handlers/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/handlers/add/%\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.delete_form','/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/delete','/admin/structure/webform/manage/%/handlers/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:45:\"\\Drupal\\webform\\Form\\WebformHandlerDeleteForm\";s:6:\"_title\";s:22:\"Delete webform handler\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/handlers/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.disable','/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/disable','/admin/structure/webform/manage/%/handlers/%/disable',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityHandlersForm::ajaxOperation\";s:9:\"operation\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/handlers/%/disable\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.duplicate_form','/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/duplicate','/admin/structure/webform/manage/%/handlers/%/duplicate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:48:\"\\Drupal\\webform\\Form\\WebformHandlerDuplicateForm\";s:6:\"_title\";s:25:\"Duplicate webform handler\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:54:\"/admin/structure/webform/manage/%/handlers/%/duplicate\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.edit_form','/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/edit','/admin/structure/webform/manage/%/handlers/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformHandlerEditForm\";s:6:\"_title\";s:20:\"Edit webform handler\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/manage/%/handlers/%/edit\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.enable','/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/enable','/admin/structure/webform/manage/%/handlers/%/enable',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityHandlersForm::ajaxOperation\";s:9:\"operation\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/handlers/%/enable\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handlers','/admin/structure/webform/manage/{webform}/handlers','/admin/structure/webform/manage/%/handlers',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/webform/manage/{webform}/handlers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"webform.handlers\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/manage/%/handlers\";s:8:\"numParts\";i:6;}}',6),('entity.webform.multiple_delete_confirm','/admin/structure/webform/delete','/admin/structure/webform/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/webform/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:52:\"\\Drupal\\webform\\Form\\WebformEntityDeleteMultipleForm\";s:14:\"entity_type_id\";s:7:\"webform\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:7:\"webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/webform/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/webform/delete\";s:8:\"numParts\";i:4;}}',4),('entity.webform.results.source_entity.autocomplete','/admin/structure/webform/manage/{webform}/results/source-entity/autocomplete','/admin/structure/webform/manage/%/results/source-entity/autocomplete',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/webform/manage/{webform}/results/source-entity/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:81:\"\\Drupal\\webform\\Controller\\WebformSubmissionsController::sourceEntityAutocomplete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/source\\-entity/autocomplete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/results/source-entity/autocomplete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:68:\"/admin/structure/webform/manage/%/results/source-entity/autocomplete\";s:8:\"numParts\";i:8;}}',8),('entity.webform.results_clear','/admin/structure/webform/manage/{webform}/results/clear','/admin/structure/webform/manage/%/results/clear',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/results/clear\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"Drupal\\webform\\Form\\WebformResultsClearForm\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:28:\"webform.submission_purge_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/clear$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/results/clear\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/results/clear\";s:8:\"numParts\";i:7;}}',7),('entity.webform.results_export','/admin/structure/webform/manage/{webform}/results/download','/admin/structure/webform/manage/%/results/download',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/webform/manage/{webform}/results/download\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformResultsExportController::index\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/download$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/results/download\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/webform/manage/%/results/download\";s:8:\"numParts\";i:7;}}',7),('entity.webform.results_export_file','/admin/structure/webform/manage/{webform}/results/download/file/{filename}','/admin/structure/webform/manage/%/results/download/file/%',494,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/structure/webform/manage/{webform}/results/download/file/{filename}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:63:\"\\Drupal\\webform\\Controller\\WebformResultsExportController::file\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"filename\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/download/file/(?P<filename>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"filename\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/results/download/file\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"filename\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:494;s:14:\"patternOutline\";s:57:\"/admin/structure/webform/manage/%/results/download/file/%\";s:8:\"numParts\";i:9;}}',9),('entity.webform.results_submissions','/admin/structure/webform/manage/{webform}/results/submissions/{submission_view}','/admin/structure/webform/manage/%/results/submissions',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/webform/manage/{webform}/results/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/results/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/results/submissions\";s:8:\"numParts\";i:8;}}',8),('entity.webform.results_submissions.custom','/admin/structure/webform/manage/{webform}/results/submissions/custom','/admin/structure/webform/manage/%/results/submissions/custom',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/webform/manage/{webform}/results/submissions/custom\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"Drupal\\webform\\Form\\WebformResultsCustomForm\";s:6:\"_title\";s:15:\"Customize table\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/submissions/custom$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/results/submissions/custom\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:60:\"/admin/structure/webform/manage/%/results/submissions/custom\";s:8:\"numParts\";i:8;}}',8),('entity.webform.results_submissions.custom.user','/admin/structure/webform/manage/{webform}/results/submissions/custom/user','/admin/structure/webform/manage/%/results/submissions/custom/user',495,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/results/submissions/custom/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:44:\"Drupal\\webform\\Form\\WebformResultsCustomForm\";s:6:\"_title\";s:18:\"Customize my table\";s:4:\"type\";s:4:\"user\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/submissions/custom/user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/results/submissions/custom/user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:495;s:14:\"patternOutline\";s:65:\"/admin/structure/webform/manage/%/results/submissions/custom/user\";s:8:\"numParts\";i:9;}}',9),('entity.webform.settings','/admin/structure/webform/manage/{webform}/settings','/admin/structure/webform/manage/%/settings',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/webform/manage/{webform}/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"webform.settings\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/settings\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/manage/%/settings\";s:8:\"numParts\";i:6;}}',6),('entity.webform.settings_access','/admin/structure/webform/manage/{webform}/access','/admin/structure/webform/manage/%/access',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/access\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform.settings_access\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/access$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/access\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/access\";s:8:\"numParts\";i:6;}}',6),('entity.webform.settings_assets','/admin/structure/webform/manage/{webform}/settings/assets','/admin/structure/webform/manage/%/settings/assets',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/webform/manage/{webform}/settings/assets\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform.settings_assets\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"edit webform assets\";s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/assets$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/settings/assets\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/manage/%/settings/assets\";s:8:\"numParts\";i:7;}}',7),('entity.webform.settings_confirmation','/admin/structure/webform/manage/{webform}/settings/confirmation','/admin/structure/webform/manage/%/settings/confirmation',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/webform/manage/{webform}/settings/confirmation\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"webform.settings_confirmation\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/confirmation$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/settings/confirmation\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:55:\"/admin/structure/webform/manage/%/settings/confirmation\";s:8:\"numParts\";i:7;}}',7),('entity.webform.settings_form','/admin/structure/webform/manage/{webform}/settings/form','/admin/structure/webform/manage/%/settings/form',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/settings/form\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"webform.settings_form\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/form$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/settings/form\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/settings/form\";s:8:\"numParts\";i:7;}}',7),('entity.webform.settings_submissions','/admin/structure/webform/manage/{webform}/settings/submissions','/admin/structure/webform/manage/%/settings/submissions',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/webform/manage/{webform}/settings/submissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:28:\"webform.settings_submissions\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/submissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/settings/submissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:54:\"/admin/structure/webform/manage/%/settings/submissions\";s:8:\"numParts\";i:7;}}',7),('entity.webform.test_form','/webform/{webform}/test','/webform/%/test',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/webform/{webform}/test\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\webform\\Controller\\WebformTestController::testForm\";s:15:\"_title_callback\";s:55:\"\\Drupal\\webform\\Controller\\WebformTestController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.test\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/webform/(?P<webform>[^/]++)/test$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/test\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/webform/%/test\";s:8:\"numParts\";i:3;}}',3),('entity.webform.user.drafts','/webform/{webform}/drafts/{submission_view}','/webform/%/drafts',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/webform/{webform}/drafts/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:6:\"Drafts\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform.submission_create\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess::checkDraftsAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/webform/(?P<webform>[^/]++)/drafts(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/drafts\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/webform/%/drafts\";s:8:\"numParts\";i:4;}}',4),('entity.webform.user.submission','/webform/{webform}/submissions/{webform_submission}','/webform/%/submissions/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/webform/{webform}/submissions/{webform_submission}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"html\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:24:\"/webform/%/submissions/%\";s:8:\"numParts\";i:4;}}',4),('entity.webform.user.submission.delete','/webform/{webform}/submissions/{webform_submission}/delete','/webform/%/submissions/%/delete',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/webform/{webform}/submissions/{webform_submission}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"webform_submission.delete\";s:6:\"_title\";s:25:\"Delete webform submission\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.delete\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:31:\"/webform/%/submissions/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.webform.user.submission.duplicate','/webform/{webform}/submissions/{webform_submission}/duplicate','/webform/%/submissions/%/duplicate',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/webform/{webform}/submissions/{webform_submission}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:28:\"webform_submission.duplicate\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"duplicate\";b:1;s:7:\"setting\";s:25:\"submission_user_duplicate\";s:5:\"value\";b:1;}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:28:\"webform_submission.duplicate\";s:14:\"_custom_access\";s:68:\"\\Drupal\\webform\\Access\\WebformEntityAccess::checkWebformSettingValue\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:34:\"/webform/%/submissions/%/duplicate\";s:8:\"numParts\";i:5;}}',5),('entity.webform.user.submission.edit','/webform/{webform}/submissions/{webform_submission}/edit','/webform/%/submissions/%/edit',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/webform/{webform}/submissions/{webform_submission}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform_submission.edit\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:29:\"/webform/%/submissions/%/edit\";s:8:\"numParts\";i:5;}}',5),('entity.webform.user.submissions','/webform/{webform}/submissions/{submission_view}','/webform/%/submissions',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/webform/{webform}/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:11:\"Submissions\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:27:\"webform.submission_view_own\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/webform/(?P<webform>[^/]++)/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:22:\"/webform/%/submissions\";s:8:\"numParts\";i:4;}}',4),('entity.webform.variant','/admin/structure/webform/manage/{webform}/variants/add','/admin/structure/webform/manage/%/variants/add',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/webform/manage/{webform}/variants/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:71:\"\\Drupal\\webform\\Controller\\WebformPluginVariantController::listVariants\";s:6:\"_title\";s:16:\"Select a variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/variants/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/manage/%/variants/add\";s:8:\"numParts\";i:7;}}',7),('entity.webform.variant.add_form','/admin/structure/webform/manage/{webform}/variants/add/{webform_variant}','/admin/structure/webform/manage/%/variants/add/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/webform/manage/{webform}/variants/add/{webform_variant}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\webform\\Form\\WebformVariantAddForm\";s:6:\"_title\";s:19:\"Add webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:69:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantCreateAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/add/(?P<webform_variant>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/variants/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/variants/add/%\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.apply_form','/admin/structure/webform/manage/{webform}/variants/apply','/admin/structure/webform/manage/%/variants/apply',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/webform/manage/{webform}/variants/apply\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\webform\\Form\\WebformVariantApplyForm\";s:6:\"_title\";s:21:\"Apply webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/apply$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/variants/apply\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/variants/apply\";s:8:\"numParts\";i:7;}}',7),('entity.webform.variant.delete_form','/admin/structure/webform/manage/{webform}/variants/{webform_variant}/delete','/admin/structure/webform/manage/%/variants/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:45:\"\\Drupal\\webform\\Form\\WebformVariantDeleteForm\";s:6:\"_title\";s:22:\"Delete webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/variants/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.disable','/admin/structure/webform/manage/{webform}/variants/{webform_variant}/disable','/admin/structure/webform/manage/%/variants/%/disable',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityVariantsForm::ajaxOperation\";s:9:\"operation\";s:7:\"disable\";}s:12:\"requirements\";a:4:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:4:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";i:3;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/variants/%/disable\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.duplicate_form','/admin/structure/webform/manage/{webform}/variants/{webform_variant}/duplicate','/admin/structure/webform/manage/%/variants/%/duplicate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:48:\"\\Drupal\\webform\\Form\\WebformVariantDuplicateForm\";s:6:\"_title\";s:25:\"Duplicate webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:54:\"/admin/structure/webform/manage/%/variants/%/duplicate\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.edit_form','/admin/structure/webform/manage/{webform}/variants/{webform_variant}/edit','/admin/structure/webform/manage/%/variants/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformVariantEditForm\";s:6:\"_title\";s:20:\"Edit webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/manage/%/variants/%/edit\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.enable','/admin/structure/webform/manage/{webform}/variants/{webform_variant}/enable','/admin/structure/webform/manage/%/variants/%/enable',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityVariantsForm::ajaxOperation\";s:9:\"operation\";s:6:\"enable\";}s:12:\"requirements\";a:4:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:4:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";i:3;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/variants/%/enable\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.test_form','/admin/structure/webform/manage/{webform}/variants/test','/admin/structure/webform/manage/%/variants/test',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/variants/test\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformVariantViewForm\";s:6:\"_title\";s:21:\"Test webform variants\";s:9:\"operation\";s:4:\"test\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/test$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/variants/test\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/variants/test\";s:8:\"numParts\";i:7;}}',7),('entity.webform.variant.view_form','/admin/structure/webform/manage/{webform}/variants/view','/admin/structure/webform/manage/%/variants/view',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/variants/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformVariantViewForm\";s:6:\"_title\";s:21:\"View webform variants\";s:9:\"operation\";s:4:\"view\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/view$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/variants/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/variants/view\";s:8:\"numParts\";i:7;}}',7),('entity.webform.variants','/admin/structure/webform/manage/{webform}/variants','/admin/structure/webform/manage/%/variants',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/webform/manage/{webform}/variants\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"webform.variants\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/manage/%/variants\";s:8:\"numParts\";i:6;}}',6),('entity.webform_options.add_form','/admin/structure/webform/options/manage/add','/admin/structure/webform/options/manage/add',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/structure/webform/options/manage/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"webform_options.add\";s:6:\"_title\";s:19:\"Add webform options\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:15:\"webform_options\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/structure/webform/options/manage/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/options/manage/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/options/manage/add\";s:8:\"numParts\";i:6;}}',6),('entity.webform_options.autocomplete','/admin/structure/webform/options/autocomplete','/admin/structure/webform/options/autocomplete',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/webform/options/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:65:\"\\Drupal\\webform\\Controller\\WebformOptionsController::autocomplete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/webform/options/autocomplete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/structure/webform/options/autocomplete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:45:\"/admin/structure/webform/options/autocomplete\";s:8:\"numParts\";i:5;}}',5),('entity.webform_options.collection','/admin/structure/webform/options/manage','/admin/structure/webform/options/manage',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/webform/options/manage\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:15:\"webform_options\";s:6:\"_title\";s:17:\"Webforms: Options\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/structure/webform/options/manage$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/webform/options/manage\";s:8:\"numParts\";i:5;}}',5),('entity.webform_options.delete_form','/admin/structure/webform/options/{webform_options}/delete','/admin/structure/webform/options/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/webform/options/{webform_options}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"webform_options.delete\";s:6:\"_title\";s:22:\"Delete webform options\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:22:\"webform_options.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/webform/options/(?P<webform_options>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/webform/options\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/webform/options/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.webform_options.duplicate_form','/admin/structure/webform/options/{webform_options}/duplicate','/admin/structure/webform/options/%/duplicate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/webform/options/{webform_options}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"webform_options.duplicate\";s:6:\"_title\";s:25:\"Duplicate webform options\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_options.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/webform/options/(?P<webform_options>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/webform/options\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/webform/options/%/duplicate\";s:8:\"numParts\";i:6;}}',6),('entity.webform_options.edit_form','/admin/structure/webform/options/manage/{webform_options}/edit','/admin/structure/webform/options/manage/%/edit',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/webform/options/manage/{webform_options}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"webform_options.edit\";s:6:\"_title\";s:20:\"Edit webform options\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:22:\"webform_options.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/webform/options/manage/(?P<webform_options>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/options/manage/%/edit\";s:8:\"numParts\";i:7;}}',7),('entity.webform_submission.access_denied','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/access-denied','/admin/structure/webform/manage/%/submission/%/access-denied',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/access-denied\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::accessDenied\";s:15:\"_title_callback\";s:73:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::accessDeniedTitle\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/access\\-denied$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/access-denied\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:60:\"/admin/structure/webform/manage/%/submission/%/access-denied\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.canonical','/admin/structure/webform/manage/{webform}/submission/{webform_submission}','/admin/structure/webform/manage/%/submission/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"html\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/manage/%/submission/%\";s:8:\"numParts\";i:7;}}',7),('entity.webform_submission.collection','/admin/structure/webform/submissions/manage/{submission_view}','/admin/structure/webform/submissions/manage',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/webform/submissions/manage/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:21:\"Webforms: Submissions\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform\\Access\\WebformAccountAccess:checkSubmissionAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/webform/submissions/manage(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/submissions/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/submissions/manage\";s:8:\"numParts\";i:6;}}',6),('entity.webform_submission.collection_purge','/admin/structure/webform/submissions/purge','/admin/structure/webform/submissions/purge',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/webform/submissions/purge\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"Drupal\\webform\\Form\\WebformSubmissionsPurgeForm\";s:6:\"_title\";s:27:\"Webforms: Submissions purge\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/admin/structure/webform/submissions/purge$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/webform/submissions/purge\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/submissions/purge\";s:8:\"numParts\";i:5;}}',5),('entity.webform_submission.delete_form','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/delete','/admin/structure/webform/manage/%/submission/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"webform_submission.delete\";s:6:\"_title\";s:25:\"Delete webform submission\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.duplicate_form','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/duplicate','/admin/structure/webform/manage/%/submission/%/duplicate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:28:\"webform_submission.duplicate\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"duplicate\";b:1;}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"webform_submission.update_any\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:110:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/webform/manage/%/submission/%/duplicate\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.edit_form','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit','/admin/structure/webform/manage/%/submission/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform_submission.edit\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/submission/%/edit\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.edit_form.all','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit/all','/admin/structure/webform/manage/%/submission/%/edit/all',491,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit/all\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:27:\"webform_submission.edit_all\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";s:14:\"_custom_access\";s:70:\"\\Drupal\\webform\\Access\\WebformSubmissionAccess::checkWizardPagesAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/edit/all$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/edit/all\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:55:\"/admin/structure/webform/manage/%/submission/%/edit/all\";s:8:\"numParts\";i:9;}}',9),('entity.webform_submission.locked_toggle','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/locked','/admin/structure/webform/manage/%/submission/%/locked',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/locked\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::locked\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/locked$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/locked\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/locked\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.notes_form','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/notes','/admin/structure/webform/manage/%/submission/%/notes',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/notes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"webform_submission.notes\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"webform_submission.notes\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/notes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/notes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/submission/%/notes\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.resend_form','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/resend','/admin/structure/webform/manage/%/submission/%/resend',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/resend\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"Drupal\\webform\\Form\\WebformSubmissionResendForm\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.resend\";s:14:\"_custom_access\";s:65:\"\\Drupal\\webform\\Access\\WebformSubmissionAccess::checkResendAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/resend$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/resend\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/resend\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.sticky_toggle','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/sticky','/admin/structure/webform/manage/%/submission/%/sticky',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/sticky\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::sticky\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/sticky$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/sticky\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/sticky\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.table','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/table','/admin/structure/webform/manage/%/submission/%/table',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/table\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:5:\"table\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/table$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/table\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/submission/%/table\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.text','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/text','/admin/structure/webform/manage/%/submission/%/text',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/text\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"text\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:27:\"webform_submission.view_any\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/text$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/text\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/submission/%/text\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.user','/user/{user}/submissions/{submission_view}','/user/%/submissions',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/user/{user}/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:11:\"Submissions\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkUserSubmissionsAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"user\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/user/(?P<user>[^/]++)/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"user\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"user\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:19:\"/user/%/submissions\";s:8:\"numParts\";i:4;}}',4),('entity.webform_submission.yaml','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/yaml','/admin/structure/webform/manage/%/submission/%/yaml',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/yaml\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"yaml\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"edit webform source\";s:14:\"_entity_access\";s:27:\"webform_submission.view_any\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/yaml$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/yaml\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/submission/%/yaml\";s:8:\"numParts\";i:8;}}',8),('entity_reference_revisions.delete_orphans','/admin/config/system/delete-orphans','/admin/config/system/delete-orphans',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/config/system/delete-orphans\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:74:\"Drupal\\entity_reference_revisions\\Form\\OrphanedCompositeEntitiesDeleteForm\";s:6:\"_title\";s:34:\"Delete orphaned composite entities\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"delete orphan revisions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/config/system/delete\\-orphans$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/system/delete-orphans\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/config/system/delete-orphans\";s:8:\"numParts\";i:4;}}',4),('ept_core.settings','/admin/config/content/ept-core','/admin/config/content/ept-core',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/config/content/ept-core\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:41:\"\\Drupal\\ept_core\\Form\\EptCoreSettingsForm\";s:6:\"_title\";s:36:\"Extra Paragraph Types (EPT) settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/config/content/ept\\-core$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/content/ept-core\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/config/content/ept-core\";s:8:\"numParts\";i:4;}}',4),('field_ui.display_mode','/admin/structure/display-modes','/admin/structure/display-modes',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/structure/display-modes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:13:\"Display modes\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:24:\"administer display modes\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/display\\-modes$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/display-modes\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/admin/structure/display-modes\";s:8:\"numParts\";i:3;}}',3),('field_ui.entity_form_mode_add','/admin/structure/display-modes/form/add','/admin/structure/display-modes/form/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/display-modes/form/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:78:\"\\Drupal\\field_ui\\Controller\\EntityDisplayModeController::formModeTypeSelection\";s:6:\"_title\";s:28:\"Choose form mode entity type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/display\\-modes/form/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/form/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/display-modes/form/add\";s:8:\"numParts\";i:5;}}',5),('field_ui.entity_view_mode_add','/admin/structure/display-modes/view/add','/admin/structure/display-modes/view/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/display-modes/view/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:78:\"\\Drupal\\field_ui\\Controller\\EntityDisplayModeController::viewModeTypeSelection\";s:6:\"_title\";s:28:\"Choose view mode entity type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/display\\-modes/view/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/view/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/display-modes/view/add\";s:8:\"numParts\";i:5;}}',5),('field_ui.field_add_block_content','/admin/structure/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}','/admin/structure/block-content/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:95:\"/admin/structure/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:53:\"/admin/structure/block-content/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_comment','/admin/structure/comment/manage/{comment_type}/add-field/{entity_type}/{field_name}','/admin/structure/comment/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/comment/manage/{comment_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:47:\"/admin/structure/comment/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_contact_message','/admin/structure/contact/manage/{contact_form}/add-field/{entity_type}/{field_name}','/admin/structure/contact/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/contact/manage/{contact_form}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:47:\"/admin/structure/contact/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_media','/admin/structure/media/manage/{media_type}/add-field/{entity_type}/{field_name}','/admin/structure/media/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/media/manage/{media_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:45:\"/admin/structure/media/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_node','/admin/structure/types/manage/{node_type}/add-field/{entity_type}/{field_name}','/admin/structure/types/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/types/manage/{node_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:116:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:45:\"/admin/structure/types/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_paragraph','/admin/structure/paragraphs_type/{paragraphs_type}/add-field/{entity_type}/{field_name}','/admin/structure/paragraphs_type/%/add-field/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/paragraphs_type/{paragraphs_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:125:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:48:\"/admin/structure/paragraphs_type/%/add-field/%/%\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_add_taxonomy_term','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/add-field/{entity_type}/{field_name}','/admin/structure/taxonomy/manage/%/overview/add-field/%/%',492,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:100:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:138:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/overview/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:492;s:14:\"patternOutline\";s:57:\"/admin/structure/taxonomy/manage/%/overview/add-field/%/%\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_add_user','/admin/config/people/accounts/add-field/{entity_type}/{field_name}','/admin/config/people/accounts/add-field/%/%',124,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/config/people/accounts/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"entity_type\";i:1;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/config/people/accounts/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/people/accounts/add-field\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"entity_type\";i:1;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:124;s:14:\"patternOutline\";s:43:\"/admin/config/people/accounts/add-field/%/%\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_block_content.display','/admin/structure/block-content/manage/{block_content_type}/display/add-group','/admin/structure/block-content/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/block-content/manage/{block_content_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:57:\"/admin/structure/block-content/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_block_content.display.view_mode','/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/add-group','/admin/structure/block-content/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:122:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:59:\"/admin/structure/block-content/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_block_content.form_display','/admin/structure/block-content/manage/{block_content_type}/form-display/add-group','/admin/structure/block-content/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/block-content/manage/{block_content_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:62:\"/admin/structure/block-content/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_block_content.form_display.form_mode','/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/add-group','/admin/structure/block-content/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:128:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:64:\"/admin/structure/block-content/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_comment.display','/admin/structure/comment/manage/{comment_type}/display/add-group','/admin/structure/comment/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/comment/manage/{comment_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/comment/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_comment.display.view_mode','/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/add-group','/admin/structure/comment/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/comment/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_comment.form_display','/admin/structure/comment/manage/{comment_type}/form-display/add-group','/admin/structure/comment/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/comment/manage/{comment_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/comment/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_comment.form_display.form_mode','/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/add-group','/admin/structure/comment/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:58:\"/admin/structure/comment/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_contact_message.display','/admin/structure/contact/manage/{contact_form}/display/add-group','/admin/structure/contact/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/contact/manage/{contact_form}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/contact/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_contact_message.display.view_mode','/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/add-group','/admin/structure/contact/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/contact/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_contact_message.form_display','/admin/structure/contact/manage/{contact_form}/form-display/add-group','/admin/structure/contact/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/contact/manage/{contact_form}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/contact/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_contact_message.form_display.form_mode','/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/add-group','/admin/structure/contact/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:58:\"/admin/structure/contact/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_media.display','/admin/structure/media/manage/{media_type}/display/add-group','/admin/structure/media/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/media/manage/{media_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:49:\"/admin/structure/media/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_media.display.view_mode','/admin/structure/media/manage/{media_type}/display/{view_mode_name}/add-group','/admin/structure/media/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/media/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_media.form_display','/admin/structure/media/manage/{media_type}/form-display/add-group','/admin/structure/media/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/media/manage/{media_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:54:\"/admin/structure/media/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_media.form_display.form_mode','/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/add-group','/admin/structure/media/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/media/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_node.display','/admin/structure/types/manage/{node_type}/display/add-group','/admin/structure/types/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/types/manage/{node_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:49:\"/admin/structure/types/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_node.display.view_mode','/admin/structure/types/manage/{node_type}/display/{view_mode_name}/add-group','/admin/structure/types/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/types/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_node.form_display','/admin/structure/types/manage/{node_type}/form-display/add-group','/admin/structure/types/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/types/manage/{node_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:54:\"/admin/structure/types/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_node.form_display.form_mode','/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/add-group','/admin/structure/types/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:110:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/types/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_paragraph.display','/admin/structure/paragraphs_type/{paragraphs_type}/display/add-group','/admin/structure/paragraphs_type/%/display/add-group',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:52:\"/admin/structure/paragraphs_type/%/display/add-group\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_group_add_paragraph.display.view_mode','/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/add-group','/admin/structure/paragraphs_type/%/display/%/add-group',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:54:\"/admin/structure/paragraphs_type/%/display/%/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_paragraph.form_display','/admin/structure/paragraphs_type/{paragraphs_type}/form-display/add-group','/admin/structure/paragraphs_type/%/form-display/add-group',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/admin/structure/paragraphs_type/%/form-display/add-group\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_group_add_paragraph.form_display.form_mode','/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/add-group','/admin/structure/paragraphs_type/%/form-display/%/add-group',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:90:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:119:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:59:\"/admin/structure/paragraphs_type/%/form-display/%/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_taxonomy_term.display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/add-group','/admin/structure/taxonomy/manage/%/overview/display/add-group',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/overview/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:61:\"/admin/structure/taxonomy/manage/%/overview/display/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_taxonomy_term.display.view_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/add-group','/admin/structure/taxonomy/manage/%/overview/display/%/add-group',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:63:\"/admin/structure/taxonomy/manage/%/overview/display/%/add-group\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_add_taxonomy_term.form_display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/add-group','/admin/structure/taxonomy/manage/%/overview/form-display/add-group',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/overview/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:66:\"/admin/structure/taxonomy/manage/%/overview/form-display/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_taxonomy_term.form_display.form_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/add-group','/admin/structure/taxonomy/manage/%/overview/form-display/%/add-group',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:103:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:132:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:68:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/add-group\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_add_user.display','/admin/config/people/accounts/display/add-group','/admin/config/people/accounts/display/add-group',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/people/accounts/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/config/people/accounts/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/people/accounts/display/add-group\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:47:\"/admin/config/people/accounts/display/add-group\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_group_add_user.display.view_mode','/admin/config/people/accounts/display/{view_mode_name}/add-group','/admin/config/people/accounts/display/%/add-group',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/config/people/accounts/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:49:\"/admin/config/people/accounts/display/%/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_user.form_display','/admin/config/people/accounts/form-display/add-group','/admin/config/people/accounts/form-display/add-group',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/people/accounts/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/config/people/accounts/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/people/accounts/form-display/add-group\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:52:\"/admin/config/people/accounts/form-display/add-group\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_group_add_user.form_display.form_mode','/admin/config/people/accounts/form-display/{form_mode_name}/add-group','/admin/config/people/accounts/form-display/%/add-group',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/people/accounts/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:54:\"/admin/config/people/accounts/form-display/%/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_block_content.display','/admin/structure/block-content/manage/{block_content_type}/display/{field_group_name}/delete','/admin/structure/block-content/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/block-content/manage/{block_content_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:120:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/block-content/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_block_content.display.view_mode','/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/block-content/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:109:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:147:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:58:\"/admin/structure/block-content/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_block_content.form_display','/admin/structure/block-content/manage/{block_content_type}/form-display/{field_group_name}/delete','/admin/structure/block-content/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:61:\"/admin/structure/block-content/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_block_content.form_display.form_mode','/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/block-content/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:114:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:153:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:63:\"/admin/structure/block-content/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_comment.display','/admin/structure/comment/manage/{comment_type}/display/{field_group_name}/delete','/admin/structure/comment/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/comment/manage/{comment_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/comment/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_comment.display.view_mode','/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/comment/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:52:\"/admin/structure/comment/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_comment.form_display','/admin/structure/comment/manage/{comment_type}/form-display/{field_group_name}/delete','/admin/structure/comment/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/comment/manage/{comment_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/comment/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_comment.form_display.form_mode','/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/comment/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:140:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:57:\"/admin/structure/comment/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_contact_message.display','/admin/structure/contact/manage/{contact_form}/display/{field_group_name}/delete','/admin/structure/contact/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/contact/manage/{contact_form}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/contact/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_contact_message.display.view_mode','/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/contact/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:52:\"/admin/structure/contact/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_contact_message.form_display','/admin/structure/contact/manage/{contact_form}/form-display/{field_group_name}/delete','/admin/structure/contact/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/contact/manage/{contact_form}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/contact/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_contact_message.form_display.form_mode','/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/contact/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:140:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:57:\"/admin/structure/contact/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_media.display','/admin/structure/media/manage/{media_type}/display/{field_group_name}/delete','/admin/structure/media/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/media/manage/{media_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/media/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_media.display.view_mode','/admin/structure/media/manage/{media_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/media/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:50:\"/admin/structure/media/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_media.form_display','/admin/structure/media/manage/{media_type}/form-display/{field_group_name}/delete','/admin/structure/media/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/media/manage/{media_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/media/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_media.form_display.form_mode','/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/media/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:136:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:55:\"/admin/structure/media/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_node.display','/admin/structure/types/manage/{node_type}/display/{field_group_name}/delete','/admin/structure/types/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/types/manage/{node_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/types/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_node.display.view_mode','/admin/structure/types/manage/{node_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/types/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:50:\"/admin/structure/types/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_node.form_display','/admin/structure/types/manage/{node_type}/form-display/{field_group_name}/delete','/admin/structure/types/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/types/manage/{node_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/types/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_node.form_display.form_mode','/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/types/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:135:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:55:\"/admin/structure/types/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_paragraph.display','/admin/structure/paragraphs_type/{paragraphs_type}/display/{field_group_name}/delete','/admin/structure/paragraphs_type/%/display/%/delete',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:84:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:51:\"/admin/structure/paragraphs_type/%/display/%/delete\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_paragraph.display.view_mode','/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/paragraphs_type/%/display/%/%/delete',233,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:101:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:138:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:233;s:14:\"patternOutline\";s:53:\"/admin/structure/paragraphs_type/%/display/%/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_paragraph.form_display','/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{field_group_name}/delete','/admin/structure/paragraphs_type/%/form-display/%/delete',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:56:\"/admin/structure/paragraphs_type/%/form-display/%/delete\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_paragraph.form_display.form_mode','/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/paragraphs_type/%/form-display/%/%/delete',233,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:106:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:144:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:233;s:14:\"patternOutline\";s:58:\"/admin/structure/paragraphs_type/%/form-display/%/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_taxonomy_term.display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/display/%/delete',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:124:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:60:\"/admin/structure/taxonomy/manage/%/overview/display/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_taxonomy_term.display.view_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/display/%/%/delete',985,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:114:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:151:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:985;s:14:\"patternOutline\";s:62:\"/admin/structure/taxonomy/manage/%/overview/display/%/%/delete\";s:8:\"numParts\";i:10;}}',10),('field_ui.field_group_delete_taxonomy_term.form_display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/form-display/%/delete',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:65:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_taxonomy_term.form_display.form_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/form-display/%/%/delete',985,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:119:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:157:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:985;s:14:\"patternOutline\";s:67:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/%/delete\";s:8:\"numParts\";i:10;}}',10),('field_ui.field_group_delete_user.display','/admin/config/people/accounts/display/{field_group_name}/delete','/admin/config/people/accounts/display/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/people/accounts/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/config/people/accounts/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/people/accounts/display/%/delete\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_user.display.view_mode','/admin/config/people/accounts/display/{view_mode_name}/{field_group_name}/delete','/admin/config/people/accounts/display/%/%/delete',249,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/config/people/accounts/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"view_mode_name\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"view_mode_name\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:249;s:14:\"patternOutline\";s:48:\"/admin/config/people/accounts/display/%/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_user.form_display','/admin/config/people/accounts/form-display/{field_group_name}/delete','/admin/config/people/accounts/form-display/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/people/accounts/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/people/accounts/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/config/people/accounts/form-display/%/delete\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_user.form_display.form_mode','/admin/config/people/accounts/form-display/{form_mode_name}/{field_group_name}/delete','/admin/config/people/accounts/form-display/%/%/delete',249,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/config/people/accounts/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"form_mode_name\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"form_mode_name\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:249;s:14:\"patternOutline\";s:53:\"/admin/config/people/accounts/form-display/%/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_storage_config_add_block_content','/admin/structure/block-content/manage/{block_content_type}/fields/add-field','/admin/structure/block-content/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/block-content/manage/{block_content_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/block-content/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_comment','/admin/structure/comment/manage/{comment_type}/fields/add-field','/admin/structure/comment/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/comment/manage/{comment_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/comment/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_contact_message','/admin/structure/contact/manage/{contact_form}/fields/add-field','/admin/structure/contact/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/contact/manage/{contact_form}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/contact/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_media','/admin/structure/media/manage/{media_type}/fields/add-field','/admin/structure/media/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/media/manage/{media_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/media/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_node','/admin/structure/types/manage/{node_type}/fields/add-field','/admin/structure/types/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/types/manage/{node_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/types/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_paragraph','/admin/structure/paragraphs_type/{paragraphs_type}/fields/add-field','/admin/structure/paragraphs_type/%/fields/add-field',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:51:\"/admin/structure/paragraphs_type/%/fields/add-field\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_storage_config_add_taxonomy_term','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/add-field','/admin/structure/taxonomy/manage/%/overview/fields/add-field',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/overview/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:60:\"/admin/structure/taxonomy/manage/%/overview/fields/add-field\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_storage_config_add_user','/admin/config/people/accounts/fields/add-field','/admin/config/people/accounts/fields/add-field',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/config/people/accounts/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/config/people/accounts/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/config/people/accounts/fields/add-field\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:46:\"/admin/config/people/accounts/fields/add-field\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_storage_config_reuse_block_content','/admin/structure/block-content/manage/{block_content_type}/fields/reuse','/admin/structure/block-content/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/block-content/manage/{block_content_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:52:\"/admin/structure/block-content/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_comment','/admin/structure/comment/manage/{comment_type}/fields/reuse','/admin/structure/comment/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/comment/manage/{comment_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/comment/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_contact_message','/admin/structure/contact/manage/{contact_form}/fields/reuse','/admin/structure/contact/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/contact/manage/{contact_form}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/contact/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_media','/admin/structure/media/manage/{media_type}/fields/reuse','/admin/structure/media/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/media/manage/{media_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:44:\"/admin/structure/media/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_node','/admin/structure/types/manage/{node_type}/fields/reuse','/admin/structure/types/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/types/manage/{node_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:44:\"/admin/structure/types/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_paragraph','/admin/structure/paragraphs_type/{paragraphs_type}/fields/reuse','/admin/structure/paragraphs_type/%/fields/reuse',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/admin/structure/paragraphs_type/%/fields/reuse\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_storage_config_reuse_taxonomy_term','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/reuse','/admin/structure/taxonomy/manage/%/overview/fields/reuse',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:56:\"/admin/structure/taxonomy/manage/%/overview/fields/reuse\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_storage_config_reuse_user','/admin/config/people/accounts/fields/reuse','/admin/config/people/accounts/fields/reuse',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/people/accounts/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/admin/config/people/accounts/fields/reuse$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/fields/reuse\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:42:\"/admin/config/people/accounts/fields/reuse\";s:8:\"numParts\";i:6;}}',6),('file.ajax_progress','/file/progress/{key}','/file/progress/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/file/progress/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\file\\Controller\\FileWidgetAjaxController::progress\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/file/progress/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/file/progress\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/file/progress/%\";s:8:\"numParts\";i:3;}}',3),('file_mdm.settings','/admin/config/system/file_mdm','/admin/config/system/file_mdm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/system/file_mdm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\file_mdm\\Form\\SettingsForm\";s:6:\"_title\";s:21:\"File metadata manager\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/system/file_mdm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/system/file_mdm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/system/file_mdm\";s:8:\"numParts\";i:4;}}',4),('filter.admin_overview','/admin/config/content/formats','/admin/config/content/formats',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/content/formats\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:13:\"filter_format\";s:6:\"_title\";s:24:\"Text formats and editors\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer filters\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/content/formats$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/content/formats\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/content/formats\";s:8:\"numParts\";i:4;}}',4),('filter.format_add','/admin/config/content/formats/add','/admin/config/content/formats/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/content/formats/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"filter_format.add\";s:6:\"_title\";s:15:\"Add text format\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:13:\"filter_format\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/content/formats/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/content/formats/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:33:\"/admin/config/content/formats/add\";s:8:\"numParts\";i:5;}}',5),('filter.tips','/filter/tips/{filter_format}','/filter/tips/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/filter/tips/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\filter\\Controller\\FilterController::filterTips\";s:6:\"_title\";s:12:\"Compose tips\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"filter_format.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/filter/tips/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/filter/tips\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:14:\"/filter/tips/%\";s:8:\"numParts\";i:3;}}',3),('filter.tips_all','/filter/tips','/filter/tips',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/filter/tips\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\filter\\Controller\\FilterController::filterTips\";s:6:\"_title\";s:12:\"Compose tips\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/filter/tips$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/filter/tips\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/filter/tips\";s:8:\"numParts\";i:2;}}',2),('glightbox.admin_settings','/admin/config/media/glightbox','/admin/config/media/glightbox',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/media/glightbox\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\glightbox\\Form\\GLightboxSettingsForm\";s:6:\"_title\";s:18:\"GLightbox settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/media/glightbox$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/media/glightbox\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/media/glightbox\";s:8:\"numParts\";i:4;}}',4),('help.help_topic','/admin/help/topic/{id}','/admin/help/topic/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/help/topic/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:64:\"\\Drupal\\help\\Controller\\HelpTopicPluginController::viewHelpTopic\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/help/topic/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/help/topic\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:19:\"/admin/help/topic/%\";s:8:\"numParts\";i:4;}}',4),('help.main','/admin/help','/admin/help',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/admin/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\help\\Controller\\HelpController::helpMain\";s:6:\"_title\";s:4:\"Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/admin/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/admin/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/admin/help\";s:8:\"numParts\";i:2;}}',2),('help.page','/admin/help/{name}','/admin/help/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/admin/help/{name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\help\\Controller\\HelpController::helpPage\";s:6:\"_title\";s:4:\"Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/help/(?P<name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/admin/help\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:13:\"/admin/help/%\";s:8:\"numParts\";i:3;}}',3),('history.get_last_node_view','/history/get_node_read_timestamps','/history/get_node_read_timestamps',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/history/get_node_read_timestamps\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:67:\"\\Drupal\\history\\Controller\\HistoryController::getNodeReadTimestamps\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/history/get_node_read_timestamps$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/history/get_node_read_timestamps\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:33:\"/history/get_node_read_timestamps\";s:8:\"numParts\";i:2;}}',2),('history.read_node','/history/{node}/read','/history/%/read',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/history/{node}/read\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:54:\"\\Drupal\\history\\Controller\\HistoryController::readNode\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:9:\"node.view\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/history/(?P<node>\\d+)/read$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/read\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/history\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/history/%/read\";s:8:\"numParts\";i:3;}}',3),('image.effect_add_form','/admin/config/media/image-styles/manage/{image_style}/add/{image_effect}','/admin/config/media/image-styles/manage/%/add/%',250,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/media/image-styles/manage/{image_style}/add/{image_effect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\image\\Form\\ImageEffectAddForm\";s:6:\"_title\";s:16:\"Add image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/add/(?P<image_effect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:47:\"/admin/config/media/image-styles/manage/%/add/%\";s:8:\"numParts\";i:8;}}',8),('image.effect_delete','/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}/delete','/admin/config/media/image-styles/manage/%/effects/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\image\\Form\\ImageEffectDeleteForm\";s:6:\"_title\";s:19:\"Delete image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/effects/(?P<image_effect>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/effects\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:58:\"/admin/config/media/image-styles/manage/%/effects/%/delete\";s:8:\"numParts\";i:9;}}',9),('image.effect_edit_form','/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}','/admin/config/media/image-styles/manage/%/effects/%',250,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:38:\"\\Drupal\\image\\Form\\ImageEffectEditForm\";s:6:\"_title\";s:17:\"Edit image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/effects/(?P<image_effect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/effects\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:51:\"/admin/config/media/image-styles/manage/%/effects/%\";s:8:\"numParts\";i:8;}}',8),('image.style_add','/admin/config/media/image-styles/add','/admin/config/media/image-styles/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/config/media/image-styles/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"image_style.add\";s:6:\"_title\";s:15:\"Add image style\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/media/image\\-styles/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/media/image-styles/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:36:\"/admin/config/media/image-styles/add\";s:8:\"numParts\";i:5;}}',5),('image.style_private','/system/files/styles/{image_style}/{scheme}','/system/files/styles/%/%',28,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/system/files/styles/{image_style}/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:62:\"\\Drupal\\image\\Controller\\ImageStyleDownloadController::deliver\";s:26:\"required_derivative_scheme\";s:7:\"private\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/system/files/styles/(?P<image_style>[^/]++)/(?P<scheme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/system/files/styles\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:28;s:14:\"patternOutline\";s:24:\"/system/files/styles/%/%\";s:8:\"numParts\";i:5;}}',5),('image.style_public','/sites/default/files/styles/{image_style}/{scheme}','/sites/default/files/styles/%/%',60,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/sites/default/files/styles/{image_style}/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:61:\"Drupal\\image\\Controller\\ImageStyleDownloadController::deliver\";s:26:\"required_derivative_scheme\";s:6:\"public\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/sites/default/files/styles/(?P<image_style>[^/]++)/(?P<scheme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/sites/default/files/styles\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:60;s:14:\"patternOutline\";s:31:\"/sites/default/files/styles/%/%\";s:8:\"numParts\";i:6;}}',6),('image_effects.settings','/admin/config/media/image_effects','/admin/config/media/image_effects',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/media/image_effects\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\image_effects\\Form\\SettingsForm\";s:6:\"_title\";s:13:\"Image Effects\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/media/image_effects$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/media/image_effects\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/media/image_effects\";s:8:\"numParts\";i:4;}}',4),('layout_paragraphs.builder.choose_component','/layout-paragraphs-builder/{layout_paragraphs_layout}/choose-component','/layout-paragraphs-builder/%/choose-component',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/choose-component\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\layout_paragraphs\\Controller\\ChooseComponentController::list\";s:9:\"operation\";s:6:\"create\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:24:\"layout_paragraphs_layout\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/choose\\-component$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/choose-component\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:1:{i:0;s:24:\"layout_paragraphs_layout\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:45:\"/layout-paragraphs-builder/%/choose-component\";s:8:\"numParts\";i:3;}}',3),('layout_paragraphs.builder.delete_item','/layout-paragraphs-builder/{layout_paragraphs_layout}/delete/{component_uuid}','/layout-paragraphs-builder/%/delete/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/delete/{component_uuid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:50:\"\\Drupal\\layout_paragraphs\\Form\\DeleteComponentForm\";s:9:\"operation\";s:6:\"delete\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:14:\"component_uuid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/delete/(?P<component_uuid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"component_uuid\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:14:\"component_uuid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:37:\"/layout-paragraphs-builder/%/delete/%\";s:8:\"numParts\";i:4;}}',4),('layout_paragraphs.builder.duplicate_item','/layout-paragraphs-builder/{layout_paragraphs_layout}/duplicate/{source_uuid}','/layout-paragraphs-builder/%/duplicate/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/duplicate/{source_uuid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:67:\"\\Drupal\\layout_paragraphs\\Controller\\DuplicateController::duplicate\";s:9:\"operation\";s:9:\"duplicate\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:11:\"source_uuid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/duplicate/(?P<source_uuid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_uuid\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:11:\"source_uuid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:40:\"/layout-paragraphs-builder/%/duplicate/%\";s:8:\"numParts\";i:4;}}',4),('layout_paragraphs.builder.edit_item','/layout-paragraphs-builder/{layout_paragraphs_layout}/edit/{component_uuid}','/layout-paragraphs-builder/%/edit/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/edit/{component_uuid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:48:\"\\Drupal\\layout_paragraphs\\Form\\EditComponentForm\";s:9:\"operation\";s:6:\"update\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:14:\"component_uuid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/edit/(?P<component_uuid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"component_uuid\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:14:\"component_uuid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:35:\"/layout-paragraphs-builder/%/edit/%\";s:8:\"numParts\";i:4;}}',4),('layout_paragraphs.builder.formatter','/layout-paragraphs-builder/formatter/{entity_type}/{entity}/{field_name}/{view_mode}','/layout-paragraphs-builder/formatter/%/%/%/%',48,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:84:\"/layout-paragraphs-builder/formatter/{entity_type}/{entity}/{field_name}/{view_mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:77:\"\\Drupal\\layout_paragraphs\\Controller\\LayoutParagraphsBuilderController::build\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:78:\"\\Drupal\\layout_paragraphs\\Controller\\LayoutParagraphsBuilderController::access\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:3:{s:4:\"type\";s:20:\"entity:{entity_type}\";s:20:\"load_latest_revision\";b:1;s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:11:\"entity_type\";i:1;s:6:\"entity\";i:2;s:10:\"field_name\";i:3;s:9:\"view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:133:\"{^/layout\\-paragraphs\\-builder/formatter/(?P<entity_type>[^/]++)/(?P<entity>[^/]++)/(?P<field_name>[^/]++)/(?P<view_mode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"view_mode\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/layout-paragraphs-builder/formatter\";}}s:9:\"path_vars\";a:4:{i:0;s:11:\"entity_type\";i:1;s:6:\"entity\";i:2;s:10:\"field_name\";i:3;s:9:\"view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:48;s:14:\"patternOutline\";s:44:\"/layout-paragraphs-builder/formatter/%/%/%/%\";s:8:\"numParts\";i:6;}}',6),('layout_paragraphs.builder.insert','/layout-paragraphs-builder/{layout_paragraphs_layout}/insert/{paragraph_type_id}','/layout-paragraphs-builder/%/insert/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/insert/{paragraph_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:72:\"\\Drupal\\layout_paragraphs\\Controller\\ComponentFormController::insertForm\";s:9:\"operation\";s:6:\"create\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:17:\"paragraph_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/insert/(?P<paragraph_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"paragraph_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/insert\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:17:\"paragraph_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:37:\"/layout-paragraphs-builder/%/insert/%\";s:8:\"numParts\";i:4;}}',4),('layout_paragraphs.builder.reorder','/layout-paragraphs-builder/{layout_paragraphs_layout}/reorder','/layout-paragraphs-builder/%/reorder',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/reorder\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:61:\"\\Drupal\\layout_paragraphs\\Controller\\ReorderController::build\";s:9:\"operation\";s:7:\"reorder\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}s:14:\"paragraph_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:24:\"layout_paragraphs_layout\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/reorder$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/reorder\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:1:{i:0;s:24:\"layout_paragraphs_layout\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:36:\"/layout-paragraphs-builder/%/reorder\";s:8:\"numParts\";i:3;}}',3),('layout_paragraphs.label_settings','/admin/config/content/layout_paragraphs/labels','/admin/config/content/layout_paragraphs/labels',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/config/content/layout_paragraphs/labels\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\layout_paragraphs\\Form\\LayoutParagraphsSettingsForm\";s:6:\"_title\";s:24:\"Layout Paragraphs Labels\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/admin/config/content/layout_paragraphs/labels$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/config/content/layout_paragraphs/labels\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:46:\"/admin/config/content/layout_paragraphs/labels\";s:8:\"numParts\";i:5;}}',5),('layout_paragraphs.modal_settings','/admin/config/content/layout_paragraphs/modal-settings','/admin/config/content/layout_paragraphs/modal-settings',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/content/layout_paragraphs/modal-settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:64:\"\\Drupal\\layout_paragraphs\\Form\\LayoutParagraphsModalSettingsForm\";s:6:\"_title\";s:32:\"Layout Paragraphs Modal Settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/config/content/layout_paragraphs/modal\\-settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:54:\"/admin/config/content/layout_paragraphs/modal-settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:54:\"/admin/config/content/layout_paragraphs/modal-settings\";s:8:\"numParts\";i:5;}}',5),('layout_paragraphs.section_settings','/admin/config/content/layout_paragraphs/sections','/admin/config/content/layout_paragraphs/sections',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/config/content/layout_paragraphs/sections\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:67:\"\\Drupal\\layout_paragraphs\\Form\\LayoutParagraphsSectionsSettingsForm\";s:6:\"_title\";s:26:\"Layout Paragraphs Sections\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/config/content/layout_paragraphs/sections$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/admin/config/content/layout_paragraphs/sections\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:48:\"/admin/config/content/layout_paragraphs/sections\";s:8:\"numParts\";i:5;}}',5),('media.filter.preview','/media/{filter_format}/preview','/media/%/preview',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/media/{filter_format}/preview\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:55:\"\\Drupal\\media\\Controller\\MediaFilterController::preview\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"filter_format.use\";s:14:\"_custom_access\";s:74:\"\\Drupal\\media\\Controller\\MediaFilterController::formatUsesMediaEmbedFilter\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/media/(?P<filter_format>[^/]++)/preview$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/preview\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:16:\"/media/%/preview\";s:8:\"numParts\";i:3;}}',3),('media.oembed_iframe','/media/oembed','/media/oembed',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/media/oembed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:55:\"\\Drupal\\media\\Controller\\OEmbedIframeController::render\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:10:\"view media\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/media/oembed$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/media/oembed\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/media/oembed\";s:8:\"numParts\";i:2;}}',2),('media.settings','/admin/config/media/media-settings','/admin/config/media/media-settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/media/media-settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\media\\Form\\MediaSettingsForm\";s:6:\"_title\";s:14:\"Media settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/config/media/media\\-settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/media/media-settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/config/media/media-settings\";s:8:\"numParts\";i:4;}}',4),('media_library.settings','/admin/config/media/media-library','/admin/config/media/media-library',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/media/media-library\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\media_library\\Form\\SettingsForm\";s:6:\"_title\";s:22:\"Media Library settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/media/media\\-library$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/media/media-library\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/media/media-library\";s:8:\"numParts\";i:4;}}',4),('media_library.ui','/media-library','/media-library',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/media-library\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:32:\"media_library.ui_builder:buildUi\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:36:\"media_library.ui_builder:checkAccess\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:22:\"{^/media\\-library$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/media-library\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:14:\"/media-library\";s:8:\"numParts\";i:1;}}',1),('menu_ui.link_edit','/admin/structure/menu/link/{menu_link_plugin}/edit','/admin/structure/menu/link/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/menu/link/{menu_link_plugin}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\menu_ui\\Form\\MenuLinkEditForm\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"menu_link_plugin\";a:2:{s:4:\"type\";s:16:\"menu_link_plugin\";s:9:\"converter\";s:54:\"drupal.proxy_original_service.paramconverter.menu_link\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/menu/link/(?P<menu_link_plugin>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"menu_link_plugin\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/link\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/link/%/edit\";s:8:\"numParts\";i:6;}}',6),('menu_ui.link_reset','/admin/structure/menu/link/{menu_link_plugin}/reset','/admin/structure/menu/link/%/reset',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/link/{menu_link_plugin}/reset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:38:\"\\Drupal\\menu_ui\\Form\\MenuLinkResetForm\";s:6:\"_title\";s:15:\"Reset menu link\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:15:\"administer menu\";s:14:\"_custom_access\";s:56:\"\\Drupal\\menu_ui\\Form\\MenuLinkResetForm::linkIsResettable\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"menu_link_plugin\";a:2:{s:4:\"type\";s:16:\"menu_link_plugin\";s:9:\"converter\";s:54:\"drupal.proxy_original_service.paramconverter.menu_link\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/link/(?P<menu_link_plugin>[^/]++)/reset$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reset\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"menu_link_plugin\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/link\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/menu/link/%/reset\";s:8:\"numParts\";i:6;}}',6),('menu_ui.parent_options_js','/admin/structure/menu/parents','/admin/structure/menu/parents',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/menu/parents\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:59:\"\\Drupal\\menu_ui\\Controller\\MenuController::getParentOptions\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/menu/parents$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/menu/parents\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/menu/parents\";s:8:\"numParts\";i:4;}}',4),('node.add','/node/add/{node_type}','/node/add/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/node/add/{node_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"node.default\";s:15:\"_title_callback\";s:52:\"\\Drupal\\node\\Controller\\NodeController::addPageTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:16:\"node:{node_type}\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:3:{s:4:\"type\";s:16:\"entity:node_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/node/add/(?P<node_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/node/add\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:11:\"/node/add/%\";s:8:\"numParts\";i:3;}}',3),('node.add_page','/node/add','/node/add',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:9:\"/node/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:11:\"Add content\";s:11:\"_controller\";s:47:\"\\Drupal\\node\\Controller\\NodeController::addPage\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:4:\"node\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:16:\"{^/node/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/node/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:9:\"/node/add\";s:8:\"numParts\";i:2;}}',2),('node.configure_rebuild_confirm','/admin/reports/status/rebuild','/admin/reports/status/rebuild',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/status/rebuild\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\RebuildPermissionsForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer nodes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/status/rebuild$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/status/rebuild\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/reports/status/rebuild\";s:8:\"numParts\";i:4;}}',4),('node.multiple_delete_confirm','/admin/content/node/delete','/admin/content/node/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/content/node/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\node\\Form\\DeleteMultiple\";s:14:\"entity_type_id\";s:4:\"node\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:4:\"node\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/node/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/node/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/content/node/delete\";s:8:\"numParts\";i:4;}}',4),('node.revision_delete_confirm','/node/{node}/revisions/{node_revision}/delete','/node/%/revisions/%/delete',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/node/{node}/revisions/{node_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\NodeRevisionDeleteForm\";s:6:\"_title\";s:23:\"Delete earlier revision\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.delete revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/node/%/revisions/%/delete\";s:8:\"numParts\";i:5;}}',5),('node.revision_revert_confirm','/node/{node}/revisions/{node_revision}/revert','/node/%/revisions/%/revert',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/node/{node}/revisions/{node_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\NodeRevisionRevertForm\";s:6:\"_title\";s:26:\"Revert to earlier revision\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.revert revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/node/%/revisions/%/revert\";s:8:\"numParts\";i:5;}}',5),('node.revision_revert_translation_confirm','/node/{node}/revisions/{node_revision}/revert/{langcode}','/node/%/revisions/%/revert/%',42,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/node/{node}/revisions/{node_revision}/revert/{langcode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\node\\Form\\NodeRevisionRevertTranslationForm\";s:6:\"_title\";s:43:\"Revert to earlier revision of a translation\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.revert revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/revert/(?P<langcode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:42;s:14:\"patternOutline\";s:28:\"/node/%/revisions/%/revert/%\";s:8:\"numParts\";i:6;}}',6),('node.type_add','/admin/structure/types/add','/admin/structure/types/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/types/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"node_type.add\";s:6:\"_title\";s:16:\"Add content type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/types/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/types/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/types/add\";s:8:\"numParts\";i:4;}}',4),('paragraphs.settings','/admin/config/content/paragraphs','/admin/config/content/paragraphs',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/content/paragraphs\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:46:\"\\Drupal\\paragraphs\\Form\\ParagraphsSettingsForm\";s:6:\"_title\";s:19:\"Paragraphs settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer paragraphs settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/content/paragraphs$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/content/paragraphs\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/content/paragraphs\";s:8:\"numParts\";i:4;}}',4),('paragraphs.type_add','/admin/structure/paragraphs_type/add','/admin/structure/paragraphs_type/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/structure/paragraphs_type/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"paragraphs_type.add\";s:6:\"_title\";s:19:\"Add Paragraphs type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/paragraphs_type/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/structure/paragraphs_type/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:36:\"/admin/structure/paragraphs_type/add\";s:8:\"numParts\";i:4;}}',4),('shortcut.link_add','/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link','/admin/config/user-interface/shortcut/manage/%/add-link',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\shortcut\\Controller\\ShortcutController::addForm\";s:6:\"_title\";s:8:\"Add link\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:23:\"shortcut:{shortcut_set}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/add\\-link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/add-link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:55:\"/admin/config/user-interface/shortcut/manage/%/add-link\";s:8:\"numParts\";i:7;}}',7),('shortcut.link_add_inline','/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link-inline','/admin/config/user-interface/shortcut/manage/%/add-link-inline',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link-inline\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\shortcut\\Controller\\ShortcutSetController::addShortcutLinkInline\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/add\\-link\\-inline$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/add-link-inline\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:62:\"/admin/config/user-interface/shortcut/manage/%/add-link-inline\";s:8:\"numParts\";i:7;}}',7),('shortcut.set_add','/admin/config/user-interface/shortcut/add-set','/admin/config/user-interface/shortcut/add-set',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/user-interface/shortcut/add-set\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut_set.add\";s:6:\"_title\";s:16:\"Add shortcut set\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:12:\"shortcut_set\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/config/user\\-interface/shortcut/add\\-set$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/user-interface/shortcut/add-set\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:45:\"/admin/config/user-interface/shortcut/add-set\";s:8:\"numParts\";i:5;}}',5),('shortcut.set_switch','/user/{user}/shortcuts','/user/%/shortcuts',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/user/{user}/shortcuts\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\shortcut\\Form\\SwitchShortcutSet\";s:6:\"_title\";s:9:\"Shortcuts\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:52:\"\\Drupal\\shortcut\\Form\\SwitchShortcutSet::checkAccess\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"user\";s:3:\"\\d+\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/user/(?P<user>[^/]++)/shortcuts$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/shortcuts\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/user/%/shortcuts\";s:8:\"numParts\";i:3;}}',3),('system.401','/system/401','/system/401',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/401\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on401\";s:6:\"_title\";s:12:\"Unauthorized\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/401$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/401\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/401\";s:8:\"numParts\";i:2;}}',2),('system.403','/system/403','/system/403',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/403\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on403\";s:6:\"_title\";s:13:\"Access denied\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/403$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/403\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/403\";s:8:\"numParts\";i:2;}}',2),('system.404','/system/404','/system/404',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/404\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on404\";s:6:\"_title\";s:14:\"Page not found\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/404$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/404\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/404\";s:8:\"numParts\";i:2;}}',2),('system.4xx','/system/4xx','/system/4xx',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/4xx\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on4xx\";s:6:\"_title\";s:12:\"Client error\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/4xx$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/4xx\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/4xx\";s:8:\"numParts\";i:2;}}',2),('system.admin','/admin','/admin',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/admin\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:14:\"Administration\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/admin$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/admin\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/admin\";s:8:\"numParts\";i:1;}}',1),('system.admin_compact_page','/admin/compact/{mode}','/admin/compact',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/compact/{mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\system\\Controller\\SystemController::compactPage\";s:4:\"mode\";s:3:\"off\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"access administration pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/compact(?:/(?P<mode>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/compact\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/compact\";s:8:\"numParts\";i:3;}}',3),('system.admin_config','/admin/config','/admin/config',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\SystemController::overview\";s:7:\"link_id\";s:19:\"system.admin_config\";s:6:\"_title\";s:13:\"Configuration\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:27:\"_access_admin_overview_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:32:\"access_check.admin_overview_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/config\";s:8:\"numParts\";i:2;}}',2),('system.admin_config_content','/admin/config/content','/admin/config/content',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/config/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:17:\"Content authoring\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/config/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/config/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/config/content\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_development','/admin/config/development','/admin/config/development',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/development\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:11:\"Development\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/development$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/development\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/config/development\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_media','/admin/config/media','/admin/config/media',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/config/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:5:\"Media\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/config/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/config/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/config/media\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_regional','/admin/config/regional','/admin/config/regional',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/regional\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:19:\"Region and language\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/regional$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/regional\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/regional\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_search','/admin/config/search','/admin/config/search',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/search\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:19:\"Search and metadata\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/search$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/search\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/search\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_services','/admin/config/services','/admin/config/services',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/services\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:12:\"Web services\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/services$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/services\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/services\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_system','/admin/config/system','/admin/config/system',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/system\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:6:\"System\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/system$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/system\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/system\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_ui','/admin/config/user-interface','/admin/config/user-interface',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/config/user-interface\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:14:\"User interface\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/user\\-interface$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/user-interface\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/config/user-interface\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_workflow','/admin/config/workflow','/admin/config/workflow',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/workflow\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:8:\"Workflow\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/workflow$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/workflow\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/workflow\";s:8:\"numParts\";i:3;}}',3),('system.admin_content','/admin/content','/admin/content',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:23:\"access content overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/content\";s:8:\"numParts\";i:2;}}',2),('system.admin_index','/admin/index','/admin/index',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/admin/index\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\system\\Controller\\AdminController::index\";s:6:\"_title\";s:14:\"Administration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"access administration pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/admin/index$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/admin/index\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/admin/index\";s:8:\"numParts\";i:2;}}',2),('system.admin_reports','/admin/reports','/admin/reports',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/reports\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:7:\"Reports\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/reports$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/reports\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/reports\";s:8:\"numParts\";i:2;}}',2),('system.admin_structure','/admin/structure','/admin/structure',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:16:\"/admin/structure\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:9:\"Structure\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:23:\"{^/admin/structure$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/admin/structure\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:16:\"/admin/structure\";s:8:\"numParts\";i:2;}}',2),('system.batch_page.html','/batch','/batch',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/batch\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\BatchController::batchPage\";s:15:\"_title_callback\";s:57:\"\\Drupal\\system\\Controller\\BatchController::batchPageTitle\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:12:\"_no_big_pipe\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/batch$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/batch\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/batch\";s:8:\"numParts\";i:1;}}',1),('system.batch_page.json','/batch','/batch',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/batch\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\BatchController::batchPage\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/batch$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/batch\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/batch\";s:8:\"numParts\";i:1;}}',1),('system.cron','/cron/{key}','/cron/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/cron/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:34:\"\\Drupal\\system\\CronController::run\";}s:12:\"requirements\";a:1:{s:19:\"_access_system_cron\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:17:\"access_check.cron\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/cron/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/cron\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/cron/%\";s:8:\"numParts\";i:2;}}',2),('system.cron_settings','/admin/config/system/cron','/admin/config/system/cron',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/system/cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:28:\"\\Drupal\\system\\Form\\CronForm\";s:6:\"_title\";s:4:\"Cron\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/system/cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/system/cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/config/system/cron\";s:8:\"numParts\";i:4;}}',4),('system.csrftoken','/session/token','/session/token',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/session/token\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:56:\"\\Drupal\\system\\Controller\\CsrfTokenController::csrfToken\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/session/token$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/session/token\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/session/token\";s:8:\"numParts\";i:2;}}',2),('system.css_asset','/sites/default/files/css/{file_name}','/sites/default/files/css/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/sites/default/files/css/{file_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"Drupal\\system\\Controller\\CssAssetController::deliver\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"file_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/sites/default/files/css/(?P<file_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"file_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/sites/default/files/css\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"file_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:26:\"/sites/default/files/css/%\";s:8:\"numParts\";i:5;}}',5),('system.date_format_add','/admin/config/regional/date-time/formats/add','/admin/config/regional/date-time/formats/add',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/config/regional/date-time/formats/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"date_format.add\";s:6:\"_title\";s:15:\"Add date format\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/config/regional/date\\-time/formats/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/regional/date-time/formats/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:44:\"/admin/config/regional/date-time/formats/add\";s:8:\"numParts\";i:6;}}',6),('system.db_update','/update.php/{op}','/update.php',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:16:\"/update.php/{op}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:2:\"op\";s:4:\"info\";}s:12:\"requirements\";a:1:{s:21:\"_access_system_update\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"default_url_options\";a:1:{s:15:\"path_processing\";b:0;}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:22:\"access_check.db_update\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"op\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/update\\.php(?:/(?P<op>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"op\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/update.php\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"op\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:11:\"/update.php\";s:8:\"numParts\";i:2;}}',2),('system.development_settings','/admin/config/development/settings','/admin/config/development/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/development/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\system\\Form\\DevelopmentSettingsForm\";s:6:\"_title\";s:20:\"Development settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/development/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/development/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/config/development/settings\";s:8:\"numParts\";i:4;}}',4),('system.entity_autocomplete','/entity_reference_autocomplete/{target_type}/{selection_handler}/{selection_settings_key}','/entity_reference_autocomplete/%/%/%',8,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/entity_reference_autocomplete/{target_type}/{selection_handler}/{selection_settings_key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:74:\"\\Drupal\\system\\Controller\\EntityAutocompleteController::handleAutocomplete\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:11:\"target_type\";i:1;s:17:\"selection_handler\";i:2;s:22:\"selection_settings_key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/entity_reference_autocomplete/(?P<target_type>[^/]++)/(?P<selection_handler>[^/]++)/(?P<selection_settings_key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"selection_settings_key\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"selection_handler\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/entity_reference_autocomplete\";}}s:9:\"path_vars\";a:3:{i:0;s:11:\"target_type\";i:1;s:17:\"selection_handler\";i:2;s:22:\"selection_settings_key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:8;s:14:\"patternOutline\";s:36:\"/entity_reference_autocomplete/%/%/%\";s:8:\"numParts\";i:4;}}',4),('system.files','/system/files/{scheme}','/system/files',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/system/files/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";s:6:\"scheme\";s:7:\"private\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/system/files(?:/(?P<scheme>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/system/files\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/system/files\";s:8:\"numParts\";i:3;}}',3),('system.file_system_settings','/admin/config/media/file-system','/admin/config/media/file-system',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/config/media/file-system\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\system\\Form\\FileSystemForm\";s:6:\"_title\";s:11:\"File system\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/media/file\\-system$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/config/media/file-system\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/config/media/file-system\";s:8:\"numParts\";i:4;}}',4),('system.image_toolkit_settings','/admin/config/media/image-toolkit','/admin/config/media/image-toolkit',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/media/image-toolkit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\system\\Form\\ImageToolkitForm\";s:6:\"_title\";s:13:\"Image toolkit\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/media/image\\-toolkit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/media/image-toolkit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/media/image-toolkit\";s:8:\"numParts\";i:4;}}',4),('system.js_asset','/sites/default/files/js/{file_name}','/sites/default/files/js/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/sites/default/files/js/{file_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"Drupal\\system\\Controller\\JsAssetController::deliver\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"file_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/sites/default/files/js/(?P<file_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"file_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/sites/default/files/js\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"file_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:25:\"/sites/default/files/js/%\";s:8:\"numParts\";i:5;}}',5),('system.linkset_settings','/admin/config/services/linkset','/admin/config/services/linkset',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/config/services/linkset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:21:\"Menu Linkset Settings\";s:5:\"_form\";s:42:\"Drupal\\system\\Form\\MenuLinksetSettingsForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/admin/config/services/linkset$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/services/linkset\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/config/services/linkset\";s:8:\"numParts\";i:4;}}',4),('system.logging_settings','/admin/config/development/logging','/admin/config/development/logging',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/development/logging\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\system\\Form\\LoggingForm\";s:6:\"_title\";s:18:\"Logging and errors\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/development/logging$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/development/logging\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/development/logging\";s:8:\"numParts\";i:4;}}',4),('system.modules_list','/admin/modules','/admin/modules',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/modules\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:6:\"Extend\";s:14:\"_title_context\";s:15:\"With components\";s:5:\"_form\";s:35:\"\\Drupal\\system\\Form\\ModulesListForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_no_big_pipe\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/modules$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/modules\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/modules\";s:8:\"numParts\";i:2;}}',2),('system.modules_list_confirm','/admin/modules/list/confirm','/admin/modules/list/confirm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/modules/list/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\system\\Form\\ModulesListConfirmForm\";s:6:\"_title\";s:39:\"Some required modules must be installed\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/modules/list/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/modules/list/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:27:\"/admin/modules/list/confirm\";s:8:\"numParts\";i:4;}}',4),('system.modules_list_non_stable_confirm','/admin/modules/list/confirm-non-stable','/admin/modules/list/confirm-non-stable',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/modules/list/confirm-non-stable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\system\\Form\\ModulesListNonStableConfirmForm\";s:6:\"_title\";s:18:\"Non-stable modules\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/modules/list/confirm\\-non\\-stable$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/modules/list/confirm-non-stable\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:38:\"/admin/modules/list/confirm-non-stable\";s:8:\"numParts\";i:4;}}',4),('system.modules_uninstall','/admin/modules/uninstall','/admin/modules/uninstall',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/modules/uninstall\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\system\\Form\\ModulesUninstallForm\";s:6:\"_title\";s:9:\"Uninstall\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/modules/uninstall$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/modules/uninstall\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/modules/uninstall\";s:8:\"numParts\";i:3;}}',3),('system.modules_uninstall_confirm','/admin/modules/uninstall/confirm','/admin/modules/uninstall/confirm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/modules/uninstall/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"\\Drupal\\system\\Form\\ModulesUninstallConfirmForm\";s:6:\"_title\";s:17:\"Confirm uninstall\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/modules/uninstall/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/modules/uninstall/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/modules/uninstall/confirm\";s:8:\"numParts\";i:4;}}',4),('system.performance_settings','/admin/config/development/performance','/admin/config/development/performance',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/development/performance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\PerformanceController::build\";s:6:\"_title\";s:11:\"Performance\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/development/performance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/development/performance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/development/performance\";s:8:\"numParts\";i:4;}}',4),('system.php','/admin/reports/status/php','/admin/reports/status/php',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/reports/status/php\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\system\\Controller\\SystemInfoController::php\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/reports/status/php$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/reports/status/php\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/reports/status/php\";s:8:\"numParts\";i:4;}}',4),('system.prepare_modules_entity_uninstall','/admin/modules/uninstall/entity/{entity_type_id}','/admin/modules/uninstall/entity/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/modules/uninstall/entity/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:53:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm\";s:15:\"_title_callback\";s:64:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm::formTitle\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:18:\"administer modules\";s:14:\"_custom_access\";s:66:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm::checkAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/modules/uninstall/entity/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/modules/uninstall/entity\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/modules/uninstall/entity/%\";s:8:\"numParts\";i:5;}}',5),('system.private_file_download','/system/files/{filepath}','/system/files/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/system/files/{filepath}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";}s:12:\"requirements\";a:2:{s:8:\"filepath\";s:2:\".+\";s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"filepath\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/system/files/(?P<filepath>.+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:2:\".+\";i:3;s:8:\"filepath\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/system/files\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"filepath\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:15:\"/system/files/%\";s:8:\"numParts\";i:3;}}',3),('system.regional_settings','/admin/config/regional/settings','/admin/config/regional/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/config/regional/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\system\\Form\\RegionalForm\";s:6:\"_title\";s:17:\"Regional settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/config/regional/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/config/regional/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/config/regional/settings\";s:8:\"numParts\";i:4;}}',4),('system.rss_feeds_settings','/admin/config/services/rss-publishing','/admin/config/services/rss-publishing',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/services/rss-publishing\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\system\\Form\\RssFeedsForm\";s:6:\"_title\";s:14:\"RSS publishing\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/services/rss\\-publishing$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/services/rss-publishing\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/services/rss-publishing\";s:8:\"numParts\";i:4;}}',4),('system.run_cron','/admin/reports/status/run-cron','/admin/reports/status/run-cron',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/reports/status/run-cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:42:\"\\Drupal\\system\\CronController::runManually\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/status/run\\-cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/reports/status/run-cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/reports/status/run-cron\";s:8:\"numParts\";i:4;}}',4),('system.site_information_settings','/admin/config/system/site-information','/admin/config/system/site-information',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/system/site-information\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\system\\Form\\SiteInformationForm\";s:6:\"_title\";s:19:\"Basic site settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/system/site\\-information$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/system/site-information\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/system/site-information\";s:8:\"numParts\";i:4;}}',4),('system.site_maintenance_mode','/admin/config/development/maintenance','/admin/config/development/maintenance',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/development/maintenance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\system\\Form\\SiteMaintenanceModeForm\";s:6:\"_title\";s:16:\"Maintenance mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:57:\"administer site configuration+administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/development/maintenance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/development/maintenance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/development/maintenance\";s:8:\"numParts\";i:4;}}',4),('system.status','/admin/reports/status','/admin/reports/status',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/reports/status\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\SystemInfoController::status\";s:6:\"_title\";s:13:\"Status report\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/reports/status$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/reports/status\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/reports/status\";s:8:\"numParts\";i:3;}}',3),('system.temporary','/system/temporary','/system/temporary',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/system/temporary\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";s:6:\"scheme\";s:9:\"temporary\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/system/temporary$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/system/temporary\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:17:\"/system/temporary\";s:8:\"numParts\";i:2;}}',2),('system.themes_page','/admin/appearance','/admin/appearance',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/admin/appearance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:10:\"Appearance\";s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\SystemController::themesPage\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/admin/appearance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/appearance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:17:\"/admin/appearance\";s:8:\"numParts\";i:2;}}',2),('system.theme_install','/admin/appearance/install','/admin/appearance/install',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/appearance/install\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:50:\"\\Drupal\\system\\Controller\\ThemeController::install\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/appearance/install$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/appearance/install\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/appearance/install\";s:8:\"numParts\";i:3;}}',3),('system.theme_settings','/admin/appearance/settings','/admin/appearance/settings',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/appearance/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\system\\Form\\ThemeSettingsForm\";s:6:\"_title\";s:19:\"Appearance settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/appearance/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/appearance/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/admin/appearance/settings\";s:8:\"numParts\";i:3;}}',3),('system.theme_settings_theme','/admin/appearance/settings/{theme}','/admin/appearance/settings/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/appearance/settings/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\system\\Form\\ThemeSettingsForm\";s:15:\"_title_callback\";s:21:\"theme_handler:getName\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/appearance/settings/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/appearance/settings\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:28:\"/admin/appearance/settings/%\";s:8:\"numParts\";i:4;}}',4),('system.theme_set_default','/admin/appearance/default','/admin/appearance/default',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/appearance/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:20:\"Set as default theme\";s:11:\"_controller\";s:58:\"\\Drupal\\system\\Controller\\ThemeController::setDefaultTheme\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/appearance/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/appearance/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/appearance/default\";s:8:\"numParts\";i:3;}}',3),('system.theme_uninstall','/admin/appearance/uninstall','/admin/appearance/uninstall',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/appearance/uninstall\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\ThemeController::uninstall\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/appearance/uninstall$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/appearance/uninstall\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/appearance/uninstall\";s:8:\"numParts\";i:3;}}',3),('system.timezone','/system/timezone/{abbreviation}/{offset}/{is_daylight_saving_time}','/system/timezone',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/system/timezone/{abbreviation}/{offset}/{is_daylight_saving_time}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:57:\"\\Drupal\\system\\Controller\\TimezoneController::getTimezone\";s:12:\"abbreviation\";s:0:\"\";s:6:\"offset\";i:-1;s:23:\"is_daylight_saving_time\";N;}s:12:\"requirements\";a:4:{s:7:\"_access\";s:4:\"TRUE\";s:12:\"abbreviation\";s:14:\"0|([A-Z]{3,5})\";s:6:\"offset\";s:6:\"\\-?\\d+\";s:23:\"is_daylight_saving_time\";s:7:\"\\-1|0|1\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"abbreviation\";i:1;s:6:\"offset\";i:2;s:23:\"is_daylight_saving_time\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/system/timezone(?:/(?P<abbreviation>0|(?:[A-Z]{3,5}))(?:/(?P<offset>\\-?\\d+)(?:/(?P<is_daylight_saving_time>\\-1|0|1))?)?)?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:7:\"\\-1|0|1\";i:3;s:23:\"is_daylight_saving_time\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"\\-?\\d+\";i:3;s:6:\"offset\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:16:\"0|(?:[A-Z]{3,5})\";i:3;s:12:\"abbreviation\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/system/timezone\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"abbreviation\";i:1;s:6:\"offset\";i:2;s:23:\"is_daylight_saving_time\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:16:\"/system/timezone\";s:8:\"numParts\";i:5;}}',5),('tb_megamenu.admin.save','/admin/structure/tb-megamenu/save/{tb_megamenu}','/admin/structure/tb-megamenu/save/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/structure/tb-megamenu/save/{tb_megamenu}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:34:\"Save configuration of TB Mega Menu\";s:11:\"_controller\";s:75:\"\\Drupal\\tb_megamenu\\Controller\\TBMegaMenuAdminController::saveConfiguration\";}s:12:\"requirements\";a:3:{s:11:\"_csrf_token\";s:4:\"TRUE\";s:11:\"_permission\";s:22:\"administer tb_megamenu\";s:11:\"tb_megamenu\";s:14:\"[a-zA-Z0-9_-]+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:17:\"access_check.csrf\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/tb\\-megamenu/save/(?P<tb_megamenu>[a-zA-Z0-9_-]+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:14:\"[a-zA-Z0-9_-]+\";i:3;s:11:\"tb_megamenu\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/structure/tb-megamenu/save\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:35:\"/admin/structure/tb-megamenu/save/%\";s:8:\"numParts\";i:5;}}',5),('toolbar.subtrees','/toolbar/subtrees/{hash}','/toolbar/subtrees/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/toolbar/subtrees/{hash}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\toolbar\\Controller\\ToolbarController::subtreesAjax\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\toolbar\\Controller\\ToolbarController::checkSubTreeAccess\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/toolbar/subtrees/(?P<hash>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/toolbar/subtrees\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:19:\"/toolbar/subtrees/%\";s:8:\"numParts\";i:3;}}',3),('update.confirmation_page','/admin/update/ready','/admin/update/ready',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/update/ready\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\update\\Form\\UpdateReady\";s:6:\"_title\";s:15:\"Ready to update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/update/ready$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/update/ready\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/update/ready\";s:8:\"numParts\";i:3;}}',3),('update.manual_status','/admin/reports/updates/check','/admin/reports/updates/check',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/updates/check\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:19:\"Manual update check\";s:11:\"_controller\";s:64:\"\\Drupal\\update\\Controller\\UpdateController::updateStatusManually\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/reports/updates/check$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/updates/check\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/reports/updates/check\";s:8:\"numParts\";i:4;}}',4),('update.module_update','/admin/modules/update','/admin/modules/update',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/modules/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/modules/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/modules/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/modules/update\";s:8:\"numParts\";i:3;}}',3),('update.report_update','/admin/reports/updates/update','/admin/reports/updates/update',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/updates/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/updates/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/updates/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/reports/updates/update\";s:8:\"numParts\";i:4;}}',4),('update.settings','/admin/reports/updates/settings','/admin/reports/updates/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/reports/updates/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:33:\"\\Drupal\\update\\UpdateSettingsForm\";s:6:\"_title\";s:23:\"Update Manager settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/updates/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/reports/updates/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/reports/updates/settings\";s:8:\"numParts\";i:4;}}',4),('update.status','/admin/reports/updates','/admin/reports/updates',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/reports/updates\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\update\\Controller\\UpdateController::updateStatus\";s:6:\"_title\";s:17:\"Available updates\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/reports/updates$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/reports/updates\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/reports/updates\";s:8:\"numParts\";i:3;}}',3),('update.theme_update','/admin/appearance/update','/admin/appearance/update',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/appearance/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/appearance/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/appearance/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/appearance/update\";s:8:\"numParts\";i:3;}}',3),('user.admin_create','/admin/people/create','/admin/people/create',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/people/create\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"user.register\";s:6:\"_title\";s:8:\"Add user\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"user\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/people/create$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/people/create\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/people/create\";s:8:\"numParts\";i:3;}}',3),('user.admin_index','/admin/config/people','/admin/config/people',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:6:\"People\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/people\";s:8:\"numParts\";i:3;}}',3),('user.admin_permissions','/admin/people/permissions','/admin/people/permissions',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/people/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\user\\Form\\UserPermissionsForm\";s:6:\"_title\";s:11:\"Permissions\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/people/permissions$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/people/permissions\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/people/permissions\";s:8:\"numParts\";i:3;}}',3),('user.admin_permissions.module','/admin/people/permissions/module/{modules}','/admin/people/permissions/module/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/people/permissions/module/{modules}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\user\\Form\\UserPermissionsModuleSpecificForm\";s:6:\"_title\";s:18:\"Module Permissions\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:22:\"administer permissions\";s:7:\"modules\";s:16:\"[a-z][a-z0-9_,]*\";s:14:\"_custom_access\";s:59:\"\\Drupal\\user\\Form\\UserPermissionsModuleSpecificForm::access\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"modules\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/people/permissions/module/(?P<modules>[a-z][a-z0-9_,]*)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:16:\"[a-z][a-z0-9_,]*\";i:3;s:7:\"modules\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/people/permissions/module\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"modules\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:34:\"/admin/people/permissions/module/%\";s:8:\"numParts\";i:5;}}',5),('user.cancel_confirm','/user/{user}/cancel/confirm/{timestamp}/{hashed_pass}','/user/%/cancel/confirm',11,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/user/{user}/cancel/confirm/{timestamp}/{hashed_pass}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:28:\"Confirm account cancellation\";s:11:\"_controller\";s:53:\"\\Drupal\\user\\Controller\\UserController::confirmCancel\";s:9:\"timestamp\";i:0;s:11:\"hashed_pass\";s:0:\"\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"user.delete\";s:4:\"user\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"user\";i:1;s:9:\"timestamp\";i:2;s:11:\"hashed_pass\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:97:\"{^/user/(?P<user>\\d+)/cancel/confirm(?:/(?P<timestamp>[^/]++)(?:/(?P<hashed_pass>[^/]++))?)?$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"hashed_pass\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/cancel/confirm\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"user\";i:1;s:9:\"timestamp\";i:2;s:11:\"hashed_pass\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:22:\"/user/%/cancel/confirm\";s:8:\"numParts\";i:6;}}',6),('user.edit','/user/edit','/user/edit',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/user/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\user\\Controller\\UserController::userEditPage\";s:6:\"_title\";s:12:\"Edit account\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/user/edit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/user/edit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/user/edit\";s:8:\"numParts\";i:2;}}',2),('user.login','/user/login','/user/login',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/user/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\user\\Form\\UserLoginForm\";s:6:\"_title\";s:6:\"Log in\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/user/login$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/login\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/user/login\";s:8:\"numParts\";i:2;}}',2),('user.login.http','/user/login','/user/login',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/user/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:59:\"\\Drupal\\user\\Controller\\UserAuthenticationController::login\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/user/login$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/login\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/user/login\";s:8:\"numParts\";i:2;}}',2),('user.login_status.http','/user/login_status','/user/login_status',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/user/login_status\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:65:\"\\Drupal\\user\\Controller\\UserAuthenticationController::loginStatus\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/user/login_status$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/user/login_status\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:18:\"/user/login_status\";s:8:\"numParts\";i:2;}}',2),('user.logout','/user/logout','/user/logout',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/logout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:46:\"\\Drupal\\user\\Controller\\UserController::logout\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:24:\"_csrf_confirm_form_route\";s:19:\"user.logout.confirm\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/user/logout$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/user/logout\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/user/logout\";s:8:\"numParts\";i:2;}}',2),('user.logout.confirm','/user/logout/confirm','/user/logout/confirm',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/user/logout/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:35:\"\\Drupal\\user\\Form\\UserLogoutConfirm\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/user/logout/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/user/logout/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/user/logout/confirm\";s:8:\"numParts\";i:3;}}',3),('user.logout.http','/user/logout','/user/logout',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/logout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:60:\"\\Drupal\\user\\Controller\\UserAuthenticationController::logout\";}s:12:\"requirements\";a:3:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/user/logout$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/user/logout\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/user/logout\";s:8:\"numParts\";i:2;}}',2),('user.multiple_cancel_confirm','/admin/people/cancel','/admin/people/cancel',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/people/cancel\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\user\\Form\\UserMultipleCancelConfirm\";s:6:\"_title\";s:11:\"Cancel user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer users\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/people/cancel$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/people/cancel\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/people/cancel\";s:8:\"numParts\";i:3;}}',3),('user.page','/user','/user',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:5:\"/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\user\\Controller\\UserController::userPage\";s:6:\"_title\";s:10:\"My account\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:12:\"{^/user$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:5:\"/user\";s:8:\"numParts\";i:1;}}',1),('user.pass','/user/password','/user/password',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\user\\Form\\UserPasswordForm\";s:6:\"_title\";s:19:\"Reset your password\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/password\";s:8:\"numParts\";i:2;}}',2),('user.pass.http','/user/password','/user/password',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:67:\"\\Drupal\\user\\Controller\\UserAuthenticationController::resetPassword\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/password\";s:8:\"numParts\";i:2;}}',2),('user.register','/user/register','/user/register',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/register\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"user.register\";s:6:\"_title\";s:18:\"Create new account\";}s:12:\"requirements\";a:1:{s:21:\"_access_user_register\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.user.register\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/register$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/register\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/register\";s:8:\"numParts\";i:2;}}',2),('user.reset','/user/reset/{uid}/{timestamp}/{hash}','/user/reset/%/%/%',24,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/user/reset/{uid}/{timestamp}/{hash}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\user\\Controller\\UserController::resetPass\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/user/reset/(?P<uid>[^/]++)/(?P<timestamp>[^/]++)/(?P<hash>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:24;s:14:\"patternOutline\";s:17:\"/user/reset/%/%/%\";s:8:\"numParts\";i:5;}}',5),('user.reset.form','/user/reset/{uid}','/user/reset/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/user/reset/{uid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\user\\Controller\\UserController::getResetPassForm\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"uid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/user/reset/(?P<uid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"uid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:13:\"/user/reset/%\";s:8:\"numParts\";i:3;}}',3),('user.reset.login','/user/reset/{uid}/{timestamp}/{hash}/login','/user/reset/%/%/%/login',49,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/user/reset/{uid}/{timestamp}/{hash}/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\user\\Controller\\UserController::resetPassLogin\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/user/reset/(?P<uid>[^/]++)/(?P<timestamp>[^/]++)/(?P<hash>[^/]++)/login$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/login\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:49;s:14:\"patternOutline\";s:23:\"/user/reset/%/%/%/login\";s:8:\"numParts\";i:6;}}',6),('user.role.settings','/admin/people/role-settings','/admin/people/role-settings',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/people/role-settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\user\\Form\\RoleSettingsForm\";s:6:\"_title\";s:13:\"Role settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/people/role\\-settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/people/role-settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/people/role-settings\";s:8:\"numParts\";i:3;}}',3),('user.role_add','/admin/people/roles/add','/admin/people/roles/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/admin/people/roles/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"user_role.default\";s:6:\"_title\";s:8:\"Add role\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:30:\"{^/admin/people/roles/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/admin/people/roles/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:23:\"/admin/people/roles/add\";s:8:\"numParts\";i:4;}}',4),('user.well-known.change_password','/.well-known/change-password','/.well-known/change-password',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/.well-known/change-password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\user\\Controller\\UserController::userEditPage\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/\\.well\\-known/change\\-password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/.well-known/change-password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:28:\"/.well-known/change-password\";s:8:\"numParts\";i:2;}}',2),('view.block_content.page_1','/admin/content/block','/admin/content/block',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"block_content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"access block library\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/block\";s:8:\"numParts\";i:3;}}',3),('view.comment.page_published','/admin/content/comment','/admin/content/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/content/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:14:\"page_published\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/content/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/content/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/content/comment\";s:8:\"numParts\";i:3;}}',3),('view.comment.page_unapproved','/admin/content/comment/approval','/admin/content/comment/approval',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/content/comment/approval\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:15:\"page_unapproved\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/content/comment/approval$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/content/comment/approval\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/content/comment/approval\";s:8:\"numParts\";i:4;}}',4),('view.content.page_1','/admin/content','/admin/content',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:23:\"access content overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/content\";s:8:\"numParts\";i:2;}}',2),('view.files.page_1','/admin/content/files','/admin/content/files',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/files\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"files\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access files overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/files$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/files\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/files\";s:8:\"numParts\";i:3;}}',3),('view.files.page_2','/admin/content/files/usage/{arg_0}','/admin/content/files/usage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/content/files/usage/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"files\";s:10:\"display_id\";s:6:\"page_2\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access files overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/content/files/usage/(?P<arg_0>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/files/usage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/content/files/usage/%\";s:8:\"numParts\";i:5;}}',5),('view.frontpage.feed_1','/rss.xml','/rss.xml',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:8:\"/rss.xml\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:9:\"frontpage\";s:10:\"display_id\";s:6:\"feed_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"feed\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Feed\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:16:\"{^/rss\\.xml$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/rss.xml\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:8:\"/rss.xml\";s:8:\"numParts\";i:1;}}',1),('view.frontpage.page_1','/node','/node',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:5:\"/node\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:9:\"frontpage\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:12:\"{^/node$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:5:\"/node\";s:8:\"numParts\";i:1;}}',1),('view.media.media_page_list','/admin/content/media','/admin/content/media',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"media\";s:10:\"display_id\";s:15:\"media_page_list\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access media overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/media\";s:8:\"numParts\";i:3;}}',3),('view.media_library.page','/admin/content/media-grid','/admin/content/media-grid',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/content/media-grid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"media_library\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access media overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/media\\-grid$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/content/media-grid\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/content/media-grid\";s:8:\"numParts\";i:3;}}',3),('view.media_library.widget','/admin/content/media-widget/{arg_0}','/admin/content/media-widget',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/content/media-widget/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:6:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"media_library\";s:10:\"display_id\";s:6:\"widget\";s:30:\"_view_display_show_admin_links\";b:1;s:5:\"arg_0\";N;}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:10:\"view media\";s:7:\"_format\";s:4:\"html\";s:14:\"_custom_access\";s:36:\"media_library.ui_builder:checkAccess\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/content/media\\-widget(?:/(?P<arg_0>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/content/media-widget\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/content/media-widget\";s:8:\"numParts\";i:4;}}',4),('view.media_library.widget_table','/admin/content/media-widget-table/{arg_0}','/admin/content/media-widget-table',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/content/media-widget-table/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:6:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"media_library\";s:10:\"display_id\";s:12:\"widget_table\";s:30:\"_view_display_show_admin_links\";b:1;s:5:\"arg_0\";N;}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:10:\"view media\";s:7:\"_format\";s:4:\"html\";s:14:\"_custom_access\";s:36:\"media_library.ui_builder:checkAccess\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/content/media\\-widget\\-table(?:/(?P<arg_0>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/content/media-widget-table\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:33:\"/admin/content/media-widget-table\";s:8:\"numParts\";i:4;}}',4),('view.taxonomy_term.feed_1','/taxonomy/term/{arg_0}/feed','/taxonomy/term/%/feed',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/taxonomy/term/{arg_0}/feed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"feed_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"feed\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Feed\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/taxonomy/term/(?P<arg_0>[^/]++)/feed$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/feed\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:21:\"/taxonomy/term/%/feed\";s:8:\"numParts\";i:4;}}',4),('view.taxonomy_term.page_1','/taxonomy/term/{arg_0}','/taxonomy/term/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/taxonomy/term/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/taxonomy/term/(?P<arg_0>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/taxonomy/term/%\";s:8:\"numParts\";i:3;}}',3),('view.user_admin_people.page_1','/admin/people','/admin/people',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:17:\"user_admin_people\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:16:\"administer users\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/people\";s:8:\"numParts\";i:2;}}',2),('view.watchdog.page','/admin/reports/dblog','/admin/reports/dblog',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/reports/dblog\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"watchdog\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/reports/dblog$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/reports/dblog\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/reports/dblog\";s:8:\"numParts\";i:3;}}',3),('views.ajax','/views/ajax','/views/ajax',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/views/ajax\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:53:\"\\Drupal\\views\\Controller\\ViewAjaxController::ajaxView\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/views/ajax$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/views/ajax\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/views/ajax\";s:8:\"numParts\";i:2;}}',2),('views_ui.add','/admin/structure/views/add','/admin/structure/views/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/views/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:8:\"view.add\";s:6:\"_title\";s:8:\"Add view\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/views/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/views/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/views/add\";s:8:\"numParts\";i:4;}}',4),('views_ui.autocomplete','/admin/views/ajax/autocomplete/tag','/admin/views/ajax/autocomplete/tag',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/views/ajax/autocomplete/tag\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::autocompleteTag\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/views/ajax/autocomplete/tag$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/views/ajax/autocomplete/tag\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/views/ajax/autocomplete/tag\";s:8:\"numParts\";i:5;}}',5),('views_ui.form_add_handler','/admin/structure/views/{js}/add-handler/{view}/{display_id}/{type}','/admin/structure/views/%/add-handler/%/%/%',232,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/views/{js}/add-handler/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:46:\"\\Drupal\\views_ui\\Form\\Ajax\\AddHandler::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/views/(?P<js>nojs|ajax)/add\\-handler/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/add-handler\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:42:\"/admin/structure/views/%/add-handler/%/%/%\";s:8:\"numParts\";i:8;}}',8),('views_ui.form_analyze','/admin/structure/views/{js}/analyze/{view}/{display_id}','/admin/structure/views/%/analyze/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/views/{js}/analyze/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:43:\"\\Drupal\\views_ui\\Form\\Ajax\\Analyze::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/views/(?P<js>nojs|ajax)/analyze/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/analyze\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:36:\"/admin/structure/views/%/analyze/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.form_display','/admin/structure/views/{js}/display/{view}/{display_id}/{type}','/admin/structure/views/%/display/%/%/%',232,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/views/{js}/display/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:43:\"\\Drupal\\views_ui\\Form\\Ajax\\Display::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/structure/views/(?P<js>nojs|ajax)/display/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:38:\"/admin/structure/views/%/display/%/%/%\";s:8:\"numParts\";i:8;}}',8),('views_ui.form_edit_details','/admin/structure/views/{js}/edit-details/{view}/{display_id}','/admin/structure/views/%/edit-details/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/views/{js}/edit-details/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\views_ui\\Form\\Ajax\\EditDetails::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/views/(?P<js>nojs|ajax)/edit\\-details/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/edit-details\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:41:\"/admin/structure/views/%/edit-details/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.form_handler','/admin/structure/views/{js}/handler/{view}/{display_id}/{type}/{id}','/admin/structure/views/%/handler/%/%/%/%',464,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/views/{js}/handler/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:49:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandler::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:127:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/handler\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:40:\"/admin/structure/views/%/handler/%/%/%/%\";s:8:\"numParts\";i:9;}}',9),('views_ui.form_handler_extra','/admin/structure/views/{js}/handler-extra/{view}/{display_id}/{type}/{id}','/admin/structure/views/%/handler-extra/%/%/%/%',464,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/views/{js}/handler-extra/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:54:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandlerExtra::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler\\-extra/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/handler-extra\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:46:\"/admin/structure/views/%/handler-extra/%/%/%/%\";s:8:\"numParts\";i:9;}}',9),('views_ui.form_handler_group','/admin/structure/views/{js}/handler-group/{view}/{display_id}/{type}/{id}','/admin/structure/views/%/handler-group/%/%/%/%',464,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/views/{js}/handler-group/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandlerGroup::getForm\";s:10:\"form_state\";N;}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler\\-group/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/handler-group\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:46:\"/admin/structure/views/%/handler-group/%/%/%/%\";s:8:\"numParts\";i:9;}}',9),('views_ui.form_rearrange','/admin/structure/views/{js}/rearrange/{view}/{display_id}/{type}','/admin/structure/views/%/rearrange/%/%/%',232,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/rearrange/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:45:\"\\Drupal\\views_ui\\Form\\Ajax\\Rearrange::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/structure/views/(?P<js>nojs|ajax)/rearrange/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/rearrange\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:40:\"/admin/structure/views/%/rearrange/%/%/%\";s:8:\"numParts\";i:8;}}',8),('views_ui.form_rearrange_filter','/admin/structure/views/{js}/rearrange-filter/{view}/{display_id}','/admin/structure/views/%/rearrange-filter/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/rearrange-filter/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Form\\Ajax\\RearrangeFilter::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/views/(?P<js>nojs|ajax)/rearrange\\-filter/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/rearrange-filter\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:45:\"/admin/structure/views/%/rearrange-filter/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.form_reorder_displays','/admin/structure/views/{js}/reorder-displays/{view}/{display_id}','/admin/structure/views/%/reorder-displays/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/reorder-displays/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Form\\Ajax\\ReorderDisplays::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/views/(?P<js>nojs|ajax)/reorder\\-displays/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/reorder-displays\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:45:\"/admin/structure/views/%/reorder-displays/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.reports_fields','/admin/reports/fields/views-fields','/admin/reports/fields/views-fields',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/reports/fields/views-fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::reportFields\";s:6:\"_title\";s:13:\"Used in views\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/reports/fields/views\\-fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/reports/fields/views-fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/reports/fields/views-fields\";s:8:\"numParts\";i:4;}}',4),('views_ui.reports_plugins','/admin/reports/views-plugins','/admin/reports/views-plugins',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/views-plugins\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::reportPlugins\";s:6:\"_title\";s:13:\"Views plugins\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/views\\-plugins$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/views-plugins\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/reports/views-plugins\";s:8:\"numParts\";i:3;}}',3),('views_ui.settings_advanced','/admin/structure/views/settings/advanced','/admin/structure/views/settings/advanced',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/views/settings/advanced\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\views_ui\\Form\\AdvancedSettingsForm\";s:6:\"_title\";s:23:\"Advanced Views settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/views/settings/advanced$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/views/settings/advanced\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/views/settings/advanced\";s:8:\"numParts\";i:5;}}',5),('views_ui.settings_basic','/admin/structure/views/settings','/admin/structure/views/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/views/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\views_ui\\Form\\BasicSettingsForm\";s:6:\"_title\";s:14:\"Views settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/views/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/views/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/views/settings\";s:8:\"numParts\";i:4;}}',4),('views_year_filter.settings_form','/admin/config/views-year-filter/settings','/admin/config/views-year-filter/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/config/views-year-filter/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\views_year_filter\\Form\\SettingsForm\";s:6:\"_title\";s:26:\"Views year filter settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/admin/config/views\\-year\\-filter/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/config/views-year-filter/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:40:\"/admin/config/views-year-filter/settings\";s:8:\"numParts\";i:4;}}',4),('webform.addons','/admin/structure/webform/addons','/admin/structure/webform/addons',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/webform/addons\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:57:\"\\Drupal\\webform\\Controller\\WebformAddonsController::index\";s:6:\"_title\";s:17:\"Webforms: Add-ons\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/webform/addons$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/addons\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/webform/addons\";s:8:\"numParts\";i:4;}}',4),('webform.config','/admin/structure/webform/config','/admin/structure/webform/config',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/webform/config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:60:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigFormsForm\";s:6:\"_title\";s:29:\"Webforms: Forms configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/webform/config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/webform/config\";s:8:\"numParts\";i:4;}}',4),('webform.config.advanced','/admin/structure/webform/config/advanced','/admin/structure/webform/config/advanced',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/advanced\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigAdvancedForm\";s:6:\"_title\";s:32:\"Webforms: Advanced configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/advanced$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/advanced\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/advanced\";s:8:\"numParts\";i:5;}}',5),('webform.config.elements','/admin/structure/webform/config/elements','/admin/structure/webform/config/elements',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/elements\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigElementsForm\";s:6:\"_title\";s:32:\"Webforms: Elements configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/elements$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/elements\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/elements\";s:8:\"numParts\";i:5;}}',5),('webform.config.exporters','/admin/structure/webform/config/exporters','/admin/structure/webform/config/exporters',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/webform/config/exporters\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:64:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigExportersForm\";s:6:\"_title\";s:33:\"Webforms: Exporters configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/structure/webform/config/exporters$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/structure/webform/config/exporters\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:41:\"/admin/structure/webform/config/exporters\";s:8:\"numParts\";i:5;}}',5),('webform.config.handlers','/admin/structure/webform/config/handlers','/admin/structure/webform/config/handlers',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/handlers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigHandlersForm\";s:6:\"_title\";s:32:\"Webforms: Handlers configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/handlers$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/handlers\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/handlers\";s:8:\"numParts\";i:5;}}',5),('webform.config.libraries','/admin/structure/webform/config/libraries','/admin/structure/webform/config/libraries',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/webform/config/libraries\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:64:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigLibrariesForm\";s:6:\"_title\";s:33:\"Webforms: Libraries configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/structure/webform/config/libraries$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/structure/webform/config/libraries\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:41:\"/admin/structure/webform/config/libraries\";s:8:\"numParts\";i:5;}}',5),('webform.config.repair','/admin/structure/webform/config/repair','/admin/structure/webform/config/repair',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/structure/webform/config/repair\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:61:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigRepairForm\";s:6:\"_title\";s:38:\"Webforms: Repair webform configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/structure/webform/config/repair$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/structure/webform/config/repair\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:38:\"/admin/structure/webform/config/repair\";s:8:\"numParts\";i:5;}}',5),('webform.config.submissions','/admin/structure/webform/config/submissions','/admin/structure/webform/config/submissions',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/structure/webform/config/submissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:66:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigSubmissionsForm\";s:6:\"_title\";s:35:\"Webforms: Submissions configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/structure/webform/config/submissions$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/config/submissions\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/config/submissions\";s:8:\"numParts\";i:5;}}',5),('webform.config.variants','/admin/structure/webform/config/variants','/admin/structure/webform/config/variants',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/variants\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigVariantsForm\";s:6:\"_title\";s:32:\"Webforms: Variants configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/variants$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/variants\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/variants\";s:8:\"numParts\";i:5;}}',5),('webform.element.autocomplete','/webform/{webform}/autocomplete/{key}','/webform/%/autocomplete/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/webform/{webform}/autocomplete/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:65:\"\\Drupal\\webform\\Controller\\WebformElementController::autocomplete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform.submission_create\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/webform/(?P<webform>[^/]++)/autocomplete/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/autocomplete\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:25:\"/webform/%/autocomplete/%\";s:8:\"numParts\";i:4;}}',4),('webform.element.message.close','/webform/message/close/{storage}/{id}','/webform/message/close/%/%',28,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/webform/message/close/{storage}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\webform\\Controller\\WebformElementController::close\";s:8:\"_storage\";s:4:\"user\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"storage\";i:1;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/webform/message/close/(?P<storage>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"storage\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/webform/message/close\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"storage\";i:1;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:28;s:14:\"patternOutline\";s:26:\"/webform/message/close/%/%\";s:8:\"numParts\";i:5;}}',5),('webform.help','/admin/structure/webform/help','/admin/structure/webform/help',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/webform/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\webform\\Controller\\WebformHelpController::index\";s:6:\"_title\";s:14:\"Webforms: Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access webform help\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/webform/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/webform/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/webform/help\";s:8:\"numParts\";i:4;}}',4),('webform.help.video','/admin/help/webform/video/{id}','/admin/help/webform/video/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/help/webform/video/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:41:\"\\Drupal\\webform\\Form\\WebformHelpVideoForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/help/webform/video/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/help/webform/video\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:27:\"/admin/help/webform/video/%\";s:8:\"numParts\";i:5;}}',5),('webform.reports_plugins.elements','/admin/reports/webform-plugins/elements','/admin/reports/webform-plugins/elements',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/reports/webform-plugins/elements\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformPluginElementController::index\";s:6:\"_title\";s:25:\"Webform plugins: Elements\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/reports/webform\\-plugins/elements$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/reports/webform-plugins/elements\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/reports/webform-plugins/elements\";s:8:\"numParts\";i:4;}}',4),('webform.reports_plugins.exporters','/admin/reports/webform-plugins/exporters','/admin/reports/webform-plugins/exporters',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/reports/webform-plugins/exporters\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:65:\"\\Drupal\\webform\\Controller\\WebformPluginExporterController::index\";s:6:\"_title\";s:26:\"Webform plugins: Exporters\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/reports/webform\\-plugins/exporters$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/reports/webform-plugins/exporters\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:40:\"/admin/reports/webform-plugins/exporters\";s:8:\"numParts\";i:4;}}',4),('webform.reports_plugins.handlers','/admin/reports/webform-plugins/handlers','/admin/reports/webform-plugins/handlers',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/reports/webform-plugins/handlers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformPluginHandlerController::index\";s:6:\"_title\";s:25:\"Webform plugins: Handlers\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/reports/webform\\-plugins/handlers$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/reports/webform-plugins/handlers\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/reports/webform-plugins/handlers\";s:8:\"numParts\";i:4;}}',4),('webform.reports_plugins.variants','/admin/reports/webform-plugins/variants','/admin/reports/webform-plugins/variants',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/reports/webform-plugins/variants\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformPluginVariantController::index\";s:6:\"_title\";s:25:\"Webform plugins: Variants\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/reports/webform\\-plugins/variants$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/reports/webform-plugins/variants\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/reports/webform-plugins/variants\";s:8:\"numParts\";i:4;}}',4),('webform_submission.multiple_delete_confirm','/admin/structure/webform/results/delete','/admin/structure/webform/results/delete',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/webform/results/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\webform\\Form\\WebformSubmissionDeleteMultipleForm\";s:14:\"entity_type_id\";s:18:\"webform_submission\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:18:\"webform_submission\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/structure/webform/results/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/results/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/webform/results/delete\";s:8:\"numParts\";i:5;}}',5);
/*!40000 ALTER TABLE `router` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `semaphore`
--

DROP TABLE IF EXISTS `semaphore`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `semaphore` (
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique name.',
  `value` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A value for the semaphore.',
  `expire` double NOT NULL COMMENT 'A Unix timestamp with microseconds indicating when the semaphore should expire.',
  PRIMARY KEY (`name`),
  KEY `value` (`value`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Table for holding semaphores, locks, flags, etc. that…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `semaphore`
--

LOCK TABLES `semaphore` WRITE;
/*!40000 ALTER TABLE `semaphore` DISABLE KEYS */;
/*!40000 ALTER TABLE `semaphore` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sequences`
--

DROP TABLE IF EXISTS `sequences`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `sequences` (
  `value` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'The value of the sequence.',
  PRIMARY KEY (`value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores IDs.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sequences`
--

LOCK TABLES `sequences` WRITE;
/*!40000 ALTER TABLE `sequences` DISABLE KEYS */;
/*!40000 ALTER TABLE `sequences` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sessions`
--

DROP TABLE IF EXISTS `sessions`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `sessions` (
  `uid` int unsigned NOT NULL COMMENT 'The "users".uid corresponding to a session, or 0 for anonymous user.',
  `sid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'A session ID (hashed). The value is generated by Drupal''s session handlers.',
  `hostname` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The IP address that last used this session ID (sid).',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when this session last requested a page. Old records are purged by PHP automatically.',
  `session` longblob COMMENT 'The serialized contents of the user''s session, an array of name/value pairs that persists across page requests by this session ID. Drupal loads the user''s session from here   at the start of each request and saves it at the end.',
  PRIMARY KEY (`sid`),
  KEY `timestamp` (`timestamp`),
  KEY `uid` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Drupal''s session handlers read and write into the sessions…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sessions`
--

LOCK TABLES `sessions` WRITE;
/*!40000 ALTER TABLE `sessions` DISABLE KEYS */;
INSERT INTO `sessions` VALUES (1,'1dj2FDgLy0CeBE1gbQbVHebh0B2UPCYZwLQTmi_5-Ms','127.0.0.1',1730546261,_binary '_sf2_attributes|a:1:{s:3:\"uid\";s:1:\"1\";}_sf2_meta|a:4:{s:1:\"u\";i:1730546262;s:1:\"c\";i:1728225698;s:1:\"l\";i:2000000;s:1:\"s\";s:43:\"gINuL4UrvX8Iu44MoeuUjOTazW29nEoGiSJaUkQuyXQ\";}'),(1,'9v0gzdUS8j4jBKsJjrwTKorjGzB5WDPkGbjS5KkwzZA','127.0.0.1',1731877893,_binary '_sf2_attributes|a:1:{s:3:\"uid\";s:1:\"1\";}_sf2_meta|a:4:{s:1:\"u\";i:1731877895;s:1:\"c\";i:1731587020;s:1:\"l\";i:2000000;s:1:\"s\";s:43:\"PGfzfR5m2ASJ0avJgZ21Il1GfvC0kd_hVuGhS_L9OgM\";}'),(1,'G-sFibniA1m-QY7YohAtN8vKQIUiMPKvhqpGMk8fRi8','127.0.0.1',1735501058,_binary '_sf2_attributes|a:1:{s:3:\"uid\";s:1:\"1\";}_sf2_meta|a:4:{s:1:\"u\";i:1735500986;s:1:\"c\";i:1735498845;s:1:\"l\";i:2000000;s:1:\"s\";s:43:\"6sM9Pk21Z7kIvsJciJJ989zM8buQrWkhvBhOXbqA0cM\";}');
/*!40000 ALTER TABLE `sessions` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shortcut`
--

DROP TABLE IF EXISTS `shortcut`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `shortcut` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `shortcut_set` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `shortcut_field__uuid__value` (`uuid`),
  KEY `shortcut_field__shortcut_set__target_id` (`shortcut_set`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for shortcut entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shortcut`
--

LOCK TABLES `shortcut` WRITE;
/*!40000 ALTER TABLE `shortcut` DISABLE KEYS */;
INSERT INTO `shortcut` VALUES (1,'default','058f69d6-9706-4edf-b105-fa8fe49752de','en'),(2,'default','41d418df-6cba-4cbc-ab6d-de19dec6233b','en');
/*!40000 ALTER TABLE `shortcut` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shortcut_field_data`
--

DROP TABLE IF EXISTS `shortcut_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `shortcut_field_data` (
  `id` int unsigned NOT NULL,
  `shortcut_set` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `weight` int DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `shortcut__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `shortcut_field__shortcut_set__target_id` (`shortcut_set`),
  KEY `shortcut_field__link__uri` (`link__uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for shortcut entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shortcut_field_data`
--

LOCK TABLES `shortcut_field_data` WRITE;
/*!40000 ALTER TABLE `shortcut_field_data` DISABLE KEYS */;
INSERT INTO `shortcut_field_data` VALUES (1,'default','en','Add content',-20,'internal:/node/add',NULL,_binary 'a:0:{}',1),(2,'default','en','All content',-19,'internal:/admin/content',NULL,_binary 'a:0:{}',1);
/*!40000 ALTER TABLE `shortcut_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shortcut_set_users`
--

DROP TABLE IF EXISTS `shortcut_set_users`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `shortcut_set_users` (
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid for this set.',
  `set_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "shortcut_set".set_name that will be displayed for this user.',
  PRIMARY KEY (`uid`),
  KEY `set_name` (`set_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maps users to shortcut sets.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shortcut_set_users`
--

LOCK TABLES `shortcut_set_users` WRITE;
/*!40000 ALTER TABLE `shortcut_set_users` DISABLE KEYS */;
/*!40000 ALTER TABLE `shortcut_set_users` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_index`
--

DROP TABLE IF EXISTS `taxonomy_index`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_index` (
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid this record tracks.',
  `tid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The term ID.',
  `status` int NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether the node is published (visible to non-administrators).',
  `sticky` tinyint DEFAULT '0' COMMENT 'Boolean indicating whether the node is sticky.',
  `created` int NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was created.',
  PRIMARY KEY (`nid`,`tid`),
  KEY `term_node` (`tid`,`status`,`sticky`,`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maintains denormalized information about node/term…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_index`
--

LOCK TABLES `taxonomy_index` WRITE;
/*!40000 ALTER TABLE `taxonomy_index` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_index` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term__parent`
--

DROP TABLE IF EXISTS `taxonomy_term__parent`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term__parent` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `parent_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `revision_id` (`revision_id`),
  KEY `parent_target_id` (`parent_target_id`),
  KEY `bundle_delta_target_id` (`bundle`,`delta`,`parent_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for taxonomy_term field parent.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term__parent`
--

LOCK TABLES `taxonomy_term__parent` WRITE;
/*!40000 ALTER TABLE `taxonomy_term__parent` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term__parent` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_data`
--

DROP TABLE IF EXISTS `taxonomy_term_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_data` (
  `tid` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `vid` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`tid`),
  UNIQUE KEY `taxonomy_term_field__uuid__value` (`uuid`),
  UNIQUE KEY `taxonomy_term__revision_id` (`revision_id`),
  KEY `taxonomy_term_field__vid__target_id` (`vid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_data`
--

LOCK TABLES `taxonomy_term_data` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_field_data`
--

DROP TABLE IF EXISTS `taxonomy_term_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_field_data` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `vid` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `name` varchar(255) NOT NULL,
  `description__value` longtext,
  `description__format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `weight` int NOT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`tid`,`langcode`),
  KEY `taxonomy_term__id__default_langcode__langcode` (`tid`,`default_langcode`,`langcode`),
  KEY `taxonomy_term__revision_id` (`revision_id`),
  KEY `taxonomy_term_field__name` (`name`(191)),
  KEY `taxonomy_term__status_vid` (`status`,`vid`,`tid`),
  KEY `taxonomy_term__tree` (`vid`,`weight`,`name`(191)),
  KEY `taxonomy_term__vid_name` (`vid`,`name`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_field_data`
--

LOCK TABLES `taxonomy_term_field_data` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_field_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_field_revision`
--

DROP TABLE IF EXISTS `taxonomy_term_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_field_revision` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `name` varchar(255) DEFAULT NULL,
  `description__value` longtext,
  `description__format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `taxonomy_term__id__default_langcode__langcode` (`tid`,`default_langcode`,`langcode`),
  KEY `taxonomy_term_field__description__format` (`description__format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_field_revision`
--

LOCK TABLES `taxonomy_term_field_revision` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_field_revision` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_revision`
--

DROP TABLE IF EXISTS `taxonomy_term_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_revision` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `taxonomy_term__tid` (`tid`),
  KEY `taxonomy_term_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_revision`
--

LOCK TABLES `taxonomy_term_revision` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_revision` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_revision__parent`
--

DROP TABLE IF EXISTS `taxonomy_term_revision__parent`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_revision__parent` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `parent_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `parent_target_id` (`parent_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for taxonomy_term field parent.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_revision__parent`
--

LOCK TABLES `taxonomy_term_revision__parent` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_revision__parent` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term_revision__parent` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `user__roles`
--

DROP TABLE IF EXISTS `user__roles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `user__roles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `roles_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `roles_target_id` (`roles_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for user field roles.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `user__roles`
--

LOCK TABLES `user__roles` WRITE;
/*!40000 ALTER TABLE `user__roles` DISABLE KEYS */;
INSERT INTO `user__roles` VALUES ('user',0,1,1,'en',0,'administrator');
/*!40000 ALTER TABLE `user__roles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `user__user_picture`
--

DROP TABLE IF EXISTS `user__user_picture`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `user__user_picture` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `user_picture_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `user_picture_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `user_picture_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `user_picture_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `user_picture_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `user_picture_target_id` (`user_picture_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for user field user_picture.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `user__user_picture`
--

LOCK TABLES `user__user_picture` WRITE;
/*!40000 ALTER TABLE `user__user_picture` DISABLE KEYS */;
/*!40000 ALTER TABLE `user__user_picture` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users`
--

DROP TABLE IF EXISTS `users`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `users` (
  `uid` int unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`uid`),
  UNIQUE KEY `user_field__uuid__value` (`uuid`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for user entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users`
--

LOCK TABLES `users` WRITE;
/*!40000 ALTER TABLE `users` DISABLE KEYS */;
INSERT INTO `users` VALUES (0,'995f9b83-5f2a-499f-8700-1ff5fb7cb3ec','en'),(1,'7faa4afd-eb0d-4de9-8f53-f303a3bac462','en');
/*!40000 ALTER TABLE `users` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users_data`
--

DROP TABLE IF EXISTS `users_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `users_data` (
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid this record affects.',
  `module` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the module declaring the variable.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The identifier of the data.',
  `value` longblob COMMENT 'The value.',
  `serialized` tinyint unsigned DEFAULT '0' COMMENT 'Whether value is serialized.',
  PRIMARY KEY (`uid`,`module`,`name`),
  KEY `module` (`module`),
  KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores module data as key/value pairs per user.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users_data`
--

LOCK TABLES `users_data` WRITE;
/*!40000 ALTER TABLE `users_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `users_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users_field_data`
--

DROP TABLE IF EXISTS `users_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `users_field_data` (
  `uid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `preferred_langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `preferred_admin_langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `name` varchar(60) NOT NULL,
  `pass` varchar(255) DEFAULT NULL,
  `mail` varchar(254) DEFAULT NULL,
  `timezone` varchar(32) DEFAULT NULL,
  `status` tinyint DEFAULT NULL,
  `created` int NOT NULL,
  `changed` int DEFAULT NULL,
  `access` int NOT NULL,
  `login` int DEFAULT NULL,
  `init` varchar(254) DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`uid`,`langcode`),
  UNIQUE KEY `user__name` (`name`,`langcode`),
  KEY `user__id__default_langcode__langcode` (`uid`,`default_langcode`,`langcode`),
  KEY `user_field__mail` (`mail`(191)),
  KEY `user_field__created` (`created`),
  KEY `user_field__access` (`access`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for user entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users_field_data`
--

LOCK TABLES `users_field_data` WRITE;
/*!40000 ALTER TABLE `users_field_data` DISABLE KEYS */;
INSERT INTO `users_field_data` VALUES (0,'en','en',NULL,'',NULL,NULL,NULL,0,1728225213,1728225213,0,0,NULL,1),(1,'en','en',NULL,'admin','$2y$10$VeOI3DQW97.sTCGsRA4gfO6FSHJ3S.8cFaM9hVA7jLtwbklv/1VGS','admin@example.com','Europe/Belgrade',1,1728225213,1728225671,1735500979,1735498843,'admin@example.com',1);
/*!40000 ALTER TABLE `users_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `watchdog`
--

DROP TABLE IF EXISTS `watchdog`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `watchdog` (
  `wid` bigint NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique watchdog event ID.',
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid of the user who triggered the event.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Type of log message, for example "user" or "page not found."',
  `message` longtext NOT NULL COMMENT 'Text of log message to be passed into the t() function.',
  `variables` longblob NOT NULL COMMENT 'Serialized array of variables that match the message string and that is passed into the t() function.',
  `severity` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'The severity level of the event. ranges from 0 (Emergency) to 7 (Debug)',
  `link` text COMMENT 'Link to view the result of the event.',
  `location` text NOT NULL COMMENT 'URL of the origin of the event.',
  `referer` text COMMENT 'URL of referring page.',
  `hostname` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Hostname of the user who triggered the event.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'Unix timestamp of when event occurred.',
  PRIMARY KEY (`wid`),
  KEY `type` (`type`),
  KEY `uid` (`uid`),
  KEY `severity` (`severity`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Table that contains logs of all system events.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `watchdog`
--

LOCK TABLES `watchdog` WRITE;
/*!40000 ALTER TABLE `watchdog` DISABLE KEYS */;
/*!40000 ALTER TABLE `watchdog` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `webform`
--

DROP TABLE IF EXISTS `webform`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `webform` (
  `webform_id` varchar(32) NOT NULL COMMENT 'The webform id.',
  `next_serial` int unsigned NOT NULL DEFAULT '1' COMMENT 'The serial number to give to the next submission to this webform.',
  PRIMARY KEY (`webform_id`,`next_serial`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores all webform data.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `webform`
--

LOCK TABLES `webform` WRITE;
/*!40000 ALTER TABLE `webform` DISABLE KEYS */;
INSERT INTO `webform` VALUES ('contact',1);
/*!40000 ALTER TABLE `webform` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `webform_submission`
--

DROP TABLE IF EXISTS `webform_submission`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `webform_submission` (
  `sid` int NOT NULL AUTO_INCREMENT,
  `webform_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `serial` int DEFAULT NULL,
  `token` varchar(255) DEFAULT NULL,
  `uri` varchar(2000) DEFAULT NULL,
  `created` int DEFAULT NULL,
  `completed` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `in_draft` tinyint DEFAULT NULL,
  `current_page` varchar(128) DEFAULT NULL,
  `remote_addr` varchar(128) DEFAULT NULL,
  `uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `entity_id` varchar(255) DEFAULT NULL,
  `locked` tinyint DEFAULT NULL,
  `sticky` tinyint DEFAULT NULL,
  `notes` longtext,
  PRIMARY KEY (`sid`),
  UNIQUE KEY `webform_submission_field__uuid__value` (`uuid`),
  KEY `webform_submission_field__webform_id__target_id` (`webform_id`),
  KEY `webform_submission_field__uid__target_id` (`uid`),
  KEY `webform_submission_field__token` (`token`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for webform_submission entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `webform_submission`
--

LOCK TABLES `webform_submission` WRITE;
/*!40000 ALTER TABLE `webform_submission` DISABLE KEYS */;
/*!40000 ALTER TABLE `webform_submission` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `webform_submission_data`
--

DROP TABLE IF EXISTS `webform_submission_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `webform_submission_data` (
  `webform_id` varchar(32) NOT NULL COMMENT 'The webform id.',
  `sid` int unsigned NOT NULL COMMENT 'The unique identifier for this submission.',
  `name` varchar(128) NOT NULL COMMENT 'The name of the element.',
  `property` varchar(128) NOT NULL DEFAULT '' COMMENT 'The property of the element''s value.',
  `delta` int unsigned NOT NULL DEFAULT '0' COMMENT 'The delta of the element''s value.',
  `value` mediumtext NOT NULL COMMENT 'The element''s value.',
  PRIMARY KEY (`sid`,`name`,`property`,`delta`),
  KEY `webform_id` (`webform_id`),
  KEY `sid_webform_id` (`sid`,`webform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores all submitted data for webform submissions.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `webform_submission_data`
--

LOCK TABLES `webform_submission_data` WRITE;
/*!40000 ALTER TABLE `webform_submission_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `webform_submission_data` ENABLE KEYS */;
UNLOCK TABLES;

-- Dump completed on 2024-12-29 20:42:59
